@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    agentManager.py
 # @author  Michael Behrisch
@@ -15,7 +16,7 @@
 from __future__ import absolute_import
 import vehicleControl
 import statistics
-from constants import *
+from constants import INFINITY, DOUBLE_ROWS, ROW_DIST, CYBER_SPEED, WAIT_PER_PERSON
 
 
 class PersonAgent:
@@ -162,7 +163,7 @@ class AgentManager(vehicleControl.Manager):
         self.cyberCars = []
 
     def personArrived(self, personID, edge, target):
-        if not personID in self.agents:
+        if personID not in self.agents:
             person = PersonAgent(personID)
             self.agents[personID] = person
             person.startRequest(edge.replace("footmain", "cyber"),
