@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2011-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    runner.py
 # @author  Michael Behrisch
@@ -16,20 +17,18 @@ from __future__ import absolute_import
 from __future__ import print_function
 
 
-import os
-import sys
 import shutil
 import vehicleControl
 import simpleManager
 import agentManager
 
 # build/check network
-import createNet
+import createNet  # noqa
 # perform simple scenario
 vehicleControl.init(simpleManager.SimpleManager(), True)
 # perform agent scenario
 vehicleControl.init(agentManager.AgentManager(), True)
 try:
     shutil.copy("all-the-results.txt", "../result2")
-except:
+except IOError:
     print("Missing 'all-the-results.txt'")
