@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    simpleManager.py
 # @author  Michael Behrisch
@@ -16,7 +17,7 @@
 from __future__ import absolute_import
 import vehicleControl
 import statistics
-from constants import *
+from constants import DOUBLE_ROWS, WAIT_PER_PERSON
 
 
 class SimpleManager(vehicleControl.Manager):
@@ -26,7 +27,7 @@ class SimpleManager(vehicleControl.Manager):
         self.personsWaitingAt = {}
 
     def personArrived(self, personID, edge, target):
-        if not edge in self.personsWaitingAt:
+        if edge not in self.personsWaitingAt:
             self.personsWaitingAt[edge] = []
         self.personsWaitingAt[edge].append((personID, target))
 
@@ -59,5 +60,6 @@ class SimpleManager(vehicleControl.Manager):
             vehicleControl.stopAt(vehicleID, "cyberout")
         self.cyberCarLoad[vehicleID] = load
 
+
 if __name__ == "__main__":
     vehicleControl.init(SimpleManager())
