@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    statistics.py
 # @author  Michael Behrisch
@@ -14,6 +15,7 @@
 
 from __future__ import absolute_import
 from __future__ import print_function
+import sys
 persons = {}
 personsRunning = 0
 
@@ -54,10 +56,10 @@ def evaluate(forTest=False):
         return
     waitTimes = []
     routeTimes = {}
-    for person in persons.itervalues():
+    for person in persons.values():
         waitTimes.append(person.depart - person.waitStart)
         route = (person.source, person.target)
-        if not route in routeTimes:
+        if route not in routeTimes:
             routeTimes[route] = []
         routeTimes[route].append(person.arrive - person.depart)
     waitArray = numpy.array(waitTimes)
@@ -68,11 +70,10 @@ def evaluate(forTest=False):
         print("waiting time (max, mean, dev):", waitArray.max(),
               waitArray.mean(), math.sqrt(waitArray.var()))
 
-    for route, times in sorted(routeTimes.iteritems()):
+    for route, times in sorted(routeTimes.items()):
         timeArray = numpy.array(times)
         if forTest:
-            print(route, timeArray.max() < 1000, timeArray.mean()
-                  < 1000, math.sqrt(timeArray.var()) < 100)
+            print(route, timeArray.max() < 1000, timeArray.mean() < 1000, math.sqrt(timeArray.var()) < 100)
         else:
             print(route, timeArray.max(), timeArray.mean(),
                   math.sqrt(timeArray.var()))
@@ -90,8 +91,9 @@ def evaluate(forTest=False):
     else:
         print("CO2:", co2)
 
+
 if __name__ == "__main__":
-    from pylab import *
+    from pylab import figure, errorbar, legend, savefig, show, title, xlabel, xlim, ylabel, ylim
     stats = open(sys.argv[1])
     demand = []
     simpleWaitMean = []
