@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    runner.py
 # @author  Daniel Krajzewicz
@@ -21,10 +22,13 @@ import sys
 import shutil
 from scipy.optimize import fmin_cobyla
 
-sys.path.append(
-    os.path.join(os.path.dirname(__file__), '..', '..', '..', '..', "tools"))
+if 'SUMO_HOME' in os.environ:
+    tools = os.path.join(os.environ['SUMO_HOME'], 'tools')
+    sys.path.append(tools)
+else:
+    sys.exit("please declare environment variable 'SUMO_HOME'")
 from sumolib import checkBinary  # noqa
-import validate
+import validate  # noqa
 
 
 def buildVSS(obs7file, obs8file, vss):
@@ -98,10 +102,11 @@ def conAmax(params):  # aMax > 0.1
 netconvertBinary = checkBinary('netconvert')
 # build/check network
 retcode = subprocess.call([netconvertBinary, "-n", "data/spd-road.nod.xml", "-e",
-                           "data/spd-road.edg.xml", "-o", "data/spd-road.net.xml", "-v"], stdout=sys.stdout, stderr=sys.stderr)
+                           "data/spd-road.edg.xml", "-o", "data/spd-road.net.xml", "-v"],
+                          stdout=sys.stdout, stderr=sys.stderr)
 try:
     shutil.copy("data/spd-road.net.xml", "net.net.xml")
-except:
+except IOError:
     print("Missing 'spd-road.net.xml'")
 print(">> Netbuilding closed with status %s" % retcode)
 sys.stdout.flush()
