@@ -1,15 +1,13 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2010-2017 German Aerospace Center (DLR) and others.
+// Copyright (C) 2010-2018 German Aerospace Center (DLR) and others.
 // activitygen module
 // Copyright 2010 TUM (Technische Universitaet Muenchen, http://www.tum.de/)
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    AGAdult.cpp
 /// @author  Piotr Woznica
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "AGAdult.h"
 #include "AGWorkPosition.h"
@@ -50,14 +44,14 @@ AGAdult::randomFreeWorkPosition(std::vector<AGWorkPosition>* wps) {
         }
     }
     if (freePos.empty()) {
-        return 0;
+        return nullptr;
     }
     return RandHelper::getRandomFrom(freePos);
 }
 
 
 AGAdult::AGAdult(int age)
-    : AGPerson(age), work(0) {}
+    : AGPerson(age), work(nullptr) {}
 
 
 void
@@ -73,13 +67,13 @@ AGAdult::tryToWork(double rate, std::vector<AGWorkPosition>* wps) {
         // This avoids that the current one is the same as the new one.
         AGWorkPosition* newWork = randomFreeWorkPosition(wps);
 
-        if (work != 0) {
+        if (work != nullptr) {
             work->let();
         }
         work = newWork;
         work->take(this);
     } else {
-        if (work != 0) {
+        if (work != nullptr) {
             // Also sets work = 0 with the call back lostWorkPosition
             work->let();
         }
@@ -89,19 +83,19 @@ AGAdult::tryToWork(double rate, std::vector<AGWorkPosition>* wps) {
 
 bool
 AGAdult::isWorking() const {
-    return (work != 0);
+    return (work != nullptr);
 }
 
 
 void
 AGAdult::lostWorkPosition() {
-    work = 0;
+    work = nullptr;
 }
 
 
 void
 AGAdult::resignFromWorkPosition() {
-    if (work != 0) {
+    if (work != nullptr) {
         work->let();
     }
 }
@@ -109,7 +103,7 @@ AGAdult::resignFromWorkPosition() {
 
 const AGWorkPosition&
 AGAdult::getWorkPosition() const {
-    if (work != 0) {
+    if (work != nullptr) {
         return *work;
     }
     throw std::runtime_error("AGAdult::getWorkPosition: Adult is unemployed.");
