@@ -1,15 +1,13 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2010-2017 German Aerospace Center (DLR) and others.
+// Copyright (C) 2010-2018 German Aerospace Center (DLR) and others.
 // activitygen module
 // Copyright 2010 TUM (Technische Universitaet Muenchen, http://www.tum.de/)
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    AGCar.cpp
 /// @author  Piotr Woznica
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include <sstream>
@@ -51,7 +45,7 @@ AGCar::createName(int idHH, int idCar) {
 
 bool
 AGCar::associateTo(AGAdult* pers) {
-    if (currentUser == NULL) {
+    if (currentUser == nullptr) {
         currentUser = pers;
         return true;
     }
@@ -60,7 +54,7 @@ AGCar::associateTo(AGAdult* pers) {
 
 bool
 AGCar::isAssociated() const {
-    return (currentUser != NULL);
+    return (currentUser != nullptr);
 }
 
 std::string
