@@ -1,15 +1,13 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2010-2017 German Aerospace Center (DLR) and others.
+// Copyright (C) 2010-2018 German Aerospace Center (DLR) and others.
 // activitygen module
 // Copyright 2010 TUM (Technische Universitaet Muenchen, http://www.tum.de/)
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    AGChild.cpp
 /// @author  Piotr Woznica
@@ -27,11 +25,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include <vector>
@@ -50,7 +44,7 @@ AGChild::print() const {
 
 bool
 AGChild::setSchool(AGSchool* school) {
-    if (school == NULL) {
+    if (school == nullptr) {
         return false;
     }
     bool enoughPlace = school->addNewChild();
@@ -63,7 +57,7 @@ AGChild::setSchool(AGSchool* school) {
 bool
 AGChild::allocateASchool(std::list<AGSchool>* schools, AGPosition housePos) {
     double minDist = std::numeric_limits<double>::infinity();
-    AGSchool* sch = NULL;
+    AGSchool* sch = nullptr;
     if (schools->size() == 0) {
         return false;
     }
@@ -80,17 +74,17 @@ AGChild::allocateASchool(std::list<AGSchool>* schools, AGPosition housePos) {
 
 bool
 AGChild::leaveSchool() {
-    if (school != NULL)
+    if (school != nullptr)
         if (!school->removeChild()) {
             return false;
         }
-    school = NULL;
+    school = nullptr;
     return true;
 }
 
 bool
 AGChild::haveASchool() const {
-    return (school != NULL);
+    return (school != nullptr);
 }
 
 AGPosition
