@@ -1,15 +1,13 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
 // activitygen module
 // Copyright 2010 TUM (Technische Universitaet Muenchen, http://www.tum.de/)
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    AGWorkPosition.cpp
 /// @author  Piotr Woznica
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "AGWorkPosition.h"
 #include "AGStreet.h"
@@ -47,7 +41,7 @@
 AGWorkPosition::AGWorkPosition(AGDataAndStatistics* ds, const AGStreet& inStreet) :
     myStatData(ds),
     myLocation(inStreet),
-    myAdult(0),
+    myAdult(nullptr),
     myOpeningTime(generateOpeningTime(*ds)),
     myClosingTime(generateClosingTime(*ds)) {
     ds->workPositions++;
@@ -57,7 +51,7 @@ AGWorkPosition::AGWorkPosition(AGDataAndStatistics* ds, const AGStreet& inStreet
 AGWorkPosition::AGWorkPosition(AGDataAndStatistics* ds, const AGStreet& inStreet, double pos) :
     myStatData(ds),
     myLocation(inStreet, pos),
-    myAdult(0),
+    myAdult(nullptr),
     myOpeningTime(generateOpeningTime(*ds)),
     myClosingTime(generateClosingTime(*ds)) {
     ds->workPositions++;
@@ -111,23 +105,23 @@ AGWorkPosition::generateClosingTime(const AGDataAndStatistics& ds) {
 
 bool
 AGWorkPosition::isTaken() const {
-    return (myAdult != 0);
+    return (myAdult != nullptr);
 }
 
 
 void
 AGWorkPosition::let() {
-    if (myAdult != 0) {
+    if (myAdult != nullptr) {
         myStatData->workPositions++;
         myAdult->lostWorkPosition();
-        myAdult = 0;
+        myAdult = nullptr;
     }
 }
 
 
 void
 AGWorkPosition::take(AGAdult* worker) {
-    if (myAdult == 0) {
+    if (myAdult == nullptr) {
         myStatData->workPositions--;
         myAdult = worker;
     } else {
