@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2006-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2006-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    RODFDetector.cpp
 /// @author  Daniel Krajzewicz
@@ -27,11 +25,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <cassert>
 #include "RODFDetector.h"
@@ -47,7 +41,7 @@
 #include <utils/vehicle/SUMOVTypeParameter.h>
 #include <utils/distribution/RandomDistributor.h>
 #include <utils/common/StdDefs.h>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include <utils/geom/GeomHelper.h>
 #include "RODFNet.h"
 #include <utils/iodevices/OutputDevice.h>
@@ -60,13 +54,13 @@
 // ===========================================================================
 RODFDetector::RODFDetector(const std::string& id, const std::string& laneID,
                            double pos, const RODFDetectorType type)
-    : Named(id), myLaneID(laneID), myPosition(pos), myType(type), myRoutes(0) {}
+    : Named(id), myLaneID(laneID), myPosition(pos), myType(type), myRoutes(nullptr) {}
 
 
 RODFDetector::RODFDetector(const std::string& id, const RODFDetector& f)
     : Named(id), myLaneID(f.myLaneID), myPosition(f.myPosition),
-      myType(f.myType), myRoutes(0) {
-    if (f.myRoutes != 0) {
+      myType(f.myType), myRoutes(nullptr) {
+    if (f.myRoutes != nullptr) {
         myRoutes = new RODFRouteCont(*(f.myRoutes));
     }
 }
@@ -98,7 +92,7 @@ void
 RODFDetector::computeSplitProbabilities(const RODFNet* net, const RODFDetectorCon& detectors,
                                         const RODFDetectorFlows& flows,
                                         SUMOTime startTime, SUMOTime endTime, SUMOTime stepOffset) {
-    if (myRoutes == 0) {
+    if (myRoutes == nullptr) {
         return;
     }
     // compute edges to determine split probabilities
@@ -174,7 +168,7 @@ RODFDetector::buildDestinationDistribution(const RODFDetectorCon& detectors,
         SUMOTime startTime, SUMOTime endTime, SUMOTime stepOffset,
         const RODFNet& net,
         std::map<SUMOTime, RandomDistributor<int>* >& into) const {
-    if (myRoutes == 0) {
+    if (myRoutes == nullptr) {
         if (myType != DISCARDED_DETECTOR && myType != BETWEEN_DETECTOR) {
             WRITE_ERROR("Missing routes for detector '" + myID + "'.");
         }
@@ -202,7 +196,7 @@ RODFDetector::buildDestinationDistribution(const RODFDetectorCon& detectors,
                     continue;
                 }
                 const std::map<RODFEdge*, double>& tprobs = probs[(int)((time - startTime) / stepOffset)];
-                RODFEdge* splitEdge = 0;
+                RODFEdge* splitEdge = nullptr;
                 for (std::map<RODFEdge*, double>::const_iterator k = tprobs.begin(); k != tprobs.end(); ++k) {
                     if (find(j, (*ri).edges2Pass.end(), (*k).first) != (*ri).edges2Pass.end()) {
                         prob *= (*k).second;
@@ -210,7 +204,7 @@ RODFDetector::buildDestinationDistribution(const RODFDetectorCon& detectors,
                         break;
                     }
                 }
-                if (splitEdge != 0) {
+                if (splitEdge != nullptr) {
                     j = find(j, (*ri).edges2Pass.end(), splitEdge);
                 } else {
                     ++j;
@@ -263,7 +257,7 @@ RODFDetector::addRoutes(RODFRouteCont* routes) {
 
 void
 RODFDetector::addRoute(RODFRouteDesc& nrd) {
-    if (myRoutes == 0) {
+    if (myRoutes == nullptr) {
         myRoutes = new RODFRouteCont();
     }
     myRoutes->addRouteDesc(nrd);
@@ -272,7 +266,7 @@ RODFDetector::addRoute(RODFRouteDesc& nrd) {
 
 bool
 RODFDetector::hasRoutes() const {
-    return myRoutes != 0 && myRoutes->get().size() != 0;
+    return myRoutes != nullptr && myRoutes->get().size() != 0;
 }
 
 
@@ -292,7 +286,7 @@ RODFDetector::writeEmitterDefinition(const std::string& file,
         out.writeXMLHeader("additional", "additional_file.xsd");
     }
     // routes
-    if (myRoutes != 0 && myRoutes->get().size() != 0) {
+    if (myRoutes != nullptr && myRoutes->get().size() != 0) {
         const std::vector<RODFRouteDesc>& routes = myRoutes->get();
         out.openTag(SUMO_TAG_ROUTE_DISTRIBUTION).writeAttr(SUMO_ATTR_ID, myID);
         bool isEmptyDist = true;
@@ -302,11 +296,10 @@ RODFDetector::writeEmitterDefinition(const std::string& file,
             }
         }
         for (std::vector<RODFRouteDesc>::const_iterator i = routes.begin(); i != routes.end(); ++i) {
-            if ((*i).overallProb > 0 || includeUnusedRoutes) {
-                out.openTag(SUMO_TAG_ROUTE).writeAttr(SUMO_ATTR_REFID, (*i).routename).writeAttr(SUMO_ATTR_PROB, (*i).overallProb).closeTag();
-            }
             if (isEmptyDist) {
-                out.openTag(SUMO_TAG_ROUTE).writeAttr(SUMO_ATTR_REFID, (*i).routename).writeAttr(SUMO_ATTR_PROB, double(1)).closeTag();
+                out.openTag(SUMO_TAG_ROUTE).writeAttr(SUMO_ATTR_REFID, (*i).routename).writeAttr(SUMO_ATTR_PROB, 1.0).closeTag();
+            } else if ((*i).overallProb > 0 || includeUnusedRoutes) {
+                out.openTag(SUMO_TAG_ROUTE).writeAttr(SUMO_ATTR_REFID, (*i).routename).writeAttr(SUMO_ATTR_PROB, (*i).overallProb).closeTag();
             }
         }
         out.closeTag(); // routeDistribution
@@ -346,7 +339,15 @@ RODFDetector::writeEmitterDefinition(const std::string& file,
                 // get the vehicle parameter
                 double v = -1;
                 std::string vtype;
-                int destIndex = destDist != 0 && destDist->getOverallProb() > 0 ? (int) destDist->get() : -1;
+                int destIndex = -1;
+                if (destDist != nullptr) {
+                    if (destDist->getOverallProb() > 0) {
+                        destIndex = destDist->get();
+                    } else if (myRoutes->get().size() > 0) {
+                        // equal probabilities. see writeEmitterDefinition()
+                        destIndex = RandHelper::rand((int)myRoutes->get().size());
+                    }
+                }
                 if (srcFD.isLKW >= 1) {
                     srcFD.isLKW = srcFD.isLKW - 1.;
                     v = srcFD.vLKW;
@@ -378,7 +379,7 @@ RODFDetector::writeEmitterDefinition(const std::string& file,
                 if (oc.isSet("departlane")) {
                     out.writeNonEmptyAttr(SUMO_ATTR_DEPARTLANE, oc.getString("departlane"));
                 } else {
-                    out.writeAttr(SUMO_ATTR_DEPARTLANE, TplConvert::_2int(myLaneID.substr(myLaneID.rfind("_") + 1).c_str()));
+                    out.writeAttr(SUMO_ATTR_DEPARTLANE, StringUtils::toInt(myLaneID.substr(myLaneID.rfind("_") + 1)));
                 }
                 if (oc.isSet("departpos")) {
                     std::string posDesc = oc.getString("departpos");
@@ -386,11 +387,11 @@ RODFDetector::writeEmitterDefinition(const std::string& file,
                         double position = myPosition;
                         if (posDesc.length() > 8) {
                             if (posDesc[8] == '+') {
-                                position += TplConvert::_2double(posDesc.substr(9).c_str());
+                                position += StringUtils::toDouble(posDesc.substr(9));
                             } else if (posDesc[8] == '-') {
-                                position -= TplConvert::_2double(posDesc.substr(9).c_str());
+                                position -= StringUtils::toDouble(posDesc.substr(9));
                             } else {
-                                throw NumberFormatException();
+                                throw NumberFormatException("");
                             }
                         }
                         out.writeAttr(SUMO_ATTR_DEPARTPOS, position);
@@ -434,7 +435,7 @@ RODFDetector::writeEmitterDefinition(const std::string& file,
 bool
 RODFDetector::writeRoutes(std::vector<std::string>& saved,
                           OutputDevice& out) {
-    if (myRoutes != 0) {
+    if (myRoutes != nullptr) {
         return myRoutes->save(saved, "", out);
     }
     return false;
@@ -760,7 +761,7 @@ RODFDetectorCon::getAggFlowFor(const ROEdge* edge, SUMOTime time, SUMOTime perio
                                const RODFDetectorFlows&) const {
     UNUSED_PARAMETER(period);
     UNUSED_PARAMETER(time);
-    if (edge == 0) {
+    if (edge == nullptr) {
         return 0;
     }
 //    double stepOffset = 60; // !!!
@@ -813,7 +814,7 @@ RODFDetectorCon::writeSpeedTrigger(const RODFNet* const net,
         if (det->getType() == SINK_DETECTOR && flows.knows(det->getID())) {
             std::string filename = FileHelpers::getFilePath(file) + "vss_" + det->getID() + ".def.xml";
             out.openTag(SUMO_TAG_VSS).writeAttr(SUMO_ATTR_ID, StringUtils::escapeXML(det->getID())).writeAttr(SUMO_ATTR_LANES, det->getLaneID()).writeAttr(SUMO_ATTR_FILE, filename).closeTag();
-            double defaultSpeed = net != 0 ? net->getEdge(det->getEdgeID())->getSpeedLimit() : (double) 200.;
+            double defaultSpeed = net != nullptr ? net->getEdge(det->getEdgeID())->getSpeedLimit() : (double) 200.;
             det->writeSingleSpeedTrigger(filename, flows, startTime, endTime, stepOffset, defaultSpeed);
         }
     }
