@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    RODFNet.cpp
 /// @author  Daniel Krajzewicz
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <cassert>
 #include <iostream>
@@ -279,7 +273,7 @@ RODFNet::computeRoutesFor(ROEdge* edge, RODFRouteDesc& base, int /*no*/,
         // check for missing end connections
         if (!addNextNoFurther) {
             // ... if this one would be processed, but already too many edge
-            //  without a detector occured
+            //  without a detector occurred
             if (current.passedNo > maxFollowingLength) {
                 // mark not to process any further
                 WRITE_WARNING("Could not close route for '" + det.getID() + "'");
@@ -364,8 +358,8 @@ RODFNet::buildRoutes(RODFDetectorCon& detcont, bool keepUnfoundEnds, bool includ
         RODFRouteDesc rd;
         rd.edges2Pass.push_back(e);
         rd.duration_2 = (e->getLength() / e->getSpeedLimit()); //!!!;
-        rd.endDetectorEdge = 0;
-        rd.lastDetectorEdge = 0;
+        rd.endDetectorEdge = nullptr;
+        rd.lastDetectorEdge = nullptr;
         rd.distance = e->getLength();
         rd.distance2Last = 0;
         rd.duration2Last = 0;
@@ -633,7 +627,7 @@ RODFNet::getDetectorEdge(const RODFDetector& det) const {
     std::string edgeName = det.getLaneID();
     edgeName = edgeName.substr(0, edgeName.rfind('_'));
     ROEdge* ret = getEdge(edgeName);
-    if (ret == 0) {
+    if (ret == nullptr) {
         throw ProcessError("Edge '" + edgeName + "' used by detector '" + det.getID() + "' is not known.");
     }
     return ret;
@@ -947,7 +941,7 @@ RODFNet::buildEdgeFlowMap(const RODFDetectorFlows& flows,
 
         const std::vector<std::string>& dets = (*i).second;
         std::map<double, std::vector<std::string> > cliques;
-        std::vector<std::string>* maxClique = 0;
+        std::vector<std::string>* maxClique = nullptr;
         for (std::vector<std::string>::const_iterator j = dets.begin(); j != dets.end(); ++j) {
             if (!flows.knows(*j)) {
                 continue;
@@ -968,7 +962,7 @@ RODFNet::buildEdgeFlowMap(const RODFDetectorFlows& flows,
                 maxClique = &cliques[det.getPos()];
             }
         }
-        if (maxClique == 0) {
+        if (maxClique == nullptr) {
             continue;
         }
         std::vector<FlowDef> mflows; // !!! reserve
