@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIEvent_SimulationLoaded.h
 /// @author  Daniel Krajzewicz
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <iostream>
@@ -60,12 +54,14 @@ public:
                               SUMOTime startTime, SUMOTime endTime,
                               const std::string& file,
                               const std::vector<std::string>& settingsFiles,
-                              const bool osgView)
+                              const bool osgView,
+                              const bool viewportFromRegistry)
         : GUIEvent(EVENT_SIMULATION_LOADED),
           myNet(net), myBegin(startTime), myEnd(endTime),
           myFile(file), mySettingsFiles(settingsFiles),
-          myOsgView(osgView) {
-    }
+          myOsgView(osgView),
+          myViewportFromRegistry(viewportFromRegistry)
+    { }
 
     /// destructor
     ~GUIEvent_SimulationLoaded() { }
@@ -89,6 +85,9 @@ public:
     /// whether to load the OpenSceneGraph view
     const bool myOsgView;
 
+    /// @brief whether loading viewport from registry
+    const bool myViewportFromRegistry;
+
 private:
     /// @brief Invalidated assignment operator
     GUIEvent_SimulationLoaded& operator=(const GUIEvent_SimulationLoaded& s);
