@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUILoadThread.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include <ctime>
@@ -58,18 +52,14 @@
 #include <microsim/MSGlobals.h>
 #include <microsim/MSFrame.h>
 #include <microsim/MSRouteHandler.h>
+#include <mesogui/GUIMEVehicleControl.h>
+#include <traci-server/TraCIServer.h>
+#include "TraCIServerAPI_GUI.h"
 #include "GUIApplicationWindow.h"
 #include "GUILoadThread.h"
 #include "GUIGlobals.h"
 #include "GUIEvent_SimulationLoaded.h"
 
-#include <mesogui/GUIMEVehicleControl.h>
-
-#ifndef NO_TRACI
-#include <traci-server/TraCIServer.h>
-#include "TraCIServerAPI_GUI.h"
-#endif
-
 
 // ===========================================================================
 // member method definitions
@@ -153,7 +143,7 @@ GUILoadThread::run() {
         // the options are not valid but maybe we want to quit
         GUIGlobals::gQuitOnEnd = oc.getBool("quit-on-end");
         MsgHandler::getErrorInstance()->inform("Quitting (on error).", false);
-        submitEndAndCleanup(0, 0, 0);
+        submitEndAndCleanup(nullptr, 0, 0);
         return 0;
     }
 
@@ -164,7 +154,7 @@ GUILoadThread::run() {
     MSFrame::setMSGlobals(oc);
     GUITexturesHelper::allowTextures(!oc.getBool("disable-textures"));
 
-    MSVehicleControl* vehControl = 0;
+    MSVehicleControl* vehControl = nullptr;
     GUIVisualizationSettings::UseMesoSim = MSGlobals::gUseMesoSim;
     if (MSGlobals::gUseMesoSim) {
         vehControl = new GUIMEVehicleControl();
@@ -172,25 +162,23 @@ GUILoadThread::run() {
         vehControl = new GUIVehicleControl();
     }
 
-    GUINet* net = 0;
+    GUINet* net = nullptr;
     SUMOTime simStartTime = 0;
     SUMOTime simEndTime = 0;
     std::vector<std::string> guiSettingsFiles;
     bool osgView = false;
-    GUIEdgeControlBuilder* eb = 0;
+    GUIEdgeControlBuilder* eb = nullptr;
     try {
         net = new GUINet(
             vehControl,
             new GUIEventControl(),
             new GUIEventControl(),
             new GUIEventControl());
-#ifndef NO_TRACI
         // need to init TraCI-Server before loading routes to catch VEHICLE_STATE_BUILT
         std::map<int, TraCIServer::CmdExecutor> execs;
         execs[CMD_GET_GUI_VARIABLE] = &TraCIServerAPI_GUI::processGet;
         execs[CMD_SET_GUI_VARIABLE] = &TraCIServerAPI_GUI::processSet;
         TraCIServer::openSocket(execs);
-#endif
 
         eb = new GUIEdgeControlBuilder();
         GUIDetectorBuilder db(*net);
@@ -219,19 +207,20 @@ GUILoadThread::run() {
         }
         MsgHandler::getErrorInstance()->inform("Quitting (on error).", false);
         delete net;
-        net = 0;
+        net = nullptr;
 #ifndef _DEBUG
     } catch (std::exception& e) {
         WRITE_ERROR(e.what());
         delete net;
-        net = 0;
+        net = nullptr;
 #endif
     }
-    if (net == 0) {
+    if (net == nullptr) {
         MSNet::clearAll();
     }
     delete eb;
-    submitEndAndCleanup(net, simStartTime, simEndTime, guiSettingsFiles, osgView);
+    submitEndAndCleanup(net, simStartTime, simEndTime, guiSettingsFiles, osgView,
+            oc.getBool("registry-viewport"));
     return 0;
 }
 
@@ -241,13 +230,14 @@ GUILoadThread::submitEndAndCleanup(GUINet* net,
                                    const SUMOTime simStartTime,
                                    const SUMOTime simEndTime,
                                    const std::vector<std::string>& guiSettingsFiles,
-                                   const bool osgView) {
+                                   const bool osgView,
+                                   const bool viewportFromRegistry) {
     // remove message callbacks
     MsgHandler::getErrorInstance()->removeRetriever(myErrorRetriever);
     MsgHandler::getWarningInstance()->removeRetriever(myWarningRetriever);
     MsgHandler::getMessageInstance()->removeRetriever(myMessageRetriever);
     // inform parent about the process
-    GUIEvent* e = new GUIEvent_SimulationLoaded(net, simStartTime, simEndTime, myTitle, guiSettingsFiles, osgView);
+    GUIEvent* e = new GUIEvent_SimulationLoaded(net, simStartTime, simEndTime, myTitle, guiSettingsFiles, osgView, viewportFromRegistry);
     myEventQue.add(e);
     myEventThrow.signal();
 }
@@ -258,7 +248,7 @@ GUILoadThread::loadConfigOrNet(const std::string& file, bool isNet) {
     myFile = file;
     myLoadNet = isNet;
     if (myFile != "") {
-        OptionsIO::setArgs(0, 0);
+        OptionsIO::setArgs(0, nullptr);
     }
     start();
 }
