@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIRunThread.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <cassert>
 #include <string>
@@ -49,21 +43,18 @@
 #include <utils/common/MsgHandler.h>
 #include <utils/common/UtilExceptions.h>
 #include <utils/iodevices/OutputDevice.h>
-
-#ifndef NO_TRACI
 #include <traci-server/TraCIServer.h>
 #include <libsumo/Simulation.h>
-#endif
 
 
 // ===========================================================================
 // member method definitions
 // ===========================================================================
 GUIRunThread::GUIRunThread(FXApp* app, MFXInterThreadEventClient* parent,
-                           FXRealSpinDial& simDelay, MFXEventQue<GUIEvent*>& eq,
+                           double& simDelay, MFXEventQue<GUIEvent*>& eq,
                            FXEX::FXThreadEvent& ev)
     : FXSingleEventThread(app, parent),
-      myNet(0), myHalting(true), myQuit(false), mySimulationInProgress(false), myOk(true), myHaveSignaledEnd(false),
+      myNet(nullptr), myHalting(true), myQuit(false), mySimulationInProgress(false), myOk(true), myHaveSignaledEnd(false),
       mySimDelay(simDelay), myEventQue(eq), myEventThrow(ev) {
     myErrorRetriever = new MsgRetrievingFunction<GUIRunThread>(this, &GUIRunThread::retrieveMessage, MsgHandler::MT_ERROR);
     myMessageRetriever = new MsgRetrievingFunction<GUIRunThread>(this, &GUIRunThread::retrieveMessage, MsgHandler::MT_MESSAGE);
@@ -79,7 +70,7 @@ GUIRunThread::~GUIRunThread() {
     delete myMessageRetriever;
     delete myWarningRetriever;
     // wait for the thread
-    while (mySimulationInProgress || myNet != 0);
+    while (mySimulationInProgress || myNet != nullptr);
 }
 
 
@@ -112,6 +103,7 @@ GUIRunThread::init(GUINet* net, SUMOTime start, SUMOTime end) {
         mySimulationInProgress = false;
 #ifndef _DEBUG
     } catch (...) {
+        MsgHandler::getErrorInstance()->inform("Quitting (on error).", false);
         myHalting = true;
         myOk = false;
         mySimulationInProgress = false;
@@ -129,12 +121,10 @@ GUIRunThread::run() {
     // perform an endless loop
     while (!myQuit) {
         // if the simulation shall be perfomed, do it
-        if (!myHalting && myNet != 0 && myOk) {
-            if (getNet().logSimulationDuration()) {
-                beg = SysUtils::getCurrentMillis();
-                if (end != -1) {
-                    getNet().setIdleDuration((int)(beg - end));
-                }
+        if (!myHalting && myNet != nullptr && myOk) {
+            beg = SysUtils::getCurrentMillis();
+            if (end != -1) {
+                getNet().setIdleDuration((int)(beg - end));
             }
             // check whether we shall stop at this step
             myBreakpointLock.lock();
@@ -147,13 +137,11 @@ GUIRunThread::run() {
             if (haltAfter) {
                 stop();
             }
-            // wait if wanted
-            long wait = (long) mySimDelay.getValue();
-            if (getNet().logSimulationDuration()) {
-                end = SysUtils::getCurrentMillis();
-                getNet().setSimDuration((int)(end - beg));
-                wait -= (end - beg);
-            }
+            // wait if wanted (delay is per simulated second)
+            long wait = (long)(mySimDelay * TS);
+            end = SysUtils::getCurrentMillis();
+            getNet().setSimDuration((int)(end - beg));
+            wait -= (end - beg);
             if (wait > 0) {
                 sleep(wait);
             }
@@ -170,7 +158,7 @@ GUIRunThread::run() {
 
 void
 GUIRunThread::makeStep() {
-    GUIEvent* e = 0;
+    GUIEvent* e = nullptr;
     // simulation is being perfomed
     mySimulationInProgress = true;
     // execute a single step
@@ -185,18 +173,16 @@ GUIRunThread::makeStep() {
         myEventQue.add(e);
         myEventThrow.signal();
 
-        e = 0;
+        e = nullptr;
         MSNet::SimulationState state = myNet->simulationState(mySimEndTime);
-#ifndef NO_TRACI
         if (state == MSNet::SIMSTATE_LOADING) {
             OptionsIO::setArgs(TraCIServer::getInstance()->getLoadArgs());
             TraCIServer::getInstance()->getLoadArgs().clear();
         } else if (state != MSNet::SIMSTATE_RUNNING) {
-            if (TraCIServer::getInstance() != 0 && !TraCIServer::wasClosed()) {
+            if (TraCIServer::getInstance() != nullptr && !TraCIServer::wasClosed()) {
                 state = MSNet::SIMSTATE_RUNNING;
             }
         }
-#endif
         switch (state) {
             case MSNet::SIMSTATE_LOADING:
             case MSNet::SIMSTATE_END_STEP_REACHED:
@@ -207,13 +193,16 @@ GUIRunThread::makeStep() {
                     WRITE_MESSAGE("Simulation ended at time: " + time2string(myNet->getCurrentTimeStep()));
                     WRITE_MESSAGE("Reason: " + MSNet::getStateMessage(state));
                     e = new GUIEvent_SimulationEnded(state, myNet->getCurrentTimeStep() - DELTA_T);
+                    // ensure that files are closed (deleteSim is called a bit later by the gui thread)
+                    // MSNet destructor may trigger MsgHandler (via routing device cleanup). Closing output devices here is not safe
+                    // OutputDevice::closeAll();
                     myHaveSignaledEnd = true;
                 }
                 break;
             default:
                 break;
         }
-        if (e != 0) {
+        if (e != nullptr) {
             myEventQue.add(e);
             myEventThrow.signal();
             myHalting = true;
@@ -239,6 +228,7 @@ GUIRunThread::makeStep() {
         myOk = false;
 #ifndef _DEBUG
     } catch (...) {
+        MsgHandler::getErrorInstance()->inform("Quitting (on error).", false);
         mySimulationLock.unlock();
         mySimulationInProgress = false;
         e = new GUIEvent_SimulationEnded(MSNet::SIMSTATE_ERROR_IN_SIM, myNet->getCurrentTimeStep());
@@ -282,7 +272,7 @@ GUIRunThread::stop() {
 
 bool
 GUIRunThread::simulationAvailable() const {
-    return myNet != 0;
+    return myNet != nullptr;
 }
 
 
@@ -295,13 +285,13 @@ GUIRunThread::deleteSim() {
     MsgHandler::getMessageInstance()->removeRetriever(myMessageRetriever);
     //
     mySimulationLock.lock();
-    if (myNet != 0) {
+    if (myNet != nullptr) {
         myNet->closeSimulation(mySimStartTime);
     }
     while (mySimulationInProgress);
     delete myNet;
     GUIGlObjectStorage::gIDStorage.clear();
-    myNet = 0;
+    myNet = nullptr;
     OutputDevice::closeAll();
     mySimulationLock.unlock();
     MsgHandler::cleanupOnEnd();
@@ -331,33 +321,31 @@ GUIRunThread::retrieveMessage(const MsgHandler::MsgType type, const std::string&
 
 bool
 GUIRunThread::simulationIsStartable() const {
-    return myNet != 0 && myHalting;
+    return myNet != nullptr && myHalting;
 }
 
 
 bool
 GUIRunThread::simulationIsStopable() const {
-    return myNet != 0 && (!myHalting);
+    return myNet != nullptr && (!myHalting);
 }
 
 
 bool
 GUIRunThread::simulationIsStepable() const {
-    return myNet != 0 && myHalting;
+    return myNet != nullptr && myHalting;
 }
 
 
 void
-GUIRunThread::waitForSnapshots(SUMOTime snapShotTime) {
-    myApplicationSnapshotsLock.lock();
-    const bool wait = find(myApplicationSnapshots.begin(), myApplicationSnapshots.end(), snapShotTime) != myApplicationSnapshots.end();
-    //std::cout << SIMTIME << "waitForSnapshots " << toString(myApplicationSnapshots) << "\n";
-    myApplicationSnapshotsLock.unlock();
-    if (wait && !myHalting) {
-        sleep(50);
-        waitForSnapshots(snapShotTime);
+GUIRunThread::waitForSnapshots(const SUMOTime snapshotTime) {
+    GUIMainWindow* const mw = GUIMainWindow::getInstance();
+    if (mw != nullptr) {
+        for (GUIGlChildWindow* const window : mw->getViews()) {
+            window->getView()->waitForSnapshots(snapshotTime);
+        }
     }
 }
 
-/****************************************************************************/
 
+/****************************************************************************/
