@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIRunThread.h
 /// @author  Daniel Krajzewicz
@@ -25,19 +23,17 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
+#include <vector>
+#include <set>
 #include <iostream>
 #include <fx.h>
 #include <utils/foxtools/FXSingleEventThread.h>
-#include <utils/foxtools/FXRealSpinDial.h>
 #include <utils/foxtools/FXThreadEvent.h>
 #include <utils/foxtools/MFXEventQue.h>
+#include <utils/common/MsgHandler.h>
 #include <utils/common/SUMOTime.h>
 
 
@@ -63,7 +59,7 @@ class GUIRunThread : public FXSingleEventThread {
 public:
     /// constructor
     GUIRunThread(FXApp* app, MFXInterThreadEventClient* mw,
-                 FXRealSpinDial& simDelay, MFXEventQue<GUIEvent*>& eq, FXEX::FXThreadEvent& ev);
+                 double& simDelay, MFXEventQue<GUIEvent*>& eq, FXEX::FXThreadEvent& ev);
 
     /// destructor
     virtual ~GUIRunThread();
@@ -119,18 +115,10 @@ public:
         return myBreakpointLock;
     }
 
-    std::set<SUMOTime>& getSnapshots() {
-        return myApplicationSnapshots;
-    }
-
-    FXMutex& getSnapshotsLock() {
-        return myApplicationSnapshotsLock;
-    }
-
 protected:
     void makeStep();
 
-    void waitForSnapshots(SUMOTime snapShotTime);
+    void waitForSnapshots(const SUMOTime snapshotTime);
 
 protected:
     /// the loaded simulation network
@@ -163,7 +151,7 @@ protected:
         Needed to be deleted from the handler later on */
     OutputDevice* myErrorRetriever, *myMessageRetriever, *myWarningRetriever;
 
-    FXRealSpinDial& mySimDelay;
+    double& mySimDelay;
 
     MFXEventQue<GUIEvent*>& myEventQue;
 
@@ -177,16 +165,9 @@ protected:
     /// @brief Lock for modifying the list of breakpoints
     FXMutex myBreakpointLock;
 
-    /// @brief List of snapshot times
-    std::set<SUMOTime> myApplicationSnapshots;
-
-    /// @brief Lock for modifying the list of snapshot times
-    FXMutex myApplicationSnapshotsLock;
-
 };
 
 
 #endif
 
 /****************************************************************************/
-
