@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIDialog_Breakpoints.h
 /// @author  Daniel Krajzewicz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <vector>
@@ -56,15 +50,12 @@ public:
      */
     GUIDialog_Breakpoints(GUIMainWindow* parent, std::vector<SUMOTime>& breakpoints, FXMutex& breakpointLock);
 
-
     /// @brief Destructor
     ~GUIDialog_Breakpoints();
 
     /// @brief sets the focus after the window is created
     void show();
 
-
-
     /// @name FOX-callbacks
     /// @{
 
@@ -84,6 +75,9 @@ public:
     long onCmdEditTable(FXObject*, FXSelector, void*);
     /// @}
 
+protected:
+    /// FOX needs this
+    GUIDialog_Breakpoints() {}
 
 private:
     /// @brief Rebuilds the entire list
@@ -94,8 +88,6 @@ private:
      */
     std::string encode2TXT();
 
-
-private:
     /// @brief The list that holds the ids
     FXTable* myTable;
 
@@ -107,12 +99,6 @@ private:
 
     /// @brief Lock for modifying the list of breakpoints
     FXMutex* myBreakpointLock;
-
-
-protected:
-    /// FOX needs this
-    GUIDialog_Breakpoints() { }
-
 };
 
 
