@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUITriggerBuilder.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <fstream>
@@ -66,8 +60,9 @@ MSTriggeredRerouter*
 GUITriggerBuilder::buildRerouter(MSNet& net, const std::string& id,
                                  MSEdgeVector& edges,
                                  double prob, const std::string& file, bool off,
-                                 SUMOTime timeThreshold) {
-    GUITriggeredRerouter* rr = new GUITriggeredRerouter(id, edges, prob, file, off, timeThreshold,
+                                 SUMOTime timeThreshold,
+                                 const std::string& vTypes) {
+    GUITriggeredRerouter* rr = new GUITriggeredRerouter(id, edges, prob, file, off, timeThreshold, vTypes,
             dynamic_cast<GUINet&>(net).getVisualisationSpeedUp());
     return rr;
 }
@@ -84,10 +79,9 @@ GUITriggerBuilder::buildStoppingPlace(MSNet& net, std::string id, std::vector<st
     }
     if (!net.addStoppingPlace(element, myCurrentStop)) {
         delete myCurrentStop;
-        myCurrentStop = 0;
+        myCurrentStop = nullptr;
         throw InvalidArgument("Could not build " + toString(element) + " '" + id + "'; probably declared twice.");
     }
-    static_cast<GUINet&>(net).getVisualisationSpeedUp().addAdditionalGLObject(dynamic_cast<GUIGlObject*>(myCurrentStop));
 }
 
 
@@ -97,9 +91,10 @@ GUITriggerBuilder::beginParkingArea(MSNet& net, const std::string& id,
                                     MSLane* lane,
                                     double frompos, double topos,
                                     unsigned int capacity,
-                                    double width, double length, double angle) {
+                                    double width, double length, double angle, const std::string& name,
+                                    bool onRoad) {
     assert(myParkingArea == 0);
-    GUIParkingArea* stop = new GUIParkingArea(id, lines, *lane, frompos, topos, capacity, width, length, angle);
+    GUIParkingArea* stop = new GUIParkingArea(id, lines, *lane, frompos, topos, capacity, width, length, angle, name, onRoad);
     if (!net.addStoppingPlace(SUMO_TAG_PARKING_AREA, stop)) {
         delete stop;
         throw InvalidArgument("Could not build parking area '" + id + "'; probably declared twice.");
@@ -108,10 +103,11 @@ GUITriggerBuilder::beginParkingArea(MSNet& net, const std::string& id,
     }
 }
 
+
 void
-GUITriggerBuilder::buildChargingStation(MSNet& net, const std::string& id, MSLane* lane, double frompos, double topos,
-                                        double chargingPower, double efficiency, bool chargeInTransit, int chargeDelay) {
-    GUIChargingStation* chargingStation = new GUIChargingStation(id, *lane, frompos, topos, chargingPower, efficiency, chargeInTransit, chargeDelay);
+GUITriggerBuilder::buildChargingStation(MSNet& net, const std::string& id, MSLane* lane, double frompos, double topos, const std::string& name,
+                                        double chargingPower, double efficiency, bool chargeInTransit, double chargeDelay) {
+    GUIChargingStation* chargingStation = new GUIChargingStation(id, *lane, frompos, topos, name, chargingPower, efficiency, chargeInTransit, chargeDelay);
     if (!net.addStoppingPlace(SUMO_TAG_CHARGING_STATION, chargingStation)) {
         delete chargingStation;
         throw InvalidArgument("Could not build charging station '" + id + "'; probably declared twice.");
@@ -119,6 +115,7 @@ GUITriggerBuilder::buildChargingStation(MSNet& net, const std::string& id, MSLan
     static_cast<GUINet&>(net).getVisualisationSpeedUp().addAdditionalGLObject(chargingStation);
 }
 
+
 MSCalibrator*
 GUITriggerBuilder::buildCalibrator(MSNet& net, const std::string& id,
                                    MSEdge* edge, MSLane* lane, double pos,
@@ -134,15 +131,24 @@ GUITriggerBuilder::buildCalibrator(MSNet& net, const std::string& id,
 
 void
 GUITriggerBuilder::endParkingArea() {
-    if (myParkingArea != 0) {
+    if (myParkingArea != nullptr) {
         static_cast<GUINet*>(MSNet::getInstance())->getVisualisationSpeedUp().addAdditionalGLObject(static_cast<GUIParkingArea*>(myParkingArea));
-        myParkingArea = 0;
+        myParkingArea = nullptr;
     } else {
         throw InvalidArgument("Could not end a parking area that is not opened.");
     }
 }
 
 
+void
+GUITriggerBuilder::endStoppingPlace() {
+    if (myCurrentStop != nullptr) {
+        static_cast<GUINet*>(MSNet::getInstance())->getVisualisationSpeedUp().addAdditionalGLObject(dynamic_cast<GUIGlObject*>(myCurrentStop));
+        myCurrentStop = nullptr;
+    } else {
+        throw InvalidArgument("Could not end a stopping place that is not opened.");
+    }
+}
 
 /****************************************************************************/
 
