@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2004-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2004-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUITriggerBuilder.h
 /// @author  Daniel Krajzewicz
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <netload/NLTriggerBuilder.h>
@@ -99,7 +93,8 @@ protected:
     virtual MSTriggeredRerouter* buildRerouter(MSNet& net,
             const std::string& id, MSEdgeVector& edges,
             double prob, const std::string& file, bool off,
-            SUMOTime timeThreshold);
+            SUMOTime timeThreshold,
+            const std::string& vTypes);
 
 
     /** @brief Builds a bus stop
@@ -139,12 +134,13 @@ protected:
                                   const std::vector<std::string>& lines, MSLane* lane,
                                   double frompos, double topos,
                                   unsigned int capacity,
-                                  double width, double length, double angle);
+                                  double width, double length, double angle, const std::string& name,
+                                  bool onRoad);
 
 
     /** @brief Builds a charging station
      *
-     * Simply calls the ChrgSTN constructor.
+     * Simply calls the GUIChargingStation constructor.
      *
      * @param[in] net The net the charging station belongs to
      * @param[in] id The id of the charging station
@@ -158,8 +154,9 @@ protected:
      * @exception InvalidArgument If the charging station can not be added to the net (is duplicate)
      */
     virtual void buildChargingStation(MSNet& net, const std::string& id, MSLane* lane,
-                                      double frompos, double topos, double chargingPower, double efficiency,
-                                      bool chargeInTransit, int chargeDelay);
+                                      double frompos, double topos, const std::string& name,
+                                      double chargingPower, double efficiency,
+                                      bool chargeInTransit, double chargeDelay);
 
     /** @brief builds a microscopic calibrator
      *
@@ -183,6 +180,12 @@ protected:
      * (it must be added to the SUMORTree after all parking spaces are loaded
      */
     virtual void endParkingArea();
+
+    /** @brief End a stopping place
+     *
+     * @exception InvalidArgument If the current stopping place is 0
+     */
+    virtual void endStoppingPlace();
 };
 
 
