@@ -1,18 +1,17 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIBaseVehicle.cpp
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
+/// @author  Laura Bieker-Walz
 /// @date    Sept 2002
 /// @version $Id$
 ///
@@ -23,15 +22,12 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <cmath>
 #include <vector>
 #include <string>
+#include <functional>
 #include <utils/common/StringUtils.h>
 #include <utils/geom/GeomHelper.h>
 #include <utils/vehicle/SUMOVehicleParameter.h>
@@ -42,7 +38,6 @@
 #include <utils/gui/images/GUITexturesHelper.h>
 #include <utils/gui/div/GUIGlobalSelection.h>
 #include <utils/gui/div/GLHelper.h>
-#include <utils/gui/div/GLObjectValuePassConnector.h>
 #include <utils/gui/div/GUIGlobalSelection.h>
 #include <microsim/MSVehicle.h>
 #include <microsim/MSLane.h>
@@ -51,6 +46,7 @@
 #include <microsim/MSVehicleControl.h>
 #include <microsim/lcmodels/MSAbstractLaneChangeModel.h>
 #include <microsim/devices/MSDevice_Vehroutes.h>
+#include <microsim/devices/MSDevice_Transportable.h>
 #include <microsim/devices/MSDevice_BTreceiver.h>
 #include <gui/GUIApplicationWindow.h>
 #include <gui/GUIGlobals.h>
@@ -61,6 +57,7 @@
 #include "GUIEdge.h"
 #include "GUILane.h"
 
+//#define DRAW_BOUNDING_BOX
 
 // ===========================================================================
 // FOX callback mapping
@@ -140,6 +137,9 @@ double vehiclePoly_EmergencyLadder4[] =   { .45, .3, .4, .3, .4, -.3, .45, -.3,
 double vehiclePoly_EmergencyLadder5[] =   { .05, .3, .0, .3, .0, -.3, .05, -.3, -10000 };
 double vehiclePoly_EmergencyLadder6[] =   { -.25, .3, -.2, .3, -.2, -.3, -.25, -.3, -10000 };
 double vehiclePoly_EmergencyLadder7[] =   { .25, .3, .2, .3, .2, -.3, .25, -.3, -10000 };
+
+double vehiclePoly_Rickshaw[] = { 0.5, 0,  0.25, 0.45,  0.25, 0.5, 0.8, 0.15,     0.8, -0.15, 0.25, -0.5, 0.25, -0.45,     -10000 };
+
 // ===========================================================================
 // method definitions
 // ===========================================================================
@@ -272,7 +272,6 @@ GUIBaseVehicle::~GUIBaseVehicle() {
         while (i->first->removeAdditionalGLVisualisation(this));
     }
     myLock.unlock();
-    GLObjectValuePassConnector<double>::removeObject(*this);
     delete myRoutes;
 }
 
@@ -287,32 +286,32 @@ GUIBaseVehicle::getPopUpMenu(GUIMainWindow& app,
     buildSelectionPopupEntry(ret);
     //
     if (hasActiveAddVisualisation(&parent, VO_SHOW_ROUTE)) {
-        new FXMenuCommand(ret, "Hide Current Route", 0, ret, MID_HIDE_CURRENTROUTE);
+        new FXMenuCommand(ret, "Hide Current Route", nullptr, ret, MID_HIDE_CURRENTROUTE);
     } else {
-        new FXMenuCommand(ret, "Show Current Route", 0, ret, MID_SHOW_CURRENTROUTE);
+        new FXMenuCommand(ret, "Show Current Route", nullptr, ret, MID_SHOW_CURRENTROUTE);
     }
     if (hasActiveAddVisualisation(&parent, VO_SHOW_ALL_ROUTES)) {
-        new FXMenuCommand(ret, "Hide All Routes", 0, ret, MID_HIDE_ALLROUTES);
+        new FXMenuCommand(ret, "Hide All Routes", nullptr, ret, MID_HIDE_ALLROUTES);
     } else {
-        new FXMenuCommand(ret, "Show All Routes", 0, ret, MID_SHOW_ALLROUTES);
+        new FXMenuCommand(ret, "Show All Routes", nullptr, ret, MID_SHOW_ALLROUTES);
     }
     if (hasActiveAddVisualisation(&parent, VO_SHOW_BEST_LANES)) {
-        new FXMenuCommand(ret, "Hide Best Lanes", 0, ret, MID_HIDE_BEST_LANES);
+        new FXMenuCommand(ret, "Hide Best Lanes", nullptr, ret, MID_HIDE_BEST_LANES);
     } else {
-        new FXMenuCommand(ret, "Show Best Lanes", 0, ret, MID_SHOW_BEST_LANES);
+        new FXMenuCommand(ret, "Show Best Lanes", nullptr, ret, MID_SHOW_BEST_LANES);
     }
     if (hasActiveAddVisualisation(&parent, VO_SHOW_LFLINKITEMS)) {
-        new FXMenuCommand(ret, "Hide Link Items", 0, ret, MID_HIDE_LFLINKITEMS);
+        new FXMenuCommand(ret, "Hide Link Items", nullptr, ret, MID_HIDE_LFLINKITEMS);
     } else {
-        new FXMenuCommand(ret, "Show Link Items", 0, ret, MID_SHOW_LFLINKITEMS);
+        new FXMenuCommand(ret, "Show Link Items", nullptr, ret, MID_SHOW_LFLINKITEMS);
     }
     new FXMenuSeparator(ret);
     if (parent.getTrackedID() != getGlID()) {
-        new FXMenuCommand(ret, "Start Tracking", 0, ret, MID_START_TRACK);
+        new FXMenuCommand(ret, "Start Tracking", nullptr, ret, MID_START_TRACK);
     } else {
-        new FXMenuCommand(ret, "Stop Tracking", 0, ret, MID_STOP_TRACK);
+        new FXMenuCommand(ret, "Stop Tracking", nullptr, ret, MID_STOP_TRACK);
     }
-    new FXMenuCommand(ret, "Select Foes", 0, ret, MID_SHOW_FOES);
+    new FXMenuCommand(ret, "Select Foes", nullptr, ret, MID_SHOW_FOES);
 
     new FXMenuSeparator(ret);
     //
@@ -604,9 +603,8 @@ GUIBaseVehicle::drawAction_drawVehicleAsPoly(const GUIVisualizationSettings& s)
             break;
         }
         case SVS_EMERGENCY: // similar to delivery
-            glColor3d(1, 1, 1);
             drawPoly(vehiclePoly_PassengerVanBody, 4);
-            glColor3d(1, 0, 0);
+            GLHelper::setColor(darker);
             drawPoly(vehiclePoly_PassengerVanBodyFront, 4.5);
             glColor3d(0, 0, 0);
             drawPoly(vehiclePoly_PassengerVanFrontGlass, 4.5);
@@ -621,9 +619,8 @@ GUIBaseVehicle::drawAction_drawVehicleAsPoly(const GUIVisualizationSettings& s)
             drawPoly(vehiclePoly_Emergency2, 5);
             break;
         case SVS_FIREBRIGADE: // similar to delivery in red orange
-            glColor3d(1, 0, 0);
             drawPoly(vehiclePoly_PassengerVanBody, 4);
-            glColor3d(1, .5, 0);
+            GLHelper::setColor(lighter);
             drawPoly(vehiclePoly_PassengerVanBodyFront, 4.5);
             glColor3d(0, 0, 0);
             drawPoly(vehiclePoly_PassengerVanFrontGlass, 4.5);
@@ -643,20 +640,33 @@ GUIBaseVehicle::drawAction_drawVehicleAsPoly(const GUIVisualizationSettings& s)
             drawPoly(vehiclePoly_EmergencyLadder7, 5);
             break;
         case SVS_POLICE: // similar to passenger grey with blue
-            glColor3d(.5, .5, .5);
             drawPoly(vehiclePoly_PassengerCarBody, 4);
-            glColor3d(0, 0, 1);
+            GLHelper::setColor(lighter);
             drawPoly(vehiclePoly_PassengerCarBodyFront, 4.5);
             glColor3d(0, 0, 0);
             drawPoly(vehiclePoly_PassengerFrontGlass, 4.5);
             // first aid sign
             glTranslated(0.7, 0, 0);
-            glColor3d(0, 0, 1);
-            drawPoly(vehiclePoly_EmergencySign, 4.5);
             glColor3d(.5, .5, .5);
+            drawPoly(vehiclePoly_EmergencySign, 4.5);
+            glColor3d(0, 0, 1);
             drawPoly(vehiclePoly_Emergency, 5);
             drawPoly(vehiclePoly_Emergency2, 5);
             break;
+        case SVS_RICKSHAW: // Rickshaw
+            drawPoly(vehiclePoly_PassengerCarBody, 4);
+            // wheels
+            GLHelper::setColor(darker);
+            glPushMatrix();
+            glTranslated(.5, .5, -0.1);
+            GLHelper::drawFilledCircle(.3, 6);
+            glPopMatrix();
+            //other wheel
+            glPushMatrix();
+            glTranslated(.5, -.5, -0.1);
+            GLHelper::drawFilledCircle(.3, 6);
+            glPopMatrix();
+            break;
         default: // same as passenger
             drawPoly(vehiclePoly_PassengerCarBody, 4);
             glColor3d(1, 1, 1);
@@ -763,6 +773,7 @@ GUIBaseVehicle::drawAction_drawVehicleAsPoly(const GUIVisualizationSettings& s)
         case SVS_EMERGENCY:
         case SVS_FIREBRIGADE:
         case SVS_POLICE:
+        case SVS_RICKSHAW:
             break;
         default: // same as passenger/sedan
             drawPoly(vehiclePoly_PassengerSedanRightGlass, 4.5);
@@ -850,7 +861,7 @@ GUIBaseVehicle::drawAction_drawVehicleAsImage(const GUIVisualizationSettings& s,
     if (file != "") {
         int textureID = GUITexturesHelper::getTextureID(file);
         if (textureID > 0) {
-            const double exaggeration = s.vehicleSize.getExaggeration(s);
+            const double exaggeration = s.vehicleSize.getExaggeration(s, this);
             if (length < 0) {
                 length = getVType().getLength() * exaggeration;
             }
@@ -869,9 +880,10 @@ GUIBaseVehicle::drawOnPos(const GUIVisualizationSettings& s, const Position& pos
     glPushMatrix();
     Position p1 = pos;
     const double degAngle = RAD2DEG(angle + M_PI / 2.);
+    const double length = getVType().getLength();
     // one seat in the center of the vehicle by default
-    if (myVehicle.getLane() != 0) {
-        mySeatPositions[0] = myVehicle.getPosition(- getVType().getLength() / 2);
+    if (myVehicle.getLane() != nullptr) {
+        mySeatPositions[0] = myVehicle.getPosition(-length / 2);
     } else {
         mySeatPositions[0] = p1;
     }
@@ -880,8 +892,13 @@ GUIBaseVehicle::drawOnPos(const GUIVisualizationSettings& s, const Position& pos
     // set lane color
     setColor(s);
     // scale
-    const double upscale = s.vehicleSize.getExaggeration(s);
-    glScaled(upscale, upscale, 1);
+    const double upscale = s.vehicleSize.getExaggeration(s, this);
+    double upscaleLength = upscale;
+    if (upscale > 1 && length > 5) {
+        // reduce the length/width ratio because this is not usefull at high zoom
+        upscaleLength = MAX2(1.0, upscaleLength * (5 + sqrt(length - 5)) / length);
+    }
+    glScaled(upscale, upscaleLength, 1);
     /*
         MSLCM_DK2004 &m2 = static_cast<MSLCM_DK2004&>(veh->getLaneChangeModel());
         if((m2.getState()&LCA_URGENT)!=0) {
@@ -933,7 +950,7 @@ GUIBaseVehicle::drawOnPos(const GUIVisualizationSettings& s, const Position& pos
         glEnd();
     }
     MSDevice_BTreceiver* dev = static_cast<MSDevice_BTreceiver*>(myVehicle.getDevice(typeid(MSDevice_BTreceiver)));
-    if (dev != 0 && s.showBTRange) {
+    if (dev != nullptr && s.showBTRange) {
         glColor3d(1., 0., 0.);
         GLHelper::drawOutlineCircle(dev->getRange(), dev->getRange() - .2, 32);
     }
@@ -951,14 +968,14 @@ GUIBaseVehicle::drawOnPos(const GUIVisualizationSettings& s, const Position& pos
                 break;
             case SVS_MOTORCYCLE:
             case SVS_MOPED:
-                drawAction_drawVehicleBlinker(getVType().getLength());
-                drawAction_drawVehicleBrakeLight(getVType().getLength(), true);
+                drawAction_drawVehicleBlinker(length);
+                drawAction_drawVehicleBrakeLight(length, true);
                 break;
             default:
                 // only SVS_RAIL_CAR has blinkers and brake lights but they are drawn along with the carriages
                 if (!drawCarriages) {
-                    drawAction_drawVehicleBlinker(getVType().getLength());
-                    drawAction_drawVehicleBrakeLight(getVType().getLength());
+                    drawAction_drawVehicleBlinker(length);
+                    drawAction_drawVehicleBrakeLight(length);
                 }
                 break;
         }
@@ -1010,15 +1027,19 @@ GUIBaseVehicle::drawOnPos(const GUIVisualizationSettings& s, const Position& pos
         glEnd();
     }
     */
-    glTranslated(0, MIN2(getVType().getLength() / 2, double(5)), -getType()); // drawing name at GLO_MAX fails unless translating z
+    glTranslated(0, MIN2(length / 2, double(5)), -getType()); // drawing name at GLO_MAX fails unless translating z
+    glScaled(1 / upscale, 1 / upscaleLength, 1);
     glRotated(-degAngle, 0, 0, 1);
-    glScaled(1 / upscale, 1 / upscale, 1);
     drawName(Position(0, 0), s.scale,
-             getVType().getGuiShape() == SVS_PEDESTRIAN ? s.personName : s.vehicleName);
+             getVType().getGuiShape() == SVS_PEDESTRIAN ? s.personName : s.vehicleName, s.angle);
     if (s.vehicleName.show && myVehicle.getParameter().line != "") {
-        glTranslated(0, 0.6 * s.vehicleName.size / s.scale, 0);
-        GLHelper::drawText("line:" + myVehicle.getParameter().line, Position(0, 0),
-                           GLO_MAX, s.vehicleName.size / s.scale, s.vehicleName.color);
+        glTranslated(0, 0.6 * s.vehicleName.scaledSize(s.scale), 0);
+        GLHelper::drawTextSettings(s.vehicleName, "line:" + myVehicle.getParameter().line, Position(0, 0), s.scale, s.angle);
+    }
+    if (s.vehicleValue.show) {
+        glTranslated(0, 0.6 * s.vehicleName.scaledSize(s.scale), 0);
+        const double value = getColorValue(s.vehicleColorer.getActive()); 
+        GLHelper::drawTextSettings(s.vehicleValue, toString(value), Position(0, 0), s.scale, s.angle);
     }
     glPopMatrix();
     glPopName();
@@ -1088,6 +1109,21 @@ bool
 GUIBaseVehicle::setFunctionalColor(int activeScheme, const MSBaseVehicle* veh) {
     switch (activeScheme) {
         case 0: {
+            //test for emergency vehicle
+            if (veh->getVehicleType().getGuiShape() == SVS_EMERGENCY) {
+                GLHelper::setColor(RGBColor::WHITE);
+                return true;
+            }
+            //test for firebrigade
+            if (veh->getVehicleType().getGuiShape() == SVS_FIREBRIGADE) {
+                GLHelper::setColor(RGBColor::RED);
+                return true;
+            }
+            //test for police car
+            if (veh->getVehicleType().getGuiShape() == SVS_POLICE) {
+                GLHelper::setColor(RGBColor::BLUE);
+                return true;
+            }
             if (veh->getParameter().wasSet(VEHPARS_COLOR_SET)) {
                 GLHelper::setColor(veh->getParameter().color);
                 return true;
@@ -1152,9 +1188,10 @@ GUIBaseVehicle::setFunctionalColor(int activeScheme, const MSBaseVehicle* veh) {
             GLHelper::setColor(RGBColor::fromHSV(hue, sat, 1.));
             return true;
         }
-        case 29: { // color randomly (by pointer)
-            const double hue = (long)veh % 360; // [0-360]
-            const double sat = (((long)veh / 360) % 67) / 100.0 + 0.33; // [0.33-1]
+        case 29: { // color randomly (by pointer hash)
+            std::hash<const MSBaseVehicle*> ptr_hash;
+            const double hue = (double)(ptr_hash(veh) % 360); // [0-360]
+            const double sat = ((ptr_hash(veh) / 360) % 67) / 100.0 + 0.33; // [0.33-1]
             GLHelper::setColor(RGBColor::fromHSV(hue, sat, 1.));
             return true;
         }
@@ -1215,7 +1252,7 @@ GUIBaseVehicle::drawRoute(const GUIVisualizationSettings& s, int routeNo, double
     }
     --routeNo; // only prior routes are stored
     const MSRoute* route = myRoutes->getRoute(routeNo);
-    if (route != 0) {
+    if (route != nullptr) {
         drawRouteHelper(s, *route);
     }
 }
@@ -1228,4 +1265,45 @@ GUIBaseVehicle::getSeatPosition(int personIndex) const {
 }
 
 
+void
+GUIBaseVehicle::drawAction_drawPersonsAndContainers(const GUIVisualizationSettings& s) const {
+    if (myVehicle.myPersonDevice != nullptr) {
+        const std::vector<MSTransportable*>& ps = myVehicle.myPersonDevice->getTransportables();
+        int personIndex = 0;
+        for (std::vector<MSTransportable*>::const_iterator i = ps.begin(); i != ps.end(); ++i) {
+            GUIPerson* person = dynamic_cast<GUIPerson*>(*i);
+            assert(person != 0);
+            person->setPositionInVehicle(getSeatPosition(personIndex++));
+            person->drawGL(s);
+        }
+    }
+    if (myVehicle.myContainerDevice != nullptr) {
+        const std::vector<MSTransportable*>& cs = myVehicle.myContainerDevice->getTransportables();
+        int containerIndex = 0;
+        for (std::vector<MSTransportable*>::const_iterator i = cs.begin(); i != cs.end(); ++i) {
+            GUIContainer* container = dynamic_cast<GUIContainer*>(*i);
+            assert(container != 0);
+            container->setPositionInVehicle(getSeatPosition(containerIndex++));
+            container->drawGL(s);
+        }
+    }
+#ifdef DRAW_BOUNDING_BOX
+    glPushName(getGlID());
+    glPushMatrix();
+    glTranslated(0, 0, getType());
+    PositionVector boundingBox = getBoundingBox();
+    boundingBox.push_back(boundingBox.front());
+    PositionVector smallBB = getBoundingPoly();
+    glColor3d(0, .8, 0);
+    GLHelper::drawLine(boundingBox);
+    glColor3d(0.5, .8, 0);
+    GLHelper::drawLine(smallBB);
+    //GLHelper::drawBoxLines(getBoundingBox(), 0.5);
+    glPopMatrix();
+    glPopName();
+#endif
+}
+
+
+
 /****************************************************************************/
