@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIChargingStation.h
 /// @author  Daniel Krajzewicz
@@ -27,11 +25,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <string>
@@ -45,7 +39,6 @@
 #include <utils/gui/globjects/GUIGLObjectPopupMenu.h>
 #include <utils/geom/Position.h>
 #include <gui/GUIManipulator.h>
-#include <utils/foxtools/FXRealSpinDial.h>
 
 
 // ===========================================================================
@@ -83,7 +76,8 @@ public:
      * @param[in] chargeDelay delay in the charge
      */
     GUIChargingStation(const std::string& id, MSLane& lane, double frompos, double topos,
-                       double chargingPower, double efficiency, bool chargeInTransit, int chargeDelay);
+                       const std::string& name,
+                       double chargingPower, double efficiency, bool chargeInTransit, double chargeDelay);
 
     /// @brief Destructor
     ~GUIChargingStation();
