@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIDetectorWrapper.cpp
 /// @author  Daniel Krajzewicz
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "GUIDetectorWrapper.h"
 #include <gui/GUIApplicationWindow.h>
@@ -41,18 +35,15 @@
 // ===========================================================================
 // member method definitions
 // ===========================================================================
-GUIDetectorWrapper::GUIDetectorWrapper(
-    const std::string& prefix,
-    const std::string& id) :
-    GUIGlObject_AbstractAdd(prefix, GLO_DETECTOR, id) {}
+GUIDetectorWrapper::GUIDetectorWrapper(GUIGlObjectType type, const std::string& id) :
+    GUIGlObject_AbstractAdd(type, id) {}
 
 
 GUIDetectorWrapper::~GUIDetectorWrapper() {}
 
 
 GUIGLObjectPopupMenu*
-GUIDetectorWrapper::getPopUpMenu(GUIMainWindow& app,
-                                 GUISUMOAbstractView& parent) {
+GUIDetectorWrapper::getPopUpMenu(GUIMainWindow& app, GUISUMOAbstractView& parent) {
     GUIGLObjectPopupMenu* ret = new GUIGLObjectPopupMenu(app, parent, *this);
     buildPopupHeader(ret, app);
     buildCenterPopupEntry(ret);
