@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIE2Collector.cpp
 /// @author  Daniel Krajzewicz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/gui/globjects/GUIGlObject.h>
 #include <utils/geom/PositionVector.h>
@@ -71,25 +65,29 @@ GUIE2Collector::buildDetectorGUIRepresentation() {
     return new MyWrapper(*this);
 }
 
+// -------------------------------------------------------------------------
+// GUIE2Collector::MyWrapper-methods
+// -------------------------------------------------------------------------
 
-
-/* -------------------------------------------------------------------------
- * GUIE2Collector::MyWrapper-methods
- * ----------------------------------------------------------------------- */
-GUIE2Collector::MyWrapper::MyWrapper(GUIE2Collector& detector)
-    : GUIDetectorWrapper("E2 detector", detector.getID()),
-      myDetector(detector) {
-
+GUIE2Collector::MyWrapper::MyWrapper(GUIE2Collector& detector) :
+    GUIDetectorWrapper(GLO_E2DETECTOR, detector.getID()),
+    myDetector(detector) {
     // collect detector shape into one vector (v)
     PositionVector v;
     const std::vector<MSLane*> lanes = detector.getLanes();
+    double detectorLength = detector.getLength();
     for (std::vector<MSLane*>::const_iterator li = lanes.begin(); li != lanes.end(); ++li) {
         const PositionVector& shape = (*li)->getShape();
+        // account for gaps between lanes (e.g. in networks without internal lanes)
+        if (v.size() > 0) {
+            detectorLength += v.back().distanceTo2D(shape.front());
+        }
         v.insert(v.end(), shape.begin(), shape.end());
     }
-
     // build geometry
-    myFullGeometry = v.getSubpart(detector.getStartPos(), detector.getStartPos() + detector.getLength());
+    myFullGeometry = v.getSubpart(
+                         lanes.front()->interpolateLanePosToGeometryPos(detector.getStartPos()),
+                         lanes.back()->interpolateLanePosToGeometryPos(detector.getStartPos() + detectorLength));
     //
     myShapeRotations.reserve(myFullGeometry.size() - 1);
     myShapeLengths.reserve(myFullGeometry.size() - 1);
@@ -162,7 +160,7 @@ GUIE2Collector::MyWrapper::drawGL(const GUIVisualizationSettings& s) const {
     glPushMatrix();
     glTranslated(0, 0, getType());
     double dwidth = 1;
-    const double exaggeration = s.addSize.getExaggeration(s);
+    const double exaggeration = s.addSize.getExaggeration(s, this);
     if (exaggeration > 0) {
         if (myDetector.getUsageType() == DU_TL_CONTROL) {
             dwidth = (double) 0.3;
