@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUILane.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <utility>
@@ -68,6 +62,12 @@
 //#define GUILane_DEBUG_DRAW_VERTICES
 //#define GUILane_DEBUG_DRAW_FOE_INTERSECTIONS
 
+// ===========================================================================
+// static member declaration
+// ===========================================================================
+const RGBColor GUILane::MESO_USE_LANE_COLOR(0, 0, 0, 0);
+
+
 // ===========================================================================
 // method definitions
 // ===========================================================================
@@ -77,6 +77,9 @@ GUILane::GUILane(const std::string& id, double maxSpeed, double length,
                  SVCPermissions permissions, int index, bool isRampAccel) :
     MSLane(id, maxSpeed, length, edge, numericalID, shape, width, permissions, index, isRampAccel),
     GUIGlObject(GLO_LANE, id),
+#ifdef HAVE_OSG
+    myGeom(0),
+#endif
     myAmClosed(false) {
     if (MSGlobals::gUseMesoSim) {
         myShape = splitAtSegments(shape);
@@ -94,8 +97,8 @@ GUILane::GUILane(const std::string& id, double maxSpeed, double length,
         myShapeRotations.push_back(RAD2DEG(atan2(s.x() - f.x(), f.y() - s.y())));
     }
     //
-    myHalfLaneWidth = (double)(myWidth / 2.);
-    myQuarterLaneWidth = (double)(myWidth / 4.);
+    myHalfLaneWidth = myWidth / 2.;
+    myQuarterLaneWidth = myWidth / 4.;
 }
 
 
@@ -137,6 +140,12 @@ GUILane::planMovements(const SUMOTime t) {
     MSLane::planMovements(t);
 }
 
+void
+GUILane::setJunctionApproaches(const SUMOTime t) {
+    AbstractMutex::ScopedLocker locker(myLock);
+    MSLane::setJunctionApproaches(t);
+}
+
 
 bool
 GUILane::executeMovements(SUMOTime t, std::vector<MSLane*>& into) {
@@ -233,10 +242,16 @@ GUILane::drawTLSLinkNo(const GUIVisualizationSettings& s, const GUINet& net) con
         // draw indices at the start and end of the crossing
         MSLink* link = MSLinkContHelper::getConnectingLink(*getLogicalPredecessorLane(), *this);
         int linkNo = net.getLinkTLIndex(link);
+        // maybe the reverse link is controlled separately
+        int linkNo2 = net.getLinkTLIndex(myLinks.front());
+        // otherwise, use the same index as the forward link
+        if (linkNo2 < 0) {
+            linkNo2 = linkNo;
+        }
         if (linkNo >= 0) {
             PositionVector shape = getShape();
             shape.extrapolate(0.5); // draw on top of the walking area
-            GLHelper::drawTextAtEnd(toString(linkNo), shape, 0, s.drawLinkTLIndex.size, s.drawLinkTLIndex.color);
+            GLHelper::drawTextAtEnd(toString(linkNo2), shape, 0, s.drawLinkTLIndex.size, s.drawLinkTLIndex.color);
             GLHelper::drawTextAtEnd(toString(linkNo), shape.reverse(), 0, s.drawLinkTLIndex.size, s.drawLinkTLIndex.color);
         }
         return;
@@ -261,15 +276,19 @@ void
 GUILane::drawLinkRules(const GUIVisualizationSettings& s, const GUINet& net) const {
     int noLinks = (int)myLinks.size();
     if (noLinks == 0) {
-        drawLinkRule(s, net, 0, getShape(), 0, 0);
+        drawLinkRule(s, net, nullptr, getShape(), 0, 0);
         return;
     }
     if (getEdge().isCrossing()) {
         // draw rules at the start and end of the crossing
         MSLink* link = MSLinkContHelper::getConnectingLink(*getLogicalPredecessorLane(), *this);
+        MSLink* link2 = myLinks.front();
+        if (link2->getTLLogic() == nullptr) {
+            link2 = link;
+        }
         PositionVector shape = getShape();
         shape.extrapolate(0.5); // draw on top of the walking area
-        drawLinkRule(s, net, link, shape, 0, myWidth);
+        drawLinkRule(s, net, link2, shape, 0, myWidth);
         drawLinkRule(s, net, link, shape.reverse(), 0, myWidth);
         return;
     }
@@ -282,6 +301,25 @@ GUILane::drawLinkRules(const GUIVisualizationSettings& s, const GUINet& net) con
         drawLinkRule(s, net, myLinks[lefthand ? noLinks - 1 - i : i], getShape(), x1, x2);
         x1 = x2;
     }
+    // draw stopOffset for passenger cars
+    if (myStopOffsets.size() != 0 && (myStopOffsets.begin()->first & SVC_PASSENGER) != 0) {
+        const double stopOffsetPassenger = myStopOffsets.begin()->second;
+        const Position& end = myShape.back();
+        const Position& f = myShape[-2];
+        const double rot = RAD2DEG(atan2((end.x() - f.x()), (f.y() - end.y())));
+        GLHelper::setColor(s.getLinkColor(LINKSTATE_MAJOR));
+        glPushMatrix();
+        glTranslated(end.x(), end.y(), 0);
+        glRotated(rot, 0, 0, 1);
+        glTranslated(0, stopOffsetPassenger, 0);
+        glBegin(GL_QUADS);
+        glVertex2d(-myHalfLaneWidth, 0.0);
+        glVertex2d(-myHalfLaneWidth, 0.2);
+        glVertex2d(myHalfLaneWidth, 0.2);
+        glVertex2d(myHalfLaneWidth, 0.0);
+        glEnd();
+        glPopMatrix();
+    }
 }
 
 
@@ -290,7 +328,7 @@ GUILane::drawLinkRule(const GUIVisualizationSettings& s, const GUINet& net, MSLi
     const Position& end = shape.back();
     const Position& f = shape[-2];
     const double rot = RAD2DEG(atan2((end.x() - f.x()), (f.y() - end.y())));
-    if (link == 0) {
+    if (link == nullptr) {
         GLHelper::setColor(GUIVisualizationSettings::getLinkColor(LINKSTATE_DEADEND));
         glPushMatrix();
         glTranslated(end.x(), end.y(), 0);
@@ -315,12 +353,12 @@ GUILane::drawLinkRule(const GUIVisualizationSettings& s, const GUINet& net, MSLi
             case LINKSTATE_TL_YELLOW_MAJOR:
             case LINKSTATE_TL_YELLOW_MINOR:
             case LINKSTATE_TL_OFF_BLINKING:
+            case LINKSTATE_TL_OFF_NOSIGNAL:
                 glPushName(net.getLinkTLID(link));
                 break;
             case LINKSTATE_MAJOR:
             case LINKSTATE_MINOR:
             case LINKSTATE_EQUAL:
-            case LINKSTATE_TL_OFF_NOSIGNAL:
             default:
                 glPushName(getGlID());
                 break;
@@ -360,7 +398,7 @@ GUILane::drawArrows() const {
     for (std::vector<MSLink*>::const_iterator i = myLinks.begin(); i != myLinks.end(); ++i) {
         LinkDirection dir = (*i)->getDirection();
         LinkState state = (*i)->getState();
-        if (state == LINKSTATE_TL_OFF_NOSIGNAL || dir == LINKDIR_NODIR) {
+        if (state == LINKSTATE_DEADEND || dir == LINKDIR_NODIR) {
             continue;
         }
         switch (dir) {
@@ -409,16 +447,24 @@ GUILane::drawArrows() const {
 
 
 void
-GUILane::drawLane2LaneConnections() const {
+GUILane::drawLane2LaneConnections(double exaggeration) const {
+    Position centroid;
+    if (exaggeration > 1) {
+        centroid = myEdge->getToJunction()->getShape().getCentroid();
+    }
     for (std::vector<MSLink*>::const_iterator i = myLinks.begin(); i != myLinks.end(); ++i) {
         const MSLane* connected = (*i)->getLane();
-        if (connected == 0) {
+        if (connected == nullptr) {
             continue;
         }
         GLHelper::setColor(GUIVisualizationSettings::getLinkColor((*i)->getState()));
         glBegin(GL_LINES);
-        const Position& p1 = getShape()[-1];
-        const Position& p2 = connected->getShape()[0];
+        Position p1 = getShape()[-1];
+        Position p2 = connected->getShape()[0];
+        if (exaggeration > 1) {
+            p1 = centroid + ((p1 - centroid) * exaggeration);
+            p2 = centroid + ((p2 - centroid) * exaggeration);
+        }
         glVertex2d(p1.x(), p1.y());
         glVertex2d(p2.x(), p2.y());
         glEnd();
@@ -442,7 +488,7 @@ GUILane::drawGL(const GUIVisualizationSettings& s) const {
     } else {
         exaggeration *= s.laneScaler.getScheme().getColor(getScaleValue(s.laneScaler.getActive()));
     }
-    const bool drawDetails =  s.scale * exaggeration > 5 && !s.drawForSelecting;
+    const bool drawDetails =  (s.scale * exaggeration > 5 || s.junctionSize.minSize == 0) && !s.drawForSelecting;
     if (isCrossing || isWalkingArea) {
         // draw internal lanes on top of junctions
         glTranslated(0, 0, GLO_JUNCTION + 0.1);
@@ -468,43 +514,58 @@ GUILane::drawGL(const GUIVisualizationSettings& s) const {
     // recognize full transparency and simply don't draw
     GLfloat color[4];
     glGetFloatv(GL_CURRENT_COLOR, color);
-    if (color[3] != 0 && s.scale * exaggeration > s.laneMinSize &&
-            // only show one edge for a pair of superposed rail edges
-            (myEdge->getMyOppositeSuperposableEdge() == 0
-             || s.showLaneDirection
-             || myEdge->getNumericalID() < myEdge->getMyOppositeSuperposableEdge()->getNumericalID())) {
+    bool hiddenBidi = myEdge->getBidiEdge() != nullptr && myEdge->getNumericalID() > myEdge->getBidiEdge()->getNumericalID();
+    if (color[3] != 0 && s.scale * exaggeration > s.laneMinSize) {
+        // scale tls-controlled lane2lane-arrows along with their junction shapes
+        double junctionExaggeration = 1;
+        if (!isInternal
+                && myEdge->getToJunction()->getType() <= NODETYPE_RAIL_CROSSING
+                && (s.junctionSize.constantSize || s.junctionSize.exaggeration > 1)) {
+            junctionExaggeration = MAX2(1.001, s.junctionSize.getExaggeration(s, this, 4));
+        }
         // draw lane
         // check whether it is not too small
-        if (s.scale * exaggeration < 1.) {
-            if (myShapeColors.size() > 0) {
-                GLHelper::drawLine(myShape, myShapeColors);
-            } else {
-                GLHelper::drawLine(myShape);
+        if (s.scale * exaggeration < 1. && junctionExaggeration == 1 && s.junctionSize.minSize != 0) {
+            if (!isInternal) {
+                if (myShapeColors.size() > 0) {
+                    GLHelper::drawLine(myShape, myShapeColors);
+                } else {
+                    GLHelper::drawLine(myShape);
+                }
             }
             glPopMatrix();
         } else {
             GUINet* net = (GUINet*) MSNet::getInstance();
-            if (drawAsRailway(s)) {
-                // draw as railway
-                const double halfRailWidth = 0.725 * exaggeration;
+            if (hiddenBidi) {
+                // do not draw shape
+            } else if (drawAsRailway(s)) {
+                // draw as railway: assume standard gauge of 1435mm when lane width is not set
+                // draw foot width 150mm, assume that distance between rail feet inner sides is reduced on both sides by 39mm with regard to the gauge
+                // assume crosstie length of 181% gauge (2600mm for standard gauge)
+                const double width = myWidth;
+                const double halfGauge = 0.5 * (width == SUMO_const_laneWidth ?  1.4350 : width) * exaggeration;
+                const double halfInnerFeetWidth = halfGauge - 0.039 * exaggeration;
+                const double halfRailWidth = halfInnerFeetWidth + 0.15 * exaggeration;
+                const double halfCrossTieWidth = halfGauge * 1.81;
                 if (myShapeColors.size() > 0) {
                     GLHelper::drawBoxLines(myShape, myShapeRotations, myShapeLengths, myShapeColors, halfRailWidth);
                 } else {
                     GLHelper::drawBoxLines(myShape, myShapeRotations, myShapeLengths, halfRailWidth);
                 }
+                // Draw white on top with reduced width (the area between the two tracks)
                 glColor3d(1, 1, 1);
                 glTranslated(0, 0, .1);
-                GLHelper::drawBoxLines(myShape, myShapeRotations, myShapeLengths, halfRailWidth - 0.2);
+                GLHelper::drawBoxLines(myShape, myShapeRotations, myShapeLengths, halfInnerFeetWidth);
                 setColor(s);
-                drawCrossties(0.3 * exaggeration, 1 * exaggeration, 1 * exaggeration);
+                GLHelper::drawCrossTies(myShape, myShapeRotations, myShapeLengths, 0.26 * exaggeration, 0.6 * exaggeration, halfCrossTieWidth, s.drawForSelecting);
             } else if (isCrossing) {
-                if (s.drawCrossingsAndWalkingareas) {
+                if (s.drawCrossingsAndWalkingareas && (s.scale > 3.0 || s.junctionSize.minSize == 0)) {
                     glTranslated(0, 0, .2);
-                    drawCrossties(0.5, 1.0, getWidth() * 0.5);
+                    GLHelper::drawCrossTies(myShape, myShapeRotations, myShapeLengths, 0.5, 1.0, getWidth() * 0.5, s.drawForSelecting);
                     glTranslated(0, 0, -.2);
                 }
             } else if (isWalkingArea) {
-                if (s.drawCrossingsAndWalkingareas) {
+                if (s.drawCrossingsAndWalkingareas && (s.scale > 3.0 || s.junctionSize.minSize == 0)) {
                     glTranslated(0, 0, .2);
                     if (s.scale * exaggeration < 20.) {
                         GLHelper::drawFilledPoly(myShape, true);
@@ -517,7 +578,10 @@ GUILane::drawGL(const GUIVisualizationSettings& s) const {
 #endif
                 }
             } else {
-                const double halfWidth = isInternal ? myQuarterLaneWidth : myHalfLaneWidth;
+                // we draw the lanes with reduced width so that the lane markings below are visible
+                // (this avoids artifacts at geometry corners without having to
+                // compute lane-marking intersection points)
+                const double halfWidth = isInternal ? myQuarterLaneWidth : (myHalfLaneWidth - SUMO_const_laneMarkWidth / 2);
                 mustDrawMarkings = !isInternal && myPermissions != 0 && myPermissions != SVC_PEDESTRIAN && exaggeration == 1.0 && !isWaterway(myPermissions);
                 const int cornerDetail = drawDetails && !isInternal ? (int)(s.scale * exaggeration) : 0;
                 const double offset = halfWidth * MAX2(0., (exaggeration - 1));
@@ -536,62 +600,67 @@ GUILane::drawGL(const GUIVisualizationSettings& s) const {
             }
 #endif
             glPopMatrix();
-            // draw ROWs (not for inner lanes)
-            if ((!isInternal || isCrossing) && (drawDetails || s.drawForSelecting)) {
+            // draw details
+            if ((!isInternal || isCrossing || !s.drawJunctionShape) && (drawDetails || s.drawForSelecting || junctionExaggeration > 1)) {
                 glPushMatrix();
                 glTranslated(0, 0, GLO_JUNCTION); // must draw on top of junction shape
                 glTranslated(0, 0, .5);
                 if (drawDetails) {
-                    if (MSGlobals::gLateralResolution > 0 && s.showSublanes) {
-                        // draw sublane-borders
-                        GLHelper::setColor(GLHelper::getColor().changedBrightness(51));
-                        for (double offset = -myHalfLaneWidth; offset < myHalfLaneWidth; offset += MSGlobals::gLateralResolution) {
-                            GLHelper::drawBoxLines(myShape, myShapeRotations, myShapeLengths, 0.01, 0, -offset);
-                        }
-                    }
-                    if (s.showLinkDecals && !drawAsRailway(s) && !drawAsWaterway(s) && myPermissions != SVC_PEDESTRIAN) {
-                        drawArrows();
-                    }
-                    if (s.showLane2Lane) {
-                        // this should be independent to the geometry:
-                        //  draw from end of first to the begin of second
-                        drawLane2LaneConnections();
-                    }
                     if (s.showLaneDirection) {
                         if (drawAsRailway(s)) {
                             // improve visibility of superposed rail edges
-                            setColor(s);
+                            GLHelper::setColor(setColor(s).changedBrightness(100));
                         } else {
                             glColor3d(0.3, 0.3, 0.3);
                         }
-                        drawDirectionIndicators();
+                        if (!isCrossing || s.drawCrossingsAndWalkingareas) {
+                            drawDirectionIndicators(exaggeration);
+                        }
+                    }
+                    if (!isInternal) {
+                        if (MSGlobals::gLateralResolution > 0 && s.showSublanes && !hiddenBidi) {
+                            // draw sublane-borders
+                            GLHelper::setColor(GLHelper::getColor().changedBrightness(51));
+                            for (double offset = -myHalfLaneWidth; offset < myHalfLaneWidth; offset += MSGlobals::gLateralResolution) {
+                                GLHelper::drawBoxLines(myShape, myShapeRotations, myShapeLengths, 0.01, 0, -offset);
+                            }
+                        }
+                        if (s.showLinkDecals && !drawAsRailway(s) && !drawAsWaterway(s) && myPermissions != SVC_PEDESTRIAN) {
+                            drawArrows();
+                        }
+                        glTranslated(0, 0, 1000);
+                        if (s.drawLinkJunctionIndex.show) {
+                            drawLinkNo(s);
+                        }
+                        if (s.drawLinkTLIndex.show) {
+                            drawTLSLinkNo(s, *net);
+                        }
+                        glTranslated(0, 0, -1000);
                     }
                     glTranslated(0, 0, .1);
-                    if (s.drawLinkJunctionIndex.show) {
-                        drawLinkNo(s);
-                    }
-                    if (s.drawLinkTLIndex.show) {
-                        drawTLSLinkNo(s, *net);
-                    }
                 }
                 // make sure link rules are drawn so tls can be selected via right-click
-                if (s.showLinkRules) {
+                if (s.showLinkRules && (drawDetails || s.drawForSelecting)) {
                     drawLinkRules(s, *net);
                 }
+                if ((drawDetails || junctionExaggeration > 1) && s.showLane2Lane) {
+                    //  draw from end of first to the begin of second but respect junction scaling
+                    drawLane2LaneConnections(junctionExaggeration);
+                }
                 glPopMatrix();
             }
         }
-        if (mustDrawMarkings && drawDetails && s.laneShowBorders) { // needs matrix reset
+        if (mustDrawMarkings && drawDetails && s.laneShowBorders && !hiddenBidi) { // needs matrix reset
             drawMarkings(s, exaggeration);
         }
-        if (drawDetails && isInternal && myPermissions == SVC_BICYCLE && exaggeration == 1.0 && s.showLinkDecals && s.laneShowBorders) {
+        if (drawDetails && isInternal && s.showBikeMarkings && myPermissions == SVC_BICYCLE && exaggeration == 1.0 && s.showLinkDecals && s.laneShowBorders && !hiddenBidi) {
             drawBikeMarkings();
         }
     } else {
         glPopMatrix();
     }
     // draw vehicles
-    if (s.scale * s.vehicleSize.getExaggeration(s) > s.vehicleSize.minSize) {
+    if (s.scale * s.vehicleSize.getExaggeration(s, nullptr) > s.vehicleSize.minSize) {
         // retrieve vehicles from lane; disallow simulation
         const MSLane::VehCont& vehicles = getVehiclesSecure();
         for (MSLane::VehCont::const_iterator v = vehicles.begin(); v != vehicles.end(); ++v) {
@@ -617,19 +686,24 @@ GUILane::drawMarkings(const GUIVisualizationSettings& s, double scale) const {
     setColor(s);
     // optionally draw inverse markings
     if (myIndex > 0 && (myEdge->getLanes()[myIndex - 1]->getPermissions() & myPermissions) != 0) {
-        double mw = (myHalfLaneWidth + SUMO_const_laneOffset + .01) * scale * (MSNet::getInstance()->lefthand() ? -1 : 1);
+        double mw = (myHalfLaneWidth + SUMO_const_laneMarkWidth) * scale;
+        double mw2 = (myHalfLaneWidth - SUMO_const_laneMarkWidth) * scale;
+        if (MSNet::getInstance()->lefthand()) {
+            mw *= -1;
+            mw2 *= -1;
+        }
         int e = (int) getShape().size() - 1;
         for (int i = 0; i < e; ++i) {
             glPushMatrix();
-            glTranslated(getShape()[i].x(), getShape()[i].y(), 0.1);
+            glTranslated(getShape()[i].x(), getShape()[i].y(), 2.1);
             glRotated(myShapeRotations[i], 0, 0, 1);
             for (double t = 0; t < myShapeLengths[i]; t += 6) {
                 const double length = MIN2((double)3, myShapeLengths[i] - t);
                 glBegin(GL_QUADS);
                 glVertex2d(-mw, -t);
                 glVertex2d(-mw, -t - length);
-                glVertex2d(myQuarterLaneWidth * scale, -t - length);
-                glVertex2d(myQuarterLaneWidth * scale, -t);
+                glVertex2d(-mw2, -t - length);
+                glVertex2d(-mw2, -t);
                 glEnd();
             }
             glPopMatrix();
@@ -641,7 +715,7 @@ GUILane::drawMarkings(const GUIVisualizationSettings& s, double scale) const {
         getShape(),
         getShapeRotations(),
         getShapeLengths(),
-        (myHalfLaneWidth + SUMO_const_laneOffset) * scale);
+        (myHalfLaneWidth + SUMO_const_laneMarkWidth) * scale);
     glPopMatrix();
 }
 
@@ -650,11 +724,12 @@ void
 GUILane::drawBikeMarkings() const {
     // draw bike lane markings onto the intersection
     glColor3d(1, 1, 1);
-    int e = (int) getShape().size() - 1;
-    double mw = (myHalfLaneWidth + SUMO_const_laneOffset);
+    const int e = (int) getShape().size() - 1;
+    const double markWidth = 0.1;
+    const double mw = myHalfLaneWidth;
     for (int i = 0; i < e; ++i) {
         glPushMatrix();
-        glTranslated(getShape()[i].x(), getShape()[i].y(), GLO_JUNCTION + 0.1);
+        glTranslated(getShape()[i].x(), getShape()[i].y(), GLO_JUNCTION + 0.4);
         glRotated(myShapeRotations[i], 0, 0, 1);
         for (double t = 0; t < myShapeLengths[i]; t += 0.5) {
             // left and right marking
@@ -662,8 +737,8 @@ GUILane::drawBikeMarkings() const {
                 glBegin(GL_QUADS);
                 glVertex2d(side * mw, -t);
                 glVertex2d(side * mw, -t - 0.35);
-                glVertex2d(side * (mw + SUMO_const_laneOffset), -t - 0.35);
-                glVertex2d(side * (mw + SUMO_const_laneOffset), -t);
+                glVertex2d(side * (mw + markWidth), -t - 0.35);
+                glVertex2d(side * (mw + markWidth), -t);
                 glEnd();
             }
         }
@@ -672,44 +747,23 @@ GUILane::drawBikeMarkings() const {
 }
 
 void
-GUILane::drawCrossties(double length, double spacing, double halfWidth) const {
-    glPushMatrix();
-    // draw on top of of the white area between the rails
-    glTranslated(0, 0, 0.1);
-    int e = (int) getShape().size() - 1;
-    for (int i = 0; i < e; ++i) {
-        glPushMatrix();
-        glTranslated(getShape()[i].x(), getShape()[i].y(), 0.0);
-        glRotated(myShapeRotations[i], 0, 0, 1);
-        for (double t = 0; t < myShapeLengths[i]; t += spacing) {
-            glBegin(GL_QUADS);
-            glVertex2d(-halfWidth, -t);
-            glVertex2d(-halfWidth, -t - length);
-            glVertex2d(halfWidth, -t - length);
-            glVertex2d(halfWidth, -t);
-            glEnd();
-        }
-        glPopMatrix();
-    }
-    glPopMatrix();
-}
-
-
-void
-GUILane::drawDirectionIndicators() const {
+GUILane::drawDirectionIndicators(double exaggeration) const {
     glPushMatrix();
     glTranslated(0, 0, GLO_EDGE);
     int e = (int) getShape().size() - 1;
+    const double w = MAX2(POSITION_EPS, myWidth);
+    const double w2 = MAX2(POSITION_EPS, myHalfLaneWidth);
+    const double w4 = MAX2(POSITION_EPS, myQuarterLaneWidth);
     for (int i = 0; i < e; ++i) {
         glPushMatrix();
         glTranslated(getShape()[i].x(), getShape()[i].y(), 0.1);
         glRotated(myShapeRotations[i], 0, 0, 1);
-        for (double t = 0; t < myShapeLengths[i]; t += myWidth) {
-            const double length = MIN2((double)myHalfLaneWidth, myShapeLengths[i] - t);
+        for (double t = 0; t < myShapeLengths[i]; t += w) {
+            const double length = MIN2(w2, myShapeLengths[i] - t) * exaggeration;
             glBegin(GL_TRIANGLES);
             glVertex2d(0, -t - length);
-            glVertex2d(-myQuarterLaneWidth, -t);
-            glVertex2d(+myQuarterLaneWidth, -t);
+            glVertex2d(-w4 * exaggeration, -t);
+            glVertex2d(+w4 * exaggeration, -t);
             glEnd();
         }
         glPopMatrix();
@@ -744,44 +798,42 @@ GUILane::debugDrawFoeIntersections() const {
 
 // ------ inherited from GUIGlObject
 GUIGLObjectPopupMenu*
-GUILane::getPopUpMenu(GUIMainWindow& app,
-                      GUISUMOAbstractView& parent) {
+GUILane::getPopUpMenu(GUIMainWindow& app, GUISUMOAbstractView& parent) {
     GUIGLObjectPopupMenu* ret = new GUIGLObjectPopupMenu(app, parent, *this);
     buildPopupHeader(ret, app);
     buildCenterPopupEntry(ret);
     //
-    new FXMenuCommand(ret, "Copy edge name to clipboard", 0, ret, MID_COPY_EDGE_NAME);
+    new FXMenuCommand(ret, "Copy edge name to clipboard", nullptr, ret, MID_COPY_EDGE_NAME);
     buildNameCopyPopupEntry(ret);
     buildSelectionPopupEntry(ret);
     //
     buildShowParamsPopupEntry(ret, false);
     const double pos = interpolateGeometryPosToLanePos(myShape.nearest_offset_to_point2D(parent.getPositionInformation()));
     const double height = myShape.positionAtOffset2D(myShape.nearest_offset_to_point2D(parent.getPositionInformation())).z();
-    new FXMenuCommand(ret, ("pos: " + toString(pos) + " height: " + toString(height)).c_str(), 0, 0, 0);
+    new FXMenuCommand(ret, ("pos: " + toString(pos) + " height: " + toString(height)).c_str(), nullptr, nullptr, 0);
     new FXMenuSeparator(ret);
     buildPositionCopyEntry(ret, false);
     new FXMenuSeparator(ret);
     if (myAmClosed) {
         if (myPermissionChanges.empty()) {
-            new FXMenuCommand(ret, "Reopen lane", 0, &parent, MID_CLOSE_LANE);
-            new FXMenuCommand(ret, "Reopen edge", 0, &parent, MID_CLOSE_EDGE);
+            new FXMenuCommand(ret, "Reopen lane", nullptr, &parent, MID_CLOSE_LANE);
+            new FXMenuCommand(ret, "Reopen edge", nullptr, &parent, MID_CLOSE_EDGE);
         } else {
-            new FXMenuCommand(ret, "Reopen lane (override rerouter)", 0, &parent, MID_CLOSE_LANE);
-            new FXMenuCommand(ret, "Reopen edge (override rerouter)", 0, &parent, MID_CLOSE_EDGE);
+            new FXMenuCommand(ret, "Reopen lane (override rerouter)", nullptr, &parent, MID_CLOSE_LANE);
+            new FXMenuCommand(ret, "Reopen edge (override rerouter)", nullptr, &parent, MID_CLOSE_EDGE);
         }
     } else {
-        new FXMenuCommand(ret, "Close lane", 0, &parent, MID_CLOSE_LANE);
-        new FXMenuCommand(ret, "Close edge", 0, &parent, MID_CLOSE_EDGE);
+        new FXMenuCommand(ret, "Close lane", nullptr, &parent, MID_CLOSE_LANE);
+        new FXMenuCommand(ret, "Close edge", nullptr, &parent, MID_CLOSE_EDGE);
     }
-    new FXMenuCommand(ret, "Add rerouter", 0, &parent, MID_ADD_REROUTER);
+    new FXMenuCommand(ret, "Add rerouter", nullptr, &parent, MID_ADD_REROUTER);
     return ret;
 }
 
 
 GUIParameterTableWindow*
-GUILane::getParameterWindow(GUIMainWindow& app,
-                            GUISUMOAbstractView&) {
-    GUIParameterTableWindow* ret = new GUIParameterTableWindow(app, *this, 14);
+GUILane::getParameterWindow(GUIMainWindow& app, GUISUMOAbstractView&) {
+    GUIParameterTableWindow* ret = new GUIParameterTableWindow(app, *this, 16 + (int)myEdge->getParametersMap().size());
     // add items
     ret->mkItem("maxspeed [m/s]", false, getSpeedLimit());
     ret->mkItem("length [m]", false, myLength);
@@ -792,12 +844,18 @@ GUILane::getParameterWindow(GUIMainWindow& app,
     ret->mkItem("routing speed [m/s]", true, new FunctionBinding<MSEdge, double>(myEdge, &MSEdge::getRoutingSpeed));
     ret->mkItem("brutto occupancy [%]", true, new FunctionBinding<GUILane, double>(this, &GUILane::getBruttoOccupancy, 100.));
     ret->mkItem("netto occupancy [%]", true, new FunctionBinding<GUILane, double>(this, &GUILane::getNettoOccupancy, 100.));
+    ret->mkItem("pending insertions [#]", true, new FunctionBinding<GUILane, double>(this, &GUILane::getPendingEmits));
     ret->mkItem("edge type", false, myEdge->getEdgeType());
     ret->mkItem("priority", false, myEdge->getPriority());
     ret->mkItem("allowed vehicle class", false, getVehicleClassNames(myPermissions));
     ret->mkItem("disallowed vehicle class", false, getVehicleClassNames(~myPermissions));
     ret->mkItem("permission code", false, myPermissions);
-    // close building
+    if (myEdge->getBidiEdge() != nullptr) {
+        ret->mkItem("bidi-edge", false, myEdge->getBidiEdge()->getID());
+    }
+    for (const auto& kv : myEdge->getParametersMap()) {
+        ret->mkItem(("edgeParam:" + kv.first).c_str(), false, kv.second);
+    }
     ret->closeBuilding();
     return ret;
 }
@@ -815,11 +873,6 @@ GUILane::getCenteringBoundary() const {
 }
 
 
-
-
-
-
-
 const PositionVector&
 GUILane::getShape() const {
     return myShape;
@@ -876,38 +929,67 @@ GUILane::getLoadedEdgeWeight() const {
 }
 
 
-void
+RGBColor
 GUILane::setColor(const GUIVisualizationSettings& s) const {
-    if (MSGlobals::gUseMesoSim) {
-        GLHelper::setColor(static_cast<const GUIEdge*>(myEdge)->getMesoColor());
+    // setting and retrieving the color does not work in OSGView so we return it explicitliy
+    RGBColor col;
+    if (MSGlobals::gUseMesoSim && static_cast<const GUIEdge*>(myEdge)->getMesoColor() != MESO_USE_LANE_COLOR) {
+        col = static_cast<const GUIEdge*>(myEdge)->getMesoColor();
     } else {
         const GUIColorer& c = s.laneColorer;
-        if (!setFunctionalColor(c.getActive()) && !setMultiColor(c)) {
-            GLHelper::setColor(c.getScheme().getColor(getColorValue(c.getActive())));
+        if (!setFunctionalColor(c, col) && !setMultiColor(s, c, col)) {
+            col = c.getScheme().getColor(getColorValue(s, c.getActive()));
         }
     }
+    GLHelper::setColor(col);
+    return col;
 }
 
 
 bool
-GUILane::setFunctionalColor(int activeScheme) const {
+GUILane::setFunctionalColor(const GUIColorer& c, RGBColor& col, int activeScheme) const {
+    if (activeScheme < 0) {
+        activeScheme = c.getActive();
+    }
     switch (activeScheme) {
         case 0:
             if (myEdge->isCrossing()) {
                 // determine priority to decide color
                 MSLink* link = MSLinkContHelper::getConnectingLink(*getLogicalPredecessorLane(), *this);
-                if (link->havePriority() || link->getTLLogic() != 0) {
-                    GLHelper::setColor(RGBColor(230, 230, 230));
+                if (link->havePriority() || link->getTLLogic() != nullptr) {
+                    col = RGBColor(230, 230, 230);
                 } else {
-                    GLHelper::setColor(RGBColor(26, 26, 26));
+                    col = RGBColor(26, 26, 26);
                 }
+                GLHelper::setColor(col);
                 return true;
             } else {
                 return false;
             }
         case 18: {
             double hue = GeomHelper::naviDegree(myShape.beginEndAngle()); // [0-360]
-            GLHelper::setColor(RGBColor::fromHSV(hue, 1., 1.));
+            col = RGBColor::fromHSV(hue, 1., 1.);
+            GLHelper::setColor(col);
+            return true;
+        }
+        case 30: { // taz color
+            col = c.getScheme().getColor(0);
+            std::vector<RGBColor> tazColors;
+            for (MSEdge* e: myEdge->getPredecessors()) {
+                if (e->isTazConnector() && e->knowsParameter("tazColor")) {
+                    tazColors.push_back(RGBColor::parseColor(e->getParameter("tazColor")));
+                }
+            }
+            for (MSEdge* e: myEdge->getSuccessors()) {
+                if (e->isTazConnector() && e->knowsParameter("tazColor")) {
+                    tazColors.push_back(RGBColor::parseColor(e->getParameter("tazColor")));
+                }
+            }
+            if (tazColors.size() > 0) {
+                int randColor = RandHelper::rand((int)tazColors.size(), RGBColor::getColorRNG());
+                col = tazColors[randColor];
+            }
+            GLHelper::setColor(col);
             return true;
         }
         default:
@@ -917,7 +999,7 @@ GUILane::setFunctionalColor(int activeScheme) const {
 
 
 bool
-GUILane::setMultiColor(const GUIColorer& c) const {
+GUILane::setMultiColor(const GUIVisualizationSettings& s, const GUIColorer& c, RGBColor& col) const {
     const int activeScheme = c.getActive();
     myShapeColors.clear();
     switch (activeScheme) {
@@ -925,12 +1007,15 @@ GUILane::setMultiColor(const GUIColorer& c) const {
             for (PositionVector::const_iterator ii = myShape.begin(); ii != myShape.end() - 1; ++ii) {
                 myShapeColors.push_back(c.getScheme().getColor(ii->z()));
             }
+            // osg fallback (edge height at start)
+            col = c.getScheme().getColor(getColorValue(s, 21));
             return true;
         case 24: // color by inclination  at segment start
             for (int ii = 1; ii < (int)myShape.size(); ++ii) {
                 const double inc = (myShape[ii].z() - myShape[ii - 1].z()) / MAX2(POSITION_EPS, myShape[ii].distanceTo2D(myShape[ii - 1]));
                 myShapeColors.push_back(c.getScheme().getColor(inc));
             }
+            col = c.getScheme().getColor(getColorValue(s, 23));
             return true;
         default:
             return false;
@@ -939,7 +1024,7 @@ GUILane::setMultiColor(const GUIColorer& c) const {
 
 
 double
-GUILane::getColorValue(int activeScheme) const {
+GUILane::getColorValue(const GUIVisualizationSettings& s, int activeScheme) const {
     switch (activeScheme) {
         case 0:
             switch (myPermissions) {
@@ -952,16 +1037,18 @@ GUILane::getColorValue(int activeScheme) const {
                 case SVC_SHIP:
                     return 4;
                 case SVC_AUTHORITY:
-                    return 6;
+                    return 7;
                 default:
                     break;
             }
             if (myEdge->isTazConnector()) {
-                return 7;
-            } else if ((myPermissions & SVC_PASSENGER) != 0 || isRailway(myPermissions)) {
+                return 8;
+            } else if (isRailway(myPermissions)) {
+                return 5;
+            } else if ((myPermissions & SVC_PASSENGER) != 0) {
                 return 0;
             } else {
-                return 5;
+                return 6;
             }
         case 1:
             return isLaneOrEdgeSelected();
@@ -1037,7 +1124,25 @@ GUILane::getColorValue(int activeScheme) const {
         case 28:
             return getElectricityConsumption() / myLength;
         case 29:
-            return MSNet::getInstance()->getInsertionControl().getPendingEmits(this);
+            return getPendingEmits();
+        case 31: {
+            // by numerical edge param value
+            try {
+                return StringUtils::toDouble(myEdge->getParameter(s.edgeParam, "0"));
+            } catch (NumberFormatException&) {
+                WRITE_WARNING("Edge parameter '" + myEdge->getParameter(s.edgeParam, "0") + "' key '" + s.edgeParam + "' is not a number for edge '" + myEdge->getID() + "'");
+                return 0;
+            }
+        }
+        case 32: {
+            // by numerical lane param value
+            try {
+                return StringUtils::toDouble(getParameter(s.laneParam, "0"));
+            } catch (NumberFormatException&) {
+                WRITE_WARNING("Lane parameter '" + getParameter(s.laneParam, "0") + "' key '" + s.laneParam + "' is not a number for lane '" + getID() + "'");
+                return 0;
+            }
+        }
     }
     return 0;
 }
@@ -1115,20 +1220,24 @@ GUILane::getScaleValue(int activeScheme) const {
 
 bool
 GUILane::drawAsRailway(const GUIVisualizationSettings& s) const {
-    return isRailway(myPermissions) && s.showRails;
+    return isRailway(myPermissions) && s.showRails && !s.drawForSelecting;
 }
 
 
 bool
 GUILane::drawAsWaterway(const GUIVisualizationSettings& s) const {
-    return isWaterway(myPermissions) && s.showRails; // reusing the showRails setting
+    return isWaterway(myPermissions) && s.showRails && !s.drawForSelecting; // reusing the showRails setting
 }
 
 
 #ifdef HAVE_OSG
 void
 GUILane::updateColor(const GUIVisualizationSettings& s) {
-    const RGBColor& col = s.laneColorer.getScheme().getColor(getColorValue(s.laneColorer.getActive()));
+    if (myGeom == 0) {
+        // not drawn
+        return;
+    }
+    const RGBColor col = setColor(s);
     osg::Vec4ubArray* colors = dynamic_cast<osg::Vec4ubArray*>(myGeom->getColorArray());
     (*colors)[0].set(col.red(), col.green(), col.blue(), col.alpha());
     myGeom->setColorArray(colors);
@@ -1148,6 +1257,9 @@ GUILane::closeTraffic(bool rebuildAllowed) {
     myAmClosed = !myAmClosed;
     if (rebuildAllowed) {
         getEdge().rebuildAllowedLanes();
+        for (MSEdge* const pred : getEdge().getPredecessors()) {
+            pred->rebuildAllowedTargets();
+        }
     }
 }
 
@@ -1187,5 +1299,10 @@ GUILane::isLaneOrEdgeSelected() const {
     return isSelected() || gSelected.isSelected(GLO_EDGE, dynamic_cast<GUIEdge*>(myEdge)->getGlID());
 }
 
-/****************************************************************************/
+double
+GUILane::getPendingEmits() const {
+    return MSNet::getInstance()->getInsertionControl().getPendingEmits(this);
+}
 
+
+/****************************************************************************/
