@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUILane.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <fx.h>
 #include <string>
@@ -94,7 +88,7 @@ public:
      * @note Inherited from GUIGlObject
      * @return This object's parent id
      */
-    const std::string& getParentName() const {
+    std::string getParentName() const {
         return getEdge().getID();
     }
 
@@ -131,6 +125,10 @@ public:
         first; the access will be granted at the end of this method */
     void planMovements(const SUMOTime t);
 
+    /** the same as in MSLane, but locks the access for the visualisation
+        first; the access will be granted at the end of this method */
+    void setJunctionApproaches(const SUMOTime t);
+
     /** the same as in MSLane, but locks the access for the visualisation
         first; the access will be granted at the end of this method */
     bool executeMovements(SUMOTime t, std::vector<MSLane*>& into);
@@ -222,11 +220,8 @@ public:
     /// @brief bike lane markings on top of an intersection
     void drawBikeMarkings() const;
 
-    /// @brief draw crossties for railroads or pedestrian crossings
-    void drawCrossties(double length, double spacing, double halfWidth) const;
-
     /// @brief direction indicators for lanes
-    void drawDirectionIndicators() const;
+    void drawDirectionIndicators(double exaggeration) const;
 
     /// @brief draw intersection positions of foe internal lanes with this one
     void debugDrawFoeIntersections() const;
@@ -258,11 +253,16 @@ public:
     }
 
     /// @brief gets the color value according to the current scheme index
-    double getColorValue(int activeScheme) const;
+    double getColorValue(const GUIVisualizationSettings& s, int activeScheme) const;
 
     /// @brief whether this lane is selected in the GUI
     bool isSelected() const;
 
+    /* @brief sets the color according to the current scheme index and some lane function
+     * @param[in] id override active scheme when calling from meso gui
+     */
+    bool setFunctionalColor(const GUIColorer& c, RGBColor& col, int activeScheme=-1) const;
+
 protected:
     /// moves myTmpVehicles int myVehicles after a lane change procedure
     void swapAfterLaneChange(SUMOTime t);
@@ -290,25 +290,25 @@ private:
     void drawLinkRules(const GUIVisualizationSettings& s, const GUINet& net) const;
     void drawLinkRule(const GUIVisualizationSettings& s, const GUINet& net, MSLink* link, const PositionVector& shape, double x1, double x2) const;
     void drawArrows() const;
-    void drawLane2LaneConnections() const;
+    void drawLane2LaneConnections(double exaggeration) const;
 
 
     /// @brief add intermediate points at segment borders
     PositionVector splitAtSegments(const PositionVector& shape);
 
+    /// @brief get number of vehicles waiting for departure on this lane
+    double getPendingEmits() const;
+
 private:
 
     /// @brief gets the scaling value according to the current scheme index
     double getScaleValue(int activeScheme) const;
 
-    /// @brief sets the color according to the current scheme index and some lane function
-    bool setFunctionalColor(int activeScheme) const;
-
     /// @brief sets multiple colors according to the current scheme index and some lane function
-    bool setMultiColor(const GUIColorer& c) const;
+    bool setMultiColor(const GUIVisualizationSettings& s, const GUIColorer& c, RGBColor& col) const;
 
     /// @brief sets the color according to the currente settings
-    void setColor(const GUIVisualizationSettings& s) const;
+    RGBColor setColor(const GUIVisualizationSettings& s) const;
 
     /// @brief whether to draw this lane as a railway
     bool drawAsRailway(const GUIVisualizationSettings& s) const;
@@ -348,6 +348,9 @@ private:
     /// The mutex used to avoid concurrent updates of the vehicle buffer
     mutable MFXMutex myLock;
 
+    /// @brief special color to signify alternative coloring scheme
+    static const RGBColor MESO_USE_LANE_COLOR;
+
 
 };
 
