@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUINet.cpp
 /// @author  Daniel Krajzewicz
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utility>
 #include <set>
@@ -78,7 +72,8 @@ template MFXMutex GLObjectValuePassConnector<std::pair<int, class MSPhaseDefinit
 // member method definitions
 // ===========================================================================
 GUINet::GUINet(MSVehicleControl* vc, MSEventControl* beginOfTimestepEvents,
-               MSEventControl* endOfTimestepEvents, MSEventControl* insertionEvents) :
+               MSEventControl* endOfTimestepEvents,
+               MSEventControl* insertionEvents) :
     MSNet(vc, beginOfTimestepEvents, endOfTimestepEvents, insertionEvents, new GUIShapeContainer(myGrid)),
     GUIGlObject(GLO_NETWORK, ""),
     myLastSimDuration(0), /*myLastVisDuration(0),*/ myLastIdleDuration(0),
@@ -117,7 +112,7 @@ GUINet::getBoundary() const {
 
 MSTransportableControl&
 GUINet::getPersonControl() {
-    if (myPersonControl == 0) {
+    if (myPersonControl == nullptr) {
         myPersonControl = new GUITransportableControl();
     }
     return *myPersonControl;
@@ -126,7 +121,7 @@ GUINet::getPersonControl() {
 
 MSTransportableControl&
 GUINet::getContainerControl() {
-    if (myContainerControl == 0) {
+    if (myContainerControl == nullptr) {
         myContainerControl = new GUITransportableControl();
     }
     return *myContainerControl;
@@ -146,15 +141,15 @@ GUINet::initTLMap() {
 }
 
 
-GUIGlID
+void
 GUINet::createTLWrapper(MSTrafficLightLogic* tll) {
     if (myLogics2Wrapper.count(tll) > 0) {
-        return myLogics2Wrapper[tll]->getGlID();
+        return;
     }
     // get the links
     const MSTrafficLightLogic::LinkVectorVector& links = tll->getLinks();
     if (links.size() == 0) { // @legacy this should never happen in 0.13.0+ networks
-        return 0;
+        return;
     }
     // build the wrapper
     GUITrafficLightLogicWrapper* tllw =
@@ -169,7 +164,7 @@ GUINet::createTLWrapper(MSTrafficLightLogic* tll) {
     }
     myGrid.addAdditionalGLObject(tllw);
     myLogics2Wrapper[tll] = tllw;
-    return tllw->getGlID();
+    return;
 }
 
 
@@ -182,7 +177,7 @@ GUINet::getJunctionPosition(const std::string& name) const {
 
 bool
 GUINet::vehicleExists(const std::string& name) const {
-    return myVehicleControl->getVehicle(name) != 0;
+    return myVehicleControl->getVehicle(name) != nullptr;
 }
 
 
@@ -262,7 +257,7 @@ GUINet::initGUIStructures() {
     for (std::vector<SumoXMLTag>::const_iterator i = types.begin(); i != types.end(); ++i) {
         for (const auto& j : myDetectorControl->getTypedDetectors(*i)) {
             GUIDetectorWrapper* wrapper = j.second->buildDetectorGUIRepresentation();
-            if (wrapper != 0) {
+            if (wrapper != nullptr) {
                 myDetectorWrapper.push_back(wrapper);
                 myGrid.addAdditionalGLObject(wrapper);
             }
@@ -427,18 +422,20 @@ GUINet::getParameterWindow(GUIMainWindow& app,
     ret->mkItem("running vehicles [#]", true,
                 new FunctionBinding<MSVehicleControl, int>(&getVehicleControl(), &MSVehicleControl::getRunningVehicleNo));
     ret->mkItem("arrived vehicles [#]", true,
-                new FunctionBinding<MSVehicleControl, int>(&getVehicleControl(), &MSVehicleControl::getEndedVehicleNo));
+                new FunctionBinding<MSVehicleControl, int>(&getVehicleControl(), &MSVehicleControl::getArrivedVehicleNo));
+    ret->mkItem("discarded vehicles [#]", true,
+                new FunctionBinding<MSVehicleControl, int>(&getVehicleControl(), &MSVehicleControl::getDiscardedVehicleNo));
     ret->mkItem("collisions [#]", true,
                 new FunctionBinding<MSVehicleControl, int>(&getVehicleControl(), &MSVehicleControl::getCollisionCount));
     ret->mkItem("teleports [#]", true,
                 new FunctionBinding<MSVehicleControl, int>(&getVehicleControl(), &MSVehicleControl::getTeleportCount));
     ret->mkItem("halting [#]", true,
-                new FunctionBinding<MSNet, int>(this, &GUINet::getHaltingVehicleNumber));
+                new FunctionBinding<MSVehicleControl, int>(&getVehicleControl(), &MSVehicleControl::getHaltingVehicleNo));
     ret->mkItem("avg. speed [m/s]", true,
-                new FunctionBinding<MSNet, double>(this, &GUINet::getVehicleMeanSpeed));
+                new FunctionBinding<MSVehicleControl, double>(&getVehicleControl(), &MSVehicleControl::getVehicleMeanSpeed));
     ret->mkItem("avg. relative speed", true,
-                new FunctionBinding<MSNet, double>(this, &GUINet::getVehicleMeanSpeedRelative));
-    if (myPersonControl != 0) {
+                new FunctionBinding<MSVehicleControl, double>(&getVehicleControl(), &MSVehicleControl::getVehicleMeanSpeedRelative));
+    if (myPersonControl != nullptr) {
         ret->mkItem("loaded persons [#]", true,
                     new FunctionBinding<MSTransportableControl, int>(&getPersonControl(), &MSTransportableControl::getLoadedNumber));
         ret->mkItem("running persons [#]", true,
@@ -473,7 +470,7 @@ GUINet::getParameterWindow(GUIMainWindow& app,
             ret->mkItem("avg. trip time loss [s]", true, new FunctionBinding<GUINet, double>(this, &GUINet::getAvgTimeLoss));
             ret->mkItem("avg. trip depart delay [s]", true, new FunctionBinding<GUINet, double>(this, &GUINet::getAvgDepartDelay));
             ret->mkItem("avg. trip speed [m/s]", true, new FunctionBinding<GUINet, double>(this, &GUINet::getAvgTripSpeed));
-            if (myPersonControl != 0) {
+            if (myPersonControl != nullptr) {
                 ret->mkItem("avg. walk length [m]", true, new FunctionBinding<GUINet, double>(this, &GUINet::getAvgWalkRouteLength));
                 ret->mkItem("avg. walk duration [s]", true, new FunctionBinding<GUINet, double>(this, &GUINet::getAvgWalkDuration));
                 ret->mkItem("avg. walk time loss [s]", true, new FunctionBinding<GUINet, double>(this, &GUINet::getAvgWalkTimeLoss));
@@ -505,7 +502,7 @@ GUINet::getCenteringBoundary() const {
 GUINet*
 GUINet::getGUIInstance() {
     GUINet* net = dynamic_cast<GUINet*>(MSNet::getInstance());
-    if (net != 0) {
+    if (net != nullptr) {
         return net;
     }
     throw ProcessError("A gui-network was not yet constructed.");
