@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUINet.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <utility>
@@ -98,7 +92,8 @@ public:
      * @exception ProcessError If a network was already constructed
      */
     GUINet(MSVehicleControl* vc, MSEventControl* beginOfTimestepEvents,
-           MSEventControl* endOfTimestepEvents, MSEventControl* insertionEvents);
+           MSEventControl* endOfTimestepEvents,
+           MSEventControl* insertionEvents);
 
 
     /// @brief Destructor
@@ -327,14 +322,14 @@ public:
      */
     static GUINet* getGUIInstance();
 
+    /// @brief creates a wrapper for the given logic
+    void createTLWrapper(MSTrafficLightLogic* tll);
+
 
 private:
     /// @brief Initialises the tl-logic map and wrappers
     void initTLMap();
 
-    /// @brief creates a wrapper for the given logic and returns the GlID
-    GUIGlID createTLWrapper(MSTrafficLightLogic* tll);
-
     friend class GUIOSGBuilder;
 
 protected:
