@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIParkingArea.cpp
 /// @author  Mirco Sturari
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <utils/common/MsgHandler.h>
@@ -61,9 +55,10 @@
 // ===========================================================================
 GUIParkingArea::GUIParkingArea(const std::string& id, const std::vector<std::string>& lines, MSLane& lane,
                                double frompos, double topos, unsigned int capacity,
-                               double width, double length, double angle) :
-    MSParkingArea(id, lines, lane, frompos, topos, capacity, width, length, angle),
-    GUIGlObject_AbstractAdd("parkingArea", GLO_TRIGGER, id) {
+                               double width, double length, double angle, const std::string& name,
+                               bool onRoad) :
+    MSParkingArea(id, lines, lane, frompos, topos, capacity, width, length, angle, name, onRoad),
+    GUIGlObject_AbstractAdd(GLO_PARKING_AREA, id) {
     const double offsetSign = MSNet::getInstance()->lefthand() ? -1 : 1;
     myShapeRotations.reserve(myShape.size() - 1);
     myShapeLengths.reserve(myShape.size() - 1);
@@ -82,6 +77,8 @@ GUIParkingArea::GUIParkingArea(const std::string& id, const std::vector<std::str
         mySignRot = myShape.rotationDegreeAtOffset(double((myShape.length() / 2.)));
         mySignRot -= 90;
     }
+    myBoundary = myShape.getBoxBoundary();
+    myBoundary.grow(20);
 }
 
 GUIParkingArea::~GUIParkingArea() {}
@@ -105,8 +102,9 @@ GUIParameterTableWindow*
 GUIParkingArea::getParameterWindow(GUIMainWindow& app,
                                    GUISUMOAbstractView&) {
     GUIParameterTableWindow* ret =
-        new GUIParameterTableWindow(app, *this, 4);
+        new GUIParameterTableWindow(app, *this, 5);
     // add items
+    ret->mkItem("name", false, getMyName());
     ret->mkItem("begin position [m]", false, myBegPos);
     ret->mkItem("end position [m]", false, myEndPos);
     ret->mkItem("occupancy [#]", true, getOccupancy());
@@ -130,19 +128,18 @@ GUIParkingArea::drawGL(const GUIVisualizationSettings& s) const {
     GLHelper::setColor(blue);
     GLHelper::drawBoxLines(myShape, myShapeRotations, myShapeLengths, myWidth / 2.);
     // draw details unless zoomed out to far
-    const double exaggeration = s.addSize.getExaggeration(s);
+    const double exaggeration = s.addSize.getExaggeration(s, this);
     if (s.scale * exaggeration >= 1) {
         // draw the lots
         glTranslated(0, 0, .1);
-        std::map<unsigned int, LotSpaceDefinition >::const_iterator i;
-        for (i = mySpaceOccupancies.begin(); i != mySpaceOccupancies.end(); i++) {
+        for (const auto& lsd : mySpaceOccupancies) {
             glPushMatrix();
-            glTranslated((*i).second.myPosition.x(), (*i).second.myPosition.y(), (*i).second.myPosition.z());
-            glRotated((*i).second.myRotation, 0, 0, 1);
-            Position pos = (*i).second.myPosition;
+            glTranslated(lsd.myPosition.x(), lsd.myPosition.y(), lsd.myPosition.z());
+            glRotated(lsd.myRotation, 0, 0, 1);
+            Position pos = lsd.myPosition;
             PositionVector geom;
-            double w = (*i).second.myWidth / 2. - 0.1 * exaggeration;
-            double h = (*i).second.myLength;
+            double w = lsd.myWidth / 2. - 0.1 * exaggeration;
+            double h = lsd.myLength;
             geom.push_back(Position(- w, + 0, 0.));
             geom.push_back(Position(+ w, + 0, 0.));
             geom.push_back(Position(+ w, + h, 0.));
@@ -155,7 +152,7 @@ GUIParkingArea::drawGL(const GUIVisualizationSettings& s) const {
             geom.push_back(Position(pos.x(), pos.y() - (*l).second.myLength, pos.z()));
             geom.push_back(Position(pos.x(), pos.y(), pos.z()));
             */
-            GLHelper::setColor((*i).second.vehicle == 0 ? green : red);
+            GLHelper::setColor(lsd.vehicle == nullptr ? green : red);
             GLHelper::drawBoxLines(geom, 0.1 * exaggeration);
             glPopMatrix();
         }
@@ -190,8 +187,11 @@ GUIParkingArea::drawGL(const GUIVisualizationSettings& s) const {
         }
     }
     glPopMatrix();
+    if (s.addFullName.show && getMyName() != "") {
+        GLHelper::drawTextSettings(s.addFullName, getMyName(), mySignPos, s.scale, s.getTextAngle(mySignRot), GLO_MAX - getType());
+    }
     glPopName();
-    drawName(getCenteringBoundary().getCenter(), s.scale, s.addName);
+    drawName(getCenteringBoundary().getCenter(), s.scale, s.addName, s.angle);
     for (std::vector<MSTransportable*>::const_iterator i = myWaitingTransportables.begin(); i != myWaitingTransportables.end(); ++i) {
         glTranslated(0, 1, 0); // make multiple containers viewable
         static_cast<GUIContainer*>(*i)->drawGL(s);
@@ -205,15 +205,19 @@ GUIParkingArea::drawGL(const GUIVisualizationSettings& s) const {
 
 }
 
+void 
+GUIParkingArea::addLotEntry(double x, double y, double z,
+        double width, double length, double angle) {
+    MSParkingArea::addLotEntry(x, y, z, width, length, angle);
+    Boundary b;
+    b.add(Position(x,y));
+    b.grow(MAX2(width, length) + 5);
+    myBoundary.add(b);
+}
 
 Boundary
 GUIParkingArea::getCenteringBoundary() const {
-    Boundary b = myShape.getBoxBoundary();
-    for (std::map<unsigned int, LotSpaceDefinition >::const_iterator i = mySpaceOccupancies.begin(); i != mySpaceOccupancies.end(); i++) {
-        b.add((*i).second.myPosition);
-    }
-    b.grow(20);
-    return b;
+    return myBoundary;
 }
 
 
