@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIParkingArea.h
 /// @author  Mirco Sturari
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <string>
@@ -40,7 +34,6 @@
 #include <utils/gui/globjects/GUIGLObjectPopupMenu.h>
 #include <utils/geom/Position.h>
 #include <gui/GUIManipulator.h>
-#include <utils/foxtools/FXRealSpinDial.h>
 
 
 // ===========================================================================
@@ -83,7 +76,8 @@ public:
     GUIParkingArea(const std::string& id,
                    const std::vector<std::string>& lines, MSLane& lane,
                    double frompos, double topos, unsigned int capacity,
-                   double width, double length, double angle);
+                   double width, double length, double angle, const std::string& name,
+                   bool onRoad);
 
 
     /// @brief Destructor
@@ -125,6 +119,9 @@ public:
      */
     Boundary getCenteringBoundary() const;
 
+    /// @brief extend boundary
+    void addLotEntry(double x, double y, double z,
+            double width, double length, double angle);
 
     /** @brief Draws the object
      * @param[in] s The settings for the current view (may influence drawing)
@@ -147,6 +144,9 @@ private:
     /// @brief The rotation of the sign
     double mySignRot;
 
+    /// @brief the centering boundary
+    Boundary myBoundary;
+
 };
 
 
