@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUITriggeredRerouter.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <utils/common/MsgHandler.h>
@@ -92,7 +86,7 @@ GUITriggeredRerouter::GUIManip_TriggeredRerouter::GUIManip_TriggeredRerouter(
     const std::string& name, GUITriggeredRerouter& o,
     int /*xpos*/, int /*ypos*/)
     : GUIManipulator(app, name, 0, 0), myParent(&app),
-      myChosenValue(0), myChosenTarget(myChosenValue, NULL, MID_OPTION),
+      myChosenValue(0), myChosenTarget(myChosenValue, nullptr, MID_OPTION),
       myUsageProbability(o.getProbability()), myUsageProbabilityTarget(myUsageProbability),
       myObject(&o) {
     myChosenTarget.setTarget(this);
@@ -118,10 +112,11 @@ GUITriggeredRerouter::GUIManip_TriggeredRerouter::GUIManip_TriggeredRerouter(
                           ICON_BEFORE_TEXT | LAYOUT_SIDE_TOP | LAYOUT_CENTER_Y,
                           0, 0, 0, 0,   2, 2, 0, 0);
         myUsageProbabilityDial =
-            new FXRealSpinDial(gf12, 10, this, MID_USER_DEF,
-                               LAYOUT_TOP | FRAME_SUNKEN | FRAME_THICK);
-        myUsageProbabilityDial->setFormatString("%.2f");
-        myUsageProbabilityDial->setIncrements(.1, .1, .1);
+            new FXRealSpinner(gf12, 10, this, MID_USER_DEF,
+                              LAYOUT_TOP | FRAME_SUNKEN | FRAME_THICK);
+        //myUsageProbabilityDial->setFormatString("%.2f");
+        //myUsageProbabilityDial->setIncrements(.1, .1, .1);
+        myUsageProbabilityDial->setIncrement(.1);
         myUsageProbabilityDial->setRange(0, 1);
         myUsageProbabilityDial->setValue(myObject->getUserProbability());
     }
@@ -137,7 +132,7 @@ GUITriggeredRerouter::GUIManip_TriggeredRerouter::GUIManip_TriggeredRerouter(
                     ? myObject->getUserProbability() > 0
                     ? 1 : 2
                     : 0;
-    new FXButton(f1, "Close", NULL, this, MID_CLOSE,
+    new FXButton(f1, "Close", nullptr, this, MID_CLOSE,
                  BUTTON_INITIAL | BUTTON_DEFAULT | FRAME_RAISED | FRAME_THICK | LAYOUT_TOP | LAYOUT_LEFT | LAYOUT_CENTER_X, 0, 0, 0, 0, 30, 30, 4, 4);
 }
 
@@ -215,18 +210,14 @@ GUITriggeredRerouter::GUITriggeredRerouterPopupMenu::onCmdOpenManip(FXObject*,
     return 1;
 }
 
+// -------------------------------------------------------------------------
+// GUITriggeredRerouter - methods
+// -------------------------------------------------------------------------
 
-/* -------------------------------------------------------------------------
- * GUITriggeredRerouter - methods
- * ----------------------------------------------------------------------- */
-GUITriggeredRerouter::GUITriggeredRerouter(
-    const std::string& id,
-    const MSEdgeVector& edges,
-    double prob, const std::string& aXMLFilename, bool off,
-    SUMOTime timeThreshold,
-    SUMORTree& rtree) :
-    MSTriggeredRerouter(id, edges, prob, aXMLFilename, off, timeThreshold),
-    GUIGlObject_AbstractAdd("rerouter", GLO_TRIGGER, id) {
+GUITriggeredRerouter::GUITriggeredRerouter(const std::string& id, const MSEdgeVector& edges, double prob,
+        const std::string& aXMLFilename, bool off, SUMOTime timeThreshold, const std::string& vTypes, SUMORTree& rtree) :
+    MSTriggeredRerouter(id, edges, prob, aXMLFilename, off, timeThreshold, vTypes),
+    GUIGlObject_AbstractAdd(GLO_REROUTER, id) {
     // add visualisation objects for edges which trigger the rerouter
     for (MSEdgeVector::const_iterator it = edges.begin(); it != edges.end(); ++it) {
         myEdgeVisualizations.push_back(new GUITriggeredRerouterEdge(dynamic_cast<GUIEdge*>(*it), this, false));
@@ -276,7 +267,7 @@ GUITriggeredRerouter::getPopUpMenu(GUIMainWindow& app,
 GUIParameterTableWindow*
 GUITriggeredRerouter::getParameterWindow(GUIMainWindow&,
         GUISUMOAbstractView&) {
-    return 0;
+    return nullptr;
 }
 
 
@@ -310,7 +301,7 @@ GUITriggeredRerouter::openManipulator(GUIMainWindow& app,
  * GUITriggeredRerouterEdge - methods
  * ----------------------------------------------------------------------- */
 GUITriggeredRerouter::GUITriggeredRerouterEdge::GUITriggeredRerouterEdge(GUIEdge* edge, GUITriggeredRerouter* parent, bool closed) :
-    GUIGlObject("rerouter_edge", GLO_TRIGGER, parent->getID() + ":" + edge->getID()),
+    GUIGlObject(GLO_REROUTER_EDGE, parent->getID() + ":" + edge->getID()),
     myParent(parent),
     myEdge(edge),
     myAmClosedEdge(closed) {
@@ -340,13 +331,13 @@ GUITriggeredRerouter::GUITriggeredRerouterEdge::getPopUpMenu(GUIMainWindow& app,
 GUIParameterTableWindow*
 GUITriggeredRerouter::GUITriggeredRerouterEdge::getParameterWindow(GUIMainWindow&,
         GUISUMOAbstractView&) {
-    return 0;
+    return nullptr;
 }
 
 
 void
 GUITriggeredRerouter::GUITriggeredRerouterEdge::drawGL(const GUIVisualizationSettings& s) const {
-    const double exaggeration = s.addSize.getExaggeration(s);
+    const double exaggeration = s.addSize.getExaggeration(s, this);
     if (s.scale * exaggeration >= 3) {
         glPushName(getGlID());
         const double prob = myParent->getProbability();
@@ -354,7 +345,7 @@ GUITriggeredRerouter::GUITriggeredRerouterEdge::drawGL(const GUIVisualizationSet
             // draw closing symbol onto all lanes
             const RerouteInterval* const ri =
                 myParent->getCurrentReroute(MSNet::getInstance()->getCurrentTimeStep());
-            if (ri != 0 && prob > 0) {
+            if (ri != nullptr && prob > 0) {
                 // draw only if the edge is closed at this time
                 if (std::find(ri->closed.begin(), ri->closed.end(), myEdge) != ri->closed.end()) {
                     const int noLanes = (int)myFGPositions.size();
