@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUITriggeredRerouter.h
 /// @author  Daniel Krajzewicz
@@ -25,17 +23,12 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <string>
 #include <foreign/rtree/SUMORTree.h>
 #include <microsim/trigger/MSTriggeredRerouter.h>
-#include <utils/foxtools/FXRealSpinDial.h>
 #include <utils/gui/globjects/GUIGlObject_AbstractAdd.h>
 #include <utils/gui/globjects/GUIGLObjectPopupMenu.h>
 #include <gui/GUIManipulator.h>
@@ -70,6 +63,7 @@ public:
                          const MSEdgeVector& edges, double prob,
                          const std::string& aXMLFilename, bool off,
                          SUMOTime timeThreshold,
+                         const std::string& vTypes,
                          SUMORTree& rtree);
 
 
@@ -257,7 +251,7 @@ public:
 
         double myUsageProbability;
 
-        FXRealSpinDial* myUsageProbabilityDial;
+        FXRealSpinner* myUsageProbabilityDial;
 
         FXDataTarget myUsageProbabilityTarget;
 
