@@ -1,25 +1,22 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    GUIVehicle.h
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @author  Sascha Krieg
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUIVehicle.h 24108 2017-04-27 18:43:30Z behrisch $
+/// @version $Id$
 ///
 // A MSVehicle extended by some values for usage within the gui
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 #ifndef GUIVehicle_h
 #define GUIVehicle_h
 
@@ -27,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <string>
@@ -68,7 +61,7 @@ public:
      * @exception ProcessError If a value is wrong
      */
     GUIVehicle(SUMOVehicleParameter* pars, const MSRoute* route,
-               const MSVehicleType* type, const double speedFactor);
+               MSVehicleType* type, const double speedFactor);
 
 
     /// @brief destructor
@@ -93,11 +86,10 @@ public:
     /** @brief Draws the route
      * @param[in] r The route to draw
      */
-    void drawRouteHelper(const MSRoute& r, double exaggeration) const;
+    void drawRouteHelper(const GUIVisualizationSettings& s, const MSRoute& r) const;
 
     void drawAction_drawVehicleBlinker(double length) const;
-    void drawAction_drawVehicleBrakeLight(double length, bool onlyOne = 1) const;
-    void drawAction_drawPersonsAndContainers(const GUIVisualizationSettings& s) const;
+    void drawAction_drawVehicleBrakeLight(double length, bool onlyOne = false) const;
     void drawAction_drawLinkItems(const GUIVisualizationSettings& s) const;
     void drawAction_drawVehicleBlueLight() const;
 
@@ -139,6 +131,24 @@ public:
     /// @brief whether this vehicle is selected in the GUI
     bool isSelected() const;
 
+    /// @brief return right vehicle side on current edge (without argument)
+    double getRightSideOnEdge2() const {
+        return getRightSideOnEdge();
+    }
+    /// @brief return left vehicle side on current edge
+    double getLeftSideOnEdge() const {
+        return getRightSideOnEdge() + getVehicleType().getWidth();
+    }
+
+    /// @brief return the righmost sublane on the edge occupied by the vehicle
+    int getRightSublaneOnEdge() const;
+    int getLeftSublaneOnEdge() const;
+
+
+    /// @brief return the lane-change maneuver distance
+    double getManeuverDist() const;
+
+
 protected:
     /// @brief register vehicle for drawing while outside the network
     void drawOutsideNetwork(bool add);
