@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIVehicleControl.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/foxtools/MFXMutex.h>
 #include <microsim/MSRouteHandler.h>
@@ -57,10 +51,7 @@ GUIVehicleControl::buildVehicle(SUMOVehicleParameter* defs,
                                 const MSRoute* route, MSVehicleType* type,
                                 const bool ignoreStopErrors, const bool fromRouteFile) {
     myLoadedVehNo++;
-    if (fromRouteFile) {
-        defs->depart += computeRandomDepartOffset();
-    }
-    MSVehicle* built = new GUIVehicle(defs, route, type, type->computeChosenSpeedDeviation(fromRouteFile ? MSRouteHandler::getParsingRNG() : 0));
+    MSVehicle* built = new GUIVehicle(defs, route, type, type->computeChosenSpeedDeviation(fromRouteFile ? MSRouteHandler::getParsingRNG() : nullptr));
     built->addStops(ignoreStopErrors);
     MSNet::getInstance()->informVehicleStateListener(built, MSNet::VEHICLE_STATE_BUILT);
     return built;
@@ -81,6 +72,20 @@ GUIVehicleControl::deleteVehicle(SUMOVehicle* veh, bool discard) {
 }
 
 
+int
+GUIVehicleControl::getHaltingVehicleNo() const {
+    AbstractMutex::ScopedLocker locker(myLock);
+    return MSVehicleControl::getHaltingVehicleNo();
+}
+
+
+std::pair<double, double>
+GUIVehicleControl::getVehicleMeanSpeeds() const {
+    AbstractMutex::ScopedLocker locker(myLock);
+    return MSVehicleControl::getVehicleMeanSpeeds();
+}
+
+
 void
 GUIVehicleControl::insertVehicleIDs(std::vector<GUIGlID>& into, bool listParking, bool listTeleporting) {
     AbstractMutex::ScopedLocker locker(myLock);
