@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    guisim_main.cpp
 /// @author  Daniel Krajzewicz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #ifdef HAVE_VERSION_H
 #include <version.h>
@@ -50,10 +44,7 @@
 #include <gui/GUIApplicationWindow.h>
 #include <utils/gui/windows/GUIAppEnum.h>
 #include <utils/gui/settings/GUICompleteSchemeStorage.h>
-
-#ifndef NO_TRACI
 #include <traci-server/TraCIServer.h>
-#endif
 
 
 // ===========================================================================
@@ -67,8 +58,9 @@ main(int argc, char** argv) {
     // get the options
     OptionsCont& oc = OptionsCont::getOptions();
     // give some application descriptions
-    oc.setApplicationDescription("GUI version of the simulation SUMO.");
-    oc.setApplicationName("sumo-gui", "SUMO gui Version " VERSION_STRING);
+    oc.setApplicationDescription("GUI version of the microscopic, multi-modal traffic simulation SUMO.");
+    oc.setApplicationName("sumo-gui", "Eclipse SUMO GUI Version " VERSION_STRING);
+    gSimulation = true;
     int ret = 0;
     try {
         // initialise subsystems
@@ -81,7 +73,7 @@ main(int argc, char** argv) {
             return 0;
         }
         // Make application
-        FXApp application("SUMO GUISimulation", "DLR");
+        FXApp application("SUMO GUI", "Eclipse");
         // Open display
         application.init(argc, argv);
         int minor, major;
@@ -121,9 +113,7 @@ main(int argc, char** argv) {
         ret = 1;
 #endif
     }
-#ifndef NO_TRACI
     TraCIServer::close();
-#endif
     SystemFrame::close();
     return ret;
 }
