@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    ROJTRRouter.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <router/RONet.h>
 #include "ROJTRRouter.h"
@@ -40,7 +34,7 @@
 // ===========================================================================
 ROJTRRouter::ROJTRRouter(bool unbuildIsWarningOnly, bool acceptAllDestinations,
                          int maxEdges, bool ignoreClasses, bool allowLoops) :
-    SUMOAbstractRouter<ROEdge, ROVehicle>(0, "JTRRouter"),
+    SUMOAbstractRouter<ROEdge, ROVehicle>("JTRRouter", &ROEdge::getTravelTimeStatic),
     myUnbuildIsWarningOnly(unbuildIsWarningOnly),
     myAcceptAllDestination(acceptAllDestinations), myMaxEdges(maxEdges),
     myIgnoreClasses(ignoreClasses), myAllowLoops(allowLoops) {
@@ -58,7 +52,7 @@ ROJTRRouter::compute(const ROEdge* from, const ROEdge* to,
     double timeS = STEPS2TIME(time);
     std::set<const ROEdge*> avoidEdges;
     // route until a sinks has been found
-    while (current != 0 && current != to &&
+    while (current != nullptr && current != to &&
             !current->isSink() &&
             (int)into.size() < myMaxEdges) {
         into.push_back(current);
@@ -66,11 +60,11 @@ ROJTRRouter::compute(const ROEdge* from, const ROEdge* to,
             avoidEdges.insert(current);
         }
         timeS += current->getTravelTime(vehicle, timeS);
-        current = current->chooseNext(myIgnoreClasses ? 0 : vehicle, timeS, avoidEdges);
+        current = current->chooseNext(myIgnoreClasses ? nullptr : vehicle, timeS, avoidEdges);
         assert(myIgnoreClasses || current == 0 || !current->prohibits(vehicle));
     }
     // check whether no valid ending edge was found
-    if (current == 0 || (int) into.size() >= myMaxEdges) {
+    if (current == nullptr || (int) into.size() >= myMaxEdges) {
         if (myAcceptAllDestination) {
             return true;
         } else {
@@ -80,24 +74,12 @@ ROJTRRouter::compute(const ROEdge* from, const ROEdge* to,
         }
     }
     // append the sink
-    if (current != 0) {
+    if (current != nullptr) {
         into.push_back(current);
     }
     return true;
 }
 
 
-double
-ROJTRRouter::recomputeCosts(const ConstROEdgeVector& edges, const ROVehicle* const v, SUMOTime msTime) const {
-    const double time = STEPS2TIME(msTime);
-    double costs = 0;
-    for (ConstROEdgeVector::const_iterator i = edges.begin(); i != edges.end(); ++i) {
-        costs += (*i)->getTravelTime(v, time);
-    }
-    return costs;
-}
-
-
-
 /****************************************************************************/
 
