@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2017-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2017-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    InductionLoop.h
 /// @author  Michael Behrisch
@@ -23,21 +21,21 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
+#include <traci-server/TraCIConstants.h>
 
 
 // ===========================================================================
 // class declarations
 // ===========================================================================
+class NamedRTree;
 class MSInductLoop;
+class PositionVector;
 namespace libsumo {
 struct TraCIVehicleData;
+class VariableWrapper;
 }
 
 
@@ -63,22 +61,33 @@ public:
     static double getTimeSinceDetection(const std::string& detID);
     static std::vector<libsumo::TraCIVehicleData> getVehicleData(const std::string& detID);
 
+    LIBSUMO_SUBSCRIPTION_API
+
     /** @brief Returns a tree filled with inductive loop instances
      * @return The rtree of inductive loops
      */
     static NamedRTree* getTree();
 
+    /** @brief Saves the shape of the requested object in the given container
+    *  @param id The id of the loop to retrieve
+    *  @param shape The container to fill
+    */
+    static void storeShape(const std::string& id, PositionVector& shape);
+
+    static std::shared_ptr<VariableWrapper> makeWrapper();
+
+    static bool handleVariable(const std::string& objID, const int variable, VariableWrapper* wrapper);
+
 private:
     static MSInductLoop* getDetector(const std::string& detID);
 
+private:
+    static SubscriptionResults mySubscriptionResults;
+    static ContextSubscriptionResults myContextSubscriptionResults;
+
+private:
     /// @brief invalidated standard constructor
-    InductionLoop();
-
-    /// @brief invalidated copy constructor
-    InductionLoop(const InductionLoop& src);
-
-    /// @brief invalidated assignment operator
-    InductionLoop& operator=(const InductionLoop& src);
+    InductionLoop() = delete;
 
 };
 }
