@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2017-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2017-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    Polygon.cpp
 /// @author  Gregor L\"ammel
@@ -22,6 +20,7 @@
 // included modules
 // ===========================================================================
 #include <microsim/MSNet.h>
+#include <traci-server/TraCIConstants.h>
 #include <utils/shapes/SUMOPolygon.h>
 #include <utils/shapes/ShapeContainer.h>
 
@@ -29,11 +28,19 @@
 #include "Helper.h"
 
 
-// ===========================================================================
-// member definitions
-// ===========================================================================
 namespace libsumo {
-std::vector<std::string> Polygon::getIDList() {
+// ===========================================================================
+// static member initializations
+// ===========================================================================
+SubscriptionResults Polygon::mySubscriptionResults;
+ContextSubscriptionResults Polygon::myContextSubscriptionResults;
+
+
+// ===========================================================================
+// static member definitions
+// ===========================================================================
+std::vector<std::string>
+Polygon::getIDList() {
     std::vector<std::string> ids;
     ShapeContainer& shapeCont = MSNet::getInstance()->getShapeContainer();
     shapeCont.getPolygons().insertIDs(ids);
@@ -41,40 +48,57 @@ std::vector<std::string> Polygon::getIDList() {
 }
 
 
-std::string Polygon::getType(const std::string& polygonID) {
-    return getPolygon(polygonID)->getType();
+int
+Polygon::getIDCount() {
+    return (int)getIDList().size();
 }
 
 
-TraCIPositionVector Polygon::getShape(const std::string& polygonID) {
+std::string
+Polygon::getType(const std::string& polygonID) {
+    return getPolygon(polygonID)->getShapeType();
+}
+
+
+TraCIPositionVector
+Polygon::getShape(const std::string& polygonID) {
     SUMOPolygon* p = getPolygon(polygonID);
     return Helper::makeTraCIPositionVector(p->getShape());
 }
 
 
-bool Polygon::getFilled(const std::string& polygonID) {
+bool
+Polygon::getFilled(const std::string& polygonID) {
     return getPolygon(polygonID)->getFill();
 }
 
+double
+Polygon::getLineWidth(const std::string& polygonID) {
+    return getPolygon(polygonID)->getLineWidth();
+}
 
-TraCIColor Polygon::getColor(const std::string& polygonID) {
+TraCIColor
+Polygon::getColor(const std::string& polygonID) {
     SUMOPolygon* p = getPolygon(polygonID);
-    return Helper::makeTraCIColor(p->getColor());
+    return Helper::makeTraCIColor(p->getShapeColor());
 }
 
 
-std::string Polygon::getParameter(const std::string& polygonID, const std::string& paramName) {
-    return getPolygon(polygonID)->getParameter(paramName, "");
+std::string
+Polygon::getParameter(const std::string& polygonID, const std::string& key) {
+    return getPolygon(polygonID)->getParameter(key, "");
 }
 
 
-void Polygon::setType(const std::string& polygonID, const std::string& setType) {
+void
+Polygon::setType(const std::string& polygonID, const std::string& setType) {
     SUMOPolygon* p = getPolygon(polygonID);
-    p->setType(setType);
+    p->setShapeType(setType);
 }
 
 
-void Polygon::setShape(const std::string& polygonID, const TraCIPositionVector& shape) {
+void
+Polygon::setShape(const std::string& polygonID, const TraCIPositionVector& shape) {
     PositionVector positionVector = Helper::makePositionVector(shape);
     getPolygon(polygonID); // just to check whether it exists
     ShapeContainer& shapeCont = MSNet::getInstance()->getShapeContainer();
@@ -82,23 +106,25 @@ void Polygon::setShape(const std::string& polygonID, const TraCIPositionVector&
 }
 
 
-void Polygon::setColor(const std::string& polygonID, const TraCIColor& c) {
-    getPolygon(polygonID)->setColor(Helper::makeRGBColor(c));
+void
+Polygon::setColor(const std::string& polygonID, const TraCIColor& c) {
+    getPolygon(polygonID)->setShapeColor(Helper::makeRGBColor(c));
 }
 
 
 void
-Polygon::add(const std::string& polygonID, const TraCIPositionVector& shape, const TraCIColor& c, bool fill, const std::string& type, int layer) {
+Polygon::add(const std::string& polygonID, const TraCIPositionVector& shape, const TraCIColor& color, bool fill, double lineWidth, const std::string& polygonType, int layer) {
     ShapeContainer& shapeCont = MSNet::getInstance()->getShapeContainer();
     PositionVector pShape = Helper::makePositionVector(shape);
-    RGBColor col = Helper::makeRGBColor(c);
-    if (!shapeCont.addPolygon(polygonID, type, col, (double)layer, Shape::DEFAULT_ANGLE, Shape::DEFAULT_IMG_FILE, pShape, false, fill)) {
+    RGBColor col = Helper::makeRGBColor(color);
+    if (!shapeCont.addPolygon(polygonID, polygonType, col, (double)layer, Shape::DEFAULT_ANGLE, Shape::DEFAULT_IMG_FILE, Shape::DEFAULT_RELATIVEPATH, pShape, false, fill, lineWidth)) {
         throw TraCIException("Could not add polygon '" + polygonID + "'");
     }
 }
 
 
-void Polygon::remove(const std::string& polygonID, int /* layer */) {
+void
+Polygon::remove(const std::string& polygonID, int /* layer */) {
     // !!! layer not used yet (shouldn't the id be enough?)
     ShapeContainer& shapeCont = MSNet::getInstance()->getShapeContainer();
     if (!shapeCont.removePolygon(polygonID)) {
@@ -113,11 +139,17 @@ Polygon::setFilled(std::string polygonID, bool filled) {
     p->setFill(filled);
 }
 
+void
+Polygon::setLineWidth(std::string polygonID, double lineWidth) {
+    SUMOPolygon* p = getPolygon(polygonID);
+    p->setLineWidth(lineWidth);
+}
+
 
 SUMOPolygon*
 Polygon::getPolygon(const std::string& id) {
     SUMOPolygon* p = MSNet::getInstance()->getShapeContainer().getPolygons().get(id);
-    if (p == 0) {
+    if (p == nullptr) {
         throw TraCIException("Polygon '" + id + "' is not known");
     }
     return p;
@@ -125,11 +157,15 @@ Polygon::getPolygon(const std::string& id) {
 
 
 void
-Polygon::setParameter(std::string& id, std::string& name, std::string& value) {
-    SUMOPolygon* p = getPolygon(id);
-    p->setParameter(name, value);
+Polygon::setParameter(const std::string& polygonID, const std::string& key, const std::string& value) {
+    SUMOPolygon* p = getPolygon(polygonID);
+    p->setParameter(key, value);
 }
 
+
+LIBSUMO_SUBSCRIPTION_IMPLEMENTATION(Polygon, POLYGON)
+
+
 NamedRTree*
 Polygon::getTree() {
     NamedRTree* t = new NamedRTree();
@@ -143,6 +179,40 @@ Polygon::getTree() {
     return t;
 }
 
+
+void
+Polygon::storeShape(const std::string& id, PositionVector& shape) {
+    shape = getPolygon(id)->getShape();
+}
+
+
+std::shared_ptr<VariableWrapper>
+Polygon::makeWrapper() {
+    return std::make_shared<Helper::SubscriptionWrapper>(handleVariable, mySubscriptionResults, myContextSubscriptionResults);
+}
+
+
+bool
+Polygon::handleVariable(const std::string& objID, const int variable, VariableWrapper* wrapper) {
+    switch (variable) {
+        case TRACI_ID_LIST:
+            return wrapper->wrapStringList(objID, variable, getIDList());
+        case ID_COUNT:
+            return wrapper->wrapInt(objID, variable, getIDCount());
+        case VAR_TYPE:
+            return wrapper->wrapString(objID, variable, getType(objID));
+        case VAR_COLOR:
+            return wrapper->wrapColor(objID, variable, getColor(objID));
+        case VAR_FILL:
+            return wrapper->wrapInt(objID, variable, getFilled(objID));
+        case VAR_WIDTH:
+            return wrapper->wrapDouble(objID, variable, getLineWidth(objID));
+        default:
+            return false;
+    }
+}
+
+
 }
 
 
