@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    ROMAEdge.cpp
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "ROMAEdge.h"
 
@@ -47,8 +41,8 @@ ROMAEdge::~ROMAEdge() {
 
 
 void
-ROMAEdge::addSuccessor(ROEdge* s, std::string dir) {
-    ROEdge::addSuccessor(s, dir);
+ROMAEdge::addSuccessor(ROEdge* s, ROEdge* via, std::string dir) {
+    ROEdge::addSuccessor(s, via, dir);
     if (dir == "l" || dir == "L") {
         myLeftTurns.insert(static_cast<ROMAEdge*>(s));
     }
