@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MEInductLoop.cpp
 /// @author  Daniel Krajzewicz
@@ -21,11 +19,7 @@
 /* =========================================================================
  * included modules
  * ======================================================================= */
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "MEInductLoop.h"
 #include <cassert>
@@ -51,7 +45,7 @@ MEInductLoop::MEInductLoop(const std::string& id,
                            const std::string& vTypes) :
     MSDetectorFileOutput(id, vTypes), mySegment(s),
     myPosition(positionInMeters),
-    myMeanData(0, mySegment->getLength(), false, 0) {
+    myMeanData(nullptr, mySegment->getLength(), false, nullptr) {
     myMeanData.setDescription("inductionLoop_" + id);
     s->addDetector(&myMeanData);
 }
