@@ -1,22 +1,19 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    MEInductLoop.h
 /// @author  Daniel Krajzewicz
 /// @date    Tue, May 2005
-/// @version $Id: MEInductLoop.h 21496 2016-09-19 10:39:08Z behrisch $
+/// @version $Id$
 ///
 // An induction loop for mesoscopic simulation
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 #ifndef MEInductLoop_h
 #define MEInductLoop_h
 
@@ -24,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <deque>
@@ -56,7 +49,7 @@ class MEInductLoop : public MSDetectorFileOutput {
 public:
     MEInductLoop(const std::string& id,
                  MESegment* s,
-                 SUMOReal positionInMeters,
+                 double positionInMeters,
                  const std::string& vTypes);
 
 
@@ -74,19 +67,19 @@ public:
      * @see MSDetectorFileOutput::writeXMLDetectorProlog
      */
     void writeXMLDetectorProlog(OutputDevice& dev) const {
-        dev.writeXMLHeader("detector");
+        dev.writeXMLHeader("detector", "det_e1meso_file.xsd");
     }
 
 
     /**
      * Get the XML-formatted output of all the get*-methods except
-     * getTimestepsSinceLastDetection.
+     * getTimeSinceLastDetection.
      *
      * @param lastNTimesteps take data out of the interval
      * (now-lastNTimesteps, now].
      *
      * @return XML-formatted output of all the get*-methods except
-     * getTimestepsSinceLastDetection.
+     * getTimeSinceLastDetection.
      *
      * @see MSDetector2File
      */
@@ -99,7 +92,7 @@ protected:
     MESegment* const mySegment;
 
     /// @brief position from the start of the edge / lane
-    const SUMOReal myPosition;
+    const double myPosition;
 
     /// @brief data collector for the loop
     MSMeanData_Net::MSLaneMeanDataValues myMeanData;
