@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MESegment.h
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <utils/common/Named.h>
@@ -127,7 +121,9 @@ public:
      *
      * @return the total number of cars on the segment
      */
-    int getCarNumber() const;
+    inline int getCarNumber() const {
+        return myNumCars;
+    }
 
     /// @brief return the number of queues
     inline int numQueues() const {
@@ -213,10 +209,10 @@ public:
      *
      * @param[in] v The vehicle to remove
      * @param[in] leaveTime The time at which the vehicle is leaving the que
-     * @param[in] next The next segment for this vehicle
+     * @param[in] reason The reason for removing to send to reminders
      * @return The next first vehicle to add to the net's que
      */
-    MEVehicle* removeCar(MEVehicle* v, SUMOTime leaveTime, MESegment* next);
+    MEVehicle* removeCar(MEVehicle* v, SUMOTime leaveTime, const MSMoveReminder::Notification reason);
 
     /** @brief Returns the link the given car will use when passing the next junction
      *
@@ -245,7 +241,7 @@ public:
      * @param[in] time the leave time
      * @todo Isn't always time == veh->getEventTime?
      */
-    void send(MEVehicle* veh, MESegment* next, SUMOTime time);
+    void send(MEVehicle* veh, MESegment* next, SUMOTime time, const MSMoveReminder::Notification reason);
 
     /** @brief Adds the vehicle to the segment, adapting its parameters
      *
@@ -293,6 +289,11 @@ public:
         return STEPS2TIME(myLastHeadway);
     }
 
+    /// @brief get the last headway time in seconds
+    inline double getEntryBlockTimeSeconds() const {
+        return STEPS2TIME(myEntryBlockTime);
+    }
+
     /// @name State saving/loading
     /// @{
 
@@ -393,14 +394,6 @@ public:
     double getTLSCapacity(const MEVehicle* veh) const;
 
 private:
-    /** @brief Updates data of all detectors for a leaving vehicle
-     *
-     * @param[in] v The vehicle to update values for
-     * @param[in] currentTime The leave time of the vehicle
-     * @param[in] next The next segment on this vehicles route
-     */
-    void updateDetectorsOnLeave(MEVehicle* v, SUMOTime currentTime, MESegment* next);
-
     bool overtake();
 
     SUMOTime getTimeHeadway(const MESegment* pred, const MEVehicle* veh);
@@ -487,6 +480,9 @@ private:
     /// @brief The car queues. Vehicles are inserted in the front and removed in the back
     Queues myCarQues;
 
+    /// @brief The cached value for the number of cars
+    int myNumCars;
+
     /// @brief The follower edge to que index mapping for multi queue segments
     std::map<const MSEdge*, std::vector<int> > myFollowerMap;
 
