@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MEVehicle.cpp
 /// @author  Daniel Krajzewicz
@@ -21,11 +19,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include <cassert>
@@ -35,12 +29,16 @@
 #include <utils/iodevices/BinaryInputDevice.h>
 #include <utils/iodevices/OutputDevice.h>
 #include <utils/xml/SUMOSAXAttributes.h>
+#include <microsim/devices/MSDevice_Vehroutes.h>
+#include <microsim/output/MSStopOut.h>
 #include <microsim/MSGlobals.h>
 #include <microsim/MSEdge.h>
 #include <microsim/MSLane.h>
 #include <microsim/MSNet.h>
 #include <microsim/MSVehicleType.h>
 #include <microsim/MSLink.h>
+#include <microsim/MSVehicleControl.h>
+#include <microsim/MSTransportableControl.h>
 #include <microsim/devices/MSDevice.h>
 #include "MELoop.h"
 #include "MEVehicle.h"
@@ -53,13 +51,13 @@
 MEVehicle::MEVehicle(SUMOVehicleParameter* pars, const MSRoute* route,
                      MSVehicleType* type, const double speedFactor) :
     MSBaseVehicle(pars, route, type, speedFactor),
-    mySegment(0),
+    mySegment(nullptr),
     myQueIndex(0),
     myEventTime(SUMOTime_MIN),
     myLastEntryTime(SUMOTime_MIN),
     myBlockTime(SUMOTime_MAX) {
     if (!(*myCurrEdge)->isTazConnector()) {
-        if ((*myCurrEdge)->allowedLanes(type->getVehicleClass()) == 0) {
+        if ((*myCurrEdge)->allowedLanes(type->getVehicleClass()) == nullptr) {
             throw ProcessError("Vehicle '" + pars->id + "' is not allowed to depart on any lane of its first edge.");
         }
         if (pars->departSpeedProcedure == DEPART_SPEED_GIVEN && pars->departSpeed > type->getMaxSpeed()) {
@@ -80,7 +78,7 @@ double
 MEVehicle::getPositionOnLane() const {
 // the following interpolation causes problems with arrivals and calibrators
 //    const double fracOnSegment = MIN2(double(1), STEPS2TIME(MSNet::getInstance()->getCurrentTimeStep() - myLastEntryTime) / STEPS2TIME(myEventTime - myLastEntryTime));
-    return mySegment == 0 ? 0 : (double(mySegment->getIndex()) /* + fracOnSegment */) * mySegment->getLength();
+    return mySegment == nullptr ? 0 : (double(mySegment->getIndex()) /* + fracOnSegment */) * mySegment->getLength();
 }
 
 
@@ -159,14 +157,14 @@ bool
 MEVehicle::hasArrived() const {
     // mySegment may be 0 due to teleporting or arrival
     return myCurrEdge == myRoute->end() - 1 && (
-               (mySegment == 0)
+               (mySegment == nullptr)
                || myEventTime == SUMOTime_MIN
                || getPositionOnLane() > myArrivalPos - POSITION_EPS);
 }
 
 bool
 MEVehicle::isOnRoad() const {
-    return getSegment() != 0;
+    return getSegment() != nullptr;
 }
 
 
@@ -177,7 +175,7 @@ MEVehicle::isParking() const {
 
 
 bool
-MEVehicle::replaceRoute(const MSRoute* newRoute, bool onInit, int offset, bool addStops, bool removeStops) {
+MEVehicle::replaceRoute(const MSRoute* newRoute, const std::string& info,  bool onInit, int offset, bool addStops, bool removeStops) {
     UNUSED_PARAMETER(addStops); // @todo recheck!
     UNUSED_PARAMETER(removeStops); // @todo recheck!
     const ConstMSEdgeVector& edges = newRoute->getEdges();
@@ -185,9 +183,9 @@ MEVehicle::replaceRoute(const MSRoute* newRoute, bool onInit, int offset, bool a
     if (!onInit && !newRoute->contains(*myCurrEdge)) {
         return false;
     }
-    MSLink* oldLink = 0;
-    MSLink* newLink = 0;
-    if (mySegment != 0) {
+    MSLink* oldLink = nullptr;
+    MSLink* newLink = nullptr;
+    if (mySegment != nullptr) {
         oldLink = mySegment->getLink(this);
     }
     // rebuild in-vehicle route information
@@ -201,11 +199,11 @@ MEVehicle::replaceRoute(const MSRoute* newRoute, bool onInit, int offset, bool a
     myRoute->release();
     // assign new route
     myRoute = newRoute;
-    if (mySegment != 0) {
+    if (mySegment != nullptr) {
         newLink = mySegment->getLink(this);
     }
     // update approaching vehicle information
-    if (oldLink != 0 && oldLink != newLink) {
+    if (oldLink != nullptr && oldLink != newLink) {
         oldLink->removeApproaching(this);
         MELoop::setApproaching(this, newLink);
     }
@@ -213,19 +211,23 @@ MEVehicle::replaceRoute(const MSRoute* newRoute, bool onInit, int offset, bool a
     calculateArrivalParams();
     // save information that the vehicle was rerouted
     myNumberReroutes++;
-    MSNet::getInstance()->informVehicleStateListener(this, MSNet::VEHICLE_STATE_NEWROUTE);
+    MSNet::getInstance()->informVehicleStateListener(this, MSNet::VEHICLE_STATE_NEWROUTE, info);
     calculateArrivalParams();
     return true;
 }
 
 
 bool
-MEVehicle::addStop(const SUMOVehicleParameter::Stop& stopPar, std::string& /*errorMsg*/, SUMOTime /* untilOffset */, bool /*collision*/,
+MEVehicle::addStop(const SUMOVehicleParameter::Stop& stopPar, std::string& /*errorMsg*/, SUMOTime untilOffset, bool /*collision*/,
                    MSRouteIterator* /* searchStart */) {
     const MSEdge* const edge = MSEdge::dictionary(stopPar.lane.substr(0, stopPar.lane.rfind('_')));
     assert(edge != 0);
     MESegment* stopSeg = MSGlobals::gMesoNet->getSegmentForEdge(*edge, stopPar.endPos);
-    myStops[stopSeg] += stopPar.duration;
+    myStops[stopSeg].push_back(stopPar);
+    if (myStops[stopSeg].back().until >= 0) {
+        myStops[stopSeg].back().until += untilOffset;
+    }
+    myStopEdges.push_back(edge);
     return true;
 }
 
@@ -250,33 +252,74 @@ MEVehicle::isStoppedInRange(double pos) const {
 
 
 SUMOTime
-MEVehicle::getStoptime(const MESegment* const seg) const {
+MEVehicle::getStoptime(const MESegment* const seg, SUMOTime time) const {
     if (myStops.find(seg) != myStops.end()) {
-        return myStops.find(seg)->second;
+        for (const SUMOVehicleParameter::Stop& stop : myStops.find(seg)->second) {
+            time += stop.duration;
+            if (stop.until > time) {
+                // @note: this assumes the stop is reached at time. With the way this is called in MESegment (time == entryTime),
+                // travel time is overestimated of the stop is not at the start of the segment
+                time = stop.until;
+            }
+        }
     }
-    return 0;
+    return time;
+}
+
+
+double
+MEVehicle::getCurrentStoppingTimeSeconds() const {
+    return STEPS2TIME(getStoptime(mySegment, myLastEntryTime) - myLastEntryTime);
 }
 
 
 const ConstMSEdgeVector
 MEVehicle::getStopEdges() const {
-    ConstMSEdgeVector result;
-    for (std::map<const MESegment* const, SUMOTime>::const_iterator iter = myStops.begin(); iter != myStops.end(); ++iter) {
-        result.push_back(&iter->first->getEdge());
+// TODO: myStopEdges still needs to be updated when leaving a stop
+    return myStopEdges;
+}
+
+
+void
+MEVehicle::processStop() {
+    assert(isStopped());
+    MSEdge* edge = const_cast<MSEdge*>(getEdge());
+    for (const SUMOVehicleParameter::Stop& stop : myStops.find(mySegment)->second) {
+        //SUMOTime started = MSNet::getInstance()->getCurrentTimeStep() - TIME2STEPS(getCurrentStoppingTimeSeconds());
+        SUMOTime started = myLastEntryTime;
+        //std::cout << SIMTIME << " veh=" << getID() << " lastEntry=" << STEPS2TIME(myLastEntryTime) << " stopStarted=" << STEPS2TIME(started) << "\n";
+        if (MSStopOut::active()) {
+            MSStopOut::getInstance()->stopStarted(this, getPersonNumber(), getContainerNumber(), started);
+        }
+        MSNet* const net = MSNet::getInstance();
+        SUMOTime dummyDuration; // boarding- and loading-time are not considered
+        if (net->hasPersons()) {
+            net->getPersonControl().boardAnyWaiting(edge, this, stop, started, dummyDuration);
+        }
+        if (net->hasContainers()) {
+            net->getContainerControl().loadAnyWaiting(edge, this, stop, started, dummyDuration);
+        }
+        MSDevice_Vehroutes* vehroutes = static_cast<MSDevice_Vehroutes*>(getDevice(typeid(MSDevice_Vehroutes)));
+        if (vehroutes != nullptr) {
+            vehroutes->stopEnded(stop);
+        }
+        if (MSStopOut::active()) {
+            MSStopOut::getInstance()->stopEnded(this, stop, mySegment->getEdge().getID());
+        }
     }
-    return result;
+    MSNet::getInstance()->getVehicleControl().removeWaiting(&mySegment->getEdge(), this);
 }
 
 
 bool
 MEVehicle::mayProceed() const {
-    return mySegment == 0 || mySegment->isOpen(this);
+    return mySegment == nullptr || mySegment->isOpen(this);
 }
 
 
 double
 MEVehicle::getCurrentLinkPenaltySeconds() const {
-    if (mySegment == 0) {
+    if (mySegment == nullptr) {
         return 0;
     } else {
         return STEPS2TIME(mySegment->getLinkPenalty(this));
@@ -343,23 +386,21 @@ MEVehicle::saveState(OutputDevice& out) {
     std::vector<SUMOTime> internals;
     internals.push_back(myDeparture);
     internals.push_back((SUMOTime)distance(myRoute->begin(), myCurrEdge));
-    internals.push_back(mySegment == 0 ? (SUMOTime) - 1 : (SUMOTime)mySegment->getIndex());
+    internals.push_back(mySegment == nullptr ? (SUMOTime) - 1 : (SUMOTime)mySegment->getIndex());
     internals.push_back((SUMOTime)getQueIndex());
     internals.push_back(myEventTime);
     internals.push_back(myLastEntryTime);
     internals.push_back(myBlockTime);
     out.writeAttr(SUMO_ATTR_STATE, toString(internals));
     // save stops and parameters
-    for (std::map<const MESegment* const, SUMOTime>::const_iterator it = myStops.begin(); it != myStops.end(); ++it) {
-        out.openTag(SUMO_TAG_STOP);
-        out.writeAttr(SUMO_ATTR_LANE, it->first->getEdge().getLanes()[0]->getID());
-        out.writeAttr(SUMO_ATTR_ENDPOS, it->first->getIndex() * it->first->getLength());
-        out.writeAttr(SUMO_ATTR_DURATION, STEPS2TIME(it->second));
-        out.closeTag();
+    for (const auto& it : myStops) {
+        for (const SUMOVehicleParameter::Stop& stop : it.second) {
+            stop.write(out);
+        }
     }
     myParameter->writeParams(out);
-    for (std::vector<MSDevice*>::const_iterator dev = myDevices.begin(); dev != myDevices.end(); ++dev) {
-        (*dev)->saveState(out);
+    for (MSDevice* dev : myDevices) {
+        dev->saveState(out);
     }
     out.closeTag();
 }
@@ -395,9 +436,9 @@ MEVehicle::loadState(const SUMOSAXAttributes& attrs, const SUMOTime offset) {
             setSegment(seg, queIndex);
         } else {
             // on teleport
-            setSegment(0, 0);
+            setSegment(nullptr, 0);
             assert(myEventTime != SUMOTime_MIN);
-            MSGlobals::gMesoNet->addLeaderCar(this, 0);
+            MSGlobals::gMesoNet->addLeaderCar(this, nullptr);
         }
     }
     if (myBlockTime != SUMOTime_MAX) {
