@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSBaseVehicle.cpp
 /// @author  Michael Behrisch
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include <cassert>
@@ -35,6 +29,7 @@
 #include <utils/common/MsgHandler.h>
 #include <utils/options/OptionsCont.h>
 #include <utils/iodevices/OutputDevice.h>
+#include <microsim/pedestrians/MSPerson.h>
 #include "MSGlobals.h"
 #include "MSTransportable.h"
 #include "MSVehicleControl.h"
@@ -46,15 +41,19 @@
 #include "MSNet.h"
 #include "devices/MSDevice.h"
 #include "devices/MSDevice_Routing.h"
+#include <microsim/devices/MSDevice_Transportable.h>
 #include "MSInsertionControl.h"
 
 // ===========================================================================
 // static members
 // ===========================================================================
 const SUMOTime MSBaseVehicle::NOT_YET_DEPARTED = SUMOTime_MAX;
+std::vector<MSTransportable*> MSBaseVehicle::myEmptyTransportableVector;
 #ifdef _DEBUG
 std::set<std::string> MSBaseVehicle::myShallTraceMoveReminders;
 #endif
+SUMOVehicle::NumericalID MSBaseVehicle::myCurrentNumericalIndex = 0;
+
 
 // ===========================================================================
 // method definitions
@@ -74,11 +73,14 @@ MSBaseVehicle::MSBaseVehicle(SUMOVehicleParameter* pars, const MSRoute* route,
     myCurrEdge(route->begin()),
     myChosenSpeedFactor(speedFactor),
     myMoveReminders(0),
+    myPersonDevice(nullptr),
+    myContainerDevice(nullptr),
     myDeparture(NOT_YET_DEPARTED),
     myDepartPos(-1),
     myArrivalPos(-1),
     myArrivalLane(-1),
-    myNumberReroutes(0)
+    myNumberReroutes(0),
+    myNumericalID(myCurrentNumericalIndex++)
 #ifdef _DEBUG
     , myTraceMoveReminders(myShallTraceMoveReminders.count(pars->id) > 0)
 #endif
@@ -89,8 +91,8 @@ MSBaseVehicle::MSBaseVehicle(SUMOVehicleParameter* pars, const MSRoute* route,
     // init devices
     MSDevice::buildVehicleDevices(*this, myDevices);
     //
-    for (std::vector< MSDevice* >::iterator dev = myDevices.begin(); dev != myDevices.end(); ++dev) {
-        myMoveReminders.push_back(std::make_pair(*dev, 0.));
+    for (MSVehicleDevice* dev : myDevices) {
+        myMoveReminders.push_back(std::make_pair(dev, 0.));
     }
     myRoute->addReference();
     if (!pars->wasSet(VEHPARS_FORCE_REROUTE)) {
@@ -110,8 +112,8 @@ MSBaseVehicle::~MSBaseVehicle() {
     if (myParameter->repetitionNumber == 0) {
         MSRoute::checkDist(myParameter->routeid);
     }
-    for (std::vector< MSDevice* >::iterator dev = myDevices.begin(); dev != myDevices.end(); ++dev) {
-        delete *dev;
+    for (MSVehicleDevice* dev : myDevices) {
+        delete dev;
     }
     delete myParameter;
 }
@@ -128,6 +130,11 @@ MSBaseVehicle::getParameter() const {
     return *myParameter;
 }
 
+void
+MSBaseVehicle::replaceParameter(const SUMOVehicleParameter* newParameter) {
+    delete myParameter;
+    myParameter = newParameter;
+}
 
 double
 MSBaseVehicle::getMaxSpeed() const {
@@ -140,7 +147,7 @@ MSBaseVehicle::succEdge(int nSuccs) const {
     if (myCurrEdge + nSuccs < myRoute->end() && std::distance(myCurrEdge, myRoute->begin()) <= nSuccs) {
         return *(myCurrEdge + nSuccs);
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
@@ -152,16 +159,17 @@ MSBaseVehicle::getEdge() const {
 
 
 void
-MSBaseVehicle::reroute(SUMOTime t, SUMOAbstractRouter<MSEdge, SUMOVehicle>& router, const bool onInit, const bool withTaz) {
+MSBaseVehicle::reroute(SUMOTime t, const std::string& info, SUMOAbstractRouter<MSEdge, SUMOVehicle>& router, const bool onInit, const bool withTaz) {
     // check whether to reroute
     const MSEdge* source = withTaz && onInit ? MSEdge::dictionary(myParameter->fromTaz + "-source") : getRerouteOrigin();
-    if (source == 0) {
+    if (source == nullptr) {
         source = getRerouteOrigin();
     }
     const MSEdge* sink = withTaz ? MSEdge::dictionary(myParameter->toTaz + "-sink") : myRoute->getLastEdge();
-    if (sink == 0) {
+    if (sink == nullptr) {
         sink = myRoute->getLastEdge();
     }
+    ConstMSEdgeVector oldEdgesRemaining(source == *myCurrEdge ? myCurrEdge : myCurrEdge + 1, myRoute->end());
     ConstMSEdgeVector edges;
     ConstMSEdgeVector stops;
     if (myParameter->via.size() == 0) {
@@ -172,7 +180,7 @@ MSBaseVehicle::reroute(SUMOTime t, SUMOAbstractRouter<MSEdge, SUMOVehicle>& rout
         for (std::vector<std::string>::const_iterator it = myParameter->via.begin(); it != myParameter->via.end(); ++it) {
             MSEdge* viaEdge = MSEdge::dictionary(*it);
             assert(viaEdge != 0);
-            if (viaEdge->allowedLanes(getVClass()) == 0) {
+            if (!viaEdge->isTazConnector() && viaEdge->allowedLanes(getVClass()) == nullptr) {
                 throw ProcessError("Vehicle '" + getID() + "' is not allowed on any lane of via edge '" + viaEdge->getID() + "'.");
             }
             stops.push_back(viaEdge);
@@ -187,6 +195,12 @@ MSBaseVehicle::reroute(SUMOTime t, SUMOAbstractRouter<MSEdge, SUMOVehicle>& rout
             if (into.size() > 0) {
                 into.pop_back();
                 edges.insert(edges.end(), into.begin(), into.end());
+                if ((*s)->isTazConnector()) {
+                    source = into.back();
+                    edges.pop_back();
+                } else {
+                    source = *s;
+                }
             } else {
                 std::string error = "Vehicle '" + getID() + "' has no valid route from edge '" + source->getID() + "' to stop edge '" + (*s)->getID() + "'.";
                 if (MSGlobals::gCheckRoutes) {
@@ -195,8 +209,8 @@ MSBaseVehicle::reroute(SUMOTime t, SUMOAbstractRouter<MSEdge, SUMOVehicle>& rout
                     WRITE_WARNING(error);
                     edges.push_back(source);
                 }
+                source = *s;
             }
-            source = *s;
         }
     }
     router.compute(source, sink, this, t, edges);
@@ -206,7 +220,15 @@ MSBaseVehicle::reroute(SUMOTime t, SUMOAbstractRouter<MSEdge, SUMOVehicle>& rout
     if (!edges.empty() && edges.back()->isTazConnector()) {
         edges.pop_back();
     }
-    replaceRouteEdges(edges, onInit);
+    const double routeCost = router.recomputeCosts(edges, this, t);
+    const double previousCost = onInit ? routeCost : router.recomputeCosts(oldEdgesRemaining, this, t);
+    const double savings = previousCost - routeCost;
+    //if (getID() == "43") std::cout << SIMTIME << " pCost=" << previousCost << " cost=" << routeCost
+    //    << " onInit=" << onInit
+    //        << " prevEdges=" << toString(oldEdgesRemaining)
+    //        << " newEdges=" << toString(edges)
+    //        << "\n";
+    replaceRouteEdges(edges, routeCost, savings, info, onInit);
     // this must be called even if the route could not be replaced
     if (onInit) {
         if (edges.empty()) {
@@ -224,7 +246,7 @@ MSBaseVehicle::reroute(SUMOTime t, SUMOAbstractRouter<MSEdge, SUMOVehicle>& rout
 
 
 bool
-MSBaseVehicle::replaceRouteEdges(ConstMSEdgeVector& edges, bool onInit, bool check, bool removeStops) {
+MSBaseVehicle::replaceRouteEdges(ConstMSEdgeVector& edges, double cost, double savings, const std::string& info, bool onInit, bool check, bool removeStops) {
     if (edges.empty()) {
         WRITE_WARNING("No route for vehicle '" + getID() + "' found.");
         return false;
@@ -252,7 +274,9 @@ MSBaseVehicle::replaceRouteEdges(ConstMSEdgeVector& edges, bool onInit, bool che
         return true;
     }
     const RGBColor& c = myRoute->getColor();
-    MSRoute* newRoute = new MSRoute(id, edges, false, &c == &RGBColor::DEFAULT_COLOR ? 0 : new RGBColor(c), std::vector<SUMOVehicleParameter::Stop>());
+    MSRoute* newRoute = new MSRoute(id, edges, false, &c == &RGBColor::DEFAULT_COLOR ? nullptr : new RGBColor(c), std::vector<SUMOVehicleParameter::Stop>());
+    newRoute->setCosts(cost);
+    newRoute->setSavings(savings);
     if (!MSRoute::dictionary(id, newRoute)) {
         delete newRoute;
         return false;
@@ -267,7 +291,7 @@ MSBaseVehicle::replaceRouteEdges(ConstMSEdgeVector& edges, bool onInit, bool che
             return false;
         }
     }
-    if (!replaceRoute(newRoute, onInit, (int)edges.size() - oldSize, false, removeStops)) {
+    if (!replaceRoute(newRoute, info, onInit, (int)edges.size() - oldSize, false, removeStops)) {
         newRoute->addReference();
         newRoute->release();
         return false;
@@ -304,23 +328,37 @@ MSBaseVehicle::hasDeparted() const {
 
 bool
 MSBaseVehicle::hasArrived() const {
-    return succEdge(1) == 0;
+    return succEdge(1) == nullptr;
 }
 
 void
 MSBaseVehicle::addPerson(MSTransportable* person) {
-    throw ProcessError("Person '" + person->getID() + "' cannot ride in vehicle '" + getID() + "' in the mesoscopic simulation.");
+    if (myPersonDevice == nullptr) {
+        myPersonDevice = MSDevice_Transportable::buildVehicleDevices(*this, myDevices, false);
+        myMoveReminders.push_back(std::make_pair(myPersonDevice, 0.));
+        if (myParameter->departProcedure == DEPART_TRIGGERED && myParameter->depart == -1) {
+            const_cast<SUMOVehicleParameter*>(myParameter)->depart = MSNet::getInstance()->getCurrentTimeStep();
+        }
+    }
+    myPersonDevice->addTransportable(person);
 }
 
 void
 MSBaseVehicle::addContainer(MSTransportable* container) {
-    throw ProcessError("Container '" + container->getID() + "' cannot ride in vehicle '" + getID() + "' in the mesoscopic simulation.");
+    if (myContainerDevice == nullptr) {
+        myContainerDevice = MSDevice_Transportable::buildVehicleDevices(*this, myDevices, true);
+        myMoveReminders.push_back(std::make_pair(myContainerDevice, 0.));
+        if (myParameter->departProcedure == DEPART_TRIGGERED && myParameter->depart == -1) {
+            const_cast<SUMOVehicleParameter*>(myParameter)->depart = MSNet::getInstance()->getCurrentTimeStep();
+        }
+    }
+    myContainerDevice->addTransportable(container);
 }
 
 bool
 MSBaseVehicle::hasValidRoute(std::string& msg, const MSRoute* route) const {
     MSRouteIterator start = myCurrEdge;
-    if (route == 0) {
+    if (route == nullptr) {
         route = myRoute;
     } else {
         start = route->begin();
@@ -328,7 +366,7 @@ MSBaseVehicle::hasValidRoute(std::string& msg, const MSRoute* route) const {
     MSRouteIterator last = route->end() - 1;
     // check connectivity, first
     for (MSRouteIterator e = start; e != last; ++e) {
-        if ((*e)->allowedLanes(**(e + 1), myType->getVehicleClass()) == 0) {
+        if ((*e)->allowedLanes(**(e + 1), myType->getVehicleClass()) == nullptr) {
             msg = "No connection between edge '" + (*e)->getID() + "' and edge '" + (*(e + 1))->getID() + "'.";
             return false;
         }
@@ -413,7 +451,10 @@ MSBaseVehicle::calculateArrivalParams() {
             }
             break;
         case ARRIVAL_POS_RANDOM:
-            myArrivalPos = RandHelper::rand(0., lastLaneLength);
+            myArrivalPos = RandHelper::rand(lastLaneLength);
+            break;
+        case ARRIVAL_POS_CENTER:
+            myArrivalPos = lastLaneLength / 2.;
             break;
         default:
             myArrivalPos = lastLaneLength;
@@ -443,14 +484,14 @@ MSBaseVehicle::getImpatience() const {
 }
 
 
-MSDevice*
+MSVehicleDevice*
 MSBaseVehicle::getDevice(const std::type_info& type) const {
-    for (std::vector<MSDevice*>::const_iterator dev = myDevices.begin(); dev != myDevices.end(); ++dev) {
-        if (typeid(**dev) == type) {
-            return *dev;
+    for (MSVehicleDevice* const dev : myDevices) {
+        if (typeid(*dev) == type) {
+            return dev;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 
@@ -461,6 +502,7 @@ MSBaseVehicle::saveState(OutputDevice& out) {
     myParameter->write(out, OptionsCont::getOptions(), SUMO_TAG_VEHICLE, getVehicleType().getID());
     // params and stops must be written in child classes since they may wish to add additional attributes first
     out.writeAttr(SUMO_ATTR_ROUTE, myRoute->getID());
+    out.writeAttr(SUMO_ATTR_SPEEDFACTOR, myChosenSpeedFactor);
     if (myParameter->wasSet(VEHPARS_FORCE_REROUTE) && !hasDeparted()) {
         out.writeAttr(SUMO_ATTR_REROUTE, true);
     }
@@ -493,10 +535,64 @@ MSBaseVehicle::addStops(const bool ignoreStopErrors) {
 }
 
 
+int
+MSBaseVehicle::getPersonNumber() const {
+    int boarded = myPersonDevice == nullptr ? 0 : myPersonDevice->size();
+    return boarded + myParameter->personNumber;
+}
+
+std::vector<std::string>
+MSBaseVehicle::getPersonIDList() const {
+    std::vector<std::string> ret;
+    const std::vector<MSTransportable*>& persons = getPersons();
+    for (std::vector<MSTransportable*>::const_iterator it_p = persons.begin(); it_p != persons.end(); ++it_p) {
+        ret.push_back((*it_p)->getID());
+    }
+    return ret;
+}
+
+int
+MSBaseVehicle::getContainerNumber() const {
+    int loaded = myContainerDevice == nullptr ? 0 : myContainerDevice->size();
+    return loaded + myParameter->containerNumber;
+}
+
+
+void
+MSBaseVehicle::removeTransportable(MSTransportable* t) {
+    const bool isPerson = dynamic_cast<MSPerson*>(t) != nullptr;
+    MSDevice_Transportable* device = isPerson ? myPersonDevice : myContainerDevice;
+    if (device != nullptr) {
+        device->removeTransportable(t);
+    }
+}
+
+
+const std::vector<MSTransportable*>&
+MSBaseVehicle::getPersons() const {
+    if (myPersonDevice == nullptr) {
+        return myEmptyTransportableVector;
+    } else {
+        return myPersonDevice->getTransportables();
+    }
+}
+
+
+const std::vector<MSTransportable*>&
+MSBaseVehicle::getContainers() const {
+    if (myContainerDevice == nullptr) {
+        return myEmptyTransportableVector;
+    } else {
+        return myContainerDevice->getTransportables();
+    }
+}
+
+
+
 bool
 MSBaseVehicle::hasDevice(const std::string& deviceName) const {
-    for (std::vector<MSDevice* >::const_iterator dev = myDevices.begin(); dev != myDevices.end(); ++dev) {
-        if ((*dev)->deviceName() == deviceName) {
+    for (MSDevice* const dev : myDevices) {
+        if (dev->deviceName() == deviceName) {
             return true;
         }
     }
@@ -525,9 +621,9 @@ MSBaseVehicle::createDevice(const std::string& deviceName) {
 
 std::string
 MSBaseVehicle::getDeviceParameter(const std::string& deviceName, const std::string& key) const {
-    for (std::vector<MSDevice* >::const_iterator dev = myDevices.begin(); dev != myDevices.end(); ++dev) {
-        if ((*dev)->deviceName() == deviceName) {
-            return (*dev)->getParameter(key);
+    for (MSVehicleDevice* const dev : myDevices) {
+        if (dev->deviceName() == deviceName) {
+            return dev->getParameter(key);
         }
     }
     throw InvalidArgument("No device of type '" + deviceName + "' exists");
@@ -536,9 +632,9 @@ MSBaseVehicle::getDeviceParameter(const std::string& deviceName, const std::stri
 
 void
 MSBaseVehicle::setDeviceParameter(const std::string& deviceName, const std::string& key, const std::string& value) {
-    for (std::vector<MSDevice* >::iterator dev = myDevices.begin(); dev != myDevices.end(); ++dev) {
-        if ((*dev)->deviceName() == deviceName) {
-            (*dev)->setParameter(key, value);
+    for (MSVehicleDevice* const dev : myDevices) {
+        if (dev->deviceName() == deviceName) {
+            dev->setParameter(key, value);
             return;
         }
     }
@@ -548,7 +644,8 @@ MSBaseVehicle::setDeviceParameter(const std::string& deviceName, const std::stri
 
 void
 MSBaseVehicle::replaceVehicleType(MSVehicleType* type) {
-    if (myType->isVehicleSpecific()) {
+    assert(type != nullptr);
+    if (myType->isVehicleSpecific() && type != myType) {
         MSNet::getInstance()->getVehicleControl().removeVType(myType);
     }
     myType = type;
