@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2010-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2010-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSBaseVehicle.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include <vector>
@@ -44,6 +38,9 @@
 // class declarations
 // ===========================================================================
 class MSLane;
+class MSDevice_Transportable;
+class MSVehicleDevice;
+
 
 // ===========================================================================
 // class definitions
@@ -89,6 +86,9 @@ public:
      */
     const SUMOVehicleParameter& getParameter() const;
 
+    /// @brief replace the vehicle parameter (deleting the old one)
+    void replaceParameter(const SUMOVehicleParameter* newParameter);
+
     /// @brief check whether the vehicle is equiped with a device of the given type
     bool hasDevice(const std::string& deviceName) const;
 
@@ -161,6 +161,11 @@ public:
         return false;
     }
 
+    virtual bool wasRemoteControlled(SUMOTime lookBack = DELTA_T) const {
+        UNUSED_PARAMETER(lookBack);
+        return false;
+    }
+
     /** @brief Returns the information whether the front of the vehhicle is on the given lane
      * @return Whether the vehicle's front is on that lane
      */
@@ -203,7 +208,7 @@ public:
      * @param[in] router The router to use
      * @see replaceRoute
      */
-    void reroute(SUMOTime t, SUMOAbstractRouter<MSEdge, SUMOVehicle>& router, const bool onInit = false, const bool withTaz = false);
+    void reroute(SUMOTime t, const std::string& info, SUMOAbstractRouter<MSEdge, SUMOVehicle>& router, const bool onInit = false, const bool withTaz = false);
 
 
     /** @brief Replaces the current route by the given edges
@@ -218,7 +223,7 @@ public:
      * @param[in] removeStops Whether stops should be removed if they do not fit onto the new route
      * @return Whether the new route was accepted
      */
-    bool replaceRouteEdges(ConstMSEdgeVector& edges, bool onInit = false, bool check = false, bool removeStops = true);
+    bool replaceRouteEdges(ConstMSEdgeVector& edges, double cost, double savings, const std::string& info, bool onInit = false, bool check = false, bool removeStops = true);
 
 
     /** @brief Returns the vehicle's acceleration
@@ -295,11 +300,26 @@ public:
     /// @brief Returns this vehicles impatience
     double getImpatience() const;
 
+    /** @brief Returns the number of persons
+     * @return The number of passengers on-board
+     */
+    int getPersonNumber() const;
+
+    /** @brief Returns the list of persons
+     * @return The list of passengers on-board
+     */
+    std::vector<std::string> getPersonIDList() const;
+
+    /** @brief Returns the number of containers
+     * @return The number of contaiers on-board
+     */
+    int getContainerNumber() const;
+
 
     /** @brief Returns this vehicle's devices
      * @return This vehicle's devices
      */
-    inline const std::vector<MSDevice*>& getDevices() const {
+    inline const std::vector<MSVehicleDevice*>& getDevices() const {
         return myDevices;
     }
 
@@ -320,6 +340,16 @@ public:
      */
     virtual void addContainer(MSTransportable* container);
 
+    /// @brief removes a person or container
+    void removeTransportable(MSTransportable* t);
+
+    /// @brief retrieve riding persons
+    const std::vector<MSTransportable*>& getPersons() const;
+
+    /// @brief retrieve riding containers
+    const std::vector<MSTransportable*>& getContainers() const;
+
+
     /** @brief Validates the current or given route
      * @param[out] msg Description why the route is not valid (if it is the case)
      * @param[in] route The route to check (or 0 if the current route shall be checked)
@@ -386,7 +416,7 @@ public:
     }
 
     /// @brief Returns a device of the given type if it exists or 0
-    MSDevice* getDevice(const std::type_info& type) const;
+    MSVehicleDevice* getDevice(const std::type_info& type) const;
 
 
     /** @brief Replaces the current vehicle type by the one given
@@ -431,6 +461,10 @@ public:
         return false;
     }
 
+    inline NumericalID getNumericalID() const {
+        return myNumericalID;
+    }
+
 protected:
     /** @brief (Re-)Calculates the arrival position and lane from the vehicle parameters
      */
@@ -472,7 +506,13 @@ protected:
     /// @}
 
     /// @brief The devices this vehicle has
-    std::vector<MSDevice*> myDevices;
+    std::vector<MSVehicleDevice*> myDevices;
+
+    /// @brief The passengers this vehicle may have
+    MSDevice_Transportable* myPersonDevice;
+
+    /// @brief The containers this vehicle may have
+    MSDevice_Transportable* myContainerDevice;
 
     /// @brief The real departure time
     SUMOTime myDeparture;
@@ -494,6 +534,13 @@ protected:
      */
     static const SUMOTime NOT_YET_DEPARTED;
 
+    static std::vector<MSTransportable*> myEmptyTransportableVector;
+
+private:
+    const NumericalID myNumericalID;
+
+    static NumericalID myCurrentNumericalIndex;
+
 private:
     /// invalidated assignment operator
     MSBaseVehicle& operator=(const MSBaseVehicle& s);
