@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSEdge.h
 /// @author  Christian Roessel
@@ -27,11 +25,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <map>
@@ -76,14 +70,15 @@ class MSTransportable;
 
 typedef std::vector<MSEdge*> MSEdgeVector;
 typedef std::vector<const MSEdge*> ConstMSEdgeVector;
+typedef std::vector<std::pair<const MSEdge*, const MSEdge*> > MSConstEdgePairVector;
 
 class MSEdge : public Named, public Parameterised {
-public:
-    /** @brief Suceeding edges (keys) and allowed lanes to reach these edges (values). */
-    typedef std::map< const MSEdge*, std::vector<MSLane*>* > AllowedLanesCont;
+private:
+    /** @brief "Map" from vehicle class to allowed lanes */
+    typedef std::vector<std::pair<SVCPermissions, const std::vector<MSLane*>* > > AllowedLanesCont;
 
-    /** @brief Map from vehicle types to lanes that may be used to reach one of the next edges */
-    typedef std::map< SUMOVehicleClass, AllowedLanesCont > ClassedAllowedLanesCont;
+    /** @brief Succeeding edges (keys) and allowed lanes to reach these edges (values). */
+    typedef std::map<const MSEdge*, AllowedLanesCont> AllowedLanesByTarget;
 
 
 public:
@@ -128,7 +123,7 @@ public:
     /* @brief returns whether initizliaing a lane change is permitted on this edge
      * @note Has to be called after all sucessors and predecessors have been set (after closeBuilding())
      */
-    bool allowsLaneChanging();
+    bool allowsLaneChanging() const;
 
     /// @name Access to the edge's lanes
     /// @{
@@ -164,7 +159,7 @@ public:
      *
      * @return This edge's lanes
      */
-    const std::vector<MSLane*>& getLanes() const {
+    inline const std::vector<MSLane*>& getLanes() const {
         return *myLanes;
     }
 
@@ -196,12 +191,13 @@ public:
      *
      * @param[in] destination The edge to reach
      * @param[in] vclass The vehicle class for which this information shall be returned
-     * @return The lanes that may be used to reach the given edge, 0 if no such lanes exist
+     * @return The lanes that may be used to reach the given edge, nullptr if no such lanes exist
      */
     const std::vector<MSLane*>* allowedLanes(const MSEdge& destination,
             SUMOVehicleClass vclass = SVC_IGNORING) const;
 
 
+
     /** @brief Get the allowed lanes for the given vehicle class.
      *
      * If there is no such edge, get 0. Then you are on the wrong edge.
@@ -237,11 +233,11 @@ public:
 
 
     /// @brief check and register the opposite superposable edge if any
-    void checkAndRegisterBiDirEdge();
+    void checkAndRegisterBiDirEdge(const std::string& bidiID="");
 
     /// @brief return opposite superposable/congruent edge, if it exist and 0 else
-    inline const MSEdge* getMyOppositeSuperposableEdge() const {
-        return myOppositingSuperposableEdge;
+    inline const MSEdge* getBidiEdge() const {
+        return myBidiEdge;
     }
 
     /// @brief return whether this edge is walking area
@@ -304,7 +300,7 @@ public:
      * This is mainly used by the taz (district) parsing
      * @param[in] edge The edge to add
      */
-    void addSuccessor(MSEdge* edge);
+    void addSuccessor(MSEdge* edge, const MSEdge* via = nullptr);
 
     /** @brief Returns the number of edges that may be reached from this edge
      * @return The number of following edges
@@ -314,18 +310,17 @@ public:
     }
 
 
-    /** @brief Returns the following edges
-     */
-    const MSEdgeVector& getSuccessors() const {
-        return mySuccessors;
-    }
-
-
     /** @brief Returns the following edges, restricted by vClass
      * @param[in] vClass The vClass for which to restrict the successors
      * @return The eligible following edges
      */
-    const MSEdgeVector& getSuccessors(SUMOVehicleClass vClass) const;
+    const MSEdgeVector& getSuccessors(SUMOVehicleClass vClass = SVC_IGNORING) const;
+
+    /** @brief Returns the following edges with internal vias, restricted by vClass
+     * @param[in] vClass The vClass for which to restrict the successors
+     * @return The eligible following edges
+     */
+    const MSConstEdgePairVector& getViaSuccessors(SUMOVehicleClass vClass = SVC_IGNORING) const;
 
 
     /** @brief Returns the number of edges this edge is connected to
@@ -354,10 +349,7 @@ public:
     }
 
 
-    void setJunctions(MSJunction* from, MSJunction* to) {
-        myFromJunction = from;
-        myToJunction = to;
-    }
+    void setJunctions(MSJunction* from, MSJunction* to);
     /// @}
 
 
@@ -555,12 +547,19 @@ public:
 
     void rebuildAllowedLanes();
 
+    void rebuildAllowedTargets(const bool updateVehicles=true);
+
 
     /** @brief optimistic air distance heuristic for use in routing
      * @param[in] other The edge to which the distance shall be returned
+     * @param[in] doBoundaryEstimate whether the distance should be estimated by looking at the distance of the bounding boxes
      * @return The distance to the other edge
      */
-    double getDistanceTo(const MSEdge* other) const;
+    double getDistanceTo(const MSEdge* other, const bool doBoundaryEstimate=false) const;
+
+
+    /// @brief return the coordinates of the center of the given stop
+    static const Position getStopPosition(const SUMOVehicleParameter::Stop& stop);
 
 
     /** @brief return the length of the edge
@@ -592,6 +591,7 @@ public:
      */
     double getVehicleMaxSpeed(const SUMOVehicle* const veh) const;
 
+
     virtual void addPerson(MSTransportable* p) const {
         myPersons.insert(p);
     }
@@ -628,6 +628,11 @@ public:
         myAmDelayed = true;
     }
 
+    // return whether there have been vehicles on this edge at least once
+    inline bool isDelayed() const {
+        return myAmDelayed;
+    }
+
     bool hasLaneChanger() const {
         return myLaneChanger != 0;
     }
@@ -635,6 +640,9 @@ public:
     /// @brief whether this edge allows changing to the opposite direction edge
     bool canChangeToOpposite();
 
+    /// @brief Returns the opposite direction edge if on exists else a nullptr
+    const MSEdge* getOppositeEdge() const;
+
     /// @brief get the mean speed
     double getMeanSpeed() const;
 
@@ -646,6 +654,11 @@ public:
         return myAmFringe;
     }
 
+    /// @brief whether this lane is selected in the GUI
+    virtual bool isSelected() const {
+        return false;
+    }
+
     /// @brief grant exclusive access to the mesoscopic state
     virtual void lock() const {}
 
@@ -711,7 +724,7 @@ protected:
 
         /// @brief comparing operator
         int operator()(const MSEdge* const e1, const MSEdge* const e2) const {
-            return e1->getID() < e2->getID();
+            return e1->getNumericalID() < e2->getNumericalID();
         }
 
     };
@@ -731,22 +744,6 @@ protected:
     };
 
 
-    /** @brief Get the allowed lanes to reach the destination-edge.
-     *
-     * If there is no such edge, get 0. Then you are on the wrong edge.
-     *
-     * @param[in] destination The edge to reach
-     * @param[in] vclass The vehicle class for which this information shall be returned
-     * @return The lanes that may be used to reach the given edge, 0 if no such lanes exist
-     */
-    const std::vector<MSLane*>* allowedLanes(const MSEdge* destination,
-            SUMOVehicleClass vclass = SVC_IGNORING) const;
-
-
-    /// @brief lookup in map and return 0 if not found
-    const std::vector<MSLane*>* getAllowedLanesWithDefault(const AllowedLanesCont& c, const MSEdge* dest) const;
-
-
     /// @brief return upper bound for the depart position on this edge
     double getDepartPosBound(const MSVehicle& veh, bool upper = true) const;
 
@@ -780,6 +777,8 @@ protected:
     /// @brief The succeeding edges
     MSEdgeVector mySuccessors;
 
+    MSConstEdgePairVector myViaSuccessors;
+
     /// @brief The preceeding edges
     MSEdgeVector myPredecessors;
 
@@ -796,12 +795,11 @@ protected:
     /// @name Storages for allowed lanes (depending on vehicle classes)
     /// @{
 
-    /// @brief Associative container from destination-edge to allowed-lanes.
+    /// @brief Associative container from vehicle class to allowed-lanes.
     AllowedLanesCont myAllowed;
 
-    /// @brief From vehicle class to lanes allowed to be used by it
-    // @note: this map is filled on demand
-    mutable ClassedAllowedLanesCont myClassedAllowed;
+    /// @brief From target edge to lanes allowed to be used to reach it
+    AllowedLanesByTarget myAllowedTargets;
 
     /// @brief The intersection of lane permissions for this edge
     SVCPermissions myMinimumPermissions;
@@ -860,13 +858,16 @@ protected:
     /// @brief The successors available for a given vClass
     mutable std::map<SUMOVehicleClass, MSEdgeVector> myClassesSuccessorMap;
 
-    /// @brief The bounding rectangle of incoming or outgoing edges for taz connectors
-    Boundary myTazBoundary;
+    /// @brief The successors available for a given vClass
+    mutable std::map<SUMOVehicleClass, MSConstEdgePairVector> myClassesViaSuccessorMap;
+
+    /// @brief The bounding rectangle of end nodes incoming or outgoing edges for taz connectors or of my own start and end node for normal edges
+    Boundary myBoundary;
 
 private:
 
     /// @brief the oppositing superposble edge
-    const MSEdge* myOppositingSuperposableEdge;
+    const MSEdge* myBidiEdge;
 
     /// @brief Invalidated copy constructor.
     MSEdge(const MSEdge&);
@@ -875,6 +876,8 @@ private:
     MSEdge& operator=(const MSEdge&);
 
     bool isSuperposable(const MSEdge* other);
+
+    void addToAllowed(const SVCPermissions permissions, const std::vector<MSLane*>* allowedLanes, AllowedLanesCont& laneCont) const;
 };
 
 
