@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSEdgeControl.cpp
 /// @author  Christian Roessel
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "MSEdgeControl.h"
 #include "MSGlobals.h"
@@ -52,16 +46,12 @@ MSEdgeControl::MSEdgeControl(const std::vector< MSEdge* >& edges)
         if (!(*i)->hasLaneChanger()) {
             int pos = (*lanes.begin())->getNumericalID();
             myLanes[pos].lane = *(lanes.begin());
-            myLanes[pos].firstNeigh = lanes.end();
-            myLanes[pos].lastNeigh = lanes.end();
             myLanes[pos].amActive = false;
             myLanes[pos].haveNeighbors = false;
         } else {
             for (std::vector<MSLane*>::const_iterator j = lanes.begin(); j != lanes.end(); ++j) {
                 int pos = (*j)->getNumericalID();
                 myLanes[pos].lane = *j;
-                myLanes[pos].firstNeigh = (j + 1);
-                myLanes[pos].lastNeigh = lanes.end();
                 myLanes[pos].amActive = false;
                 myLanes[pos].haveNeighbors = true;
             }
@@ -77,7 +67,7 @@ MSEdgeControl::~MSEdgeControl() {
 
 void
 MSEdgeControl::patchActiveLanes() {
-    for (std::set<MSLane*, Named::ComparatorIdLess>::iterator i = myChangedStateLanes.begin(); i != myChangedStateLanes.end(); ++i) {
+    for (std::set<MSLane*, ComparatorNumericalIdLess>::iterator i = myChangedStateLanes.begin(); i != myChangedStateLanes.end(); ++i) {
         LaneUsage& lu = myLanes[(*i)->getNumericalID()];
         // if the lane was inactive but is now...
         if (!lu.amActive && (*i)->getVehicleNumber() > 0) {
@@ -106,6 +96,12 @@ MSEdgeControl::planMovements(SUMOTime t) {
     }
 }
 
+void
+MSEdgeControl::setJunctionApproaches(SUMOTime t) {
+    for (MSLane* lane : myActiveLanes) {
+        lane->setJunctionApproaches(t);
+    }
+}
 
 void
 MSEdgeControl::executeMovements(SUMOTime t) {
@@ -136,7 +132,6 @@ MSEdgeControl::executeMovements(SUMOTime t) {
         // not be sorted otherwise
         for (LaneUsageVector::iterator it = myLanes.begin(); it != myLanes.end(); ++it) {
             (*it).lane->sortPartialVehicles();
-            (*it).lane->sortManeuverReservations();
         }
     }
 }
@@ -145,6 +140,7 @@ MSEdgeControl::executeMovements(SUMOTime t) {
 void
 MSEdgeControl::changeLanes(SUMOTime t) {
     std::vector<MSLane*> toAdd;
+    MSGlobals::gComputeLC = true;
     for (std::list<MSLane*>::iterator i = myActiveLanes.begin(); i != myActiveLanes.end();) {
         LaneUsage& lu = myLanes[(*i)->getNumericalID()];
         if (lu.haveNeighbors) {
@@ -170,17 +166,26 @@ MSEdgeControl::changeLanes(SUMOTime t) {
             i = myActiveLanes.end();
         }
     }
+    MSGlobals::gComputeLC = false;
     for (std::vector<MSLane*>::iterator i = toAdd.begin(); i != toAdd.end(); ++i) {
         myActiveLanes.push_front(*i);
     }
+    if (MSGlobals::gLateralResolution > 0) {
+        // sort maneuver reservations
+        for (LaneUsageVector::iterator it = myLanes.begin(); it != myLanes.end(); ++it) {
+            (*it).lane->sortManeuverReservations();
+        }
+    }
 }
 
 
 void
 MSEdgeControl::detectCollisions(SUMOTime timestep, const std::string& stage) {
     // Detections is made by the edge's lanes, therefore hand over.
-    for (std::list<MSLane*>::iterator i = myActiveLanes.begin(); i != myActiveLanes.end(); ++i) {
-        (*i)->detectCollisions(timestep, stage);
+    for (MSLane* lane : myActiveLanes) {
+        if (lane->needsCollisionCheck()) {
+            lane->detectCollisions(timestep, stage);
+        }
     }
 }
 
