@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSFrame.cpp
 /// @author  Daniel Krajzewicz
@@ -27,11 +25,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include <iomanip>
@@ -42,6 +36,7 @@
 #include <utils/common/MsgHandler.h>
 #include <utils/common/UtilExceptions.h>
 #include <utils/common/ToString.h>
+#include <utils/common/StringUtils.h>
 #include <utils/geom/GeoConvHelper.h>
 #include <utils/iodevices/OutputDevice.h>
 #include <utils/xml/SUMOVehicleParserHelper.h>
@@ -145,6 +140,10 @@ MSFrame::fillOptions() {
     oc.addDescription("fcd-output.geo", "Output", "Save the Floating Car Data using geo-coordinates (lon/lat)");
     oc.doRegister("fcd-output.signals", new Option_Bool(false));
     oc.addDescription("fcd-output.signals", "Output", "Add the vehicle signal state to the FCD output (brake lights etc.)");
+    oc.doRegister("fcd-output.filter-edges.input-file", new Option_FileName());
+    oc.addDescription("fcd-output.filter-edges.input-file", "Output", "Restrict fcd output to the edge selection from the given input file");
+
+
     oc.doRegister("full-output", new Option_FileName());
     oc.addDescription("full-output", "Output", "Save a lot of information for each timestep (very redundant)");
     oc.doRegister("queue-output", new Option_FileName());
@@ -186,6 +185,9 @@ MSFrame::fillOptions() {
     oc.addSynonyme("vehroute-output.dua", "vehroutes.dua");
     oc.addDescription("vehroute-output.dua", "Output", "Write the output in the duarouter alternatives style");
 
+    oc.doRegister("vehroute-output.cost", new Option_Bool(false));
+    oc.addDescription("vehroute-output.cost", "Output", "Write costs for all routes");
+
     oc.doRegister("vehroute-output.intended-depart", new Option_Bool(false));
     oc.addSynonyme("vehroute-output.intended-depart", "vehroutes.intended-depart");
     oc.addDescription("vehroute-output.intended-depart", "Output", "Write the output with the intended instead of the real departure time");
@@ -252,10 +254,6 @@ MSFrame::fillOptions() {
     oc.doRegister("lateral-resolution", new Option_Float(-1));
     oc.addDescription("lateral-resolution", "Processing", "Defines the resolution in m when handling lateral positioning within a lane (with -1 all vehicles drive at the center of their lane");
 
-    oc.doRegister("carfollow.model", new Option_String("Krauss"));
-    oc.addDescription("carfollow.model", "Processing", "Select default car following model (Krauss, IDM, ...)");
-    oc.addSynonyme("carfollow.model", "carfollowing.model", false);
-
     // register the processing options
     oc.doRegister("route-steps", 's', new Option_String("200", "TIME"));
     oc.addDescription("route-steps", "Processing", "Load routes for the next number of seconds ahead");
@@ -267,7 +265,7 @@ MSFrame::fillOptions() {
     oc.addDescription("ignore-junction-blocker", "Processing", "Ignore vehicles which block the junction after they have been standing for SECONDS (-1 means never ignore)");
 
     oc.doRegister("ignore-route-errors", new Option_Bool(false));
-    oc.addDescription("ignore-route-errors", "Processing", "Do not check whether routes are connected");
+    oc.addDescription("ignore-route-errors", "Processing", "(1) Do not check whether routes are connected. (2) Allow inserting a vehicle in a situation which requires emergency braking.");
 
     oc.doRegister("ignore-accidents", new Option_Bool(false));
     oc.addDescription("ignore-accidents", "Processing", "Do not check whether accidents occur");
@@ -281,8 +279,8 @@ MSFrame::fillOptions() {
     oc.doRegister("collision.check-junctions", new Option_Bool(false));
     oc.addDescription("collision.check-junctions", "Processing", "Enables collisions checks on junctions");
 
-    oc.doRegister("collision.mingap-factor", new Option_Float(1.0));
-    oc.addDescription("collision.mingap-factor", "Processing", "Sets the fraction of minGap that must be maintained to avoid collision detection.");
+    oc.doRegister("collision.mingap-factor", new Option_Float(-1));
+    oc.addDescription("collision.mingap-factor", "Processing", "Sets the fraction of minGap that must be maintained to avoid collision detection. If a negative value is given, the carFollowModel parameter is used");
 
     oc.doRegister("max-num-vehicles", new Option_Integer(-1));
     oc.addDescription("max-num-vehicles", "Processing", "Delay vehicle insertion to stay within the given maximum number");
@@ -329,6 +327,19 @@ MSFrame::fillOptions() {
     oc.doRegister("default.action-step-length", new Option_Float(0.0));
     oc.addDescription("default.action-step-length", "Processing", "Length of the default interval length between action points for the car-following and lane-change models (in seconds). If not specified, the simulation step-length is used per default. Vehicle- or VType-specific settings override the default. Must be a multiple of the simulation step-length.");
 
+    oc.doRegister("default.carfollowmodel", new Option_String("Krauss"));
+    oc.addDescription("default.carfollowmodel", "Processing", "Select default car following model (Krauss, IDM, ...)");
+    oc.addSynonyme("default.carfollowmodel", "carfollow.model", false);
+
+    oc.doRegister("default.speeddev", new Option_Float(-1));
+    oc.addDescription("default.speeddev", "Processing", "Select default speed deviation. A negative value implies vClass specific defaults (0.1 for the default passenger class");
+
+    oc.doRegister("default.emergencydecel", new Option_String("default"));
+    oc.addDescription("default.emergencydecel", "Processing", "Select default emergencyDecel value among ('decel', 'default', FLOAT) which sets the value either to the same as the deceleration value, a vClass-class specific default or the given FLOAT in m/s^2");
+
+    oc.doRegister("emergencydecel.warning-threshold", new Option_Float(1));
+    oc.addDescription("emergencydecel.warning-threshold", "Processing", "Sets the fraction of emergency decel capability that must be used to trigger a warning.");
+
     // pedestrian model
     oc.doRegister("pedestrian.model", new Option_String("striping"));
     oc.addDescription("pedestrian.model", "Processing", "Select among pedestrian models ['nonInteracting', 'striping', 'remote']");
@@ -384,8 +395,6 @@ MSFrame::fillOptions() {
     oc.doRegister("no-step-log", new Option_Bool(false));
     oc.addDescription("no-step-log", "Report", "Disable console output of current simulation step");
 
-
-#ifndef NO_TRACI
     //remote port 0 if not used
     oc.addOptionSubTopic("TraCI Server");
     oc.doRegister("remote-port", new Option_Integer(0));
@@ -395,7 +404,6 @@ MSFrame::fillOptions() {
 #ifdef HAVE_PYTHON
     oc.doRegister("python-script", new Option_String());
     oc.addDescription("python-script", "TraCI Server", "Runs TraCI script with embedded python");
-#endif
 #endif
     //
     oc.addOptionSubTopic("Mesoscopic");
@@ -438,7 +446,7 @@ MSFrame::fillOptions() {
     // add GUI options
     // the reason that we include them in vanilla sumo as well is to make reusing config files easy
     oc.addOptionSubTopic("GUI Only");
-    oc.doRegister("gui-settings-file", new Option_FileName());
+    oc.doRegister("gui-settings-file", 'g', new Option_FileName());
     oc.addDescription("gui-settings-file", "GUI Only", "Load visualisation settings from FILE");
 
     oc.doRegister("quit-on-end", 'Q', new Option_Bool(false));
@@ -450,12 +458,18 @@ MSFrame::fillOptions() {
     oc.doRegister("start", 'S', new Option_Bool(false));
     oc.addDescription("start", "GUI Only", "Start the simulation after loading");
 
+    oc.doRegister("breakpoints", new Option_String());
+    oc.addDescription("breakpoints", "GUI Only", "Use TIME[] as times when the simulation should halt");
+
     oc.doRegister("demo", 'D', new Option_Bool(false));
     oc.addDescription("demo", "GUI Only", "Restart the simulation after ending (demo mode)");
 
     oc.doRegister("disable-textures", 'T', new Option_Bool(false));
     oc.addDescription("disable-textures", "GUI Only", "Do not load background pictures");
 
+    oc.doRegister("registry-viewport", new Option_Bool(false));
+    oc.addDescription("registry-viewport", "GUI Only", "Load current viewport from registry");
+
     oc.doRegister("window-size", new Option_String());
     oc.addDescription("window-size", "GUI Only", "Create initial window with the given x,y size");
 
@@ -542,6 +556,9 @@ MSFrame::checkOptions() {
     if (oc.getBool("meso-junction-control.limited") && !oc.getBool("meso-junction-control")) {
         oc.set("meso-junction-control", "true");
     }
+    if (oc.getBool("mesosim") && oc.isDefault("pedestrian.model")) {
+        oc.set("pedestrian.model", "nonInteracting");
+    }
     const SUMOTime begin = string2time(oc.getString("begin"));
     const SUMOTime end = string2time(oc.getString("end"));
     if (begin < 0) {
@@ -573,12 +590,10 @@ MSFrame::checkOptions() {
     if (oc.getBool("ignore-accidents")) {
         WRITE_WARNING("The option 'ignore-accidents' is deprecated. Use 'collision.action none' instead.");
     }
-#ifndef NO_TRACI
 #ifdef HAVE_PYTHON
     if (oc.isSet("python-script")) {
         WRITE_WARNING("The option 'python-script' is deprecated. Use libsumo or TraCI instead.");
     }
-#endif
 #endif
     if (oc.getBool("duration-log.statistics") && oc.isDefault("verbose")) {
         oc.set("verbose", "true");
@@ -604,6 +619,26 @@ MSFrame::checkOptions() {
         WRITE_ERROR("Unknown model '" + oc.getString("carfollow.model")  + "' for option 'carfollow.model'.");
         ok = false;
     }
+    if (oc.isSet("default.emergencydecel")) {
+        const std::string val = oc.getString("default.emergencydecel");
+        if (val != "default" && val != "decel") {
+            try {
+                StringUtils::toDouble(val);
+            } catch (NumberFormatException&) {
+                WRITE_ERROR("Invalid value '" + val + "' for option 'default.emergencydecel'. Must be a FLOAT or 'default' or 'decel'");
+                ok = false;
+            }
+        }
+    }
+    for (const std::string& val : oc.getStringVector("breakpoints")) {
+        try {
+            string2time(val);
+        } catch (ProcessError& e) {
+            WRITE_ERROR("Invalid time '" + val + "' for option 'breakpoints'." + e.what());
+            ok = false;
+        }
+    };
+
     ok &= MSDevice::checkOptions(oc);
     ok &= SystemFrame::checkOptions();
 
@@ -655,6 +690,18 @@ MSFrame::setMSGlobals(OptionsCont& oc) {
     double givenDefaultActionStepLength = oc.getFloat("default.action-step-length");
     MSGlobals::gActionStepLength = SUMOVehicleParserHelper::processActionStepLength(givenDefaultActionStepLength);
 
+    const std::string defaultEmergencyDecelOption = OptionsCont::getOptions().getString("default.emergencydecel");
+    if (defaultEmergencyDecelOption == "default") {
+        MSGlobals::gDefaultEmergencyDecel = VTYPEPARS_DEFAULT_EMERGENCYDECEL_DEFAULT;
+    } else if (defaultEmergencyDecelOption == "decel") {
+        MSGlobals::gDefaultEmergencyDecel = VTYPEPARS_DEFAULT_EMERGENCYDECEL_DECEL;
+    } else {
+        // value already checked in checkOptions()
+        MSGlobals::gDefaultEmergencyDecel = StringUtils::toDouble(defaultEmergencyDecelOption);
+    }
+
+    MSGlobals::gEmergencyDecelWarningThreshold = oc.getFloat("emergencydecel.warning-threshold");
+    
 #ifdef _DEBUG
     if (oc.isSet("movereminder-output")) {
         MSBaseVehicle::initMoveReminderOutput(oc);
