@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2003-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2003-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSGlobals.h
 /// @author  Daniel Krajzewicz
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <map>
 #include <utils/common/SUMOTime.h>
@@ -117,6 +111,18 @@ public:
     /// default value for the interval between two action points for MSVehicle (defaults to DELTA_T)
     static SUMOTime gActionStepLength;
 
+    /// encoding of the string-option default.emergencydecel
+    static double gDefaultEmergencyDecel;
+
+    /// whether unit tests are being run
+    static bool gUnitTests;
+
+    /// whether the simulationLoop is in the lane changing phase
+    static bool gComputeLC;
+
+    /// treshold for warning about strong deceleration
+    static double gEmergencyDecelWarningThreshold;
+
 };
 
 
