@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSInsertionControl.cpp
 /// @author  Christian Roessel
@@ -25,17 +23,15 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include <algorithm>
 #include <cassert>
 #include <iterator>
+#include <utils/vehicle/IntermodalRouter.h>
 #include <microsim/devices/MSDevice_Routing.h>
+#include <microsim/devices/MSRoutingEngine.h>
 #include "MSGlobals.h"
 #include "MSVehicle.h"
 #include "MSVehicleControl.h"
@@ -52,12 +48,15 @@
 MSInsertionControl::MSInsertionControl(MSVehicleControl& vc,
                                        SUMOTime maxDepartDelay,
                                        bool eagerInsertionCheck,
-                                       int maxVehicleNumber) :
+                                       int maxVehicleNumber,
+                                       SUMOTime randomDepartOffset) :
     myVehicleControl(vc),
     myMaxDepartDelay(maxDepartDelay),
     myEagerInsertionCheck(eagerInsertionCheck),
     myMaxVehicleNumber(maxVehicleNumber),
     myPendingEmitsUpdateTime(SUMOTime_MIN) {
+    myMaxRandomDepartOffset = randomDepartOffset;
+    RandHelper::initRandGlobal(&myFlowRNG);
 }
 
 
@@ -75,23 +74,39 @@ MSInsertionControl::add(SUMOVehicle* veh) {
 
 
 bool
-MSInsertionControl::add(SUMOVehicleParameter* const pars) {
+MSInsertionControl::addFlow(SUMOVehicleParameter* const pars, int index) {
+    const bool loadingFromState = index >= 0;
     if (myFlowIDs.count(pars->id) > 0) {
+        if (loadingFromState) {
+            // flows loaded from simulation state must be unique
+            return false;
+        }
+        // set actual parameters for a state-loaded flow (for which only index is known)
+        for (Flow& flow : myFlows) {
+            // if the flow was loaded from state this is recognizable by having
+            // neither repetitionNumber nor repetitionProbability
+            if (flow.pars->id == pars->id && flow.pars->repetitionNumber == -1 && flow.pars->repetitionProbability == -1) {
+                delete flow.pars;
+                flow.pars = pars;
+                return true;
+            }
+        }
         return false;
+    } else {
+        Flow flow;
+        flow.pars = pars;
+        flow.index = loadingFromState ? index : 0;
+        myFlows.push_back(flow);
+        myFlowIDs.insert(pars->id);
+        return true;
     }
-    Flow flow;
-    flow.pars = pars;
-    flow.index = 0;
-    myFlows.push_back(flow);
-    myFlowIDs.insert(pars->id);
-    return true;
 }
 
 
 int
 MSInsertionControl::emitVehicles(SUMOTime time) {
     // check whether any vehicles shall be emitted within this time step
-    const bool havePreChecked = MSDevice_Routing::isEnabled();
+    const bool havePreChecked = MSRoutingEngine::isEnabled();
     if (myPendingEmits.empty() || (havePreChecked && myEmitCandidates.empty())) {
         return 0;
     }
@@ -165,7 +180,7 @@ MSInsertionControl::checkCandidates(SUMOTime time, const bool preCheck) {
                 myEmitCandidates.insert(v);
             } else {
                 MSDevice_Routing* dev = static_cast<MSDevice_Routing*>(v->getDevice(typeid(MSDevice_Routing)));
-                if (dev != 0) {
+                if (dev != nullptr) {
                     dev->skipRouting(time);
                 }
             }
@@ -187,15 +202,15 @@ MSInsertionControl::determineCandidates(SUMOTime time) {
                     && pars->depart < time + DELTA_T
                     && pars->repetitionEnd > time
                     // only call rand if all other conditions are met
-                    && RandHelper::rand() < (pars->repetitionProbability * TS))
+                    && RandHelper::rand(&myFlowRNG) < (pars->repetitionProbability * TS))
               ) {
             tryEmitByProb = false; // only emit one per step
             SUMOVehicleParameter* newPars = new SUMOVehicleParameter(*pars);
             newPars->id = pars->id + "." + toString(i->index);
-            newPars->depart = pars->repetitionProbability > 0 ? time : (SUMOTime)(pars->depart + pars->repetitionsDone * pars->repetitionOffset);
+            newPars->depart = pars->repetitionProbability > 0 ? time : (SUMOTime)(pars->depart + pars->repetitionsDone * pars->repetitionOffset) + computeRandomDepartOffset();
             pars->repetitionsDone++;
             // try to build the vehicle
-            if (vehControl.getVehicle(newPars->id) == 0) {
+            if (vehControl.getVehicle(newPars->id) == nullptr) {
                 const MSRoute* route = MSRoute::dictionary(pars->routeid);
                 MSVehicleType* vtype = vehControl.getVType(pars->vtypeid, MSRouteHandler::getParsingRNG());
                 SUMOVehicle* vehicle = vehControl.buildVehicle(newPars, route, vtype, !MSGlobals::gCheckRoutes);
@@ -207,7 +222,8 @@ MSInsertionControl::determineCandidates(SUMOTime time) {
                     while (--quota > 0) {
                         SUMOVehicleParameter* quotaPars = new SUMOVehicleParameter(*pars);
                         quotaPars->id = pars->id + "." + toString(i->index);
-                        quotaPars->depart = pars->repetitionProbability > 0 ? time : (SUMOTime)(pars->depart + pars->repetitionsDone * pars->repetitionOffset);
+                        quotaPars->depart = pars->repetitionProbability > 0 ? time :
+                                            (SUMOTime)(pars->depart + pars->repetitionsDone * pars->repetitionOffset) + computeRandomDepartOffset();
                         SUMOVehicle* vehicle = vehControl.buildVehicle(quotaPars, route, vtype, !MSGlobals::gCheckRoutes);
                         vehControl.addVehicle(quotaPars->id, vehicle);
                         add(vehicle);
@@ -233,7 +249,7 @@ MSInsertionControl::determineCandidates(SUMOTime time) {
             ++i;
         }
     }
-    checkCandidates(time, MSDevice_Routing::isEnabled());
+    checkCandidates(time, MSRoutingEngine::isEnabled());
 }
 
 
@@ -263,7 +279,7 @@ MSInsertionControl::alreadyDeparted(SUMOVehicle* veh) {
 
 
 void
-MSInsertionControl::clearPendingVehicles(std::string& route) {
+MSInsertionControl::clearPendingVehicles(const std::string& route) {
     //clear out the refused vehicle list, deleting the vehicles entirely
     MSVehicleContainer::VehicleVector::iterator veh;
     for (veh = myPendingEmits.begin(); veh != myPendingEmits.end();) {
@@ -284,7 +300,7 @@ MSInsertionControl::getPendingEmits(const MSLane* lane) {
         myPendingEmitsForLane.clear();
         for (MSVehicleContainer::VehicleVector::const_iterator veh = myPendingEmits.begin(); veh != myPendingEmits.end(); ++veh) {
             const MSLane* lane = (*veh)->getLane();
-            if (lane != 0) {
+            if (lane != nullptr) {
                 myPendingEmitsForLane[lane]++;
             } else {
                 // no (tentative) departLane was set, increase count for all
@@ -307,15 +323,35 @@ MSInsertionControl::adaptIntermodalRouter(MSNet::MSIntermodalRouter& router) con
     // fill the public transport router with pre-parsed public transport lines
     for (const Flow& f : myFlows) {
         if (f.pars->line != "") {
-            const MSRoute* route = MSRoute::dictionary(f.pars->routeid);
-            const std::vector<SUMOVehicleParameter::Stop>* addStops = 0;
-            if (route != 0) {
-                addStops = &route->getStops();
-            }
-            router.addSchedule(*f.pars, addStops);
+            const MSRoute* const route = MSRoute::dictionary(f.pars->routeid);
+            router.getNetwork()->addSchedule(*f.pars, route == nullptr ? nullptr : &route->getStops());
         }
     }
 }
 
 
+void
+MSInsertionControl::saveState(OutputDevice& out) {
+    // save flow states
+    for (const Flow& flow : myFlows) {
+        out.openTag(SUMO_TAG_FLOWSTATE);
+        out.writeAttr(SUMO_ATTR_ID, flow.pars->id);
+        out.writeAttr(SUMO_ATTR_INDEX, flow.index);
+        out.closeTag();
+    }
+}
+
+
+SUMOTime
+MSInsertionControl::computeRandomDepartOffset() const {
+    if (myMaxRandomDepartOffset > 0) {
+        // round to the closest usable simulation step
+        return DELTA_T * int((RandHelper::rand((int)myMaxRandomDepartOffset, MSRouteHandler::getParsingRNG()) + 0.5 * DELTA_T) / DELTA_T);
+    } else {
+        return 0;
+    }
+}
+
+
+
 /****************************************************************************/
