@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSInsertionControl.h
 /// @author  Christian Roessel
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <map>
@@ -74,7 +68,7 @@ public:
      * @param[in] checkEdgesOnce Whether an edge on which a vehicle could not depart should be ignored in the same step
      * @param[in] maxVehicleNumber The maximum number of vehicles that should not be exceeded
      */
-    MSInsertionControl(MSVehicleControl& vc, SUMOTime maxDepartDelay, bool checkEdgesOnce, int maxVehicleNumber);
+    MSInsertionControl(MSVehicleControl& vc, SUMOTime maxDepartDelay, bool checkEdgesOnce, int maxVehicleNumber, SUMOTime randomDepartOffset);
 
 
     /// @brief Destructor.
@@ -111,10 +105,11 @@ public:
 
     /** @brief Adds parameter for a vehicle flow for departure
      *
-     * @param[in] flow The flow to add for later insertion
+     * @param[in] pars The flow parameters to add for later insertion
+     * @param[in] index The current index when loading this flow from a simulation state
      * @return whether it could be added (no other flow with the same id was present)
      */
-    bool add(SUMOVehicleParameter* const pars);
+    bool addFlow(SUMOVehicleParameter* const pars, int index = -1);
 
 
     /** @brief Returns the number of waiting vehicles
@@ -141,7 +136,7 @@ public:
 
 
     /// @brief clears out all pending vehicles from a route, "" for all routes
-    void clearPendingVehicles(std::string& route);
+    void clearPendingVehicles(const std::string& route);
 
 
     /** @brief Checks for all vehicles whether they can be emitted
@@ -155,6 +150,18 @@ public:
 
     void adaptIntermodalRouter(MSNet::MSIntermodalRouter& router) const;
 
+    /// @brief compute (optional) random offset to the departure time
+    SUMOTime computeRandomDepartOffset() const;
+
+    /** @brief Saves the current state into the given stream
+     */
+    void saveState(OutputDevice& out);
+
+    /// @brief retrieve internal RNG
+    std::mt19937* getFlowRNG() {
+        return &myFlowRNG;
+    }
+
 private:
     /** @brief Tries to emit the vehicle
      *
@@ -182,6 +189,7 @@ private:
     void checkCandidates(SUMOTime time, const bool preCheck);
 
 
+
 private:
     /// @brief The assigned vehicle control (needed for vehicle re-insertion and deletion)
     MSVehicleControl& myVehicleControl;
@@ -229,6 +237,8 @@ private:
     /// @brief the number of pending emits for each edge in the current time step
     std::map<const MSLane*, int> myPendingEmitsForLane;
 
+    /// @brief The maximum random offset to be added to vehicles departure times (non-negative)
+    SUMOTime myMaxRandomDepartOffset;
 
 private:
     /// @brief Invalidated copy constructor.
@@ -237,6 +247,8 @@ private:
     /// @brief Invalidated assignment operator.
     MSInsertionControl& operator=(const MSInsertionControl&);
 
+    /// @brief A random number generator for probabilistic flows
+    std::mt19937 myFlowRNG;
 
 };
 
