@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSJunction.cpp
 /// @author  Christian Roessel
@@ -23,17 +21,26 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "MSVehicle.h"
 #include "MSEdge.h"
 #include "MSJunction.h"
 
 
+
+
+
+
+// ===========================================================================
+// debug constants
+// ===========================================================================
+//#define DEBUG_LINKLEADER
+//#define DEBUG_COND (ego->isSelected())
+//#define DEBUG_COND (true)
+
+
+
 // ===========================================================================
 // class declarations
 // ===========================================================================
@@ -68,25 +75,14 @@ void
 MSJunction::postloadInit() {}
 
 
-void
-MSJunction::passedJunction(const MSVehicle* vehicle) {
-    myLinkLeaders.erase(vehicle);
+int
+MSJunction::getNrOfIncomingLanes() const {
+    int nr = 0;
+    for (const MSEdge* e : myIncoming) {
+        nr += (int)e->getLanes().size();
+    }
+    return nr;
 }
 
-
-bool
-MSJunction::isLeader(const MSVehicle* ego, const MSVehicle* foe) {
-    if (foe->getLane()->getEdge().getToJunction() != this) {
-        // foe is already past the junction so is definitely a leader
-        return true;
-    }
-    if (myLinkLeaders.find(ego) == myLinkLeaders.end() || myLinkLeaders[ego].count(foe) == 0) {
-        // we are not yet the leader for foe, thus foe will be our leader
-        myLinkLeaders[foe].insert(ego);
-        return true;
-    } else {
-        return false;
-    }
-}
 /****************************************************************************/
 
