@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSJunction.h
 /// @author  Christian Roessel
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <vector>
@@ -51,9 +45,12 @@ class MSVehicle;
 class MSLink;
 class MSLane;
 class MSEdge;
+class MSJunctionLogic;
 
+typedef std::vector<MSEdge*> MSEdgeVector;
 typedef std::vector<const MSEdge*> ConstMSEdgeVector;
 
+
 // ===========================================================================
 // class definitions
 // ===========================================================================
@@ -106,6 +103,8 @@ public:
         return myIncoming;
     }
 
+    int getNrOfIncomingLanes() const;
+
     inline const ConstMSEdgeVector& getOutgoing() const {
         return myOutgoing;
     }
@@ -132,9 +131,10 @@ public:
     /// @brief erase vehicle from myLinkLeaders
     void passedJunction(const MSVehicle* vehicle);
 
-    /* @brief @return whether the foe vehicle is a leader for ego
-     * @note vehicles are added to myLinkLeaders when first seen as a foe */
-    bool isLeader(const MSVehicle* ego, const MSVehicle* foe);
+    // @brief return the underlying right-of-way and conflict matrix
+    virtual const MSJunctionLogic* getLogic() const {
+        return nullptr;
+    }
 
 protected:
     /// @brief Tye type of this junction
@@ -158,11 +158,6 @@ protected:
     /// @brief definition of the static dictionary type
     typedef std::map<std::string, MSJunction* > DictType;
 
-    /// @brief map from leader vehicle to follower vehicles
-    typedef std::map<const MSVehicle*, std::set<const MSVehicle*> > LeaderMap;
-    LeaderMap myLinkLeaders;
-
-
 private:
     /// @brief Invalidated copy constructor.
     MSJunction(const MSJunction&);
