@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSLane.h
 /// @author  Christian Roessel
@@ -30,13 +28,11 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
+#include <memory>
 #include <vector>
+#include <map>
 #include <deque>
 #include <cassert>
 #include <utils/common/Named.h>
@@ -63,6 +59,11 @@ class MSVehicleControl;
 class OutputDevice;
 class MSLeaderInfo;
 
+// ===========================================================================
+// type definitions
+// ===========================================================================
+/// Coverage info
+typedef std::map<const MSLane*, std::pair<double, double> >  LaneCoverageInfo; // also declared in libsumo/Helper.h!
 
 // ===========================================================================
 // class definitions
@@ -100,20 +101,27 @@ public:
     ///        that may be of importance for the car-following dynamics along that lane. The relevant types of vehicles are:
     ///        1) vehicles with their front on the lane (myVehicles),
     ///        2) vehicles intersecting the lane but with front on another lane (myPartialVehicles)
+    ///
+    ///        In the context of retrieving linkLeaders during lane changing a third group of vehicles is checked:
+    ///        3) vehicles processed during lane changing (myTmpVehicles)
     class AnyVehicleIterator {
     public:
         AnyVehicleIterator(
             const MSLane* lane,
             int i1,
             int i2,
+            int i3,
             const int i1End,
             const int i2End,
+            const int i3End,
             bool downstream = true) :
             myLane(lane),
             myI1(i1),
             myI2(i2),
+            myI3(i3),
             myI1End(i1End),
             myI2End(i2End),
+            myI3End(i3End),
             myDownstream(downstream),
             myDirection(downstream ? 1 : -1) {
         }
@@ -121,8 +129,10 @@ public:
         bool operator== (AnyVehicleIterator const& other) const {
             return (myI1 == other.myI1
                     && myI2 == other.myI2
+                    && myI3 == other.myI3
                     && myI1End == other.myI1End
-                    && myI2End == other.myI2End);
+                    && myI2End == other.myI2End
+                    && myI3End == other.myI3End);
         }
 
         bool operator!= (AnyVehicleIterator const& other) const {
@@ -146,10 +156,14 @@ public:
         int myI1;
         /// @brief index for myPartialVehicles
         int myI2;
+        /// @brief index for myTmpVehicles
+        int myI3;
         /// @brief end index for myVehicles
         int myI1End;
         /// @brief end index for myPartialVehicles
         int myI2End;
+        /// @brief end index for myTmpVehicles
+        int myI3End;
         /// @brief iteration direction
         bool myDownstream;
         /// @brief index delta
@@ -180,7 +194,7 @@ public:
      * @param[in] width The width of the lane
      * @param[in] permissions Encoding of the Vehicle classes that may drive on this lane
      * @param[in] index The index of this lane within its parent edge
-     * @param[in] isRampAccel Whether this lane is an acceleratin lane
+     * @param[in] isRampAccel Whether this lane is an acceleration lane
      * @see SUMOVehicleClass
      */
     MSLane(const std::string& id, double maxSpeed, double length, MSEdge* const edge,
@@ -396,22 +410,25 @@ public:
 
     /// @brief begin iterator for iterating over all vehicles touching this lane in downstream direction
     AnyVehicleIterator anyVehiclesBegin() const {
-        return AnyVehicleIterator(this, 0, 0, (int)myVehicles.size(), (int)myPartialVehicles.size(), true);
+        return AnyVehicleIterator(this, 0, 0, 0,
+                                  (int)myVehicles.size(), (int)myPartialVehicles.size(), (int)myTmpVehicles.size(), true);
     }
 
     /// @brief end iterator for iterating over all vehicles touching this lane in downstream direction
     AnyVehicleIterator anyVehiclesEnd() const {
-        return AnyVehicleIterator(this, (int)myVehicles.size(), (int)myPartialVehicles.size(), (int)myVehicles.size(), (int)myPartialVehicles.size(), true);
+        return AnyVehicleIterator(this, (int)myVehicles.size(), (int)myPartialVehicles.size(), (int)myTmpVehicles.size(),
+                                  (int)myVehicles.size(), (int)myPartialVehicles.size(), (int)myTmpVehicles.size(), true);
     }
 
     /// @brief begin iterator for iterating over all vehicles touching this lane in upstream direction
     AnyVehicleIterator anyVehiclesUpstreamBegin() const {
-        return AnyVehicleIterator(this, (int)myVehicles.size() - 1, (int)myPartialVehicles.size() - 1, -1, -1, false);
+        return AnyVehicleIterator(this, (int)myVehicles.size() - 1, (int)myPartialVehicles.size() - 1, (int)myTmpVehicles.size() - 1,
+                                  -1, -1, -1, false);
     }
 
     /// @brief end iterator for iterating over all vehicles touching this lane in upstream direction
     AnyVehicleIterator anyVehiclesUpstreamEnd() const {
-        return AnyVehicleIterator(this, -1, -1, -1, -1, false);
+        return AnyVehicleIterator(this, -1, -1, -1, -1, -1, -1, false);
     }
 
     /** @brief Allows to use the container for microsimulation again
@@ -538,6 +555,13 @@ public:
      */
     virtual void planMovements(const SUMOTime t);
 
+    /** @brief Register junction approaches for all vehicles after velocities
+     * have been planned. 
+     *
+     * This method goes through all vehicles calling their * "setApproachingForAllLinks" method.
+     */
+    virtual void setJunctionApproaches(const SUMOTime t);
+
     /** @brief This updates the MSLeaderInfo argument with respect to the given MSVehicle.
      *         All leader-vehicles on the same edge, which are relevant for the vehicle
      *         (i.e. with position > vehicle's position) and not already integrated into
@@ -565,6 +589,15 @@ public:
     ///@}
 
 
+    /// @brief short-circut collision check if nothing changed since the last check
+    inline bool needsCollisionCheck() const {
+        return myNeedsCollisionCheck;
+    }
+
+    /// @brief require another collision check due to relevant changes in the simulation
+    inline void requireCollisionCheck() {
+        myNeedsCollisionCheck = true;
+    }
 
     /// Check if vehicles are too close.
     virtual void detectCollisions(SUMOTime timestep, const std::string& stage);
@@ -732,8 +765,8 @@ public:
      * @param[in] permissions The new permissions
      * @param[in] transientID The id of the permission-modification or the special value PERMANENT
      */
-    void setPermissions(SVCPermissions permissions, long transientID);
-    void resetPermissions(long transientID);
+    void setPermissions(SVCPermissions permissions, long long transientID);
+    void resetPermissions(long long transientID);
 
 
     inline bool allowsVehicleClass(SUMOVehicleClass vclass) const {
@@ -758,7 +791,18 @@ public:
     bool isApproachedFrom(MSEdge* const edge);
     bool isApproachedFrom(MSEdge* const edge, MSLane* const lane);
 
+    /// @brief Returns vehicle class specific stopOffset for the vehicle
+    double getStopOffset(const MSVehicle* veh) const;
 
+    /// @brief Returns vehicle class specific stopOffsets
+    const std::map<SVCPermissions, double>& getStopOffsets() const {
+        return myStopOffsets;
+    };
+
+    /// @brief Set vehicle class specific stopOffsets
+    void setStopOffsets(std::map<SVCPermissions, double> stopOffsets) {
+        myStopOffsets = stopOffsets;
+    };
 
     /// @brief return the sublane followers with the largest missing rear gap among all predecessor lanes (within dist)
     MSLeaderDistanceInfo getFollowersOnConsecutive(const MSVehicle* ego, double backOffset,
@@ -836,6 +880,29 @@ public:
     /// @brief get all vehicles that are inlapping from consecutive edges
     MSLeaderInfo getPartialBeyond() const;
 
+    /// @brief Returns all vehicles closer than downstreamDist along the along the road network starting on the given
+    ///        position. Predecessor lanes are searched upstream for the given upstreamDistance
+    /// @note  Re-implementation of the corresponding method in MSDevice_SSM, which cannot be easily adapted, as it gathers
+    ///        additional information for conflict lanes, etc.
+    /// @param[in] lanes - sequence of lanes to search along
+    /// @param[in] startPos - start position of the search on the first lane
+    /// @param[in] downstreamDist - distance to search downstream
+    /// @param[in] upstreamDist - distance to search upstream
+    /// @param[in/out] checkedLanes - lanes, which were already scanned (current lane is added, if not present,
+    ///                otherwise the scan is aborted; TODO: this may disregard unscanned parts of the lane in specific circular set ups.)
+    /// @return    vehs - List of vehicles found
+    std::set<MSVehicle*> getSurroundingVehicles(double startPos, double downstreamDist, double upstreamDist, std::shared_ptr<LaneCoverageInfo> checkedLanes) const;
+
+    /// @brief Returns all vehicles on the lane overlapping with the interval [a,b]
+    /// @note  Does not consider vehs with front on subsequent lanes
+    std::set<MSVehicle*> getVehiclesInRange(double a, double b) const;
+
+
+    /// @brief Returns all upcoming junctions within given range along the given (non-internal) continuation lanes measured from given position
+    std::vector<const MSJunction*> getUpcomingJunctions(double pos, double range, const std::vector<MSLane*>& contLanes) const;
+    /// @brief Returns all upcoming junctions within given range along the given (non-internal) continuation lanes measured from given position
+    std::vector<const MSLink*> getUpcomingLinks(double pos, double range, const std::vector<MSLane*>& contLanes) const;
+
     /** @brief get the most likely precedecessor lane (sorted using by_connections_to_sorter).
      * The result is cached in myLogicalPredecessorLane
      */
@@ -865,7 +932,7 @@ public:
     LinkState getIncomingLinkState() const;
 
     /// @brief get the list of outgoing lanes
-    std::vector<const MSLane*> getOutgoingLanes() const;
+    const std::vector<std::pair<const MSLane*, const MSEdge*> > getOutgoingViaLanes() const;
 
     /// @name Current state retrieval
     //@{
@@ -981,7 +1048,7 @@ public:
     /// @brief return the corresponding position on the opposite lane
     double getOppositePos(double pos) const;
 
-    /* @brief find leader for a vehicle depending the relative driving direction
+    /* @brief find leader for a vehicle depending on the relative driving direction
      * @param[in] ego The ego vehicle
      * @param[in] dist The look-ahead distance when looking at consecutive lanes
      * @param[in] oppositeDir Whether the lane has the opposite driving direction of ego
@@ -1098,13 +1165,13 @@ protected:
 
     /// @brief detect whether there is a collision between the two vehicles
     bool detectCollisionBetween(SUMOTime timestep, const std::string& stage, MSVehicle* collider, MSVehicle* victim,
-                                std::set<const MSVehicle*, SUMOVehicle::ComparatorIdLess>& toRemove,
+                                std::set<const MSVehicle*, ComparatorNumericalIdLess>& toRemove,
                                 std::set<const MSVehicle*>& toTeleport) const;
 
     /// @brief take action upon collision
     void handleCollisionBetween(SUMOTime timestep, const std::string& stage, MSVehicle* collider, MSVehicle* victim,
                                 double gap, double latGap,
-                                std::set<const MSVehicle*, SUMOVehicle::ComparatorIdLess>& toRemove,
+                                std::set<const MSVehicle*, ComparatorNumericalIdLess>& toRemove,
                                 std::set<const MSVehicle*>& toTeleport) const;
 
     /// @brief compute maximum braking distance on this lane
@@ -1127,9 +1194,6 @@ protected:
      * (a negative value indicates that safe insertion is impossible) */
     double safeInsertionSpeed(const MSVehicle* veh, double seen, const MSLeaderInfo& leaders, double speed);
 
-    /// @brief departure position where the vehicle fits fully onto the lane (if possible)
-    double basePos(const MSVehicle& veh) const;
-
     /// @brief check whether pedestrians on this lane interfere with vehicle insertion
     bool checkForPedestrians(const MSVehicle* aVehicle, double& speed, double& dist, double pos, bool patchSpeed) const;
 
@@ -1194,6 +1258,11 @@ protected:
     /// Lane width [m]
     const double myWidth;
 
+    /// Lane's vClass specific stop offset [m]. The map is either of length 0, which means no
+    /// special stopOffset was set, or of length 1, where the key is a bitset representing a subset
+    /// of the SUMOVehicleClass Enum and the value is the offset in meters.
+    std::map<SVCPermissions, double> myStopOffsets;
+
     /// The lane's edge, for routing only.
     MSEdge* const myEdge;
 
@@ -1257,11 +1326,14 @@ protected:
     /// @brief the index of the rightmost sublane of this lane on myEdge
     int myRightmostSublane;
 
+    /// @brief whether a collision check is currently needed
+    bool myNeedsCollisionCheck;
+
     // @brief the ids of neighboring lanes
     std::vector<std::string> myNeighs;
 
     // @brief transient changes in permissions
-    std::map<long, SVCPermissions> myPermissionChanges;
+    std::map<long long, SVCPermissions> myPermissionChanges;
 
     /// definition of the static dictionary type
     typedef std::map< std::string, MSLane* > DictType;
