@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSLink.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <set>
@@ -204,7 +198,7 @@ public:
     ApproachingVehicleInformation getApproaching(const SUMOVehicle* veh) const;
 
     /// @brief return all approaching vehicles
-    const std::map<const SUMOVehicle*, ApproachingVehicleInformation, SUMOVehicle::ComparatorIdLess>& getApproaching() const {
+    const std::map<const SUMOVehicle*, ApproachingVehicleInformation, ComparatorNumericalIdLess>& getApproaching() const {
         return myApproachingVehicles;
     }
 
@@ -274,6 +268,15 @@ public:
     }
 
 
+    /** @brief Returns the off-state for the link
+     *
+     * @return The current state of this link
+     */
+    LinkState getOffState() const {
+        return myOffState;
+    }
+
+
     //@brief Returns the time of the last state change
     inline SUMOTime getLastStateChange() const {
         return myLastStateChange;
@@ -370,10 +373,8 @@ public:
         return myHasFoes;
     }
 
-    // @todo documentation
-    bool isCont() const {
-        return myAmCont;
-    }
+    // @brief return whether the vehicle may continute past this link to wait within the intersection
+    bool isCont() const;
 
 
     /// @brief whether the junction after this link must be kept clear
@@ -446,21 +447,24 @@ public:
     /// @brief write information about all approaching vehicles to the given output device
     void writeApproaching(OutputDevice& od, const std::string fromLaneID) const;
 
-    /// @brief erase vehicle from myLinkLeaders of this links junction
-    void passedJunction(const MSVehicle* vehicle) const;
-
     /// @brief return the link that is parallel to this lane or 0
     MSLink* getParallelLink(int direction) const;
 
-    //// @brief @return whether the foe vehicle is a leader for ego
-    bool isLeader(const MSVehicle* ego, const MSVehicle* foe) const;
-
     /// @brief return whether the fromLane of this link is an internal lane
     bool fromInternalLane() const;
 
+    /// @brief return whether the toLane of this link is an internal lane and fromLane is a normal lane
+    bool isEntryLink() const;
+
+    /// @brief return whether this link enters the conflict area (not a continuation link)
+    bool isConflictEntryLink() const;
+
     /// @brief return whether the fromLane of this link is an internal lane and toLane is a normal lane
     bool isExitLink() const;
 
+    /// @brief return whether the fromLane of this link is an internal lane and its incoming lane is also an internal lane
+    bool isExitLinkAfterInternalJunction() const;
+
     /// @brief returns the corresponding exit link for entryLinks to a junction.
     MSLink* getCorrespondingExitLink() const;
 
@@ -502,6 +506,11 @@ public:
     /// @brief initialize parallel links (to be called after all links are loaded)
     void initParallelLinks();
 
+    /// @brief return lateral shift that must be applied when passing this link
+    double getLateralShift() {
+        return myLateralShift;
+    }
+
 private:
     /// @brief return whether the given vehicles may NOT merge safely
     static inline bool unsafeMergeSpeeds(double leaderSpeed, double followerSpeed, double leaderDecel, double followerDecel) {
@@ -522,6 +531,12 @@ private:
                       bool sameTargetLane, double impatience, double decel, SUMOTime waitingTime,
                       const SUMOVehicle* ego) const;
 
+    /// @brief figure out whether the cont status remains in effect when switching off the tls
+    bool checkContOff() const;
+
+    /// @brief check if the lane intersects with a foe cont-lane
+    bool contIntersect(const MSLane* lane, const MSLane* foe);
+
 private:
     /// @brief The lane behind the junction approached by this link
     MSLane* myLane;
@@ -529,7 +544,7 @@ private:
     /// @brief The lane approaching this link
     MSLane* myLaneBefore;
 
-    std::map<const SUMOVehicle*, ApproachingVehicleInformation, SUMOVehicle::ComparatorIdLess> myApproachingVehicles;
+    std::map<const SUMOVehicle*, ApproachingVehicleInformation, ComparatorNumericalIdLess> myApproachingVehicles;
     std::set<MSLink*> myBlockedFoeLinks;
 
     /// @brief The position within this respond
@@ -543,6 +558,8 @@ private:
 
     /// @brief The state of the link
     LinkState myState;
+    /// @brief The state of the link when switching of traffic light control
+    const LinkState myOffState;
 
     /// @brief The time of the last state change
     SUMOTime myLastStateChange;
@@ -562,9 +579,12 @@ private:
     /// @brief Whether any foe links exist
     bool myHasFoes;
 
-    // @todo documentation
+    // @brief whether vehicles may continue past this link to wait within the intersection
     bool myAmCont;
+    // @brief whether vehicles may continue past this link to wait within the intersection after switching of the traffic light at this intersection
+    bool myAmContOff;
 
+    // @brief whether vehicles must keep the intersection clear if there is a downstream jam
     bool myKeepClear;
 
     /// @brief The following junction-internal lane if used
@@ -581,6 +601,9 @@ private:
     /// @brief green fraction at tls for mesoscopic simulation
     double myGreenFraction;
 
+    /// @brief lateral shift to be applied when passing this link
+    double myLateralShift;
+
     /* @brief lengths after the crossing point with foeLane
      * (lengthOnThis, lengthOnFoe)
      * (index corresponds to myFoeLanes)
@@ -593,9 +616,15 @@ private:
     std::vector<const MSLane*> myFoeLanes;
     const MSLane* myWalkingAreaFoe;
 
+    /// @brief whether on of myFoeLanes is a crossing
+    bool myHavePedestrianCrossingFoe;
+
     /* @brief Links with the same origin lane and the same destination edge that may
        be in conflict for sublane simulation */
     std::vector<MSLink*> mySublaneFoeLinks;
+    /* @brief Links with the same origin lane and different destination edge that may
+       be in conflict for sublane simulation */
+    std::vector<MSLink*> mySublaneFoeLinks2;
 
     /* @brief Internal Lanes with the same origin lane and the same destination edge that may
        be in conflict for sublane simulation */
