@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2004-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2004-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSLinkCont.cpp
 /// @author  Daniel Krajzewicz
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "MSLinkCont.h"
 #include "MSLane.h"
@@ -43,14 +37,14 @@ MSLinkContHelper::getInternalFollowingEdge(const MSLane* fromLane,
     for (MSLinkCont::const_iterator j = lc.begin(); j != lc.end(); j++) {
         MSLink* link = *j;
         if (&link->getLane()->getEdge() == followerAfterInternal) {
-            if (link->getViaLane() != 0) {
+            if (link->getViaLane() != nullptr) {
                 return &link->getViaLane()->getEdge();
             } else {
-                return 0; // network without internal links
+                return nullptr; // network without internal links
             }
         }
     }
-    return 0;
+    return nullptr;
 }
 
 
@@ -62,14 +56,14 @@ MSLinkContHelper::getInternalFollowingLane(const MSLane* fromLane,
     for (MSLinkCont::const_iterator j = lc.begin(); j != lc.end(); j++) {
         MSLink* link = *j;
         if (link->getLane() == followerAfterInternal) {
-            if (link->getViaLane() != 0) {
+            if (link->getViaLane() != nullptr) {
                 return link->getViaLane();
             } else {
-                return 0; // network without internal links
+                return nullptr; // network without internal links
             }
         }
     }
-    return 0;
+    return nullptr;
 }
 
 
@@ -84,7 +78,7 @@ MSLinkContHelper::getConnectingLink(const MSLane& from, const MSLane& to) {
             return link;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 
