@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSNet.cpp
 /// @author  Christian Roessel
@@ -29,10 +27,10 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
+
+#ifdef HAVE_VERSION_H
+#include <version.h>
 #endif
 
 #include <string>
@@ -62,18 +60,22 @@
 #include <utils/shapes/ShapeContainer.h>
 #include <utils/vehicle/DijkstraRouter.h>
 #include <utils/vehicle/AStarRouter.h>
+#include <utils/vehicle/IntermodalRouter.h>
 #include <utils/vehicle/PedestrianRouter.h>
 #include <utils/xml/SUMORouteLoaderControl.h>
 #include <utils/xml/XMLSubSys.h>
+#include <traci-server/TraCIServer.h>
+#include <libsumo/Simulation.h>
 #include <mesosim/MELoop.h>
 #include <microsim/output/MSDetectorControl.h>
 #include <microsim/MSCModel_NonInteracting.h>
 #include <microsim/MSVehicleTransfer.h>
-#include <microsim/devices/MSDevice_Routing.h>
+#include <microsim/devices/MSRoutingEngine.h>
 #include <microsim/devices/MSDevice_Vehroutes.h>
 #include <microsim/devices/MSDevice_Tripinfo.h>
 #include <microsim/devices/MSDevice_BTsender.h>
 #include <microsim/devices/MSDevice_SSM.h>
+#include <microsim/devices/MSDevice_ToC.h>
 #include <microsim/output/MSBatteryExport.h>
 #include <microsim/output/MSEmissionExport.h>
 #include <microsim/output/MSFCDExport.h>
@@ -82,6 +84,7 @@
 #include <microsim/output/MSVTKExport.h>
 #include <microsim/output/MSXMLRawOut.h>
 #include <microsim/output/MSAmitranTrajectories.h>
+#include <microsim/output/MSStopOut.h>
 #include <microsim/pedestrians/MSPModel.h>
 #include <microsim/pedestrians/MSPerson.h>
 #include <microsim/traffic_lights/MSTrafficLightLogic.h>
@@ -107,11 +110,6 @@
 #include "MSStoppingPlace.h"
 #include "MSNet.h"
 
-#ifndef NO_TRACI
-#include <traci-server/TraCIServer.h>
-#include <libsumo/Simulation.h>
-#endif
-
 
 // ===========================================================================
 // debug constants
@@ -122,7 +120,7 @@
 // ===========================================================================
 // static member definitions
 // ===========================================================================
-MSNet* MSNet::myInstance = 0;
+MSNet* MSNet::myInstance = nullptr;
 
 const std::string MSNet::STAGE_EVENTS("events");
 const std::string MSNet::STAGE_MOVEMENTS("move");
@@ -136,7 +134,7 @@ double
 MSNet::getEffort(const MSEdge* const e, const SUMOVehicle* const v, double t) {
     double value;
     const MSVehicle* const veh = dynamic_cast<const MSVehicle* const>(v);
-    if (veh != 0 && veh->getWeightsStorage().retrieveExistingEffort(e, t, value)) {
+    if (veh != nullptr && veh->getWeightsStorage().retrieveExistingEffort(e, t, value)) {
         return value;
     }
     if (getInstance()->getWeightsStorage().retrieveExistingEffort(e, t, value)) {
@@ -150,7 +148,7 @@ double
 MSNet::getTravelTime(const MSEdge* const e, const SUMOVehicle* const v, double t) {
     double value;
     const MSVehicle* const veh = dynamic_cast<const MSVehicle* const>(v);
-    if (veh != 0 && veh->getWeightsStorage().retrieveExistingTravelTime(e, t, value)) {
+    if (veh != nullptr && veh->getWeightsStorage().retrieveExistingTravelTime(e, t, value)) {
         return value;
     }
     if (getInstance()->getWeightsStorage().retrieveExistingTravelTime(e, t, value)) {
@@ -165,7 +163,7 @@ MSNet::getTravelTime(const MSEdge* const e, const SUMOVehicle* const v, double t
 // ---------------------------------------------------------------------------
 MSNet*
 MSNet::getInstance(void) {
-    if (myInstance != 0) {
+    if (myInstance != nullptr) {
         return myInstance;
     }
     throw ProcessError("A network was not yet constructed.");
@@ -173,17 +171,18 @@ MSNet::getInstance(void) {
 
 
 MSNet::MSNet(MSVehicleControl* vc, MSEventControl* beginOfTimestepEvents,
-             MSEventControl* endOfTimestepEvents, MSEventControl* insertionEvents,
+             MSEventControl* endOfTimestepEvents,
+             MSEventControl* insertionEvents,
              ShapeContainer* shapeCont):
+    myAmInterrupted(false),
     myVehiclesMoved(0),
     myHavePermissions(false),
     myHasInternalLinks(false),
     myHasElevation(false),
-    myRouterTT(0),
-    myRouterEffort(0),
-    myPedestrianRouter(0),
-    myIntermodalRouter(0) {
-    if (myInstance != 0) {
+    myRouterTT(nullptr),
+    myRouterEffort(nullptr),
+    myPedestrianRouter(nullptr) {
+    if (myInstance != nullptr) {
         throw ProcessError("A network was already constructed.");
     }
     OptionsCont& oc = OptionsCont::getOptions();
@@ -191,17 +190,18 @@ MSNet::MSNet(MSVehicleControl* vc, MSEventControl* beginOfTimestepEvents,
     myMaxTeleports = oc.getInt("max-num-teleports");
     myLogExecutionTime = !oc.getBool("no-duration-log");
     myLogStepNumber = !oc.getBool("no-step-log");
-    myInserter = new MSInsertionControl(*vc, string2time(oc.getString("max-depart-delay")), oc.getBool("eager-insert"), oc.getInt("max-num-vehicles"));
+    myInserter = new MSInsertionControl(*vc, string2time(oc.getString("max-depart-delay")), oc.getBool("eager-insert"), oc.getInt("max-num-vehicles"),
+                                        string2time(oc.getString("random-depart-offset")));
     myVehicleControl = vc;
     myDetectorControl = new MSDetectorControl();
-    myEdges = 0;
-    myJunctions = 0;
-    myRouteLoaders = 0;
-    myLogics = 0;
-    myPersonControl = 0;
-    myContainerControl = 0;
-    myEdgeWeights = 0;
-    myShapeContainer = shapeCont == 0 ? new ShapeContainer() : shapeCont;
+    myEdges = nullptr;
+    myJunctions = nullptr;
+    myRouteLoaders = nullptr;
+    myLogics = nullptr;
+    myPersonControl = nullptr;
+    myContainerControl = nullptr;
+    myEdgeWeights = nullptr;
+    myShapeContainer = shapeCont == nullptr ? new ShapeContainer() : shapeCont;
 
     myBeginOfTimestepEvents = beginOfTimestepEvents;
     myEndOfTimestepEvents = endOfTimestepEvents;
@@ -240,9 +240,7 @@ MSNet::closeBuilding(const OptionsCont& oc, MSEdgeControl* edges, MSJunctionCont
     myJunctions->postloadInitContainer();
 
     // initialise performance computation
-    if (myLogExecutionTime) {
-        mySimBeginMillis = SysUtils::getCurrentMillis();
-    }
+    mySimBeginMillis = SysUtils::getCurrentMillis();
     myHasInternalLinks = hasInternalLinks;
     if (hasNeighs && MSGlobals::gLateralResolution > 0) {
         WRITE_WARNING("Opposite direction driving does not work together with the sublane model.");
@@ -254,13 +252,6 @@ MSNet::closeBuilding(const OptionsCont& oc, MSEdgeControl* edges, MSJunctionCont
 
 
 MSNet::~MSNet() {
-    // delete events first maybe they do some cleanup
-    delete myBeginOfTimestepEvents;
-    myBeginOfTimestepEvents = 0;
-    delete myEndOfTimestepEvents;
-    myEndOfTimestepEvents = 0;
-    delete myInsertionEvents;
-    myInsertionEvents = 0;
     // delete controls
     delete myJunctions;
     delete myDetectorControl;
@@ -269,27 +260,35 @@ MSNet::~MSNet() {
     delete myInserter;
     delete myLogics;
     delete myRouteLoaders;
-    if (myPersonControl != 0) {
+    if (myPersonControl != nullptr) {
         delete myPersonControl;
     }
-    if (myContainerControl != 0) {
+    if (myContainerControl != nullptr) {
         delete myContainerControl;
     }
     delete myVehicleControl; // must happen after deleting transportables
+    // delete events late so that vehicles can get rid of references first
+    delete myBeginOfTimestepEvents;
+    myBeginOfTimestepEvents = nullptr;
+    delete myEndOfTimestepEvents;
+    myEndOfTimestepEvents = nullptr;
+    delete myInsertionEvents;
+    myInsertionEvents = nullptr;
     delete myShapeContainer;
     delete myEdgeWeights;
     delete myRouterTT;
     delete myRouterEffort;
-    if (myPedestrianRouter != 0) {
-        delete myPedestrianRouter;
+    delete myPedestrianRouter;
+    for (auto& router : myIntermodalRouter) {
+        delete router.second;
     }
+    myIntermodalRouter.clear();
     myLanesRTree.second.RemoveAll();
     clearAll();
     if (MSGlobals::gUseMesoSim) {
         delete MSGlobals::gMesoNet;
     }
-//    delete myPedestrianRouter;
-    myInstance = 0;
+    myInstance = nullptr;
 }
 
 
@@ -303,7 +302,7 @@ const std::map<SUMOVehicleClass, double>*
 MSNet::getRestrictions(const std::string& id) const {
     std::map<std::string, std::map<SUMOVehicleClass, double> >::const_iterator i = myRestrictions.find(id);
     if (i == myRestrictions.end()) {
-        return 0;
+        return nullptr;
     }
     return &i->second;
 }
@@ -312,12 +311,11 @@ MSNet::getRestrictions(const std::string& id) const {
 MSNet::SimulationState
 MSNet::simulate(SUMOTime start, SUMOTime stop) {
     // report the begin when wished
-    WRITE_MESSAGE("Simulation started with time: " + time2string(start));
+    WRITE_MESSAGE("Simulation version " + std::string(VERSION_STRING) + " started with time: " + time2string(start));
     // the simulation loop
     SimulationState state = SIMSTATE_RUNNING;
     // state loading may have changed the start time so we need to reinit it
     myStep = start;
-#ifndef NO_TRACI
 #ifdef HAVE_PYTHON
     if (OptionsCont::getOptions().isSet("python-script")) {
         TraCIServer::runEmbedded(OptionsCont::getOptions().getString("python-script"));
@@ -326,7 +324,6 @@ MSNet::simulate(SUMOTime start, SUMOTime stop) {
         WRITE_MESSAGE("Reason: Script ended");
         return state;
     }
-#endif
 #endif
     while (state == SIMSTATE_RUNNING) {
         if (myLogStepNumber) {
@@ -342,17 +339,15 @@ MSNet::simulate(SUMOTime start, SUMOTime stop) {
                   << "\n simulation state: " << getStateMessage(state)
                   << std::endl;
 #endif
-#ifndef NO_TRACI
         if (state == SIMSTATE_LOADING) {
             OptionsIO::setArgs(TraCIServer::getInstance()->getLoadArgs());
             TraCIServer::getInstance()->getLoadArgs().clear();
         } else if (state != SIMSTATE_RUNNING) {
-            if (TraCIServer::getInstance() != 0 && !TraCIServer::wasClosed()) {
+            if (TraCIServer::getInstance() != nullptr && !TraCIServer::wasClosed()) {
                 // overrides SIMSTATE_END_STEP_REACHED, e.g. (TraCI ignore SUMO's --end option)
                 state = SIMSTATE_RUNNING;
             }
         }
-#endif
     }
     // report the end when wished
     WRITE_MESSAGE("Simulation ended at time: " + time2string(getCurrentTimeStep()));
@@ -362,12 +357,68 @@ MSNet::simulate(SUMOTime start, SUMOTime stop) {
     return state;
 }
 
+
 void
 MSNet::loadRoutes() {
     myRouteLoaders->loadNext(myStep);
 }
 
 
+const std::string
+MSNet::generateStatistics(SUMOTime start) {
+    long duration = SysUtils::getCurrentMillis() - mySimBeginMillis;
+    std::ostringstream msg;
+    // print performance notice
+    msg << "Performance: " << "\n" << " Duration: " << duration << "ms" << "\n";
+    if (duration != 0) {
+        msg << " Real time factor: " << (STEPS2TIME(myStep - start) * 1000. / (double)duration) << "\n";
+        msg.setf(std::ios::fixed , std::ios::floatfield);    // use decimal format
+        msg.setf(std::ios::showpoint);    // print decimal point
+        msg << " UPS: " << ((double)myVehiclesMoved / ((double)duration / 1000)) << "\n";
+    }
+    // print vehicle statistics
+    const std::string discardNotice = ((myVehicleControl->getLoadedVehicleNo() != myVehicleControl->getDepartedVehicleNo()) ?
+                                        " (Loaded: " + toString(myVehicleControl->getLoadedVehicleNo()) + ")" : "");
+    msg << "Vehicles: " << "\n"
+        << " Inserted: " << myVehicleControl->getDepartedVehicleNo() << discardNotice << "\n"
+        << " Running: " << myVehicleControl->getRunningVehicleNo() << "\n"
+        << " Waiting: " << myInserter->getWaitingVehicleNo() << "\n";
+
+    if (myVehicleControl->getTeleportCount() > 0 || myVehicleControl->getCollisionCount() > 0) {
+        // print optional teleport statistics
+        std::vector<std::string> reasons;
+        if (myVehicleControl->getCollisionCount() > 0) {
+            reasons.push_back("Collisions: " + toString(myVehicleControl->getCollisionCount()));
+        }
+        if (myVehicleControl->getTeleportsJam() > 0) {
+            reasons.push_back("Jam: " + toString(myVehicleControl->getTeleportsJam()));
+        }
+        if (myVehicleControl->getTeleportsYield() > 0) {
+            reasons.push_back("Yield: " + toString(myVehicleControl->getTeleportsYield()));
+        }
+        if (myVehicleControl->getTeleportsWrongLane() > 0) {
+            reasons.push_back("Wrong Lane: " + toString(myVehicleControl->getTeleportsWrongLane()));
+        }
+        msg << "Teleports: " << myVehicleControl->getTeleportCount() << " (" << joinToString(reasons, ", ") << ")\n";
+    }
+    if (myVehicleControl->getEmergencyStops() > 0) {
+        msg << "Emergency Stops: " << myVehicleControl->getEmergencyStops() << "\n";
+    }
+    if (myPersonControl != nullptr && myPersonControl->getLoadedNumber() > 0) {
+        msg << "Persons: " << "\n"
+            << " Inserted: " << myPersonControl->getLoadedNumber() << "\n"
+            << " Running: " << myPersonControl->getRunningNumber() << "\n";
+        if (myPersonControl->getJammedNumber() > 0) {
+            msg << " Jammed: " << myPersonControl->getJammedNumber() << "\n";
+        }
+    }
+    if (OptionsCont::getOptions().getBool("duration-log.statistics")) {
+        msg << MSDevice_Tripinfo::printStatistics();
+    }
+    return msg.str();
+}
+
+
 void
 MSNet::closeSimulation(SUMOTime start) {
     myDetectorControl->close(myStep);
@@ -381,56 +432,7 @@ MSNet::closeSimulation(SUMOTime start) {
         writeChargingStationOutput();
     }
     if (myLogExecutionTime) {
-        long duration = SysUtils::getCurrentMillis() - mySimBeginMillis;
-        std::ostringstream msg;
-        // print performance notice
-        msg << "Performance: " << "\n" << " Duration: " << duration << "ms" << "\n";
-        if (duration != 0) {
-            msg << " Real time factor: " << (STEPS2TIME(myStep - start) * 1000. / (double)duration) << "\n";
-            msg.setf(std::ios::fixed , std::ios::floatfield);    // use decimal format
-            msg.setf(std::ios::showpoint);    // print decimal point
-            msg << " UPS: " << ((double)myVehiclesMoved / ((double)duration / 1000)) << "\n";
-        }
-        // print vehicle statistics
-        const std::string discardNotice = ((myVehicleControl->getLoadedVehicleNo() != myVehicleControl->getDepartedVehicleNo()) ?
-                                           " (Loaded: " + toString(myVehicleControl->getLoadedVehicleNo()) + ")" : "");
-        msg << "Vehicles: " << "\n"
-            << " Inserted: " << myVehicleControl->getDepartedVehicleNo() << discardNotice << "\n"
-            << " Running: " << myVehicleControl->getRunningVehicleNo() << "\n"
-            << " Waiting: " << myInserter->getWaitingVehicleNo() << "\n";
-
-        if (myVehicleControl->getTeleportCount() > 0 || myVehicleControl->getCollisionCount() > 0) {
-            // print optional teleport statistics
-            std::vector<std::string> reasons;
-            if (myVehicleControl->getCollisionCount() > 0) {
-                reasons.push_back("Collisions: " + toString(myVehicleControl->getCollisionCount()));
-            }
-            if (myVehicleControl->getTeleportsJam() > 0) {
-                reasons.push_back("Jam: " + toString(myVehicleControl->getTeleportsJam()));
-            }
-            if (myVehicleControl->getTeleportsYield() > 0) {
-                reasons.push_back("Yield: " + toString(myVehicleControl->getTeleportsYield()));
-            }
-            if (myVehicleControl->getTeleportsWrongLane() > 0) {
-                reasons.push_back("Wrong Lane: " + toString(myVehicleControl->getTeleportsWrongLane()));
-            }
-            msg << "Teleports: " << myVehicleControl->getTeleportCount() << " (" << joinToString(reasons, ", ") << ")\n";
-        }
-        if (myVehicleControl->getEmergencyStops() > 0) {
-            msg << "Emergency Stops: " << myVehicleControl->getEmergencyStops() << "\n";
-        }
-        if (myPersonControl != 0 && myPersonControl->getLoadedNumber() > 0) {
-            msg << "Persons: " << "\n"
-                << " Inserted: " << myPersonControl->getLoadedNumber() << "\n"
-                << " Running: " << myPersonControl->getRunningNumber() << "\n";
-            if (myPersonControl->getJammedNumber() > 0) {
-                msg << " Jammed: " << myPersonControl->getJammedNumber() << "\n";
-            }
-        }
-        if (OptionsCont::getOptions().getBool("duration-log.statistics")) {
-            msg << MSDevice_Tripinfo::printStatistics();
-        }
-        WRITE_MESSAGE(msg.str());
+        WRITE_MESSAGE(generateStatistics(start));
     }
 }
 
@@ -442,12 +444,11 @@ MSNet::simulationStep() {
               << ", myStep = " << myStep
               << std::endl;
 #endif
-#ifndef NO_TRACI
     if (myLogExecutionTime) {
         myTraCIStepDuration = SysUtils::getCurrentMillis();
     }
     TraCIServer* t = TraCIServer::getInstance();
-    if (t != 0 && !t->isEmbedded()) {
+    if (t != nullptr && !t->isEmbedded()) {
         t->processCommandsUntilSimStep(myStep);
 #ifdef DEBUG_SIMSTEP
         bool loadRequested = !TraCI::getLoadArgs().empty();
@@ -460,7 +461,6 @@ MSNet::simulationStep() {
     }
 #ifdef DEBUG_SIMSTEP
     std::cout << SIMTIME << ": TraCI target time: " << t->getTargetTime() << std::endl;
-#endif
 #endif
     // execute beginOfTimestepEvents
     if (myLogExecutionTime) {
@@ -477,7 +477,7 @@ MSNet::simulationStep() {
     }
     myBeginOfTimestepEvents->execute(myStep);
 #ifdef HAVE_FOX
-    MSDevice_Routing::waitForAll();
+    MSRoutingEngine::waitForAll();
 #endif
     if (MSGlobals::gCheck4Accidents) {
         myEdges->detectCollisions(myStep, STAGE_EVENTS);
@@ -495,6 +495,9 @@ MSNet::simulationStep() {
         // also register ApproachingVehicleInformation for all links
         myEdges->planMovements(myStep);
 
+        // register junction approaches based on planned velocities as basis for right-of-way decision
+        myEdges->setJunctionApproaches(myStep);
+
         // decide right-of-way and execute movements
         myEdges->executeMovements(myStep);
         if (MSGlobals::gCheck4Accidents) {
@@ -511,18 +514,18 @@ MSNet::simulationStep() {
     loadRoutes();
 
     // persons
-    if (myPersonControl != 0 && myPersonControl->hasTransportables()) {
+    if (myPersonControl != nullptr && myPersonControl->hasTransportables()) {
         myPersonControl->checkWaiting(this, myStep);
     }
     // containers
-    if (myContainerControl != 0 && myContainerControl->hasTransportables()) {
+    if (myContainerControl != nullptr && myContainerControl->hasTransportables()) {
         myContainerControl->checkWaiting(this, myStep);
     }
     // insert vehicles
     myInserter->determineCandidates(myStep);
     myInsertionEvents->execute(myStep);
 #ifdef HAVE_FOX
-    MSDevice_Routing::waitForAll();
+    MSRoutingEngine::waitForAll();
 #endif
     myInserter->emitVehicles(myStep);
     if (MSGlobals::gCheck4Accidents) {
@@ -534,17 +537,13 @@ MSNet::simulationStep() {
     // execute endOfTimestepEvents
     myEndOfTimestepEvents->execute(myStep);
 
-#ifndef NO_TRACI
-    if (TraCIServer::getInstance() != 0) {
-        if (myLogExecutionTime) {
-            myTraCIStepDuration -= SysUtils::getCurrentMillis();
-        }
-        libsumo::Helper::postProcessRemoteControl();
-        if (myLogExecutionTime) {
-            myTraCIStepDuration += SysUtils::getCurrentMillis();
-        }
+    if (myLogExecutionTime) {
+        myTraCIStepDuration -= SysUtils::getCurrentMillis();
+    }
+    libsumo::Helper::postProcessRemoteControl();
+    if (myLogExecutionTime) {
+        myTraCIStepDuration += SysUtils::getCurrentMillis();
     }
-#endif
     // update and write (if needed) detector values
     writeOutput();
 
@@ -558,22 +557,17 @@ MSNet::simulationStep() {
 
 MSNet::SimulationState
 MSNet::simulationState(SUMOTime stopTime) const {
-#ifndef NO_TRACI
     if (TraCIServer::wasClosed()) {
         return SIMSTATE_CONNECTION_CLOSED;
     }
-    if (TraCIServer::getInstance() != 0 && !TraCIServer::getInstance()->getLoadArgs().empty()) {
+    if (TraCIServer::getInstance() != nullptr && !TraCIServer::getInstance()->getLoadArgs().empty()) {
         return SIMSTATE_LOADING;
     }
-    if ((stopTime < 0 || myStep > stopTime) && TraCIServer::getInstance() == 0) {
-#else
-    if (stopTime < 0 || myStep > stopTime) {
-#endif
-        if (myInsertionEvents->isEmpty()
-                && (myVehicleControl->getActiveVehicleCount() == 0)
+    if ((stopTime < 0 || myStep > stopTime) && TraCIServer::getInstance() == nullptr) {
+        if ((myVehicleControl->getActiveVehicleCount() == 0)
                 && (myInserter->getPendingFlowCount() == 0)
-                && (myPersonControl == 0 || !myPersonControl->hasNonWaiting())
-                && (myContainerControl == 0 || !myContainerControl->hasNonWaiting())) {
+                && (myPersonControl == nullptr || !myPersonControl->hasNonWaiting())
+                && (myContainerControl == nullptr || !myContainerControl->hasNonWaiting())) {
             if (myPersonControl) {
                 myPersonControl->abortWaitingForVehicle();
             }
@@ -590,6 +584,9 @@ MSNet::simulationState(SUMOTime stopTime) const {
     if (myMaxTeleports >= 0 && myVehicleControl->getTeleportCount() > myMaxTeleports) {
         return SIMSTATE_TOO_MANY_TELEPORTS;
     }
+    if (myAmInterrupted) {
+        return SIMSTATE_INTERRUPTED;
+    }
     return SIMSTATE_RUNNING;
 }
 
@@ -606,7 +603,9 @@ MSNet::getStateMessage(MSNet::SimulationState state) {
         case MSNet::SIMSTATE_CONNECTION_CLOSED:
             return "TraCI requested termination.";
         case MSNet::SIMSTATE_ERROR_IN_SIM:
-            return "An error occured (see log).";
+            return "An error occurred (see log).";
+        case MSNet::SIMSTATE_INTERRUPTED:
+            return "Interrupted.";
         case MSNet::SIMSTATE_TOO_MANY_TELEPORTS:
             return "Too many teleports.";
         case MSNet::SIMSTATE_LOADING:
@@ -631,13 +630,14 @@ MSNet::clearAll() {
     MSCModel_NonInteracting::cleanup();
     MSDevice_BTsender::cleanup();
     MSDevice_SSM::cleanup();
-#ifndef NO_TRACI
+    MSDevice_ToC::cleanup();
+    MSStopOut::cleanup();
     TraCIServer* t = TraCIServer::getInstance();
-    if (t != 0) {
+    if (t != nullptr) {
         t->cleanup();
     }
     libsumo::Helper::cleanup();
-#endif
+    OutputDevice::closeAll(true);
 }
 
 
@@ -719,8 +719,8 @@ MSNet::writeOutput() {
         od.writeAttr("ended", myVehicleControl->getEndedVehicleNo());
         od.writeAttr("meanWaitingTime", meanWaitingTime);
         od.writeAttr("meanTravelTime", meanTravelTime);
-        od.writeAttr("halting", getHaltingVehicleNumber());
-        std::pair<double, double> meanSpeed = getVehicleMeanSpeeds();
+        od.writeAttr("halting", myVehicleControl->getHaltingVehicleNo());
+        std::pair<double, double> meanSpeed = myVehicleControl->getVehicleMeanSpeeds();
         od.writeAttr("meanSpeed", meanSpeed.first);
         od.writeAttr("meanSpeedRelative", meanSpeed.second);
         if (myLogExecutionTime) {
@@ -751,10 +751,18 @@ MSNet::writeOutput() {
     }
 
     // write SSM output
-    for (std::set<MSDevice*>::iterator di = MSDevice_SSM::getInstances().begin(); di != MSDevice_SSM::getInstances().end(); ++di) {
-        MSDevice_SSM* dev = static_cast<MSDevice_SSM*>(*di);
+    for (std::set<MSDevice_SSM*>::iterator di = MSDevice_SSM::getInstances().begin(); di != MSDevice_SSM::getInstances().end(); ++di) {
+        MSDevice_SSM* dev = (*di);
         dev->updateAndWriteOutput();
     }
+
+    // write ToC output
+    for (std::set<MSDevice_ToC*>::iterator di = MSDevice_ToC::getInstances().begin(); di != MSDevice_ToC::getInstances().end(); ++di) {
+        MSDevice_ToC* dev = (*di);
+        if (dev->generatesOutput()) {
+            dev->writeOutput();
+        }
+    }
 }
 
 
@@ -766,7 +774,7 @@ MSNet::logSimulationDuration() const {
 
 MSTransportableControl&
 MSNet::getPersonControl() {
-    if (myPersonControl == 0) {
+    if (myPersonControl == nullptr) {
         myPersonControl = new MSTransportableControl();
     }
     return *myPersonControl;
@@ -774,7 +782,7 @@ MSNet::getPersonControl() {
 
 MSTransportableControl&
 MSNet::getContainerControl() {
-    if (myContainerControl == 0) {
+    if (myContainerControl == nullptr) {
         myContainerControl = new MSTransportableControl();
     }
     return *myContainerControl;
@@ -783,7 +791,7 @@ MSNet::getContainerControl() {
 
 MSEdgeWeightsStorage&
 MSNet::getWeightsStorage() {
-    if (myEdgeWeights == 0) {
+    if (myEdgeWeights == nullptr) {
         myEdgeWeights = new MSEdgeWeightsStorage();
     }
     return *myEdgeWeights;
@@ -812,11 +820,9 @@ MSNet::postSimStepOutput() const {
             oss << " (0ms ?*RT. ?";
         }
         oss << "UPS, ";
-#ifndef NO_TRACI
-        if (TraCIServer::getInstance() != 0) {
+        if (TraCIServer::getInstance() != nullptr) {
             oss << "TraCI: " << myTraCIStepDuration << "ms, ";
         }
-#endif
         oss << "vehicles TOT " << myVehicleControl->getDepartedVehicleNo()
             << " ACT " << myVehicleControl->getRunningVehicleNo()
             << " BUF " << myInserter->getWaitingVehicleNo()
@@ -846,9 +852,9 @@ MSNet::removeVehicleStateListener(VehicleStateListener* listener) {
 
 
 void
-MSNet::informVehicleStateListener(const SUMOVehicle* const vehicle, VehicleState to) {
+MSNet::informVehicleStateListener(const SUMOVehicle* const vehicle, VehicleState to, const std::string& info) {
     for (std::vector<VehicleStateListener*>::iterator i = myVehicleStateListeners.begin(); i != myVehicleStateListeners.end(); ++i) {
-        (*i)->vehicleStateChanged(vehicle, to);
+        (*i)->vehicleStateChanged(vehicle, to, info);
     }
 }
 
@@ -864,7 +870,7 @@ MSNet::getStoppingPlace(const std::string& id, const SumoXMLTag category) const
     if (myStoppingPlaces.count(category) > 0) {
         return myStoppingPlaces.find(category)->second.get(id);
     }
-    return 0;
+    return nullptr;
 }
 
 
@@ -873,7 +879,7 @@ MSNet::getStoppingPlaceID(const MSLane* lane, const double pos, const SumoXMLTag
     if (myStoppingPlaces.count(category) > 0) {
         for (const auto& it : myStoppingPlaces.find(category)->second) {
             MSStoppingPlace* stop = it.second;
-            if (&stop->getLane() == lane && stop->getBeginLanePosition() <= pos && stop->getEndLanePosition() >= pos) {
+            if (&stop->getLane() == lane && stop->getBeginLanePosition() - POSITION_EPS <= pos && stop->getEndLanePosition() + POSITION_EPS >= pos) {
                 return stop->getID();
             }
         }
@@ -895,39 +901,39 @@ MSNet::writeChargingStationOutput() const {
 
 SUMOAbstractRouter<MSEdge, SUMOVehicle>&
 MSNet::getRouterTT(const MSEdgeVector& prohibited) const {
-    if (myRouterTT == 0) {
+    if (myRouterTT == nullptr) {
         const std::string routingAlgorithm = OptionsCont::getOptions().getString("routing-algorithm");
         if (routingAlgorithm == "dijkstra") {
-            myRouterTT = new DijkstraRouter<MSEdge, SUMOVehicle, prohibited_withPermissions<MSEdge, SUMOVehicle> >(
+            myRouterTT = new DijkstraRouter<MSEdge, SUMOVehicle, SUMOAbstractRouterPermissions<MSEdge, SUMOVehicle> >(
                 MSEdge::getAllEdges(), true, &MSNet::getTravelTime);
         } else {
             if (routingAlgorithm != "astar") {
                 WRITE_WARNING("TraCI and Triggers cannot use routing algorithm '" + routingAlgorithm + "'. using 'astar' instead.");
             }
-            myRouterTT = new AStarRouter<MSEdge, SUMOVehicle, prohibited_withPermissions<MSEdge, SUMOVehicle> >(
+            myRouterTT = new AStarRouter<MSEdge, SUMOVehicle, SUMOAbstractRouterPermissions<MSEdge, SUMOVehicle> >(
                 MSEdge::getAllEdges(), true, &MSNet::getTravelTime);
         }
     }
-    dynamic_cast<prohibited_withPermissions<MSEdge, SUMOVehicle>*>(myRouterTT)->prohibit(prohibited);
+    dynamic_cast<SUMOAbstractRouterPermissions<MSEdge, SUMOVehicle>*>(myRouterTT)->prohibit(prohibited);
     return *myRouterTT;
 }
 
 
 SUMOAbstractRouter<MSEdge, SUMOVehicle>&
 MSNet::getRouterEffort(const MSEdgeVector& prohibited) const {
-    if (myRouterEffort == 0) {
-        myRouterEffort = new DijkstraRouter<MSEdge, SUMOVehicle, prohibited_withPermissions<MSEdge, SUMOVehicle> >(
+    if (myRouterEffort == nullptr) {
+        myRouterEffort = new DijkstraRouter<MSEdge, SUMOVehicle, SUMOAbstractRouterPermissions<MSEdge, SUMOVehicle> >(
             MSEdge::getAllEdges(), true, &MSNet::getEffort, &MSNet::getTravelTime);
     }
-    dynamic_cast<prohibited_withPermissions<MSEdge, SUMOVehicle>*>(myRouterEffort)->prohibit(prohibited);
+    dynamic_cast<SUMOAbstractRouterPermissions<MSEdge, SUMOVehicle>*>(myRouterEffort)->prohibit(prohibited);
     return *myRouterEffort;
 }
 
 
-MSNet::MSPedestrianRouterDijkstra&
+MSNet::MSPedestrianRouter&
 MSNet::getPedestrianRouter(const MSEdgeVector& prohibited) const {
-    if (myPedestrianRouter == 0) {
-        myPedestrianRouter = new MSPedestrianRouterDijkstra();
+    if (myPedestrianRouter == nullptr) {
+        myPedestrianRouter = new MSPedestrianRouter();
     }
     myPedestrianRouter->prohibit(prohibited);
     return *myPedestrianRouter;
@@ -935,22 +941,28 @@ MSNet::getPedestrianRouter(const MSEdgeVector& prohibited) const {
 
 
 MSNet::MSIntermodalRouter&
-MSNet::getIntermodalRouter(const MSEdgeVector& prohibited) const {
-    if (myIntermodalRouter == 0) {
+MSNet::getIntermodalRouter(const int routingMode, const MSEdgeVector& prohibited) const {
+    if (myIntermodalRouter.count(routingMode) == 0) {
         int carWalk = 0;
         for (const std::string& opt : OptionsCont::getOptions().getStringVector("persontrip.transfer.car-walk")) {
             if (opt == "parkingAreas") {
-                carWalk |= MSIntermodalRouter::PARKING_AREAS;
+                carWalk |= MSIntermodalRouter::Network::PARKING_AREAS;
             } else if (opt == "ptStops") {
-                carWalk |= MSIntermodalRouter::PT_STOPS;
+                carWalk |= MSIntermodalRouter::Network::PT_STOPS;
             } else if (opt == "allJunctions") {
-                carWalk |= MSIntermodalRouter::ALL_JUNCTIONS;
+                carWalk |= MSIntermodalRouter::Network::ALL_JUNCTIONS;
             }
         }
-        myIntermodalRouter = new MSIntermodalRouter(MSNet::adaptIntermodalRouter, carWalk);
+        const std::string routingAlgorithm = OptionsCont::getOptions().getString("routing-algorithm");
+        if (routingMode == ROUTING_MODE_COMBINED) {
+            // replace nullptr here by your EffortCalculator
+            myIntermodalRouter[routingMode] = new MSIntermodalRouter(MSNet::adaptIntermodalRouter, carWalk, routingAlgorithm, routingMode, nullptr);
+        } else {
+            myIntermodalRouter[routingMode] = new MSIntermodalRouter(MSNet::adaptIntermodalRouter, carWalk, routingAlgorithm, routingMode);
+        }
     }
-    myIntermodalRouter->prohibit(prohibited);
-    return *myIntermodalRouter;
+    myIntermodalRouter[routingMode]->prohibit(prohibited);
+    return *myIntermodalRouter[routingMode];
 }
 
 
@@ -958,13 +970,15 @@ void
 MSNet::adaptIntermodalRouter(MSIntermodalRouter& router) {
     // add access to all parking areas
     for (const auto& i : myInstance->myStoppingPlaces[SUMO_TAG_PARKING_AREA]) {
-        router.addAccess(i.first, &i.second->getLane().getEdge(), i.second->getAccessPos(&i.second->getLane().getEdge()), SUMO_TAG_PARKING_AREA);
+        const MSEdge* const edge = &i.second->getLane().getEdge();
+        router.getNetwork()->addAccess(i.first, edge, i.second->getAccessPos(edge), i.second->getAccessDistance(edge), SUMO_TAG_PARKING_AREA);
     }
     // add access to all public transport stops
     for (const auto& i : myInstance->myStoppingPlaces[SUMO_TAG_BUS_STOP]) {
-        router.addAccess(i.first, &i.second->getLane().getEdge(), i.second->getAccessPos(&i.second->getLane().getEdge()), SUMO_TAG_BUS_STOP);
+        const MSEdge* const edge = &i.second->getLane().getEdge();
+        router.getNetwork()->addAccess(i.first, edge, i.second->getAccessPos(edge), i.second->getAccessDistance(edge), SUMO_TAG_BUS_STOP);
         for (const auto& a : i.second->getAllAccessPos()) {
-            router.addAccess(i.first, &a.first->getEdge(), a.second, SUMO_TAG_BUS_STOP);
+            router.getNetwork()->addAccess(i.first, &std::get<0>(a)->getEdge(), std::get<1>(a), std::get<2>(a), SUMO_TAG_BUS_STOP);
         }
     }
     myInstance->getInsertionControl().adaptIntermodalRouter(router);
@@ -996,38 +1010,13 @@ MSNet::checkElevation() {
 }
 
 
-int
-MSNet::getHaltingVehicleNumber() const {
-    int result = 0;
-    for (MSVehicleControl::constVehIt it = myVehicleControl->loadedVehBegin(); it != myVehicleControl->loadedVehEnd(); ++it) {
-        const SUMOVehicle* veh = it->second;
-        if ((veh->isOnRoad() || veh->isRemoteControlled()) && veh->getSpeed() < SUMO_const_haltingSpeed)  {
-            result++;
-        }
+bool
+MSNet::warnOnce(const std::string& typeAndID) {
+    if (myWarnedOnce.find(typeAndID) == myWarnedOnce.end()) {
+        myWarnedOnce[typeAndID] = true;
+        return true;
     }
-    return result;
+    return false;
 }
 
-
-std::pair<double, double>
-MSNet::getVehicleMeanSpeeds() const {
-    double speedSum = 0;
-    double relSpeedSum = 0;
-    int count = 0;
-    for (MSVehicleControl::constVehIt it = myVehicleControl->loadedVehBegin(); it != myVehicleControl->loadedVehEnd(); ++it) {
-        const SUMOVehicle* veh = it->second;
-        if ((veh->isOnRoad() || veh->isRemoteControlled()) && !veh->isStopped()) {
-            count++;
-            speedSum += veh->getSpeed();
-            relSpeedSum += veh->getSpeed() / veh->getEdge()->getSpeedLimit();
-        }
-    }
-    if (count > 0) {
-        return std::make_pair(speedSum / count, relSpeedSum / count);
-    } else {
-        return std::make_pair(-1, -1);
-    }
-}
-
-
 /****************************************************************************/
