@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSNet.h
 /// @author  Christian Roessel
@@ -29,11 +27,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <typeinfo>
 #include <vector>
@@ -48,19 +42,14 @@
 #include <utils/common/NamedObjectCont.h>
 #include <utils/common/NamedRTree.h>
 #include <utils/vehicle/SUMOAbstractRouter.h>
-#include <utils/vehicle/PedestrianRouter.h>
-#include <utils/vehicle/IntermodalRouter.h>
 #include <microsim/trigger/MSChargingStation.h>
 #include "MSJunction.h"
-#include "MSParkingArea.h"
-#include "MSStoppingPlace.h"
 
 
 // ===========================================================================
 // class declarations
 // ===========================================================================
 class MSEdge;
-class MSJunction;
 class MSEdgeControl;
 class MSEventControl;
 class MSVehicleControl;
@@ -72,13 +61,18 @@ class MSVehicle;
 class MSRoute;
 class MSLane;
 class MSTLLogicControl;
+class MSTrafficLightLogic;
 class MSDetectorControl;
 class ShapeContainer;
 class BinaryInputDevice;
 class MSEdgeWeightsStorage;
 class SUMOVehicle;
+class MSStoppingPlace;
+template<class E, class L, class N, class V>
+class IntermodalRouter;
+template<class E, class L, class N, class V>
+class PedestrianRouter;
 
-typedef std::vector<MSEdge*> MSEdgeVector;
 
 // ===========================================================================
 // class definitions
@@ -103,14 +97,15 @@ public:
         SIMSTATE_NO_FURTHER_VEHICLES,
         /// @brief The connection to a client was closed by the client
         SIMSTATE_CONNECTION_CLOSED,
-        /// @brief An error occured during the simulation step
+        /// @brief An error occurred during the simulation step
         SIMSTATE_ERROR_IN_SIM,
+        /// @brief An external interrupt occured
+        SIMSTATE_INTERRUPTED,
         /// @brief The simulation had too many teleports
         SIMSTATE_TOO_MANY_TELEPORTS
     };
 
-    //typedef PedestrianRouterDijkstra<MSEdge, MSLane> MSPedestrianRouterDijkstra;
-    typedef PedestrianRouterDijkstra<MSEdge, MSLane, MSJunction, MSVehicle> MSPedestrianRouterDijkstra;
+    typedef PedestrianRouter<MSEdge, MSLane, MSJunction, MSVehicle> MSPedestrianRouter;
     typedef IntermodalRouter<MSEdge, MSLane, MSJunction, SUMOVehicle> MSIntermodalRouter;
 
 
@@ -122,6 +117,14 @@ public:
     static MSNet* getInstance();
 
 
+    /** @brief Returns whether the network was already constructed
+    * @return whether the network was already constructed
+    */
+    static bool hasInstance() {
+        return myInstance != nullptr;
+    }
+
+
     /** @brief Constructor
      *
      * This constructor builds a net of which only some basic structures are initialised.
@@ -137,7 +140,8 @@ public:
      * @see closeBuilding
      */
     MSNet(MSVehicleControl* vc, MSEventControl* beginOfTimestepEvents,
-          MSEventControl* endOfTimestepEvents, MSEventControl* insertionEvents,
+          MSEventControl* endOfTimestepEvents,
+          MSEventControl* insertionEvents,
           ShapeContainer* shapeCont = 0);
 
 
@@ -223,12 +227,18 @@ public:
     void loadRoutes();
 
 
+    /** @brief Writes performance output and running vehicle stats
+     *
+     * @param[in] start The step the simulation was started with
+     */
+    const std::string generateStatistics(SUMOTime start);
+
+
     /** @brief Closes the simulation (all files, connections, etc.)
      *
      * Writes also performance output
      *
      * @param[in] start The step the simulation was started with
-     * @todo What exceptions may occure?
      */
     void closeSimulation(SUMOTime start);
 
@@ -474,6 +484,8 @@ public:
     /// @brief write charging station output
     void writeChargingStationOutput() const;
 
+    /// @brief creates a wrapper for the given logic (see GUINet)
+    virtual void createTLWrapper(MSTrafficLightLogic*) {};
 
     /// @name Notification about vehicle state changes
     /// @{
@@ -499,7 +511,11 @@ public:
         /// @brief The vehicles starts to stop
         VEHICLE_STATE_STARTING_STOP,
         /// @brief The vehicle ends to stop
-        VEHICLE_STATE_ENDING_STOP
+        VEHICLE_STATE_ENDING_STOP,
+        /// @brief The vehicle is involved in a collision
+        VEHICLE_STATE_COLLISION,
+        /// @brief The vehicle had to brake harder than permitted
+        VEHICLE_STATE_EMERGENCYSTOP
     };
 
 
@@ -517,8 +533,9 @@ public:
         /** @brief Called if a vehicle changes its state
          * @param[in] vehicle The vehicle which changed its state
          * @param[in] to The state the vehicle has changed to
+         * @param[in] info Additional information on the state change
          */
-        virtual void vehicleStateChanged(const SUMOVehicle* const vehicle, VehicleState to) = 0;
+        virtual void vehicleStateChanged(const SUMOVehicle* const vehicle, VehicleState to, const std::string& info = "") = 0;
 
     };
 
@@ -538,9 +555,10 @@ public:
     /** @brief Informs all added listeners about a vehicle's state change
      * @param[in] vehicle The vehicle which changed its state
      * @param[in] to The state the vehicle has changed to
+     * @param[in] info Information regarding the replacement
      * @see VehicleStateListener:vehicleStateChanged
      */
-    void informVehicleStateListener(const SUMOVehicle* const vehicle, VehicleState to);
+    void informVehicleStateListener(const SUMOVehicle* const vehicle, VehicleState to, const std::string& info = "");
     /// @}
 
 
@@ -572,8 +590,8 @@ public:
         const MSEdgeVector& prohibited = MSEdgeVector()) const;
     SUMOAbstractRouter<MSEdge, SUMOVehicle>& getRouterEffort(
         const MSEdgeVector& prohibited = MSEdgeVector()) const;
-    MSPedestrianRouterDijkstra& getPedestrianRouter(const MSEdgeVector& prohibited = MSEdgeVector()) const;
-    MSIntermodalRouter& getIntermodalRouter(const MSEdgeVector& prohibited = MSEdgeVector()) const;
+    MSPedestrianRouter& getPedestrianRouter(const MSEdgeVector& prohibited = MSEdgeVector()) const;
+    MSIntermodalRouter& getIntermodalRouter(const int routingMode = 0, const MSEdgeVector& prohibited = MSEdgeVector()) const;
 
     static void adaptIntermodalRouter(MSIntermodalRouter& router);
 
@@ -599,25 +617,25 @@ public:
     }
 
     /// @brief return the network version
-    double version() const {
+    double getNetworkVersion() const {
         return myVersion;
     }
 
+    /// @brief return whether a warning regarding the given object shall be issued
+    bool warnOnce(const std::string& typeAndID);
+
+    void interrupt() {
+        myAmInterrupted = true;
+    }
+
+    bool isInterrupted() const {
+        return myAmInterrupted;
+    }
+
 protected:
     /// @brief check all lanes for elevation data
     bool checkElevation();
 
-    /// @brief count number of standing vehicles in the network
-    int getHaltingVehicleNumber() const;
-
-    /// @brief get current absolute and relative mean vehicle speed in the network
-    std::pair<double, double> getVehicleMeanSpeeds() const;
-    double getVehicleMeanSpeed() const {
-        return getVehicleMeanSpeeds().first;
-    }
-    double getVehicleMeanSpeedRelative() const {
-        return getVehicleMeanSpeeds().second;
-    }
 
 protected:
     /// @brief Unique instance of MSNet
@@ -632,6 +650,9 @@ protected:
     /// @brief Maximum number of teleports.
     int myMaxTeleports;
 
+    /// @brief whether an interrupt occured
+    bool myAmInterrupted;
+
 
 
     /// @name Substructures
@@ -728,6 +749,8 @@ protected:
     /// @brief Container for vehicle state listener
     std::vector<VehicleStateListener*> myVehicleStateListeners;
 
+    /// @brief container to record warnings that shall only be issued once
+    std::map<std::string, bool> myWarnedOnce;
 
     /* @brief The router instance for routing by trigger and by traci
      * @note MSDevice_Routing has its own instance since it uses a different weight function
@@ -735,8 +758,8 @@ protected:
      * because the class structure makes it inconvenient to use a superclass*/
     mutable SUMOAbstractRouter<MSEdge, SUMOVehicle>* myRouterTT;
     mutable SUMOAbstractRouter<MSEdge, SUMOVehicle>* myRouterEffort;
-    mutable MSPedestrianRouterDijkstra* myPedestrianRouter;
-    mutable MSIntermodalRouter* myIntermodalRouter;
+    mutable MSPedestrianRouter* myPedestrianRouter;
+    mutable std::map<int, MSIntermodalRouter*> myIntermodalRouter;
 
 
     /// @brief An RTree structure holding lane IDs
