@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSTransportable.h
 /// @author  Michael Behrisch
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <set>
 #include <cassert>
@@ -35,6 +29,7 @@
 #include <utils/geom/Position.h>
 #include <utils/geom/PositionVector.h>
 #include <utils/geom/Boundary.h>
+#include <utils/vehicle/SUMOAbstractRouter.h>
 
 
 // ===========================================================================
@@ -65,7 +60,9 @@ public:
         WAITING_FOR_DEPART = 0,
         WAITING = 1,
         MOVING_WITHOUT_VEHICLE = 2, // walking for persons, tranship for containers
-        DRIVING = 3
+        DRIVING = 3,
+        ACCESS = 4,
+        TRIP = 5
     };
 
     /**
@@ -75,16 +72,16 @@ public:
     class Stage {
     public:
         /// constructor
-        Stage(const MSEdge& destination, MSStoppingPlace* toStop, const double arrivalPos, StageType type);
+        Stage(const MSEdge* destination, MSStoppingPlace* toStop, const double arrivalPos, StageType type);
 
         /// destructor
         virtual ~Stage();
 
         /// returns the destination edge
-        const MSEdge& getDestination() const;
+        const MSEdge* getDestination() const;
 
         /// returns the destination stop (if any)
-        const MSStoppingPlace* getDestinationStop() const {
+        MSStoppingPlace* getDestinationStop() const {
             return myDestinationStop;
         }
 
@@ -93,9 +90,9 @@ public:
         }
 
         /// Returns the current edge
-        virtual const MSEdge* getEdge() const = 0;
-        virtual const MSEdge* getFromEdge() const = 0;
-        virtual double getEdgePos(SUMOTime now) const = 0;
+        virtual const MSEdge* getEdge() const;
+        virtual const MSEdge* getFromEdge() const;
+        virtual double getEdgePos(SUMOTime now) const;
 
         /// returns the position of the transportable
         virtual Position getPosition(SUMOTime now) const = 0;
@@ -108,9 +105,12 @@ public:
             return myType;
         }
 
-        /// @brief return string representation of the current stage
+        /// @brief return (brief) string representation of the current stage
         virtual std::string getStageDescription() const = 0;
 
+        /// @brief return string summary of the current stage
+        virtual std::string getStageSummary() const = 0;
+
         /// proceeds to this stage
         virtual void proceed(MSNet* net, MSTransportable* transportable, SUMOTime now, Stage* previous) = 0;
 
@@ -124,7 +124,7 @@ public:
         void setDeparted(SUMOTime now);
 
         /// logs end of the step
-        virtual void setArrived(SUMOTime now);
+        virtual void setArrived(MSNet* net, MSTransportable* transportable, SUMOTime now);
 
         /// Whether the transportable waits for a vehicle of the line specified.
         virtual bool isWaitingFor(const std::string& line) const;
@@ -136,17 +136,17 @@ public:
 
         /// @brief Whether the transportable waits for a vehicle
         virtual SUMOVehicle* getVehicle() const {
-            return 0;
+            return nullptr;
         }
 
         /// @brief the time this transportable spent waiting
-        virtual SUMOTime getWaitingTime(SUMOTime now) const = 0;
+        virtual SUMOTime getWaitingTime(SUMOTime now) const;
 
         /// @brief the speed of the transportable
-        virtual double getSpeed() const = 0;
+        virtual double getSpeed() const;
 
         /// @brief the edges of the current stage
-        virtual ConstMSEdgeVector getEdges() const = 0;
+        virtual ConstMSEdgeVector getEdges() const;
 
         /// @brief get position on edge e at length at with orthogonal offset
         Position getEdgePosition(const MSEdge* e, double at, double offset) const;
@@ -161,13 +161,14 @@ public:
          * @param[in] os The stream to write the information into
          * @exception IOError not yet implemented
          */
-        virtual void tripInfoOutput(OutputDevice& os, MSTransportable* transportable) const = 0;
+        virtual void tripInfoOutput(OutputDevice& os, const MSTransportable* const transportable) const = 0;
 
         /** @brief Called on writing vehroute output
          * @param[in] os The stream to write the information into
+         * @param[in] withRouteLength whether route length shall be written
          * @exception IOError not yet implemented
          */
-        virtual void routeOutput(OutputDevice& os) const = 0;
+        virtual void routeOutput(OutputDevice& os, const bool withRouteLength) const = 0;
 
         /** @brief Called for writing the events output (begin of an action)
          * @param[in] os The stream to write the information into
@@ -183,10 +184,10 @@ public:
 
     protected:
         /// the next edge to reach by getting transported
-        const MSEdge& myDestination;
+        const MSEdge* myDestination;
 
         /// the stop to reach by getting transported (if any)
-        MSStoppingPlace* const myDestinationStop;
+        MSStoppingPlace* myDestinationStop;
 
         /// the position at which we want to arrive
         double myArrivalPos;
@@ -210,39 +211,37 @@ public:
     };
 
     /**
-    * A "real" stage performing a waiting over the specified time
+    * A "placeholder" stage storing routing info which will result in real stages when routed
     */
-    class Stage_Waiting : public Stage {
+    class Stage_Trip : public Stage {
     public:
         /// constructor
-        Stage_Waiting(const MSEdge& destination, SUMOTime duration, SUMOTime until,
-                      double pos, const std::string& actType, const bool initial);
+        Stage_Trip(const MSEdge* origin, const MSEdge* destination, MSStoppingPlace* toStop, const SUMOTime duration, const SVCPermissions modeSet,
+            const std::string& vTypes, const double speed, const double walkFactor, const double departPosLat, const bool hasArrivalPos, const double arrivalPos);
 
         /// destructor
-        virtual ~Stage_Waiting();
+        virtual ~Stage_Trip();
 
-        /// abort this stage (TraCI)
-        void abort(MSTransportable*);
-
-        /// Returns the current edge
         const MSEdge* getEdge() const;
-        const MSEdge* getFromEdge() const;
-        double getEdgePos(SUMOTime now) const;
-        SUMOTime getUntil() const;
 
-        ///
+        double getEdgePos(SUMOTime now) const;
+
         Position getPosition(SUMOTime now) const;
 
         double getAngle(SUMOTime now) const;
 
-        SUMOTime getWaitingTime(SUMOTime now) const;
-
-        double getSpeed() const;
-
-        ConstMSEdgeVector getEdges() const;
-
         std::string getStageDescription() const {
-            return "waiting (" + myActType + ")";
+            return "trip";
+        }
+
+        std::string getStageSummary() const;
+
+        /// logs end of the step
+        virtual void setArrived(MSNet* net, MSTransportable* transportable, SUMOTime now);
+
+        /// change origin for parking area rerouting 
+        void setOrigin(const MSEdge* origin) {
+            myOrigin = origin;
         }
 
         /// proceeds to the next step
@@ -253,14 +252,110 @@ public:
         * @param[in] os The stream to write the information into
         * @exception IOError not yet implemented
         */
-        virtual void tripInfoOutput(OutputDevice& os, MSTransportable* transportable) const;
+        virtual void tripInfoOutput(OutputDevice& os, const MSTransportable* const transportable) const;
 
         /** @brief Called on writing vehroute output
         *
         * @param[in] os The stream to write the information into
         * @exception IOError not yet implemented
         */
-        virtual void routeOutput(OutputDevice& os) const;
+        virtual void routeOutput(OutputDevice& os, const bool withRouteLength) const;
+
+        /** @brief Called for writing the events output
+        * @param[in] os The stream to write the information into
+        * @exception IOError not yet implemented
+        */
+        virtual void beginEventOutput(const MSTransportable& p, SUMOTime t, OutputDevice& os) const;
+
+        /** @brief Called for writing the events output (end of an action)
+        * @param[in] os The stream to write the information into
+        * @exception IOError not yet implemented
+        */
+        virtual void endEventOutput(const MSTransportable& p, SUMOTime t, OutputDevice& os) const;
+
+    private:
+        /// the origin edge
+        const MSEdge* myOrigin;
+
+        /// the time the trip should take (applies to only walking)
+        SUMOTime myDuration;
+
+        /// @brief The allowed modes of transportation
+        const SVCPermissions myModeSet;
+
+        /// @brief The possible vehicles to use
+        const std::string myVTypes;
+
+        /// @brief The walking speed
+        const double mySpeed;
+
+        /// @brief The factor to apply to walking durations
+        const double myWalkFactor;
+
+        /// @brief The depart position
+        double myDepartPos;
+
+        /// @brief The lateral depart position
+        const double myDepartPosLat;
+
+        /// @brief whether an arrivalPos was in the input
+        const bool myHaveArrivalPos;
+
+    private:
+        /// @brief Invalidated copy constructor.
+        Stage_Trip(const Stage_Trip&);
+
+        /// @brief Invalidated assignment operator.
+        Stage_Trip& operator=(const Stage_Trip&);
+
+    };
+
+    /**
+    * A "real" stage performing a waiting over the specified time
+    */
+    class Stage_Waiting : public Stage {
+    public:
+        /// constructor
+        Stage_Waiting(const MSEdge* destination, SUMOTime duration, SUMOTime until,
+                      double pos, const std::string& actType, const bool initial);
+
+        /// destructor
+        virtual ~Stage_Waiting();
+
+        /// abort this stage (TraCI)
+        void abort(MSTransportable*);
+
+        SUMOTime getUntil() const;
+
+        ///
+        Position getPosition(SUMOTime now) const;
+
+        double getAngle(SUMOTime now) const;
+
+        SUMOTime getWaitingTime(SUMOTime now) const;
+
+        std::string getStageDescription() const {
+            return "waiting (" + myActType + ")";
+        }
+
+        std::string getStageSummary() const;
+
+        /// proceeds to the next step
+        virtual void proceed(MSNet* net, MSTransportable* transportable, SUMOTime now, Stage* previous);
+
+        /** @brief Called on writing tripinfo output
+        *
+        * @param[in] os The stream to write the information into
+        * @exception IOError not yet implemented
+        */
+        virtual void tripInfoOutput(OutputDevice& os, const MSTransportable* const transportable) const;
+
+        /** @brief Called on writing vehroute output
+        *
+        * @param[in] os The stream to write the information into
+        * @exception IOError not yet implemented
+        */
+        virtual void routeOutput(OutputDevice& os, const bool withRouteLength) const;
 
         /** @brief Called for writing the events output
         * @param[in] os The stream to write the information into
@@ -300,8 +395,9 @@ public:
     class Stage_Driving : public Stage {
     public:
         /// constructor
-        Stage_Driving(const MSEdge& destination, MSStoppingPlace* toStop,
-                      const double arrivalPos, const std::vector<std::string>& lines);
+        Stage_Driving(const MSEdge* destination, MSStoppingPlace* toStop,
+                      const double arrivalPos, const std::vector<std::string>& lines,
+                      const std::string& intendedVeh = "", SUMOTime intendedDepart = -1);
 
         /// destructor
         virtual ~Stage_Driving();
@@ -339,10 +435,12 @@ public:
 
         ConstMSEdgeVector getEdges() const;
 
+        void setDestination(const MSEdge* newDestination, MSStoppingPlace* newDestStop);
+
         void setVehicle(SUMOVehicle* v);
 
         /// @brief marks arrival time and records driven distance
-        void setArrived(SUMOTime now);
+        void setArrived(MSNet* net, MSTransportable* transportable, SUMOTime now);
 
         /** @brief Called for writing the events output
         * @param[in] os The stream to write the information into
@@ -365,6 +463,7 @@ public:
         /// @brief cached vehicle data for output after the vehicle has been removed
         std::string myVehicleID;
         std::string myVehicleLine;
+
         SUMOVehicleClass myVehicleVClass;
         double myVehicleDistance;
 
@@ -374,6 +473,9 @@ public:
         const MSEdge* myWaitingEdge;
         Position myStopWaitPos;
 
+        std::string myIntendedVehicleID;
+        SUMOTime myIntendedDepart;
+
     private:
         /// @brief Invalidated copy constructor.
         Stage_Driving(const Stage_Driving&);
@@ -414,12 +516,12 @@ public:
     void setDeparted(SUMOTime now);
 
     /// Returns the current destination.
-    const MSEdge& getDestination() const {
+    const MSEdge* getDestination() const {
         return (*myStep)->getDestination();
     }
 
     /// Returns the destination after the current destination.
-    const MSEdge& getNextDestination() const {
+    const MSEdge* getNextDestination() const {
         return (*(myStep + 1))->getDestination();
     }
 
@@ -465,6 +567,9 @@ public:
         return (*(myStep + next))->getStageType();
     }
 
+    /// @brief return textual summary for the given stage
+    std::string getStageSummary(int stageIndex) const;
+
     /// Returns the current stage description as a string
     std::string getCurrentStageDescription() const {
         return (*myStep)->getStageDescription();
@@ -475,6 +580,13 @@ public:
         return *myStep;
     }
 
+    /// @brief Return the current stage
+    MSTransportable::Stage* getNextStage(int next) const {
+        assert(myStep + next >= myPlan->begin());
+        assert(myStep + next < myPlan->end());
+        return *(myStep + next);
+    }
+
     /// @brief Return the edges of the nth next stage
     ConstMSEdgeVector getEdges(int next) const {
         assert(myStep + next < myPlan->end());
@@ -493,14 +605,14 @@ public:
      * @param[in] os The stream to write the information into
      * @exception IOError not yet implemented
      */
-    virtual void tripInfoOutput(OutputDevice& os, MSTransportable* transportable) const = 0;
+    virtual void tripInfoOutput(OutputDevice& os) const = 0;
 
     /** @brief Called on writing vehroute output
      *
      * @param[in] os The stream to write the information into
      * @exception IOError not yet implemented
      */
-    virtual void routeOutput(OutputDevice& os) const = 0;
+    virtual void routeOutput(OutputDevice& os, const bool withRouteLength) const = 0;
 
     /// @brief Whether the transportable waits for a vehicle of the line specified.
     bool isWaitingFor(const std::string& line) const {
@@ -560,6 +672,13 @@ public:
     /// @brief return the bounding box of the person
     PositionVector getBoundingBox() const;
 
+    /// @brief return whether the person has reached the end of its plan
+    bool hasArrived() const;
+
+    /// @brief adapt plan when the vehicle reroutes and now stops at replacement instead of orig
+    void rerouteParkingArea(MSStoppingPlace* orig, MSStoppingPlace* replacement);
+
+
 protected:
     /// @brief the offset for computing positions when standing at an edge
     static const double ROADSIDE_OFFSET;
