@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSVehicle.h
 /// @author  Christian Roessel
@@ -32,11 +30,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <list>
 #include <deque>
@@ -44,6 +38,7 @@
 #include <set>
 #include <string>
 #include <vector>
+#include <memory>
 #include "MSGlobals.h"
 #include "MSVehicleType.h"
 #include "MSBaseVehicle.h"
@@ -68,10 +63,11 @@ class MSDevice;
 class MSEdgeWeightsStorage;
 class OutputDevice;
 class Position;
-class MSDevice_Transportable;
 class MSContainer;
 class MSJunction;
 class MSLeaderInfo;
+//class MSDriverState;
+class MSSimpleDriverState;
 
 // ===========================================================================
 // class definitions
@@ -156,7 +152,7 @@ public:
         /// the distance covered in the last timestep
         /// NOTE: In case of ballistic positional update, this is not necessarily given by
         ///       myPos - SPEED2DIST(mySpeed + myPreviousSpeed)/2,
-        /// because a stop may have occured within the last step.
+        /// because a stop may have occurred within the last step.
         double myLastCoveredDist;
 
     };
@@ -273,10 +269,11 @@ public:
      *  contain the vehicle's current edge.
      *
      * @param[in] route The new route to pass
+     * @param[in] info Information regarding the replacement
      * @param[in] removeStops Whether stops should be removed if they do not fit onto the new route
      * @return Whether the new route was accepted
      */
-    bool replaceRoute(const MSRoute* route, bool onInit = false, int offset = 0, bool addStops = true, bool removeStops = true);
+    bool replaceRoute(const MSRoute* route, const std::string& info, bool onInit = false, int offset = 0, bool addStops = true, bool removeStops = true);
 
 
     /** @brief Returns whether the vehicle wil pass the given edge
@@ -369,6 +366,10 @@ public:
      */
     void planMove(const SUMOTime t, const MSLeaderInfo& ahead, const double lengthsInFront);
 
+    /** @brief Register junction approaches for all link items in the current
+     * plan */
+    void setApproachingForAllLinks(const SUMOTime t);
+
 
     /** @brief Executes planned vehicle movements with regards to right-of-way
      *
@@ -774,6 +775,14 @@ public:
      */
     void updateDriveItems();
 
+    /** @brief Get the distance and direction of the next upcoming turn for the vehicle (within its look-ahead range)
+     *  @return The first entry of the returned pair is the distance for the upcoming turn, the second is the link direction
+     */
+    const std::pair<double, LinkDirection>& getNextTurn() {
+        return myNextTurn;
+    }
+
+
     MSAbstractLaneChangeModel& getLaneChangeModel();
     const MSAbstractLaneChangeModel& getLaneChangeModel() const;
 
@@ -836,7 +845,7 @@ public:
      *  the best one.
      *
      * If no starting lane ("startLane") is given, the vehicle's current lane ("myLane")
-     *  is used as start of bect lanes building.
+     *  is used as start of best lanes building.
      *
      * @param[in] forceRebuild Whether the best lanes container shall be rebuilt even if the vehicle's edge has not changed
      * @param[in] startLane The lane the process shall start at ("myLane" will be used if ==0)
@@ -883,6 +892,15 @@ public:
         return myType->getCarFollowModel();
     }
 
+    /** @brief Returns the vehicle driver's state
+     *
+     * @return The vehicle driver's state
+     *
+     */
+    inline std::shared_ptr<MSSimpleDriverState> getDriverState() const {
+        return myDriverState;
+    }
+
 
     /** @brief Returns the vehicle's car following model variables
      *
@@ -962,6 +980,9 @@ public:
      */
     bool replaceParkingArea(MSParkingArea* parkingArea, std::string& errorMsg);
 
+    /** @brief Create a DriverState for the vehicle
+     */
+    void createDriverState();
 
     /** @brief get the current parking area stop
      */
@@ -974,11 +995,24 @@ public:
         return !myStops.empty();
     }
 
+    /** @brief Whether this vehicle is equipped with a MSDriverState
+     */
+    inline bool hasDriverState() const {
+        return (myDriverState != nullptr);
+    }
+
     /** @brief Returns whether the vehicle is at a stop
      * @return Whether the vehicle has stopped
      */
     bool isStopped() const;
 
+    /// @brief Returns the remaining stop duration for a stopped vehicle or 0
+    SUMOTime remainingStopDuration() const;
+
+    /** @brief Returns whether the vehicle will stop on the current edge
+     */
+    bool willStop() const;
+
     //// @brief Returns whether the vehicle is at a stop and on the correct lane
     bool isStoppedOnLane() const;
 
@@ -1130,25 +1164,6 @@ public:
      */
     void addContainer(MSTransportable* container);
 
-    /// @brief removes a person or container
-    void removeTransportable(MSTransportable* t);
-
-    /// @brief retrieve riding persons
-    const std::vector<MSTransportable*>& getPersons() const;
-
-    /// @brief retrieve riding containers
-    const std::vector<MSTransportable*>& getContainers() const;
-
-    /** @brief Returns the number of persons
-     * @return The number of passengers on-board
-     */
-    int getPersonNumber() const;
-
-    /** @brief Returns the number of containers
-     * @return The number of contaiers on-board
-     */
-    int getContainerNumber() const;
-
     /// @name Access to bool signals
     /// @{
 
@@ -1251,7 +1266,6 @@ public:
 
 
 
-#ifndef NO_TRACI
     /** @brief Returns the uninfluenced velocity
      *
      * If no influencer exists (myInfluencer==0) the vehicle's current speed is
@@ -1261,6 +1275,12 @@ public:
      */
     double getSpeedWithoutTraciInfluence() const;
 
+    /**
+     * reroute the vehicle to the new parking area, updating routes and passengers/containers associated trips
+     * @param parkingAreaID    id of the new parking area
+     */
+    bool rerouteParkingArea(const std::string& parkingAreaID, std::string& errorMsg);
+
     /**
      * schedule a new stop for the vehicle; each time a stop is reached, the vehicle
      * will wait for the given duration before continuing on its route
@@ -1296,6 +1316,12 @@ public:
     */
     Stop& getNextStop();
 
+    /**
+    * returns the list of stops not yet reached in the stop queue
+    * @return the list of upcoming stops
+    */
+    std::list<Stop> getMyStops();
+
     /**
     * resumes a vehicle from stopping
     * @return true on success, the resuming fails if the vehicle wasn't parking in the first place
@@ -1327,6 +1353,40 @@ public:
      * LaneChangeMode and any given laneTimeLine
      */
     class Influencer {
+    private:
+        /// @brief Container for state and parameters of the gap control
+        struct GapControlState {
+            GapControlState();
+            void activate(double tauOriginal, double tauTarget, double additionalGap, double duration, double changeRate, double maxDecel);
+            void deactivate();
+            /// @brief Original value for the desired headway (will be reset after duration has expired)
+            double tauOriginal;
+            /// @brief Current, interpolated value for the desired time headway
+            double tauCurrent;
+            /// @brief Target value for the desired time headway
+            double tauTarget;
+            /// @brief Current, interpolated value for the desired space headway
+            double addGapCurrent;
+            /// @brief Target value for the desired space headway
+            double addGapTarget;
+            /// @brief Remaining duration for keeping the target headway
+            double remainingDuration;
+            /// @brief Rate by which the current time and space headways are changed towards the target value.
+            ///        (A rate of one corresponds to reaching the target value within one second)
+            double changeRate;
+            /// @brief Maximal deceleration to be applied due to the adapted headway
+            double maxDecel;
+            /// @brief Whether the gap control is active
+            bool active;
+            /// @brief Whether the desired gap was attained during the current activity phase (induces the remaining duration to decrease)
+            bool gapAttained;
+            /// @brief The last recognized leader
+            const MSVehicle* prevLeader;
+            /// @brief Time of the last update of the gap control
+            SUMOTime lastUpdate;
+            /// @brief cache storage for the headway increments of the current operation
+            double timeHeadwayIncrement, spaceHeadwayIncrement;
+        };
     public:
         /// @brief Constructor
         Influencer();
@@ -1341,6 +1401,13 @@ public:
          */
         void setSpeedTimeLine(const std::vector<std::pair<SUMOTime, double> >& speedTimeLine);
 
+        /** @brief Activates the gap control with the given parameters, @see GapControlState
+         */
+        void activateGapController(double originalTau, double newTimeHeadway, double newSpaceHeadway, double duration, double changeRate, double maxDecel);
+
+        /** @brief Deactivates the gap control
+         */
+        void deactivateGapController();
 
         /** @brief Sets a new lane timeline
          * @param[in] laneTimeLine The time line of lanes to use
@@ -1356,14 +1423,17 @@ public:
         int getSpeedMode() const;
 
         /// @brief return the current lane change mode
-        int getLanechangeMode() const;
+        int getLaneChangeMode() const;
 
         /// @brief return the current routing mode
         int getRoutingMode() const {
             return myRoutingMode;
         }
+        SUMOTime getLaneTimeLineDuration();
 
-        /** @brief Applies stored velocity information on the speed to use
+        SUMOTime getLaneTimeLineEnd();
+
+        /** @brief Applies stored velocity information on the speed to use.
          *
          * The given speed is assumed to be the non-influenced speed from longitudinal control.
          *  It is stored for further usage in "myOriginalSpeed".
@@ -1376,6 +1446,20 @@ public:
          */
         double influenceSpeed(SUMOTime currentTime, double speed, double vSafe, double vMin, double vMax);
 
+        /** @brief Applies gap control logic on the speed.
+         *
+         * The given speed is assumed to be the non-influenced speed from longitudinal control.
+         *  It is stored for further usage in "myOriginalSpeed".
+         * @param[in] currentTime The current simulation time
+         * @param[in] veh The controlled vehicle
+         * @param[in] speed The undisturbed speed
+         * @param[in] vSafe The safe velocity
+         * @param[in] vMin The minimum velocity
+         * @param[in] vMax The maximum simulation time
+         * @return The speed to use (<=speed)
+         */
+        double gapControlSpeed(SUMOTime currentTime, const SUMOVehicle* veh, double speed, double vSafe, double vMin, double vMax);
+
         /** @brief Applies stored LaneChangeMode information and laneTimeLine
          * @param[in] currentTime The current simulation time
          * @param[in] currentEdge The current edge the vehicle is on
@@ -1408,6 +1492,12 @@ public:
             return myEmergencyBrakeRedLight;
         }
 
+
+        /// @brief Returns whether safe velocities shall be considered
+        bool considerSafeVelocity() const {
+            return myConsiderSafeVelocity;
+        }
+
         /** @brief Sets speed-constraining behaviors
          * @param[in] value a bitset controlling the different modes
          */
@@ -1464,6 +1554,10 @@ public:
             myLatDist = 0.;
         }
 
+        bool ignoreOverlap() const {
+            return myTraciLaneChangePriority == LCP_ALWAYS;
+        }
+
         SUMOAbstractRouter<MSEdge, SUMOVehicle>& getRouterTT() const;
 
     private:
@@ -1473,6 +1567,9 @@ public:
         /// @brief The lane usage time line to apply
         std::vector<std::pair<SUMOTime, int> > myLaneTimeLine;
 
+        /// @brief The gap control state
+        std::shared_ptr<GapControlState> myGapControlState;
+
         /// @brief The velocity before influence
         double myOriginalSpeed;
 
@@ -1550,7 +1647,8 @@ public:
     /// @brief sets position outside the road network
     void setRemoteState(Position xyPos);
 
-#endif
+    /// @brief departure position where the vehicle fits fully onto the edge (if possible)
+    double basePos(const MSEdge* edge) const;
 
     /// @brief compute safe speed for following the given leader
     double getSafeFollowSpeed(const std::pair<const MSVehicle*, double> leaderInfo,
@@ -1559,6 +1657,9 @@ public:
     /// @brief get a numerical value for the priority of the  upcoming link
     static int nextLinkPriority(const std::vector<MSLane*>& conts);
 
+    /// @brief whether the given vehicle must be followed at the given junction
+    bool isLeader(const MSLink* link, const MSVehicle* veh) const; 
+
     /// @name state io
     //@{
 
@@ -1621,9 +1722,10 @@ protected:
      *         the current (euler) / after the current (ballistic) simstep accordingly.
      *
      *  @param[in] vSafe The maximal safe (or admissible) velocity as determined from stops, junction approaches, car following, lane changing, etc.
-     *  @param[in/out] vNext The next speed (possibly subject to traci influence)
+     *  @param[in] vNext The next speed (possibly subject to traci influence)
+     *  @return updated vNext
      */
-    void processTraCISpeedControl(double vSafe, double& vNext);
+    double processTraCISpeedControl(double vSafe, double vNext);
 
 
     /** @brief Erase passed drive items from myLFLinkLanes (and unregister approaching information for
@@ -1642,6 +1744,8 @@ protected:
      */
     void updateTimeLoss(double vNext);
 
+    /// @brief whether the vehicle is a train that can reverse its direction at the current point in its route
+    bool canReverse() const;
 
     /** @brief sets the braking lights on/off
      */
@@ -1662,6 +1766,9 @@ protected:
      */
     const ConstMSEdgeVector getStopEdges() const;
 
+    /// @brief get distance for coming to a stop (used for rerouting checks)
+    double getBrakeGap() const;
+
     /// @brief ensure that a vehicle-relative position is not invalid
     Position validatePosition(Position result, double offset = 0) const;
 
@@ -1678,6 +1785,10 @@ protected:
     /// @brief This Vehicles driving state (pos and speed)
     State myState;
 
+    /// @brief This vehicle's driver state @see MSDriverState
+//    std::shared_ptr<MSDriverState> myDriverState;
+    std::shared_ptr<MSSimpleDriverState> myDriverState;
+
     /// @brief The flag myActionStep indicates whether the current time step is an action point for the vehicle.
     bool myActionStep;
     /// @brief Action offset (actions are taken at time myActionOffset + N*getActionStepLength())
@@ -1701,26 +1812,23 @@ protected:
      */
     std::vector<std::vector<LaneQ> > myBestLanes;
 
-    /* @brief iterator to speed up retrival of the current lane's LaneQ in getBestLaneOffset() and getBestLanesContinuation()
+    /* @brief iterator to speed up retrieval of the current lane's LaneQ in getBestLaneOffset() and getBestLanesContinuation()
      * This is updated in updateOccupancyAndCurrentBestLane()
      */
     std::vector<LaneQ>::iterator myCurrentLaneInBestLanes;
 
     static std::vector<MSLane*> myEmptyLaneVector;
-    static std::vector<MSTransportable*> myEmptyTransportableVector;
 
     /// @brief The vehicle's list of stops
     std::list<Stop> myStops;
 
-    /// @brief The passengers this vehicle may have
-    MSDevice_Transportable* myPersonDevice;
-
-    /// @brief The containers this vehicle may have
-    MSDevice_Transportable* myContainerDevice;
-
     /// @brief The current acceleration after dawdling in m/s
     double myAcceleration;
 
+    /// @brief the upcoming turn for the vehicle
+    /// @todo calculate during plan move
+    std::pair<double, LinkDirection> myNextTurn;
+
     /// @brief The information into which lanes the vehicle laps into
     std::vector<MSLane*> myFurtherLanes;
     /// @brief lateral positions on further lanes
@@ -1751,6 +1859,11 @@ protected:
 
     mutable Position myCachedPosition;
 
+    /// @brief time at which the current junction was entered
+    SUMOTime myJunctionEntryTime;
+    SUMOTime myJunctionEntryTimeNeverYield;
+    SUMOTime myJunctionConflictEntryTime;
+
 protected:
 
     /// @brief Drive process items represent bounds on the safe velocity
@@ -1767,7 +1880,7 @@ protected:
         double myArrivalSpeedBraking;
         double myDistance;
         double accelV;
-        bool hadVehicle;
+        bool hadStoppedVehicle;
         double availableSpace;
 
         DriveProcessItem(MSLink* link, double vPass, double vWait, bool setRequest,
@@ -1779,7 +1892,7 @@ protected:
             myArrivalTime(arrivalTime), myArrivalSpeed(arrivalSpeed),
             myArrivalTimeBraking(arrivalTimeBraking), myArrivalSpeedBraking(arrivalSpeedBraking),
             myDistance(distance),
-            accelV(leaveSpeed), hadVehicle(false), availableSpace(0) {
+            accelV(leaveSpeed), hadStoppedVehicle(false), availableSpace(0) {
             assert(vWait >= 0 || !MSGlobals::gSemiImplicitEulerUpdate);
             assert(vPass >= 0 || !MSGlobals::gSemiImplicitEulerUpdate);
         };
@@ -1791,7 +1904,7 @@ protected:
             myArrivalTime(0), myArrivalSpeed(0),
             myArrivalTimeBraking(0), myArrivalSpeedBraking(0),
             myDistance(distance),
-            accelV(-1), hadVehicle(false), availableSpace(_availableSpace) {
+            accelV(-1), hadStoppedVehicle(false), availableSpace(_availableSpace) {
             assert(vWait >= 0 || !MSGlobals::gSemiImplicitEulerUpdate);
         };
 
@@ -1811,7 +1924,13 @@ protected:
     /// Container for used Links/visited Lanes during planMove() and executeMove.
     // TODO: Consider making LFLinkLanes a std::deque for efficient front removal (needs refactoring in checkRewindLinkLanes()...)
     typedef std::vector< DriveProcessItem > DriveItemVector;
+
+    /// @brief container for the planned speeds in the current step
     DriveItemVector myLFLinkLanes;
+
+    /// @brief planned speeds from the previous step for un-registering from junctions after the new container is filled
+    DriveItemVector myLFLinkLanesPrev;
+
     /** @brief iterator pointing to the next item in myLFLinkLanes
     *   @note  This is updated whenever the vehicle advances to a subsequent lane (see processLaneAdvances())
     *          and used for inter-actionpoint actualization of myLFLinkLanes (i.e. deletion of passed items)
@@ -1820,9 +1939,9 @@ protected:
     DriveItemVector::iterator myNextDriveItem;
 
     /// @todo: documentation
-    void planMoveInternal(const SUMOTime t, MSLeaderInfo ahead, DriveItemVector& lfLinks, double& myStopDist) const;
+    void planMoveInternal(const SUMOTime t, MSLeaderInfo ahead, DriveItemVector& lfLinks, double& myStopDist, std::pair<double, LinkDirection>& myNextTurn) const;
 
-    /// @todo: documentation
+    /// @brief runs heuristic for keeping the intersection clear in case of downstream jamming
     void checkRewindLinkLanes(const double lengthsInFront, DriveItemVector& lfLinks) const;
 
     /// @brief unregister approach from all upcoming links
@@ -1874,6 +1993,10 @@ protected:
                          DriveProcessItem* const lastLink, double& v, double& vLinkPass, double& vLinkWait, bool& setRequest,
                          bool isShadowLink = false) const;
 
+    /// @brief checks for link leaders of the current link as well as the parallel link (if there is one)
+    void checkLinkLeaderCurrentAndParallel(const MSLink* link, const MSLane* lane, double seen,
+                                           DriveProcessItem* const lastLink, double& v, double& vLinkPass, double& vLinkWait, bool& setRequest) const;
+
 
     // @brief return the lane on which the back of this vehicle resides
     const MSLane* getBackLane() const;
@@ -1905,10 +2028,8 @@ private:
     /// @brief The per vehicle variables of the car following model
     MSCFModel::VehicleVariables* myCFVariables;
 
-#ifndef NO_TRACI
     /// @brief An instance of a velocity/lane influencing instance; built in "getInfluencer"
     Influencer* myInfluencer;
-#endif
 
 private:
     /// @brief invalidated default constructor
