@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSVehicleControl.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "MSVehicleControl.h"
 #include "MSVehicle.h"
@@ -35,13 +29,14 @@
 #include "MSEdge.h"
 #include "MSNet.h"
 #include "MSRouteHandler.h"
-#include <microsim/devices/MSDevice.h>
+#include <microsim/devices/MSVehicleDevice.h>
 #include <utils/common/FileHelpers.h>
 #include <utils/common/RGBColor.h>
 #include <utils/vehicle/SUMOVTypeParameter.h>
 #include <utils/iodevices/BinaryInputDevice.h>
 #include <utils/iodevices/OutputDevice.h>
 #include <utils/options/OptionsCont.h>
+#include <utils/vehicle/IntermodalRouter.h>
 
 
 // ===========================================================================
@@ -61,6 +56,7 @@ MSVehicleControl::MSVehicleControl() :
     myTotalTravelTime(0),
     myDefaultVTypeMayBeDeleted(true),
     myDefaultPedTypeMayBeDeleted(true),
+    myDefaultBikeTypeMayBeDeleted(true),
     myWaitingForPerson(0),
     myWaitingForContainer(0),
     myMaxSpeedFactor(1),
@@ -70,9 +66,11 @@ MSVehicleControl::MSVehicleControl() :
     SUMOVTypeParameter defPedType(DEFAULT_PEDTYPE_ID, SVC_PEDESTRIAN);
     defPedType.parametersSet |= VTYPEPARS_VEHICLECLASS_SET;
     myVTypeDict[DEFAULT_PEDTYPE_ID] = MSVehicleType::build(defPedType);
+    SUMOVTypeParameter defBikeType(DEFAULT_BIKETYPE_ID, SVC_BICYCLE);
+    defBikeType.parametersSet |= VTYPEPARS_VEHICLECLASS_SET;
+    myVTypeDict[DEFAULT_BIKETYPE_ID] = MSVehicleType::build(defBikeType);
     OptionsCont& oc = OptionsCont::getOptions();
     myScale = oc.getFloat("scale");
-    myMaxRandomDepartOffset = string2time(oc.getString("random-depart-offset"));
 }
 
 
@@ -94,26 +92,12 @@ MSVehicleControl::~MSVehicleControl() {
     myVTypeDict.clear();
 }
 
-SUMOTime
-MSVehicleControl::computeRandomDepartOffset() const {
-    if (myMaxRandomDepartOffset > 0) {
-        // round to the closest usable simulation step
-        return DELTA_T * int((RandHelper::rand((int)myMaxRandomDepartOffset, MSRouteHandler::getParsingRNG()) + 0.5 * DELTA_T) / DELTA_T);
-    } else {
-        return 0;
-    }
-}
-
 SUMOVehicle*
 MSVehicleControl::buildVehicle(SUMOVehicleParameter* defs,
-                               const MSRoute* route,
-                               MSVehicleType* type,
+                               const MSRoute* route, MSVehicleType* type,
                                const bool ignoreStopErrors, const bool fromRouteFile) {
     myLoadedVehNo++;
-    if (fromRouteFile) {
-        defs->depart += computeRandomDepartOffset();
-    }
-    MSVehicle* built = new MSVehicle(defs, route, type, type->computeChosenSpeedDeviation(fromRouteFile ? MSRouteHandler::getParsingRNG() : 0));
+    MSVehicle* built = new MSVehicle(defs, route, type, type->computeChosenSpeedDeviation(fromRouteFile ? MSRouteHandler::getParsingRNG() : nullptr));
     built->addStops(ignoreStopErrors);
     MSNet::getInstance()->informVehicleStateListener(built, MSNet::VEHICLE_STATE_BUILT);
     return built;
@@ -126,8 +110,8 @@ MSVehicleControl::scheduleVehicleRemoval(SUMOVehicle* veh) {
     myTotalTravelTime += STEPS2TIME(MSNet::getInstance()->getCurrentTimeStep() - veh->getDeparture());
     myRunningVehNo--;
     MSNet::getInstance()->informVehicleStateListener(veh, MSNet::VEHICLE_STATE_ARRIVED);
-    for (std::vector<MSDevice*>::const_iterator i = veh->getDevices().begin(); i != veh->getDevices().end(); ++i) {
-        (*i)->generateOutput();
+    for (MSVehicleDevice* const dev : veh->getDevices()) {
+        dev->generateOutput();
     }
     if (OptionsCont::getOptions().isSet("tripinfo-output")) {
         // close tag after tripinfo (possibly including emissions from another device) have been written
@@ -213,7 +197,7 @@ SUMOVehicle*
 MSVehicleControl::getVehicle(const std::string& id) const {
     VehicleDictType::const_iterator it = myVehicleDict.find(id);
     if (it == myVehicleDict.end()) {
-        return 0;
+        return nullptr;
     }
     return it->second;
 }
@@ -225,7 +209,7 @@ MSVehicleControl::deleteVehicle(SUMOVehicle* veh, bool discard) {
     if (discard) {
         myDiscarded++;
     }
-    if (veh != 0) {
+    if (veh != nullptr) {
         myVehicleDict.erase(veh->getID());
     }
     delete veh;
@@ -250,6 +234,14 @@ MSVehicleControl::checkVType(const std::string& id) {
         } else {
             return false;
         }
+    } else if (id == DEFAULT_BIKETYPE_ID) {
+        if (myDefaultBikeTypeMayBeDeleted) {
+            delete myVTypeDict[id];
+            myVTypeDict.erase(myVTypeDict.find(id));
+            myDefaultBikeTypeMayBeDeleted = false;
+        } else {
+            return false;
+        }
     } else {
         if (myVTypeDict.find(id) != myVTypeDict.end() || myVTypeDistDict.find(id) != myVTypeDistDict.end()) {
             return false;
@@ -273,6 +265,9 @@ MSVehicleControl::removeVType(const MSVehicleType* vehType) {
     assert(vehType != 0);
     assert(myVTypeDict.find(vehType->getID()) != myVTypeDict.end());
     myVTypeDict.erase(vehType->getID());
+    if (myVTypeToDist.find(vehType->getID()) != myVTypeToDist.end()) {
+        myVTypeToDist.erase(vehType->getID());
+    }
     delete vehType;
 }
 
@@ -281,6 +276,14 @@ bool
 MSVehicleControl::addVTypeDistribution(const std::string& id, RandomDistributor<MSVehicleType*>* vehTypeDistribution) {
     if (checkVType(id)) {
         myVTypeDistDict[id] = vehTypeDistribution;
+        std::vector<MSVehicleType*> vehTypes = vehTypeDistribution->getVals();
+        for (auto vehType : vehTypes) {
+            if (myVTypeToDist.find(vehType->getID()) != myVTypeToDist.end()) {
+                myVTypeToDist[vehType->getID()].insert(id);
+            } else {
+                myVTypeToDist[vehType->getID()] = { id };
+            }
+        }
         return true;
     }
     return false;
@@ -305,7 +308,7 @@ MSVehicleControl::getVType(const std::string& id, std::mt19937* rng) {
     if (it == myVTypeDict.end()) {
         VTypeDistDictType::iterator it2 = myVTypeDistDict.find(id);
         if (it2 == myVTypeDistDict.end()) {
-            return 0;
+            return nullptr;
         }
         return it2->second->get(rng);
     }
@@ -330,6 +333,16 @@ MSVehicleControl::insertVTypeIDs(std::vector<std::string>& into) const {
 }
 
 
+std::set<std::string>
+MSVehicleControl::getVTypeDistributionMembership(const std::string& id) const {
+    std::map<std::string, std::set<std::string>>::const_iterator it = myVTypeToDist.find(id);
+    if (it == myVTypeToDist.end()) {
+        return std::set<std::string>();
+    }
+    return it->second;
+}
+
+
 void
 MSVehicleControl::addWaiting(const MSEdge* const edge, SUMOVehicle* vehicle) {
     if (myWaiting.find(edge) == myWaiting.end()) {
@@ -340,7 +353,7 @@ MSVehicleControl::addWaiting(const MSEdge* const edge, SUMOVehicle* vehicle) {
 
 
 void
-MSVehicleControl::removeWaiting(const MSEdge* const edge, SUMOVehicle* vehicle) {
+MSVehicleControl::removeWaiting(const MSEdge* const edge, const SUMOVehicle* vehicle) {
     if (myWaiting.find(edge) != myWaiting.end()) {
         std::vector<SUMOVehicle*>::iterator it = std::find(myWaiting[edge].begin(), myWaiting[edge].end(), vehicle);
         if (it != myWaiting[edge].end()) {
@@ -378,7 +391,7 @@ MSVehicleControl::getWaitingVehicle(const MSEdge* const edge, const std::set<std
             WRITE_WARNING(ridingID + " at edge '" + edge->getID() + "' position " + toString(position) + " cannot use waiting vehicle '" + (*it)->getID() + "' at position " + toString((*it)->getPositionOnLane()) + " because it is too far away.");
         }
     }
-    return 0;
+    return nullptr;
 }
 
 
@@ -390,6 +403,41 @@ MSVehicleControl::abortWaiting() {
 }
 
 
+int
+MSVehicleControl::getHaltingVehicleNo() const {
+    int result = 0;
+    for (MSVehicleControl::constVehIt it = loadedVehBegin(); it != loadedVehEnd(); ++it) {
+        const SUMOVehicle* veh = it->second;
+        if ((veh->isOnRoad() || veh->isRemoteControlled()) && veh->getSpeed() < SUMO_const_haltingSpeed)  {
+            result++;
+        }
+    }
+    return result;
+}
+
+
+
+std::pair<double, double>
+MSVehicleControl::getVehicleMeanSpeeds() const {
+    double speedSum = 0;
+    double relSpeedSum = 0;
+    int count = 0;
+    for (MSVehicleControl::constVehIt it = loadedVehBegin(); it != loadedVehEnd(); ++it) {
+        const SUMOVehicle* veh = it->second;
+        if ((veh->isOnRoad() || veh->isRemoteControlled()) && !veh->isStopped()) {
+            count++;
+            speedSum += veh->getSpeed();
+            relSpeedSum += veh->getSpeed() / veh->getEdge()->getSpeedLimit();
+        }
+    }
+    if (count > 0) {
+        return std::make_pair(speedSum / count, relSpeedSum / count);
+    } else {
+        return std::make_pair(-1, -1);
+    }
+}
+
+
 int
 MSVehicleControl::getQuota(double frac) const {
     frac = frac < 0 ? myScale : frac;
@@ -418,7 +466,8 @@ void
 MSVehicleControl::adaptIntermodalRouter(MSNet::MSIntermodalRouter& router) const {
     for (const SUMOVehicle* const veh : myPTVehicles) {
         // add single vehicles with line attribute which are not part of a flow
-        router.addSchedule(veh->getParameter());
+        const MSRoute* const route = MSRoute::dictionary(veh->getParameter().routeid);
+        router.getNetwork()->addSchedule(veh->getParameter(), route == nullptr ? nullptr : &route->getStops());
     }
 }
 
