@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSVehicleControl.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <cmath>
 #include <string>
@@ -204,6 +198,20 @@ public:
     }
 
 
+    /** @brief Returns the number of halting vehicles
+     * @return The number of halting vehicles
+     */
+    virtual int getHaltingVehicleNo() const;
+
+    /// @brief get current absolute and relative mean vehicle speed in the network
+    virtual std::pair<double, double> getVehicleMeanSpeeds() const;
+    double getVehicleMeanSpeed() const {
+        return getVehicleMeanSpeeds().first;
+    }
+    double getVehicleMeanSpeedRelative() const {
+        return getVehicleMeanSpeeds().second;
+    }
+
     /** @brief Returns the number of removed vehicles
      * @return The number of vehicles that have left the simulation
      */
@@ -211,6 +219,20 @@ public:
         return myEndedVehNo;
     }
 
+    /** @brief Returns the number of arrived vehicles
+     * @return The number of vehicles that have arrived at their destination
+     */
+    int getArrivedVehicleNo() const {
+        return myEndedVehNo - myDiscarded;
+    }
+
+    /** @brief Returns the number of discarded vehicles
+     * @return The number of vehicles that could not be inserted and were permantently discarded
+     */
+    int getDiscardedVehicleNo() const {
+        return myDiscarded;
+    }
+
 
     /** @brief Returns the number of build and inserted, but not yet deleted vehicles
      * @return The number simulated vehicles (including those in teleporter)
@@ -274,7 +296,6 @@ public:
         return myEmergencyStops;
     }
 
-
     /** @brief Returns the total departure delay
      * @return Sum of steps vehicles had to wait until being inserted
      */
@@ -364,13 +385,20 @@ public:
      * @param[in] into The vector to fill with ids
      */
     void insertVTypeIDs(std::vector<std::string>& into) const;
+
+
+    /** @brief Return the distribution IDs the vehicle type is a member of
+    * @param[in] vehType The vehicle type to look for membership in distributions
+    */
+    std::set<std::string> getVTypeDistributionMembership(const std::string& id) const;
+
     /// @}
 
     /// @brief Adds a vehicle to the list of waiting vehiclse to a given edge
     void addWaiting(const MSEdge* const edge, SUMOVehicle* vehicle);
 
     /// @brief Removes a vehicle from the list of waiting vehicles to a given edge
-    void removeWaiting(const MSEdge* const edge, SUMOVehicle* vehicle);
+    void removeWaiting(const MSEdge* const edge, const SUMOVehicle* vehicle);
 
     /* @brief returns a vehicle of the given lines that is waiting for a for a person or a container at this edge at the given positions
      * @param[in] edge The edge at which the vehicle is positioned.
@@ -453,9 +481,6 @@ public:
      */
     void abortWaiting();
 
-    /// @brief compute (optional) random offset to the departure time
-    SUMOTime computeRandomDepartOffset() const;
-
     /// @brief return the maximum speed factor for all vehicles that ever entered the network
     double getMaxSpeedFactor() const {
         return myMaxSpeedFactor;
@@ -468,6 +493,11 @@ public:
 
     void adaptIntermodalRouter(MSNet::MSIntermodalRouter& router) const;
 
+    /// @brief sets the demand scaling factor
+    void setScale(double scale) {
+        myScale = scale;
+    }
+
 private:
     /** @brief Checks whether the vehicle type (distribution) may be added
      *
@@ -548,12 +578,18 @@ private:
     /// @brief A distribution of vehicle types (probability->vehicle type)
     VTypeDistDictType myVTypeDistDict;
 
-    /// @brief Whether no vehicle type was loaded
+    /// @brief Inverse lookup from vehicle type to distributions it is a member of
+    std::map<std::string, std::set<std::string>> myVTypeToDist;
+
+    /// @brief Whether the default vehicle type was already used or can still be replaced
     bool myDefaultVTypeMayBeDeleted;
 
-    /// @brief Whether no pedestrian type was loaded
+    /// @brief Whether the default pedestrian type was already used or can still be replaced
     bool myDefaultPedTypeMayBeDeleted;
 
+    /// @brief Whether the default bicycle type was already used or can still be replaced
+    bool myDefaultBikeTypeMayBeDeleted;
+
     /// the lists of waiting vehicles to a given edge
     std::map<const MSEdge* const, std::vector<SUMOVehicle*> > myWaiting;
 
@@ -566,9 +602,6 @@ private:
     /// @brief The scaling factor (especially for inc-dua)
     double myScale;
 
-    /// @brief The maximum random offset to be added to vehicles departure times (non-negative)
-    SUMOTime myMaxRandomDepartOffset;
-
     /// @brief The maximum speed factor for all vehicles in the network
     double myMaxSpeedFactor;
 
