@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSVehicleType.h
 /// @author  Christian Roessel
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <cassert>
 #include <map>
@@ -333,6 +327,36 @@ public:
     /// @name Setter methods
     /// @{
 
+    /** @brief Set a new value for this type's acceleration.
+     * @param[in] accel The new acceleration of this type
+     */
+    void setAccel(double accel);
+
+    /** @brief Set a new value for this type's deceleration.
+     * @param[in] decel The new deceleration of this type
+     */
+    void setDecel(double decel);
+
+    /** @brief Set a new value for this type's emergency deceleration.
+     * @param[in] emergencyDecel The new emergency deceleration of this type
+     */
+    void setEmergencyDecel(double emergencyDecel);
+
+    /** @brief Set a new value for this type's apparent deceleration.
+     * @param[in] apparentDecel The new apparent deceleration of this type
+     */
+    void setApparentDecel(double apparentDecel);
+
+    /** @brief Set a new value for this type's imperfection.
+     * @param[in] imperfection The new imperfection of this type
+     */
+    void setImperfection(double imperfection);
+
+    /** @brief Set a new value for this type's headway.
+     * @param[in] tau The new headway of this type
+     */
+    void setTau(double tau);
+
     /** @brief Set a new value for this type's length
      *
      * If the given value<0 then the one from the original type will
