@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSCFModel_IDM.h
 /// @author  Tobias Mayer
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "MSCFModel.h"
 #include <microsim/MSLane.h>
@@ -47,16 +41,10 @@
 class MSCFModel_IDM : public MSCFModel {
 public:
     /** @brief Constructor
-     * @param[in] accel The maximum acceleration
-     * @param[in] decel The maximum deceleration
-     * @param[in] emergencyDecel The maximum emergency deceleration
-     * @param[in] apparentDecel The deceleration as expected by others
-     * @param[in] headwayTime the headway gap
-     * @param[in] delta a model constant
-     * @param[in] internalStepping internal time step size
+     *  @param[in] vtype the type for which this model is built and also the parameter object to configure this model
+     *  @param[in] idmm Wether IDM or IDMM shall be built
      */
-    MSCFModel_IDM(const MSVehicleType* vtype, double accel, double decel, double emergencyDecel, double apparentDecel,
-                  double headwayTime, double delta, double internalStepping);
+    MSCFModel_IDM(const MSVehicleType* vtype, bool idmm);
 
 
     /** @brief Constructor
@@ -86,7 +74,7 @@ public:
      * @param[in] vPos The possible velocity
      * @return The velocity after applying interactions with stops and lane change model influences
      */
-    double moveHelper(MSVehicle* const veh, double vPos) const;
+    double finalizeSpeed(MSVehicle* const veh, double vPos) const;
 
 
     /** @brief Computes the vehicle's safe speed (no dawdling)
@@ -97,7 +85,7 @@ public:
      * @return EGO's safe speed
      * @see MSCFModel::ffeV
      */
-    double followSpeed(const MSVehicle* const veh, double speed, double gap2pred, double predSpeed, double predMaxDecel) const;
+    double followSpeed(const MSVehicle* const veh, double speed, double gap2pred, double predSpeed, double predMaxDecel, const MSVehicle* const pred = 0) const;
 
 
     /** @brief Computes the vehicle's safe speed for approaching a non-moving obstacle (no dawdling)
@@ -107,7 +95,7 @@ public:
      * @see MSCFModel::ffeS
      * @todo generic Interface, models can call for the values they need
      */
-    double stopSpeed(const MSVehicle* const veh, const double speed, double gap2pred) const;
+    double stopSpeed(const MSVehicle* const veh, const double speed, double gap) const;
 
 
     /** @brief Returns the maximum gap at which an interaction between both vehicles occurs
@@ -121,6 +109,12 @@ public:
      */
     double interactionGap(const MSVehicle* const , double vL) const;
 
+    /** @brief Returns the minimum gap to reserve if the leader is braking at maximum (>=0)
+      * @param[in] speed EGO's speed
+      * @param[in] leaderSpeed LEADER's speed
+      * @param[in] leaderMaxDecel LEADER's max. deceleration rate
+      */
+    double getSecureGap(const double speed, const double leaderSpeed, const double leaderMaxDecel) const;
 
     /** @brief Returns the model's name
      * @return The model's name
@@ -163,6 +157,9 @@ private:
 
 
 private:
+    /// @brief whether the model is IDMM or IDM
+    const bool myIDMM;
+
     /// @brief The IDM delta exponent
     const double myDelta;
 
