@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSCFModel_Krauss.cpp
 /// @author  Tobias Mayer
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <microsim/MSVehicle.h>
 #include <microsim/MSLane.h>
@@ -43,17 +37,16 @@
 // ===========================================================================
 // DEBUG constants
 // ===========================================================================
-//#define DEBUG_MOVE_HELPER
 //#define DEBUG_COND (true)
+#define DEBUG_COND (veh->isSelected())
+#define DEBUG_DRIVER_ERRORS
 
 
 // ===========================================================================
 // method definitions
 // ===========================================================================
-MSCFModel_Krauss::MSCFModel_Krauss(const MSVehicleType* vtype, double accel, double decel,
-                                   double emergencyDecel, double apparentDecel,
-                                   double dawdle, double headwayTime) :
-    MSCFModel_KraussOrig1(vtype, accel, decel, emergencyDecel, apparentDecel, dawdle, headwayTime) {
+MSCFModel_Krauss::MSCFModel_Krauss(const MSVehicleType* vtype) :
+    MSCFModel_KraussOrig1(vtype) {
 }
 
 
@@ -61,61 +54,40 @@ MSCFModel_Krauss::~MSCFModel_Krauss() {}
 
 
 double
-MSCFModel_Krauss::moveHelper(MSVehicle* const veh, double vPos) const {
-    const double oldV = veh->getSpeed(); // save old v for optional acceleration computation
-    const double vSafe = MIN2(vPos, veh->processNextStop(vPos)); // process stops
-    const double vMin = minNextSpeed(oldV, veh);
-
-    // aMax: Maximal admissible acceleration until the next action step, such that the vehicle's maximal
-    // desired speed on the current lane will not be exceeded.
-    double aMax = (veh->getLane()->getVehicleMaxSpeed(veh) - oldV) / veh->getActionStepLengthSecs();
-
-    // do not exceed max decel even if it is unsafe
-    double vMax = MAX2(vMin, MIN3(oldV + ACCEL2SPEED(aMax), maxNextSpeed(oldV, veh), vSafe));
-#ifdef _DEBUG
-    //if (vMin > vMax) {
-    //    WRITE_WARNING("Maximum speed of vehicle '" + veh->getID() + "' is lower than the minimum speed (min: " + toString(vMin) + ", max: " + toString(vMax) + ").");
-    //}
-#endif
-
+MSCFModel_Krauss::patchSpeedBeforeLC(const MSVehicle* veh, double vMin, double vMax) const {
     const double sigma = (veh->passingMinor()
                           ? veh->getVehicleType().getParameter().getJMParam(SUMO_ATTR_JM_SIGMA_MINOR, myDawdle)
                           : myDawdle);
     const double vDawdle = MAX2(vMin, dawdle2(vMax, sigma));
-
-    double vNext = veh->getLaneChangeModel().patchSpeed(vMin, vDawdle, vMax, *this);
-
-    assert(vNext >= vMin);
-    assert(vNext <= vMax);
-
-#ifdef DEBUG_MOVE_HELPER
-    if DEBUG_COND {
-    std::cout << "\nMOVE_HELPER\n"
-    << "veh '" << veh->getID() << "' vMin=" << vMin
-        << " vMax=" << vMax << " vDawdle=" << vDawdle
-        << " vSafe" << vSafe << " vNext=" << vNext << " vPos=" << vPos << " veh->getSpeed()=" << oldV
-        << "\n";
-    }
-#endif
-
-    return vNext;
+    return vDawdle;
 }
 
 
-
 double
 MSCFModel_Krauss::stopSpeed(const MSVehicle* const veh, const double speed, double gap) const {
     // NOTE: This allows return of smaller values than minNextSpeed().
     // Only relevant for the ballistic update: We give the argument headway=veh->getActionStepLengthSecs(), to assure that
     // the stopping position is approached with a uniform deceleration also for tau!=veh->getActionStepLengthSecs().
+    if (veh->hasDriverState()) {
+        // @todo: Provide objectID (e.g. pointer address for the relevant object at the given distance(gap))
+        //        This is for item related management of known object and perception updates when the distance
+        //        changes significantly. (Should not be too important for stationary objects though.)
+        applyHeadwayPerceptionError(veh, speed, gap);
+    }
     return MIN2(maximumSafeStopSpeed(gap, speed, false, veh->getActionStepLengthSecs()), maxNextSpeed(speed, veh));
 }
 
 
 double
-MSCFModel_Krauss::followSpeed(const MSVehicle* const veh, double speed, double gap, double predSpeed, double predMaxDecel) const {
+MSCFModel_Krauss::followSpeed(const MSVehicle* const veh, double speed, double gap, double predSpeed, double predMaxDecel, const MSVehicle* const pred) const {
+    //gDebugFlag1 = DEBUG_COND;
+    if (veh->hasDriverState()) {
+        applyHeadwayAndSpeedDifferencePerceptionErrors(veh, speed, gap, predSpeed, predMaxDecel, pred);
+    }
+    //gDebugFlag1 = DEBUG_COND; // enable for DEBUG_EMERGENCYDECEL
     const double vsafe = maximumSafeFollowSpeed(gap, speed, predSpeed, predMaxDecel);
-    const double vmin = minNextSpeed(speed);
+    //gDebugFlag1 = false;
+    const double vmin = minNextSpeedEmergency(speed);
     const double vmax = maxNextSpeed(speed, veh);
     if (MSGlobals::gSemiImplicitEulerUpdate) {
         return MIN2(vsafe, vmax);
@@ -126,7 +98,6 @@ MSCFModel_Krauss::followSpeed(const MSVehicle* const veh, double speed, double g
     }
 }
 
-
 double
 MSCFModel_Krauss::dawdle2(double speed, double sigma) const {
     if (!MSGlobals::gSemiImplicitEulerUpdate) {
@@ -154,7 +125,7 @@ MSCFModel_Krauss::dawdle2(double speed, double sigma) const {
 
 MSCFModel*
 MSCFModel_Krauss::duplicate(const MSVehicleType* vtype) const {
-    return new MSCFModel_Krauss(vtype, myAccel, myDecel, myEmergencyDecel, myApparentDecel, myDawdle, myHeadwayTime);
+    return new MSCFModel_Krauss(vtype);
 }
 
 
