@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSCFModel_KraussOrig1.h
 /// @author  Tobias Mayer
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "MSCFModel.h"
 #include <utils/xml/SUMOXMLDefinitions.h>
@@ -45,15 +39,9 @@
 class MSCFModel_KraussOrig1 : public MSCFModel {
 public:
     /** @brief Constructor
-     * @param[in] accel The maximum acceleration
-     * @param[in] decel The maximum deceleration
-     * @param[in] emergencyDecel The maximum emergency deceleration
-     * @param[in] apparentDecel The deceleration as expected by others (always equal to decel for the original model)
-     * @param[in] dawdle The driver imperfection
-     * @param[in] tau The driver's desired headway
+     *  @param[in] vtype the type for which this model is built and also the parameter object to configure this model
      */
-    MSCFModel_KraussOrig1(const MSVehicleType* vtype, double accel, double decel,
-                          double emergencyDecel, double apparentDecel, double dawdle, double headwayTime);
+    MSCFModel_KraussOrig1(const MSVehicleType* vtype);
 
 
     /// @brief Destructor
@@ -62,14 +50,8 @@ public:
 
     /// @name Implementations of the MSCFModel interface
     /// @{
-
-    /** @brief Applies interaction with stops and lane changing model influences
-     * @param[in] veh The ego vehicle
-     * @param[in] vPos The possible velocity
-     * @return The velocity after applying interactions with stops and lane change model influences
-     */
-    virtual double moveHelper(MSVehicle* const veh, double vPos) const;
-
+    /// @brief apply dawdling
+    double patchSpeedBeforeLC(const MSVehicle* veh, double vMin, double vMax) const;
 
     /** @brief Computes the vehicle's safe speed (no dawdling)
      * @param[in] veh The vehicle (EGO)
@@ -79,7 +61,7 @@ public:
      * @return EGO's safe speed
      * @see MSCFModel::ffeV
      */
-    double followSpeed(const MSVehicle* const veh, double speed, double gap2pred, double predSpeed, double predMaxDecel) const;
+    double followSpeed(const MSVehicle* const veh, double speed, double gap2pred, double predSpeed, double predMaxDecel, const MSVehicle* const pred = 0) const;
 
 
     /** @brief Computes the vehicle's safe speed for approaching a non-moving obstacle (no dawdling)
@@ -92,21 +74,6 @@ public:
     virtual double stopSpeed(const MSVehicle* const veh, const double speed, double gap2pred) const;
 
 
-    /** @brief Computes the vehicle's safe speed (no dawdling)
-     * This method is used during the insertion stage. Whereas the method
-     * followSpeed returns the desired speed which may be lower than the safe
-     * speed, this method only considers safety constraints
-     *
-     * Returns the velocity of the vehicle in dependence to the vehicle's and its leader's values and the distance between them.
-     * @param[in] veh The vehicle (EGO)
-     * @param[in] speed The vehicle's speed
-     * @param[in] gap2pred The (netto) distance to the LEADER
-     * @param[in] predSpeed The speed of LEADER
-     * @return EGO's safe speed
-     */
-    double insertionFollowSpeed(const MSVehicle* const veh, double speed, double gap2pred, double predSpeed, double predMaxDecel) const;
-
-
     /** @brief Returns the model's name
      * @return The model's name
      * @see MSCFModel::getModelName
