@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2010-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2010-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSCFModel_PWag2009.cpp
 /// @author  Peter Wagner
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <microsim/MSVehicle.h>
 #include <microsim/MSLane.h>
@@ -39,14 +33,13 @@
 // ===========================================================================
 // method definitions
 // ===========================================================================
-MSCFModel_PWag2009::MSCFModel_PWag2009(const MSVehicleType* vtype,  double accel,
-                                       double decel, double emergencyDecel, double apparentDecel,
-                                       double dawdle, double headwayTime, double tauLast, double apProb) :
-    MSCFModel(vtype, accel, decel, emergencyDecel, apparentDecel, headwayTime), myDawdle(dawdle),
-    myTauDecel(decel * headwayTime),
-    myDecelDivTau(decel / headwayTime),
-    myTauLastDecel(decel * tauLast),
-    myActionPointProbability(apProb) {
+MSCFModel_PWag2009::MSCFModel_PWag2009(const MSVehicleType* vtype) :
+    MSCFModel(vtype),
+    myDawdle(vtype->getParameter().getCFParam(SUMO_ATTR_SIGMA, SUMOVTypeParameter::getDefaultImperfection(vtype->getParameter().vehicleClass))),
+    myTauDecel(myDecel * myHeadwayTime),
+    myDecelDivTau(myDecel / myHeadwayTime),
+    myTauLastDecel(myDecel * vtype->getParameter().getCFParam(SUMO_ATTR_CF_PWAGNER2009_TAULAST, 0.3)),
+    myActionPointProbability(vtype->getParameter().getCFParam(SUMO_ATTR_CF_PWAGNER2009_APPROB, 0.5)) {
 }
 
 
@@ -54,8 +47,8 @@ MSCFModel_PWag2009::~MSCFModel_PWag2009() {}
 
 
 double
-MSCFModel_PWag2009::moveHelper(MSVehicle* const veh, double vPos) const {
-    const double vNext = MSCFModel::moveHelper(veh, vPos);
+MSCFModel_PWag2009::finalizeSpeed(MSVehicle* const veh, double vPos) const {
+    const double vNext = MSCFModel::finalizeSpeed(veh, vPos);
     VehicleVariables* vars = (VehicleVariables*)veh->getCarFollowVariables();
     double apref = SPEED2ACCEL(vNext - veh->getSpeed());
     vars->aOld = apref;
@@ -68,7 +61,7 @@ MSCFModel_PWag2009::moveHelper(MSVehicle* const veh, double vPos) const {
 // seen so far in data ...
 
 double
-MSCFModel_PWag2009::followSpeed(const MSVehicle* const veh, double speed, double gap, double predSpeed, double /*predMaxDecel*/) const {
+MSCFModel_PWag2009::followSpeed(const MSVehicle* const veh, double speed, double gap, double predSpeed, double /*predMaxDecel*/, const MSVehicle* const /*pred*/) const {
     if (predSpeed == 0 && gap < 0.01) {
         return 0;
     }
@@ -140,6 +133,5 @@ MSCFModel_PWag2009::dawdle(double speed) const {
 
 MSCFModel*
 MSCFModel_PWag2009::duplicate(const MSVehicleType* vtype) const {
-    return new MSCFModel_PWag2009(vtype, myAccel, myDecel, myEmergencyDecel, myApparentDecel,
-                                  myDawdle, myHeadwayTime, myTauLastDecel / myDecel, myActionPointProbability);
+    return new MSCFModel_PWag2009(vtype);
 }
