@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2012-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSCFModel_Rail.h
 /// @author  Gregor L\"ammel
@@ -27,18 +25,18 @@
 class MSCFModel_Rail : public MSCFModel {
 
 public:
+    /** @brief Constructor
+     *  @param[in] vtype the type for which this model is built and also the parameter object to configure this model
+     */
+    MSCFModel_Rail(const MSVehicleType* vtype);
 
     double followSpeed(const MSVehicle* const veh, double speed, double gap2pred, double predSpeed,
-                       double predMaxDecel) const;
+                       double predMaxDecel, const MSVehicle* const pred = 0) const;
 
     virtual int getModelID() const;
 
     virtual MSCFModel* duplicate(const MSVehicleType* vtype) const;
 
-    /** @brief Constructor
-     * @param[in] trainType The train type
-     */
-    MSCFModel_Rail(const MSVehicleType* vtype, std::string trainType);
 
 
     virtual ~MSCFModel_Rail();
@@ -47,11 +45,13 @@ public:
 
     virtual double minNextSpeed(double speed, const MSVehicle* const veh) const;
 
+    virtual double minNextSpeedEmergency(double speed, const MSVehicle* const veh = 0) const;
+
     double getSpeedAfterMaxDecel(double v) const;
 
     MSCFModel::VehicleVariables* createVehicleVariables() const;
 
-    double moveHelper(MSVehicle* const veh, double vPos) const;
+    double finalizeSpeed(MSVehicle* const veh, double vPos) const;
 
     double freeSpeed(const MSVehicle* const veh, double speed, double seen, double maxSpeed,
                      const bool onInsertion) const;
