@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2011-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSCFModel_Wiedemann.cpp
 /// @author  Daniel Krajzewicz
@@ -27,11 +25,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <cmath>
 #include "MSCFModel_Wiedemann.h"
@@ -51,14 +45,12 @@ const double MSCFModel_Wiedemann::D_MAX = 150;
 // ===========================================================================
 // method definitions
 // ===========================================================================
-MSCFModel_Wiedemann::MSCFModel_Wiedemann(const MSVehicleType* vtype,
-        double accel, double decel, double emergencyDecel, double apparentDecel,
-        double security, double estimation) :
-    MSCFModel(vtype, accel, decel, emergencyDecel, apparentDecel, 1.0),
-    mySecurity(security),
-    myEstimation(estimation),
-    myAX(vtype->getLength() + 1. + 2. * security),
-    myCX(25. *(1. + security + estimation)),
+MSCFModel_Wiedemann::MSCFModel_Wiedemann(const MSVehicleType* vtype) :
+    MSCFModel(vtype),
+    mySecurity(vtype->getParameter().getCFParam(SUMO_ATTR_CF_WIEDEMANN_SECURITY, 0.5)),
+    myEstimation(vtype->getParameter().getCFParam(SUMO_ATTR_CF_WIEDEMANN_ESTIMATION, 0.5)),
+    myAX(vtype->getLength() + 1. + 2. * mySecurity),
+    myCX(25. *(1. + mySecurity + myEstimation)),
     myMinAccel(0.2 * myAccel) { // +noise?
 }
 
@@ -67,8 +59,8 @@ MSCFModel_Wiedemann::~MSCFModel_Wiedemann() {}
 
 
 double
-MSCFModel_Wiedemann::moveHelper(MSVehicle* const veh, double vPos) const {
-    const double vNext = MSCFModel::moveHelper(veh, vPos);
+MSCFModel_Wiedemann::finalizeSpeed(MSVehicle* const veh, double vPos) const {
+    const double vNext = MSCFModel::finalizeSpeed(veh, vPos);
     VehicleVariables* vars = (VehicleVariables*)veh->getCarFollowVariables();
     vars->accelSign = vNext > veh->getSpeed() ? 1. : -1.;
     return vNext;
@@ -76,7 +68,7 @@ MSCFModel_Wiedemann::moveHelper(MSVehicle* const veh, double vPos) const {
 
 
 double
-MSCFModel_Wiedemann::followSpeed(const MSVehicle* const veh, double /* speed */, double gap2pred, double predSpeed, double /*predMaxDecel*/) const {
+MSCFModel_Wiedemann::followSpeed(const MSVehicle* const veh, double /* speed */, double gap2pred, double predSpeed, double /*predMaxDecel*/, const MSVehicle* const /*pred*/) const {
     return _v(veh, predSpeed, gap2pred);
 }
 
@@ -102,7 +94,7 @@ MSCFModel_Wiedemann::interactionGap(const MSVehicle* const , double vL) const {
 
 MSCFModel*
 MSCFModel_Wiedemann::duplicate(const MSVehicleType* vtype) const {
-    return new MSCFModel_Wiedemann(vtype, myAccel, myDecel, myEmergencyDecel, myApparentDecel, mySecurity, myEstimation);
+    return new MSCFModel_Wiedemann(vtype);
 }
 
 
@@ -113,44 +105,47 @@ MSCFModel_Wiedemann::_v(const MSVehicle* veh, double predSpeed, double gap) cons
     const double v = veh->getSpeed();
     const double vpref = veh->getMaxSpeed();
     const double dv = v - predSpeed;
-    const double bx = myAX + (1 + 7 * mySecurity) * sqrt(v); // Harding propose a factor of  *.8 here
+    // desired minimum following distance at low speed difference
+    const double bx = (1 + 7 * mySecurity) * sqrt(v); // Harding propose a factor of  *.8 here
+    const double abx = myAX + bx; // Harding propose a factor of  *.8 here
     const double ex = 2 - myEstimation; // + RandHelper::randNorm(0.5, 0.15)
-    const double sdx = myAX + ex * (bx - myAX); /// the distance at which we drift out of following
+    const double sdx = myAX + ex * bx; /// the distance at which we drift out of following
     const double sdv_root = (dx - myAX) / myCX;
     const double sdv = sdv_root * sdv_root;
     const double cldv = sdv * ex * ex;
     const double opdv = cldv * (-1 - 2 * RandHelper::randNorm(0.5, 0.15));
     // select the regime, get new acceleration, compute new speed based
     double accel;
-    if (dx <= bx) {
+    if (dx <= abx) {
         accel = emergency(dv, dx);
     } else if (dx < sdx) {
         if (dv > cldv) {
-            accel = approaching(dv, dx, bx);
+            accel = approaching(dv, dx, abx);
         } else if (dv > opdv) {
             accel = following(vars->accelSign);
         } else {
-            accel = fullspeed(v, vpref, dx, bx);
+            accel = fullspeed(v, vpref, dx, abx);
         }
     } else {
         if (dv > sdv && dx < D_MAX) { //@note other versions have an disjunction instead of conjunction
-            accel = approaching(dv, dx, bx);
+            accel = approaching(dv, dx, abx);
         } else {
-            accel = fullspeed(v, vpref, dx, bx);
+            accel = fullspeed(v, vpref, dx, abx);
         }
     }
     // since we have hard constrainst on accel we may as well use them here
-    accel = MAX2(MIN2(accel, myAccel), -myDecel);
+    accel = MAX2(MIN2(accel, myAccel), -myEmergencyDecel);
     const double vNew = MAX2(0., v + ACCEL2SPEED(accel)); // don't allow negative speeds
     return vNew;
 }
 
 
 double
-MSCFModel_Wiedemann::fullspeed(double v, double vpref, double dx, double bx) const {
+MSCFModel_Wiedemann::fullspeed(double v, double vpref, double dx, double abx) const {
+    // maximum acceleration is reduced with increasing speed
     double bmax = 0.2 + 0.8 * myAccel * (7 - sqrt(v));
     // if veh just drifted out of a 'following' process the acceleration is reduced
-    double accel = dx <= 2 * bx ? MIN2(myMinAccel, bmax * (dx - bx) / bx) : bmax;
+    double accel = dx <= 2 * abx ? MIN2(myMinAccel, bmax * (dx - abx) / abx) : bmax;
     if (v > vpref) {
         accel = - accel;
     }
@@ -165,10 +160,10 @@ MSCFModel_Wiedemann::following(double sign) const {
 
 
 double
-MSCFModel_Wiedemann::approaching(double dv, double dx, double bx) const {
+MSCFModel_Wiedemann::approaching(double dv, double dx, double abx) const {
     // there is singularity in the formula. we do the sanity check outside
-    assert(bx < dx);
-    return 0.5 * dv * dv / (bx - dx); // + predAccel at t-reaction_time if this is value is above a treshold
+    assert(abx < dx);
+    return 0.5 * dv * dv / (abx - dx); // + predAccel at t-reaction_time if this is value is above a treshold
 }
 
 
@@ -189,7 +184,7 @@ MSCFModel_Wiedemann::emergency(double /* dv */, double /* dx */) const {
     */
 
     // emergency according to C.Werner
-    return -myDecel;
+    return -myEmergencyDecel;
 }
 
 
