@@ -1,33 +1,26 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    MSDevice_BTreceiver.cpp
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    14.08.2013
-/// @version $Id: MSDevice_BTreceiver.cpp 24010 2017-04-21 17:00:09Z behrisch $
+/// @version $Id$
 ///
-// A BT sender
-/****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2013-2017 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
+// A BT Receiver
 /****************************************************************************/
 
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/common/MsgHandler.h>
 #include <utils/options/OptionsCont.h>
@@ -39,6 +32,7 @@
 #include <microsim/MSLane.h>
 #include <microsim/MSEdge.h>
 #include <microsim/MSVehicle.h>
+#include <microsim/MSEventControl.h>
 #include "MSDevice_Tripinfo.h"
 #include "MSDevice_BTreceiver.h"
 #include "MSDevice_BTsender.h"
@@ -50,7 +44,7 @@
 bool MSDevice_BTreceiver::myWasInitialised = false;
 double MSDevice_BTreceiver::myRange = -1.;
 double MSDevice_BTreceiver::myOffTime = -1.;
-MTRand MSDevice_BTreceiver::sRecognitionRNG;
+std::mt19937 MSDevice_BTreceiver::sRecognitionRNG;
 std::map<std::string, MSDevice_BTreceiver::VehicleInformation*> MSDevice_BTreceiver::sVehicles;
 
 
@@ -78,9 +72,9 @@ MSDevice_BTreceiver::insertOptions(OptionsCont& oc) {
 
 
 void
-MSDevice_BTreceiver::buildVehicleDevices(SUMOVehicle& v, std::vector<MSDevice*>& into) {
+MSDevice_BTreceiver::buildVehicleDevices(SUMOVehicle& v, std::vector<MSVehicleDevice*>& into) {
     OptionsCont& oc = OptionsCont::getOptions();
-    if (equippedByDefaultAssignmentOptions(oc, "btreceiver", v)) {
+    if (equippedByDefaultAssignmentOptions(oc, "btreceiver", v, false)) {
         MSDevice_BTreceiver* device = new MSDevice_BTreceiver(v, "btreceiver_" + v.getID());
         into.push_back(device);
         if (!myWasInitialised) {
@@ -290,22 +284,22 @@ MSDevice_BTreceiver::BTreceiverUpdate::leaveRange(VehicleInformation& receiverIn
 
 double
 MSDevice_BTreceiver::inquiryDelaySlots(const int backoffLimit) {
-    const int phaseOffset = sRecognitionRNG.randInt(2047);
-    const bool interlaced = sRecognitionRNG.rand() < 0.7;
-    const double delaySlots = sRecognitionRNG.rand() * 15;
-    const int backoff = sRecognitionRNG.randInt(backoffLimit);
+    const int phaseOffset = RandHelper::rand(2047, &sRecognitionRNG);
+    const bool interlaced = RandHelper::rand(&sRecognitionRNG) < 0.7;
+    const double delaySlots = RandHelper::rand(&sRecognitionRNG) * 15;
+    const int backoff = RandHelper::rand(backoffLimit, &sRecognitionRNG);
     if (interlaced) {
-        return sRecognitionRNG.rand() * 31 + backoff;
+        return RandHelper::rand(&sRecognitionRNG) * 31 + backoff;
     }
-    if (sRecognitionRNG.randInt(31) < 16) {
+    if (RandHelper::rand(31, &sRecognitionRNG) < 16) {
         // correct train for f0
         return delaySlots + backoff;
     }
-    if (sRecognitionRNG.randInt(30) < 16) {
+    if (RandHelper::rand(30, &sRecognitionRNG) < 16) {
         // correct train for f1
         return 2048 - phaseOffset + delaySlots + backoff;
     }
-    if (sRecognitionRNG.randInt(29) < 16) {
+    if (RandHelper::rand(29, &sRecognitionRNG) < 16) {
         // f2 is in train A but has overlap with both trains
         if (2 * 2048 - phaseOffset + backoff < 4096) {
             return 2 * 2048 - phaseOffset + delaySlots + backoff;
@@ -380,7 +374,7 @@ MSDevice_BTreceiver::BTreceiverUpdate::writeOutput(const std::string& id, const
 // MSDevice_BTreceiver-methods
 // ---------------------------------------------------------------------------
 MSDevice_BTreceiver::MSDevice_BTreceiver(SUMOVehicle& holder, const std::string& id)
-    : MSDevice(holder, id) {
+    : MSVehicleDevice(holder, id) {
 }
 
 
