@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSDevice_BTreceiver.h
 /// @author  Daniel Krajzewicz
@@ -24,14 +22,10 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <random>
-#include "MSDevice.h"
+#include "MSVehicleDevice.h"
 #include "MSDevice_BTsender.h"
 #include <utils/common/SUMOTime.h>
 #include <utils/common/Command.h>
@@ -53,7 +47,7 @@ class SUMOVehicle;
  *
  * @see MSDevice
  */
-class MSDevice_BTreceiver : public MSDevice {
+class MSDevice_BTreceiver : public MSVehicleDevice {
 public:
     /** @brief Inserts MSDevice_BTreceiver-options
      * @param[filled] oc The options container to add the options to
@@ -71,7 +65,7 @@ public:
      * @param[in] v The vehicle for which a device may be built
      * @param[filled] into The vector to store the built device in
      */
-    static void buildVehicleDevices(SUMOVehicle& v, std::vector<MSDevice*>& into);
+    static void buildVehicleDevices(SUMOVehicle& v, std::vector<MSVehicleDevice*>& into);
 
 
     /** @brief Returns the configured range
@@ -82,6 +76,9 @@ public:
     }
 
 
+    static std::mt19937* getRNG() {
+        return &sRecognitionRNG;
+    }
 
 public:
     /// @brief Destructor.
