@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSDevice_Battery.h
 /// @author  Tamas Kurczveil
@@ -17,21 +15,16 @@
 ///
 // The Battery parameters for the vehicle
 /****************************************************************************/
+#ifndef MSDevice_Battery_h
+#define MSDevice_Battery_h
+
 
 // ===========================================================================
 // included modules
 // ===========================================================================
-
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
-#ifndef MSDevice_Battery_h
-#define MSDevice_Battery_h
-
-#include <microsim/devices/MSDevice.h>
+#include <microsim/devices/MSVehicleDevice.h>
 #include <microsim/MSVehicle.h>
 #include <microsim/trigger/MSChargingStation.h>
 #include <utils/common/SUMOTime.h>
@@ -50,7 +43,7 @@ class SUMOVehicle;
  * @class MSDevice_Battery
  * @brief Battery device for electric vehicles
  */
-class MSDevice_Battery : public MSDevice {
+class MSDevice_Battery : public MSVehicleDevice {
 public:
     /** @brief Inserts MSDevice_Example-options
     * @param[filled] oc The options container to add the options to
@@ -67,7 +60,7 @@ public:
     * @param[in] v The vehicle for which a device may be built
     * @param[filled] into The vector to store the built device in
     */
-    static void buildVehicleDevices(SUMOVehicle& v, std::vector<MSDevice*>& into);
+    static void buildVehicleDevices(SUMOVehicle& v, std::vector<MSVehicleDevice*>& into);
 
 public:
     /// @brief Destructor.
