@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSDevice_Emissions.h
 /// @author  Daniel Krajzewicz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <set>
 #include <vector>
@@ -37,7 +31,7 @@
 #include <utils/common/WrappingCommand.h>
 #include <utils/emissions/PollutantsInterface.h>
 #include <microsim/MSVehicle.h>
-#include "MSDevice.h"
+#include "MSVehicleDevice.h"
 
 
 // ===========================================================================
@@ -61,7 +55,7 @@ class MSLane;
  * @see MSDevice
  * @see PollutantsInterface
  */
-class MSDevice_Emissions : public MSDevice {
+class MSDevice_Emissions : public MSVehicleDevice {
 public:
     /** @brief Inserts MSDevice_Emissions-options
      */
@@ -80,7 +74,7 @@ public:
      * @param[in] v The vehicle for which a device may be built
      * @param[in, filled] into The vector to store the built device in
      */
-    static void buildVehicleDevices(SUMOVehicle& v, std::vector<MSDevice*>& into);
+    static void buildVehicleDevices(SUMOVehicle& v, std::vector<MSVehicleDevice*>& into);
 
 
 public:
