@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSDevice_SSM.h
 /// @author  Daniel Krajzewicz
@@ -26,14 +24,10 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <queue>
-#include "MSDevice.h"
+#include "MSVehicleDevice.h"
 #include <utils/common/SUMOTime.h>
 #include <utils/iodevices/OutputDevice_File.h>
 #include <utils/geom/Position.h>
@@ -59,11 +53,11 @@ class SUMOVehicle;
 
 class MSCrossSection;
 
-class MSDevice_SSM : public MSDevice {
+class MSDevice_SSM : public MSVehicleDevice {
 
 private:
     /// All currently existing SSM devices
-    static std::set<MSDevice*>* instances;
+    static std::set<MSDevice_SSM*>* instances;
 
 public:
     /// @brief Different types of encounters corresponding to relative positions of the vehicles.
@@ -227,7 +221,7 @@ private:
 //        std::vector<std::pair<std::pair<const MSLane*, double>, double> > egoPETCrossSections;
 //        std::vector<std::pair<std::pair<const MSLane*, double>, double> > foePETCrossSections;
 
-        /// @name Extremal values for the SSMs (as < <time,value>,Position>-pairs)
+        /// @name Extremal values for the SSMs
         /// @{
         ConflictPointInfo minTTC;
         ConflictPointInfo maxDRAC;
@@ -308,12 +302,12 @@ public:
      * @param[in] v The vehicle for which a device may be built
      * @param[filled] into The vector to store the built device in
      */
-    static void buildVehicleDevices(SUMOVehicle& v, std::vector<MSDevice*>& into);
+    static void buildVehicleDevices(SUMOVehicle& v, std::vector<MSVehicleDevice*>& into);
 
 
     /** @brief returns all currently existing SSM devices
      */
-    static const std::set<MSDevice*>& getInstances();
+    static const std::set<MSDevice_SSM*>& getInstances();
 
     /** @brief This is called once per time step in MSNet::writeOutput() and
      *         collects the surrounding vehicles, updates information on encounters
@@ -357,7 +351,7 @@ public:
 
     /** @brief Collects all vehicles within range 'range' upstream of the position 'pos' on the edge 'edge' into foeCollector
      */
-    static void getUpstreamVehicles(const MSEdge* edge, double pos, double range, double egoDistToConflictLane, const MSLane* const egoConflictLane, FoeInfoMap& foeCollector, std::set<const MSJunction*> seenJunctions);
+    static void getUpstreamVehicles(const MSEdge* edge, double pos, double range, double egoDistToConflictLane, const MSLane* const egoConflictLane, FoeInfoMap& foeCollector, std::set<const MSJunction*>& seenJunctions);
 
     /** @brief Collects all vehicles on the junction into foeCollector
      */
@@ -458,6 +452,12 @@ private:
     void createEncounters(FoeInfoMap& foes);
 
 
+    /** @brief Stores measures, that are not associated to a specific encounter as headways and brake rates
+     *  @todo  Manage as episodes (BR -> braking episode, SGAP/TGAP -> car-following episode) with invariant leader, and filtering applying the
+     *  corresponding thresholds.
+     */
+    void computeGlobalMeasures();
+
     /** @brief Closes all current Encounters and moves conflicts to myPastConflicts, @see processEncounters
      */
     void resetEncounters();
@@ -467,6 +467,11 @@ private:
      */
     void flushConflicts(bool all = false);
 
+    /** @brief Write out all non-encounter specific measures as headways and braking rates.
+     *  @todo  Adapt accordingly if episode structure is implemented, @see computeGlobalMeasures()
+     */
+    void flushGlobalMeasures();
+
     /** @brief Updates the encounter (adds a new trajectory point) and deletes the foeInfo.
      */
     void updateEncounter(Encounter* e, FoeInfo* foeInfo);
@@ -613,7 +618,7 @@ private:
     /// @name Device parameters
     /// @{
     /// @brief thresholds for the ssms, i.e., critical values above or below which a value indicates that a conflict
-    ///        has occured. These are used in qualifiesAsConflict() and decide whether an encounter is saved.
+    ///        has occurred. These are used in qualifiesAsConflict() and decide whether an encounter is saved.
     std::map<std::string, double> myThresholds;
     /// @brief This determines whether the whole trajectories of the vehicles (position, speed, ssms) shall be saved in the ssm-output
     ///        or only the most critical value shall be reported.
@@ -625,7 +630,7 @@ private:
     /// Whether to use the original coordinate system for output
     bool myUseGeoCoords;
     /// Flags for switching on / off comutation of different SSMs, derived from myMeasures
-    bool myComputeTTC, myComputeDRAC, myComputePET;
+    bool myComputeTTC, myComputeDRAC, myComputePET, myComputeBR, myComputeSGAP, myComputeTGAP;
     MSVehicle* myHolderMS;
     /// @}
 
@@ -640,12 +645,46 @@ private:
     EncounterQueue myPastConflicts;
     /// @}
 
+
+
+    /// @name Internal storage for global measures
+    /// @{
+    std::vector<double> myGlobalMeasuresTimeSpan;
+    /// @brief All values for brake rate
+    std::vector<double> myBRspan;
+    /// @brief All values for space gap
+    std::vector<double> mySGAPspan;
+    /// @brief All values for time gap
+    std::vector<double> myTGAPspan;
+    /// @brief Extremal values for the global measures (as <<<time, Position>, value>, [leaderID]>-pairs)
+    /// @{
+    std::pair<std::pair<double, Position>, double> myMaxBR;
+    std::pair<std::pair<std::pair<double, Position>, double>, std::string>  myMinSGAP;
+    std::pair<std::pair<std::pair<double, Position>, double>, std::string>  myMinTGAP;
+    /// @}
+    /// @}
+
     /// Output device
     OutputDevice* myOutputFile;
 
     /// @brief remember which files were created already (don't duplicate xml root-elements)
     static std::set<std::string> createdOutputFiles;
 
+
+    /// @brief bitset storing info whether warning has already been issued about unset parameter (warn only once!)
+    static int issuedParameterWarnFlags;
+    enum SSMParameterWarning {
+        SSM_WARN_MEASURES = 1,
+        SSM_WARN_THRESHOLDS = 1 << 1,
+        SSM_WARN_TRAJECTORIES = 1 << 2,
+        SSM_WARN_RANGE = 1 << 3,
+        SSM_WARN_EXTRATIME = 1 << 4,
+        SSM_WARN_FILE = 1 << 5,
+        SSM_WARN_GEO = 1 << 6
+    };
+
+
+
 private:
     /// @brief Invalidated copy constructor.
     MSDevice_SSM(const MSDevice_SSM&);
