@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSDevice_Transportable.h
 /// @author  Daniel Krajzewicz
@@ -27,14 +25,10 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
-#include "MSDevice.h"
+#include "MSVehicleDevice.h"
 #include <utils/common/SUMOTime.h>
 #include <microsim/MSVehicle.h>
 #include <utils/common/WrappingCommand.h>
@@ -47,7 +41,7 @@
  * @class MSDevice_Transportable
  * @see MSDevice
  */
-class MSDevice_Transportable : public MSDevice {
+class MSDevice_Transportable : public MSVehicleDevice {
 public:
     /** @brief Build devices for the given vehicle, if needed
      *
@@ -56,7 +50,7 @@ public:
      * @param[in] v The vehicle for which a device may be built
      * @param[filled] into The vector to store the built device in
      */
-    static MSDevice_Transportable* buildVehicleDevices(SUMOVehicle& v, std::vector<MSDevice*>& into, const bool isContainer);
+    static MSDevice_Transportable* buildVehicleDevices(SUMOVehicle& v, std::vector<MSVehicleDevice*>& into, const bool isContainer);
 
 
 
@@ -142,7 +136,18 @@ public:
         return myTransportables;
     }
 
-
+protected:
+    /** @brief Internal notification about the vehicle moves, see MSMoveReminder::notifyMoveInternal()
+     *
+     */
+    void notifyMoveInternal(const SUMOVehicle& veh,
+                            const double frontOnLane,
+                            const double timeOnLane,
+                            const double meanSpeedFrontOnLane,
+                            const double meanSpeedVehicleOnLane,
+                            const double travelledDistanceFrontOnLane,
+                            const double travelledDistanceVehicleOnLane,
+                            const double /* meanLengthOnLane */);
 
 private:
     /** @brief Constructor
