@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2009-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2009-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSDevice_Tripinfo.cpp
 /// @author  Daniel Krajzewicz
@@ -23,17 +21,14 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <microsim/MSGlobals.h>
 #include <microsim/MSNet.h>
 #include <microsim/MSLane.h>
 #include <microsim/MSEdge.h>
 #include <microsim/MSVehicle.h>
+#include <mesosim/MEVehicle.h>
 #include <utils/options/OptionsCont.h>
 #include <utils/iodevices/OutputDevice.h>
 #include <utils/xml/SUMOSAXAttributes.h>
@@ -45,7 +40,7 @@
 // ===========================================================================
 // static members
 // ===========================================================================
-MSDevice_Tripinfo::DeviceSet MSDevice_Tripinfo::myPendingOutput;
+std::set<const MSDevice_Tripinfo*, ComparatorNumericalIdLess> MSDevice_Tripinfo::myPendingOutput;
 
 double MSDevice_Tripinfo::myVehicleCount(0);
 double MSDevice_Tripinfo::myTotalRouteLength(0);
@@ -53,6 +48,7 @@ SUMOTime MSDevice_Tripinfo::myTotalDuration(0);
 SUMOTime MSDevice_Tripinfo::myTotalWaitingTime(0);
 SUMOTime MSDevice_Tripinfo::myTotalTimeLoss(0);
 SUMOTime MSDevice_Tripinfo::myTotalDepartDelay(0);
+SUMOTime MSDevice_Tripinfo::myWaitingDepartDelay(-1);
 
 int MSDevice_Tripinfo::myWalkCount(0);
 double MSDevice_Tripinfo::myTotalWalkRouteLength(0);
@@ -75,7 +71,7 @@ SUMOTime MSDevice_Tripinfo::myTotalRideDuration(0);
 // static initialisation methods
 // ---------------------------------------------------------------------------
 void
-MSDevice_Tripinfo::buildVehicleDevices(SUMOVehicle& v, std::vector<MSDevice*>& into) {
+MSDevice_Tripinfo::buildVehicleDevices(SUMOVehicle& v, std::vector<MSVehicleDevice*>& into) {
     if (OptionsCont::getOptions().isSet("tripinfo-output") || OptionsCont::getOptions().getBool("duration-log.statistics")) {
         MSDevice_Tripinfo* device = new MSDevice_Tripinfo(v, "tripinfo_" + v.getID());
         into.push_back(device);
@@ -88,11 +84,15 @@ MSDevice_Tripinfo::buildVehicleDevices(SUMOVehicle& v, std::vector<MSDevice*>& i
 // MSDevice_Tripinfo-methods
 // ---------------------------------------------------------------------------
 MSDevice_Tripinfo::MSDevice_Tripinfo(SUMOVehicle& holder, const std::string& id) :
-    MSDevice(holder, id),
+    MSVehicleDevice(holder, id),
     myDepartLane(""),
     myDepartSpeed(-1),
     myDepartPosLat(0),
     myWaitingTime(0),
+    myAmWaiting(false),
+    myWaitingCount(0),
+    myStoppingTime(0),
+    myParkingStarted(0),
     myArrivalTime(NOT_ARRIVED),
     myArrivalLane(""),
     myArrivalPos(-1),
@@ -115,6 +115,7 @@ MSDevice_Tripinfo::cleanup() {
     myTotalWaitingTime = 0;
     myTotalTimeLoss = 0;
     myTotalDepartDelay = 0;
+    myWaitingDepartDelay = -1;
 
     myWalkCount = 0;
     myTotalWalkRouteLength = 0;
@@ -135,10 +136,15 @@ bool
 MSDevice_Tripinfo::notifyMove(SUMOVehicle& veh, double /*oldPos*/,
                               double /*newPos*/, double newSpeed) {
     if (veh.isStopped()) {
-        return true;
-    }
-    if (newSpeed <= SUMO_const_haltingSpeed) {
+        myStoppingTime += DELTA_T;
+    } else if (newSpeed <= SUMO_const_haltingSpeed) {
         myWaitingTime += DELTA_T;
+        if (!myAmWaiting) {
+            myWaitingCount++;
+            myAmWaiting = true;
+        }
+    } else {
+        myAmWaiting = false;
     }
     return true;
 }
@@ -154,11 +160,14 @@ MSDevice_Tripinfo::notifyMoveInternal(const SUMOVehicle& veh,
                                       const double /* meanLengthOnLane */) {
 
     // called by meso
+    const MEVehicle* mesoVeh = dynamic_cast<const MEVehicle*>(&veh);
+    assert(mesoVeh);
     const double vmax = veh.getEdge()->getVehicleMaxSpeed(&veh);
     if (vmax > 0) {
         myMesoTimeLoss += TIME2STEPS(timeOnLane * (vmax - meanSpeedVehicleOnLane) / vmax);
     }
     myWaitingTime += veh.getWaitingTime();
+    myStoppingTime += TIME2STEPS(mesoVeh->getCurrentStoppingTimeSeconds());
 }
 
 bool
@@ -169,6 +178,10 @@ MSDevice_Tripinfo::notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification re
             myDepartPosLat = static_cast<MSVehicle&>(veh).getLateralPositionOnLane();
         }
         myDepartSpeed = veh.getSpeed();
+    } else if (reason == MSMoveReminder::NOTIFICATION_PARKING) {
+        // notifyMove is not called while parking
+        // @note insertion delay when resuming after parking is included
+        myStoppingTime += (MSNet::getInstance()->getCurrentTimeStep() - myParkingStarted);
     }
     return true;
 }
@@ -192,6 +205,8 @@ MSDevice_Tripinfo::notifyLeave(SUMOVehicle& veh, double /*lastPos*/,
             myArrivalPos = myHolder.getArrivalPos();
         }
         myArrivalSpeed = veh.getSpeed();
+    } else if (reason == MSMoveReminder::NOTIFICATION_PARKING) {
+        myParkingStarted = MSNet::getInstance()->getCurrentTimeStep();
     }
     return true;
 }
@@ -255,18 +270,12 @@ MSDevice_Tripinfo::generateOutput() const {
     os.writeAttr("arrivalSpeed", myArrivalSpeed);
     os.writeAttr("duration", time2string(duration));
     os.writeAttr("routeLength", routeLength);
-    os.writeAttr("waitSteps", myWaitingTime / DELTA_T);
+    os.writeAttr("waitingTime", time2string(myWaitingTime));
+    os.writeAttr("waitingCount", myWaitingCount);
+    os.writeAttr("stopTime", time2string(myStoppingTime));
     os.writeAttr("timeLoss", time2string(timeLoss));
     os.writeAttr("rerouteNo", myHolder.getNumberReroutes());
-    const std::vector<MSDevice*>& devices = myHolder.getDevices();
-    std::ostringstream str;
-    for (std::vector<MSDevice*>::const_iterator i = devices.begin(); i != devices.end(); ++i) {
-        if (i != devices.begin()) {
-            str << ' ';
-        }
-        str << (*i)->getID();
-    }
-    os.writeAttr("devices", str.str());
+    os.writeAttr("devices", toString(myHolder.getDevices()));
     os.writeAttr("vType", myHolder.getVehicleType().getID());
     os.writeAttr("speedFactor", myHolder.getChosenSpeedFactor());
     os.writeAttr("vaporized", (myHolder.getEdge() == *(myHolder.getRoute().end() - 1) ? "" : "0"));
@@ -276,19 +285,31 @@ MSDevice_Tripinfo::generateOutput() const {
 
 void
 MSDevice_Tripinfo::generateOutputForUnfinished() {
+    const bool writeTripinfos = OptionsCont::getOptions().isSet("tripinfo-output");
+    myWaitingDepartDelay = 0;
+    int undeparted = 0;
+    int departed = 0;
+    const SUMOTime t = MSNet::getInstance()->getCurrentTimeStep();
     while (myPendingOutput.size() > 0) {
         const MSDevice_Tripinfo* d = *myPendingOutput.begin();
         if (d->myHolder.hasDeparted()) {
+            departed++;
             d->generateOutput();
-            if (!OptionsCont::getOptions().isSet("tripinfo-output")) {
-                return;
+            if (writeTripinfos) {
+                // @todo also generate emission output if holder has a device
+                OutputDevice::getDeviceByOption("tripinfo-output").closeTag();
+            } else {
+                myPendingOutput.erase(d);
             }
-            // @todo also generate emission output if holder has a device
-            OutputDevice::getDeviceByOption("tripinfo-output").closeTag();
         } else {
+            undeparted++;
+            myWaitingDepartDelay += (t - d->myHolder.getParameter().depart);
             myPendingOutput.erase(d);
         }
     }
+    if (myWaitingDepartDelay > 0) {
+        myWaitingDepartDelay /= undeparted;
+    }
 }
 
 
@@ -322,11 +343,11 @@ MSDevice_Tripinfo::addRideData(double rideLength, SUMOTime rideDuration, SUMOVeh
         myTotalRideWaitingTime += waitingTime;
         myTotalRideRouteLength += rideLength;
         myTotalRideDuration += rideDuration;
-        if (!line.empty()) {
+        if (vClass == SVC_BICYCLE) {
+            myRideBikeCount++;
+        } else if (!line.empty()) {
             if (isRailway(vClass)) {
                 myRideRailCount++;
-            } else if (vClass == SVC_BICYCLE) {
-                myRideBikeCount++;
             } else {
                 // some kind of road vehicle
                 myRideBusCount++;
@@ -349,6 +370,9 @@ MSDevice_Tripinfo::printStatistics() {
         << " WaitingTime: " << getAvgWaitingTime() << "\n"
         << " TimeLoss: " << getAvgTimeLoss() << "\n"
         << " DepartDelay: " << getAvgDepartDelay() << "\n";
+    if (myWaitingDepartDelay >= 0) {
+        msg << " DepartDelayWaiting: " << STEPS2TIME(myWaitingDepartDelay) << "\n";
+    }
     if (myWalkCount > 0) {
         msg << "Pedestrian Statistics (avg of " << myWalkCount << " walks):\n"
             << " RouteLength: " << getAvgWalkRouteLength() << "\n"
