@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2009-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2009-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSDevice_Tripinfo.h
 /// @author  Daniel Krajzewicz
@@ -25,13 +23,9 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
-#include "MSDevice.h"
+#include "MSVehicleDevice.h"
 #include <utils/common/SUMOTime.h>
 
 // ===========================================================================
@@ -50,7 +44,7 @@ class SUMOVehicle;
  *
  * @see MSDevice
  */
-class MSDevice_Tripinfo : public MSDevice {
+class MSDevice_Tripinfo : public MSVehicleDevice {
 public:
     /** @brief Build devices for the given vehicle, if needed
      *
@@ -62,7 +56,7 @@ public:
      * @param[in] v The vehicle for which a device may be built
      * @param[filled] into The vector to store the built device in
      */
-    static void buildVehicleDevices(SUMOVehicle& v, std::vector<MSDevice*>& into);
+    static void buildVehicleDevices(SUMOVehicle& v, std::vector<MSVehicleDevice*>& into);
 
     /// @brief update tripinfo statistics
     void updateStatistics(SUMOTime timeLoss) const;
@@ -209,6 +203,18 @@ private:
     /// @brief The overall waiting time
     SUMOTime myWaitingTime;
 
+    /// @brief Whether the vehicle is currently waiting
+    bool myAmWaiting;
+
+    /// @brief The overall number of unintended stops
+    int myWaitingCount;
+
+    /// @brief The overall intentional stopping time
+    SUMOTime myStoppingTime;
+
+    /// @brief The time when parking started
+    SUMOTime myParkingStarted;
+
     /// @brief The vehicle's arrival time
     SUMOTime myArrivalTime;
 
@@ -228,9 +234,7 @@ private:
     SUMOTime myMesoTimeLoss;
 
     /// @brief devices which may still need to produce output
-    typedef std::set<const MSDevice_Tripinfo*, Named::NamedLikeComparatorIdLess<MSDevice_Tripinfo> > DeviceSet;
-
-    static DeviceSet myPendingOutput;
+    static std::set<const MSDevice_Tripinfo*, ComparatorNumericalIdLess> myPendingOutput;
 
     /// @brief global tripinfo statistics
     static double myVehicleCount;
@@ -239,6 +243,7 @@ private:
     static SUMOTime myTotalWaitingTime;
     static SUMOTime myTotalTimeLoss;
     static SUMOTime myTotalDepartDelay;
+    static SUMOTime myWaitingDepartDelay;
 
     static int myWalkCount;
     static double myTotalWalkRouteLength;
