@@ -1,24 +1,21 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2009-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    MSDevice_Vehroutes.h
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Fri, 30.01.2009
-/// @version $Id: MSDevice_Vehroutes.h 18375 2015-05-15 07:05:22Z behrisch $
+/// @version $Id$
 ///
 // A device which collects info on the vehicle trip
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2009-2015 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 #ifndef MSDevice_Vehroutes_h
 #define MSDevice_Vehroutes_h
 
@@ -26,15 +23,13 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
-#include "MSDevice.h"
+#include "MSVehicleDevice.h"
 #include <microsim/MSNet.h>
+#include <microsim/MSVehicle.h>
 #include <utils/common/SUMOTime.h>
+#include <utils/iodevices/OutputDevice_String.h>
 
 
 // ===========================================================================
@@ -55,7 +50,7 @@ class MSRoute;
  *
  * @see MSDevice
  */
-class MSDevice_Vehroutes : public MSDevice {
+class MSDevice_Vehroutes : public MSVehicleDevice {
 public:
     /** @brief Static intialization
      */
@@ -72,14 +67,13 @@ public:
      * @param[in] v The vehicle for which a device may be built
      * @param[filled] into The vector to store the built device in
      */
-    static MSDevice_Vehroutes* buildVehicleDevices(SUMOVehicle& v, std::vector<MSDevice*>& into, unsigned int maxRoutes = INT_MAX);
+    static MSDevice_Vehroutes* buildVehicleDevices(SUMOVehicle& v, std::vector<MSVehicleDevice*>& into, int maxRoutes = std::numeric_limits<int>::max());
 
 
     /// @brief generate vehroute output for vehicles which are still in the network
     static void generateOutputForUnfinished();
 
 
-
 public:
     /// @brief Destructor.
     ~MSDevice_Vehroutes();
@@ -97,7 +91,7 @@ public:
      * @see MSMoveReminder::notifyEnter
      * @see MSMoveReminder::Notification
      */
-    bool notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification reason);
+    bool notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification reason, const MSLane* enteredLane = 0);
 
 
     /** @brief Saves exit times if needed
@@ -111,15 +105,19 @@ public:
      *
      * @return True, if exit times are to be collected.
      */
-    bool notifyLeave(SUMOVehicle& veh, SUMOReal lastPos, Notification reason);
+    bool notifyLeave(SUMOVehicle& veh, double lastPos, Notification reason, const MSLane* enteredLane = 0);
     /// @}
 
+    /// @brief return the name for this type of device
+    const std::string deviceName() const {
+        return "vehroute";
+    }
 
-    /** @brief Called on writing tripinfo output
+    void stopEnded(const SUMOVehicleParameter::Stop& stop);
+
+    /** @brief Called on writing vehroutes output
      *
-     * @param[in] os The stream to write the information into
      * @exception IOError not yet implemented
-     * @see MSDevice::tripInfoOutput
      */
     void generateOutput() const;
 
@@ -132,6 +130,18 @@ public:
     const MSRoute* getRoute(int index) const;
 
 
+    /** @brief Saves the state of the device
+    *
+    * @param[in] out The OutputDevice to write the information into
+    */
+    void saveState(OutputDevice& out) const;
+
+    /** @brief Loads the state of the device from the given description
+    *
+    * @param[in] attrs XML attributes describing the current state
+    */
+    void loadState(const SUMOSAXAttributes& attrs);
+
 
 private:
     /** @brief Constructor
@@ -139,7 +149,7 @@ private:
      * @param[in] holder The vehicle that holds this device
      * @param[in] id The ID of the device
      */
-    MSDevice_Vehroutes(SUMOVehicle& holder, const std::string& id, unsigned int maxRoutes);
+    MSDevice_Vehroutes(SUMOVehicle& holder, const std::string& id, int maxRoutes);
 
 
     /** @brief Called on route output
@@ -150,9 +160,17 @@ private:
     void writeXMLRoute(OutputDevice& os, int index = -1) const;
 
 
+    /** @brief Called on writing vehroutes output
+    *
+    * @param[in] hasArrived whether the vehicle has valid arrival information
+    * @exception IOError not yet implemented
+    */
+    void writeOutput(const bool hasArrived) const;
+
+
     /** @brief Called on route change
      */
-    void addRoute();
+    void addRoute(const std::string& info);
 
 
 
@@ -166,6 +184,9 @@ private:
     /// @brief A shortcut for the Option "vehroute-output.dua"
     static bool myDUAStyle;
 
+    /// @brief A shortcut for the Option "vehroute-output.costs"
+    static bool myWriteCosts;
+
     /// @brief A shortcut for the Option "vehroute-output.sorted"
     static bool mySorted;
 
@@ -175,6 +196,9 @@ private:
     /// @brief A shortcut for the Option "vehroute-output.route-length"
     static bool myRouteLength;
 
+    /// @brief A shortcut for the Option "vehroute-output.skip-ptlines"
+    static bool mySkipPTLines;
+
 
     /** @class StateListener
      * @brief A class that is notified about reroutings
@@ -188,10 +212,10 @@ private:
          * @param[in] vehicle The vehicle which changed its state
          * @param[in] to The state the vehicle has changed to
          */
-        void vehicleStateChanged(const SUMOVehicle* const vehicle, MSNet::VehicleState to);
+        void vehicleStateChanged(const SUMOVehicle* const vehicle, MSNet::VehicleState to, const std::string& info = "");
 
         /// @brief A map for internal notification
-        std::map<const SUMOVehicle*, MSDevice_Vehroutes*, Named::NamedLikeComparatorIdLess<SUMOVehicle> > myDevices;
+        std::map<const SUMOVehicle*, MSDevice_Vehroutes*, ComparatorNumericalIdLess> myDevices;
 
     };
 
@@ -222,8 +246,8 @@ private:
          * @param[in] time_ The time the route was replaced
          * @param[in] route_ The prior route
          */
-        RouteReplaceInfo(const MSEdge* const edge_, const SUMOTime time_, const MSRoute* const route_)
-            : edge(edge_), time(time_), route(route_) {}
+        RouteReplaceInfo(const MSEdge* const edge_, const SUMOTime time_, const MSRoute* const route_, const std::string& info_)
+            : edge(edge_), time(time_), route(route_), info(info_) {}
 
         /// @brief Destructor
         ~RouteReplaceInfo() { }
@@ -237,10 +261,10 @@ private:
         /// @brief The prior route
         const MSRoute* route;
 
-    };
+        /// @brief Information regarding rerouting
+        std::string info;
 
-    /// @brief The position on the lane the vehicle departed at
-    SUMOReal myDepartPos;
+    };
 
     /// @brief The currently used route
     const MSRoute* myCurrentRoute;
@@ -252,11 +276,24 @@ private:
     std::vector<SUMOTime> myExits;
 
     /// @brief The maximum number of routes to report
-    const unsigned int myMaxRoutes;
+    const int myMaxRoutes;
 
     /// @brief The last edge the exit time was saved for
     const MSEdge* myLastSavedAt;
 
+    /// @brief The lane the vehicle departed at
+    int myDepartLane;
+
+    /// @brief The lane the vehicle departed at
+    double myDepartPos;
+
+    /// @brief The speed on departure
+    double myDepartSpeed;
+
+    /// @brief The lateral depart position
+    double myDepartPosLat;
+
+    OutputDevice_String myStopOut;
 
 private:
     /// @brief Invalidated copy constructor.
