@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSAbstractLaneChangeModel.cpp
 /// @author  Daniel Krajzewicz
@@ -26,17 +24,14 @@
 // DEBUG
 // ===========================================================================
 //#define DEBUG_TARGET_LANE
+//#define DEBUG_SHADOWLANE
 #define DEBUG_COND (myVehicle.isSelected())
 
 
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/options/OptionsCont.h>
 #include "MSAbstractLaneChangeModel.h"
@@ -117,6 +112,9 @@ MSAbstractLaneChangeModel::MSAbstractLaneChangeModel(MSVehicle& v, const LaneCha
     myLastFollowerSecureGap(0.),
     myLastOrigLeaderGap(0.),
     myLastOrigLeaderSecureGap(0.),
+    myDontResetLCGaps(false),
+    myMaxSpeedLatStanding(v.getVehicleType().getParameter().getLCParam(SUMO_ATTR_LCA_MAXSPEEDLATSTANDING, v.getVehicleType().getMaxSpeedLat())),
+    myMaxSpeedLatFactor(v.getVehicleType().getParameter().getLCParam(SUMO_ATTR_LCA_MAXSPEEDLATFACTOR, 1)),
     myLastLaneChangeOffset(0),
     myAmOpposite(false) {
 }
@@ -160,7 +158,7 @@ MSAbstractLaneChangeModel::getManeuverDist() const {
 
 bool
 MSAbstractLaneChangeModel::congested(const MSVehicle* const neighLeader) {
-    if (neighLeader == 0) {
+    if (neighLeader == nullptr) {
         return false;
     }
     // Congested situation are relevant only on highways (maxSpeed > 70km/h)
@@ -199,9 +197,12 @@ MSAbstractLaneChangeModel::startLaneChangeManeuver(MSLane* source, MSLane* targe
     if (MSGlobals::gLaneChangeDuration > DELTA_T) {
         myLaneChangeCompletion = 0;
         myLaneChangeDirection = direction;
-        mySpeedLat = (target->getCenterOnEdge() - source->getCenterOnEdge()) * (double)DELTA_T / (double)MSGlobals::gLaneChangeDuration;
+        setManeuverDist(target->getCenterOnEdge() - source->getCenterOnEdge());
         myVehicle.switchOffSignal(MSVehicle::VEH_SIGNAL_BLINKER_RIGHT | MSVehicle::VEH_SIGNAL_BLINKER_LEFT);
         myVehicle.switchOnSignal(direction == 1 ? MSVehicle::VEH_SIGNAL_BLINKER_LEFT : MSVehicle::VEH_SIGNAL_BLINKER_RIGHT);
+        if (myLCOutput) {
+            memorizeGapsAtLCInit();
+        }
         return true;
     } else {
         primaryLaneChanged(source, target, direction);
@@ -209,6 +210,15 @@ MSAbstractLaneChangeModel::startLaneChangeManeuver(MSLane* source, MSLane* targe
     }
 }
 
+void
+MSAbstractLaneChangeModel::memorizeGapsAtLCInit() {
+    myDontResetLCGaps = true;
+}
+
+void
+MSAbstractLaneChangeModel::clearGapsAtLCInit() {
+    myDontResetLCGaps = false;
+}
 
 void
 MSAbstractLaneChangeModel::primaryLaneChanged(MSLane* source, MSLane* target, int direction) {
@@ -218,6 +228,9 @@ MSAbstractLaneChangeModel::primaryLaneChanged(MSLane* source, MSLane* target, in
     myVehicle.enterLaneAtLaneChange(target);
     target->enteredByLaneChange(&myVehicle);
     laneChangeOutput("change", source, target, direction);
+    // Assure that the drive items are up to date (even if the following step is no actionstep for the vehicle).
+    // This is necessary because the lane advance uses the target lane from the corresponding drive item.
+    myVehicle.updateDriveItems();
     changed();
 }
 
@@ -234,7 +247,11 @@ MSAbstractLaneChangeModel::laneChangeOutput(const std::string& tag, MSLane* sour
         of.writeAttr(SUMO_ATTR_DIR, direction);
         of.writeAttr(SUMO_ATTR_SPEED, myVehicle.getSpeed());
         of.writeAttr(SUMO_ATTR_POSITION, myVehicle.getPositionOnLane());
-        of.writeAttr("reason", toString((LaneChangeAction)(myOwnState & ~(LCA_RIGHT | LCA_LEFT))));
+        of.writeAttr("reason", toString((LaneChangeAction)(myOwnState & ~(
+                                            LCA_RIGHT | LCA_LEFT
+                                            | LCA_AMBLOCKINGLEADER | LCA_AMBLOCKINGFOLLOWER
+                                            | LCA_MRIGHT | LCA_MLEFT
+                                            | LCA_AMBACKBLOCKER | LCA_AMBACKBLOCKER_STANDING))));
         of.writeAttr("leaderGap", myLastLeaderGap == NO_NEIGHBOR ? "None" : toString(myLastLeaderGap));
         of.writeAttr("leaderSecureGap", myLastLeaderSecureGap == NO_NEIGHBOR ? "None" : toString(myLastLeaderSecureGap));
         of.writeAttr("followerGap", myLastFollowerGap == NO_NEIGHBOR ? "None" : toString(myLastFollowerGap));
@@ -246,15 +263,37 @@ MSAbstractLaneChangeModel::laneChangeOutput(const std::string& tag, MSLane* sour
             of.writeAttr("latGap", latGap == NO_NEIGHBOR ? "None" : toString(latGap));
         }
         of.closeTag();
+        if (MSGlobals::gLaneChangeDuration > DELTA_T) {
+            clearGapsAtLCInit();
+        }
     }
-    // Assure that the drive items are up to date (even if the following step is no actionstep for the vehicle).
-    myVehicle.updateDriveItems();
 }
 
+
+double
+MSAbstractLaneChangeModel::computeSpeedLat(double /*latDist*/, double& maneuverDist) {
+    if (myVehicle.getVehicleType().wasSet(VTYPEPARS_MAXSPEED_LAT_SET)) {
+        int stepsToChange = (int)ceil(maneuverDist / SPEED2DIST(myVehicle.getVehicleType().getMaxSpeedLat()));
+        return DIST2SPEED(maneuverDist / stepsToChange);
+    } else {
+        return maneuverDist / STEPS2TIME(MSGlobals::gLaneChangeDuration);
+    }
+}
+
+
+double
+MSAbstractLaneChangeModel::getAssumedDecelForLaneChangeDuration() const {
+    throw ProcessError("Method getAssumedDecelForLaneChangeDuration() not implemented by model " + toString(myModel));
+}
+
+
 bool
 MSAbstractLaneChangeModel::updateCompletion() {
     const bool pastBefore = pastMidpoint();
-    myLaneChangeCompletion += (double)DELTA_T / (double)MSGlobals::gLaneChangeDuration;
+    // maneuverDist is not updated in the context of continuous lane changing but represents the full LC distance
+    double maneuverDist = getManeuverDist();
+    mySpeedLat = computeSpeedLat(0, maneuverDist);
+    myLaneChangeCompletion += (SPEED2DIST(mySpeedLat) / myManeuverDist);
     return !pastBefore && pastMidpoint();
 }
 
@@ -279,19 +318,22 @@ MSAbstractLaneChangeModel::getShadowLane(const MSLane* lane, double posLat) cons
     if (std::find(myNoPartiallyOccupatedByShadow.begin(), myNoPartiallyOccupatedByShadow.end(), lane) == myNoPartiallyOccupatedByShadow.end()) {
         // initialize shadow lane
         const double overlap = myVehicle.getLateralOverlap(posLat);
+#ifdef DEBUG_SHADOWLANE
         if (debugVehicle()) {
             std::cout << SIMTIME << " veh=" << myVehicle.getID() << " posLat=" << posLat << " overlap=" << overlap << "\n";
         }
-        if (overlap > NUMERICAL_EPS ||
-                // "reserve" target lane even when there is no overlap yet
-                (isChangingLanes() && myLaneChangeCompletion < 0.5)) {
+#endif
+        if (overlap > NUMERICAL_EPS) {
             const int shadowDirection = posLat < 0 ? -1 : 1;
             return lane->getParallelLane(shadowDirection);
+        } else if (isChangingLanes() && myLaneChangeCompletion < 0.5) {
+            // "reserve" target lane even when there is no overlap yet
+            return lane->getParallelLane(myLaneChangeDirection);
         } else {
-            return 0;
+            return nullptr;
         }
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
@@ -304,12 +346,12 @@ MSAbstractLaneChangeModel::getShadowLane(const MSLane* lane) const {
 
 void
 MSAbstractLaneChangeModel::cleanupShadowLane() {
-    if (myShadowLane != 0) {
+    if (myShadowLane != nullptr) {
         if (debugVehicle()) {
             std::cout << SIMTIME << " cleanupShadowLane\n";
         }
         myShadowLane->resetPartialOccupation(&myVehicle);
-        myShadowLane = 0;
+        myShadowLane = nullptr;
     }
     for (std::vector<MSLane*>::const_iterator it = myShadowFurtherLanes.begin(); it != myShadowFurtherLanes.end(); ++it) {
         if (debugVehicle()) {
@@ -323,12 +365,12 @@ MSAbstractLaneChangeModel::cleanupShadowLane() {
 
 void
 MSAbstractLaneChangeModel::cleanupTargetLane() {
-    if (myTargetLane != 0) {
+    if (myTargetLane != nullptr) {
         if (debugVehicle()) {
             std::cout << SIMTIME << " cleanupTargetLane\n";
         }
         myTargetLane->resetManeuverReservation(&myVehicle);
-        myTargetLane = 0;
+        myTargetLane = nullptr;
     }
     for (std::vector<MSLane*>::const_iterator it = myFurtherTargetLanes.begin(); it != myFurtherTargetLanes.end(); ++it) {
         if (debugVehicle()) {
@@ -344,7 +386,9 @@ MSAbstractLaneChangeModel::cleanupTargetLane() {
 
 
 bool
-MSAbstractLaneChangeModel::cancelRequest(int state) {
+MSAbstractLaneChangeModel::cancelRequest(int state, int laneOffset) {
+    // store request before canceling
+    myCanceledStates[laneOffset] |= state;
     int ret = myVehicle.influenceChangeDecision(state);
     return ret != state;
 }
@@ -361,15 +405,21 @@ MSAbstractLaneChangeModel::initLastLaneChangeOffset(int dir) {
 
 void
 MSAbstractLaneChangeModel::updateShadowLane() {
-    if (myShadowLane != 0) {
+    if (!haveLateralDynamics()) {
+        // assume each vehicle drives at the center of its lane and act as if it fits
+        return;
+    }
+    if (myShadowLane != nullptr) {
+#ifdef DEBUG_SHADOWLANE
         if (debugVehicle()) {
             std::cout << SIMTIME << " updateShadowLane()\n";
         }
+#endif
         myShadowLane->resetPartialOccupation(&myVehicle);
     }
     myShadowLane = getShadowLane(myVehicle.getLane());
     std::vector<MSLane*> passed;
-    if (myShadowLane != 0) {
+    if (myShadowLane != nullptr) {
         myShadowLane->setPartialOccupation(&myVehicle);
         const std::vector<MSLane*>& further = myVehicle.getFurtherLanes();
         const std::vector<double>& furtherPosLat = myVehicle.getFurtherLanesPosLat();
@@ -377,10 +427,12 @@ MSAbstractLaneChangeModel::updateShadowLane() {
         passed.push_back(myShadowLane);
         for (int i = 0; i < (int)further.size(); ++i) {
             MSLane* shadowFurther = getShadowLane(further[i], furtherPosLat[i]);
+#ifdef DEBUG_SHADOWLANE
             if (debugVehicle()) {
                 std::cout << SIMTIME << "   further=" << further[i]->getID() << " (posLat=" << furtherPosLat[i] << ") shadowFurther=" << Named::getIDSecure(shadowFurther) << "\n";
             }
-            if (shadowFurther != 0 && MSLinkContHelper::getConnectingLink(*shadowFurther, *passed.back()) != 0) {
+#endif
+            if (shadowFurther != nullptr && MSLinkContHelper::getConnectingLink(*shadowFurther, *passed.back()) != nullptr) {
                 passed.push_back(shadowFurther);
             }
         }
@@ -392,15 +444,19 @@ MSAbstractLaneChangeModel::updateShadowLane() {
             endLaneChangeManeuver();
         }
     }
+#ifdef DEBUG_SHADOWLANE
     if (debugVehicle()) {
         std::cout << SIMTIME << " updateShadowLane() veh=" << myVehicle.getID()
                   << " newShadowLane=" << Named::getIDSecure(myShadowLane)
                   << "\n   before:" << " myShadowFurtherLanes=" << toString(myShadowFurtherLanes) << " further=" << toString(myVehicle.getFurtherLanes()) << " passed=" << toString(passed);
         std::cout << std::endl;
     }
+#endif
     myVehicle.updateFurtherLanes(myShadowFurtherLanes, myShadowFurtherLanesPosLat, passed);
+#ifdef DEBUG_SHADOWLANE
     if (debugVehicle()) std::cout
                 << "\n   after:" << " myShadowFurtherLanes=" << toString(myShadowFurtherLanes) << "\n";
+#endif
 }
 
 
@@ -412,7 +468,7 @@ MSAbstractLaneChangeModel::getShadowDirection() const {
         } else {
             return myLaneChangeDirection;
         }
-    } else if (myShadowLane == 0) {
+    } else if (myShadowLane == nullptr) {
         return 0;
     } else {
         assert(&myShadowLane->getEdge() == &myVehicle.getLane()->getEdge());
@@ -507,9 +563,117 @@ MSAbstractLaneChangeModel::getAngleOffset() const {
 }
 
 
+double
+MSAbstractLaneChangeModel::estimateLCDuration(const double speed, const double remainingManeuverDist, const double decel) const {
+
+    const SUMOVTypeParameter::SubParams& lcParams = myVehicle.getVehicleType().getParameter().getLCParams();
+    if (lcParams.find(SUMO_ATTR_LCA_MAXSPEEDLATSTANDING) == lcParams.end() && lcParams.find(SUMO_ATTR_LCA_MAXSPEEDLATFACTOR) == lcParams.end()) {
+        if (!myVehicle.getVehicleType().wasSet(VTYPEPARS_MAXSPEED_LAT_SET)) {
+            // no dependency of lateral speed on longitudinal speed. (Only called prior to LC initialization to determine whether it could be completed)
+            return STEPS2TIME(MSGlobals::gLaneChangeDuration);
+        } else {
+            return remainingManeuverDist / myVehicle.getVehicleType().getMaxSpeedLat();
+        }
+    }
+
+    if (remainingManeuverDist == 0) {
+        return 0;
+    }
+
+    // Check argument assumptions
+    assert(speed >= 0);
+    assert(remainingManeuverDist >= 0);
+    assert(decel > 0);
+    assert(myVehicle.getVehicleType().getMaxSpeedLat() > 0);
+    assert(myMaxSpeedLatStanding <= myVehicle.getVehicleType().getMaxSpeedLat());
+    assert(myMaxSpeedLatStanding >= 0);
+
+    // for brevity
+    const double v0 = speed;
+    const double D = remainingManeuverDist;
+    const double b = decel;
+    const double wmin = myMaxSpeedLatStanding;
+    const double f = myMaxSpeedLatFactor;
+    const double wmax = myVehicle.getVehicleType().getMaxSpeedLat();
+
+    /* Here's the approach for the calculation of the required time for the LC:
+     * To obtain the maximal LC-duration, for v(t) we assume that v(t)=max(0, v0-b*t),
+     * Where v(t)=0 <=> t >= ts:=v0/b
+     * For the lateral speed w(t) this gives:
+     * w(t) = min(wmax, wmin + f*v(t))
+     * The lateral distance covered until t is
+     * d(t) = int_0^t w(s) ds
+     * We distinguish three possibilities for the solution d(T)=D, where T is the time of the LC completion.
+     * 1) w(T) = wmax, i.e. v(T)>(wmax-wmin)/f
+     * 2) wmin < w(T) < wmax, i.e. (wmax-wmin)/f > v(T) > 0
+     * 3) w(T) = wmin, i.e., v(T)=0
+     */
+    const double vm = (wmax - wmin) / f;
+    double distSoFar = 0.;
+    double timeSoFar = 0.;
+    double v = v0;
+    if (v > vm) {
+        const double wmaxTime = (v0 - vm) / b;
+        const double d1 = wmax * wmaxTime;
+        if (d1 >= D) {
+            return D / wmax;
+        } else {
+            distSoFar += d1;
+            timeSoFar += wmaxTime;
+            v = vm;
+        }
+    }
+    if (v > 0) {
+        /* Here, w(t1+t) = wmin + f*v(t1+t) = wmin + f*(v - b*t)
+         * Thus, the additional lateral distance covered after time t is:
+         * d2 = (wmin + f*v)*t - 0.5*f*b*t^2
+         * and the additional lateral distance covered until v=0 at t=v/b is:
+         * d2 = (wmin + 0.5*f*v)*t
+         */
+        const double t = v / b; // stop time
+        const double d2 = (wmin + 0.5 * f * v) * t; // lateral distance covered until stop
+        assert(d2 > 0);
+        if (distSoFar + d2 >= D) {
+            // LC is completed during this phase
+            const double x = 0.5 * f * b;
+            const double y = wmin + f * v;
+            /* Solve D - distSoFar = y*t - x*t^2.
+             * 0 = x*t^2 - y*t/x + (D - distSoFar)/x
+             */
+            const double p = 0.5 * y / x;
+            const double q = (D - distSoFar) / x;
+            assert(p * p - q > 0);
+            const double t2 = p + sqrt(p * p - q);
+            return timeSoFar + t2;
+        } else {
+            distSoFar += d2;
+            timeSoFar += t;
+            //v = 0;
+        }
+    }
+    // If we didn't return yet this means the LC was not completed until the vehicle stops (if braking with rate b)
+    if (wmin == 0) {
+        // LC won't be completed if vehicle stands
+        return -1;
+    } else {
+        // complete LC with lateral speed wmin
+        return timeSoFar + (D - distSoFar) / wmin;
+    }
+}
+
 SUMOTime
 MSAbstractLaneChangeModel::remainingTime() const {
-    return (SUMOTime)((1. - myLaneChangeCompletion) * MSGlobals::gLaneChangeDuration);
+    assert(isChangingLanes()); // Only to be called during ongoing lane change
+    const SUMOVTypeParameter::SubParams& lcParams = myVehicle.getVehicleType().getParameter().getLCParams();
+    if (lcParams.find(SUMO_ATTR_LCA_MAXSPEEDLATSTANDING) == lcParams.end() && lcParams.find(SUMO_ATTR_LCA_MAXSPEEDLATFACTOR) == lcParams.end()) {
+        if (myVehicle.getVehicleType().wasSet(VTYPEPARS_MAXSPEED_LAT_SET)) {
+            return TIME2STEPS((1. - myLaneChangeCompletion) * myManeuverDist / myVehicle.getVehicleType().getMaxSpeedLat());
+        } else {
+            return (SUMOTime)((1. - myLaneChangeCompletion) * MSGlobals::gLaneChangeDuration);
+        }
+    }
+    // Using maxSpeedLat(Factor/Standing)
+    return TIME2STEPS(estimateLCDuration(myVehicle.getSpeed(), fabs(myManeuverDist * (1 - myLaneChangeCompletion)), myVehicle.getCarFollowModel().getMaxDecel()));
 }
 
 
