@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2005-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2005-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSLCM_DK2008.h
 /// @author  Daniel Krajzewicz
@@ -27,11 +25,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "MSAbstractLaneChangeModel.h"
 #include <vector>
@@ -46,25 +40,15 @@
 class MSLCM_DK2008 : public MSAbstractLaneChangeModel {
 public:
 
-    enum MyLCAEnum {
-        LCA_AMBLOCKINGLEADER = 1 << 16,
-        LCA_AMBLOCKINGFOLLOWER = 1 << 17,
-        LCA_MRIGHT = 1 << 18,
-        LCA_MLEFT = 1 << 19,
-        // !!! never set LCA_UNBLOCK = 1 << 20,
-        LCA_AMBLOCKINGFOLLOWER_DONTBRAKE = 1 << 21,
-        // !!! never used LCA_AMBLOCKINGSECONDFOLLOWER = 1 << 22,
-
-        // !!! never read LCA_KEEP1 = 1 << 24,
-        // !!! never used LCA_KEEP2 = 1 << 25,
-        LCA_AMBACKBLOCKER = 1 << 26,
-        LCA_AMBACKBLOCKER_STANDING = 1 << 27
-    };
-
     MSLCM_DK2008(MSVehicle& v);
 
     virtual ~MSLCM_DK2008();
 
+    /// @brief Returns the model's id
+    LaneChangeModel getModelID() const {
+        return LCM_DK2008;
+    }
+
     /** @brief Called to examine whether the vehicle wants to change
      * using the given laneOffset.
      * This method gets the information about the surrounding vehicles
