@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSLCM_SL2015.h
 /// @author  Jakob Erdmann
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "MSAbstractLaneChangeModel.h"
 #include <vector>
@@ -44,27 +38,15 @@
 class MSLCM_SL2015 : public MSAbstractLaneChangeModel {
 public:
 
-    enum MyLCAEnum {
-        LCA_MNone = 0,
-        LCA_AMBLOCKINGLEADER = 1 << 16,
-        LCA_AMBLOCKINGFOLLOWER = 1 << 17,
-        LCA_MRIGHT = 1 << 18,
-        LCA_MLEFT = 1 << 19,
-        // !!! never set LCA_UNBLOCK = 1 << 20,
-        LCA_AMBLOCKINGFOLLOWER_DONTBRAKE = 1 << 21,
-        // !!! never used LCA_AMBLOCKINGSECONDFOLLOWER = 1 << 22,
-        LCA_CHANGE_TO_HELP = 1 << 23,
-        // !!! never read LCA_KEEP1 = 1 << 24,
-        // !!! never used LCA_KEEP2 = 1 << 25,
-        LCA_AMBACKBLOCKER = 1 << 26,
-        LCA_AMBACKBLOCKER_STANDING = 1 << 27
-    };
-
-
     MSLCM_SL2015(MSVehicle& v);
 
     virtual ~MSLCM_SL2015();
 
+    /// @brief Returns the model's id
+    LaneChangeModel getModelID() const {
+        return LCM_SL2015;
+    }
+
     /// @brief init cached parameters derived directly from model parameters
     void initDerivedParameters();
 
@@ -128,6 +110,8 @@ public:
 
     void changed();
 
+    double getSafetyFactor() const;
+
     void prepareStep();
 
     /// @brief whether the current vehicles shall be debugged
@@ -413,6 +397,8 @@ protected:
     double myTimeToImpatience;
     // @brief lateral acceleration
     double myAccelLat;
+    // @brief distance to turn at which alignment should be adjusted to the turn direction
+    double myTurnAlignmentDist;
     // @brief the factor by which the lookahead distance to the left differs from the lookahead to the right
     double myLookaheadLeft;
     // @brief the factor by which the speedGain-threshold for the leftdiffers from the threshold for the right
