@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSE2Collector.cpp
 /// @author  Christian Roessel
@@ -37,11 +35,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <cassert>
 #include <algorithm>
@@ -59,6 +53,10 @@
 //#define DEBUG_E2_TIME_ON_DETECTOR
 //#define DEBUG_E2_JAMS
 //#define DEBUG_E2_XML_OUT
+//#define DEBUG_COND (true)
+//#define DEBUG_COND (getID()=="e2Detector_e5.601A_1_SAa")
+//#define DEBUG_COND (getID()=="702057")
+//#define DEBUG_COND (getID()=="det0")
 
 MSE2Collector::MSE2Collector(const std::string& id,
                              DetectorUsage usage, MSLane* lane, double startPos, double endPos, double length,
@@ -76,15 +74,17 @@ MSE2Collector::MSE2Collector(const std::string& id,
     reset();
 
 #ifdef DEBUG_E2_CONSTRUCTOR
+    if DEBUG_COND {
     std::cout << "\n" << "Creating MSE2Collector " << id
-              << " with lane = " << lane->getID()
-              << " startPos = " << startPos
-              << " endPos = " << endPos
-              << " length = " << length
-              << " haltingTimeThreshold = " << haltingTimeThreshold
-              << " haltingSpeedThreshold = " << haltingSpeedThreshold
-              << " jamDistThreshold = " << jamDistThreshold
-              << std::endl;
+    << " with lane = " << lane->getID()
+        << " startPos = " << startPos
+        << " endPos = " << endPos
+        << " length = " << length
+        << " haltingTimeThreshold = " << haltingTimeThreshold
+        << " haltingSpeedThreshold = " << haltingSpeedThreshold
+        << " jamDistThreshold = " << jamDistThreshold
+        << std::endl;
+    }
 #endif
 
     assert(lane != 0);
@@ -168,15 +168,17 @@ MSE2Collector::MSE2Collector(const std::string& id,
     }
 
 #ifdef DEBUG_E2_CONSTRUCTOR
+    if DEBUG_COND {
     std::cout << "\n" << "Creating MSE2Collector " << id
-              << " with endLane = " << myLastLane->getID()
-              << " endPos = " << endPos
-              << " startLane = " << myFirstLane->getID()
-              << " startPos = " << startPos
-              << " haltingTimeThreshold = " << haltingTimeThreshold
-              << " haltingSpeedThreshold = " << haltingSpeedThreshold
-              << " jamDistThreshold = " << jamDistThreshold
-              << std::endl;
+    << " with endLane = " << myLastLane->getID()
+        << " endPos = " << endPos
+        << " startLane = " << myFirstLane->getID()
+        << " startPos = " << startPos
+        << " haltingTimeThreshold = " << haltingTimeThreshold
+        << " haltingSpeedThreshold = " << haltingSpeedThreshold
+        << " jamDistThreshold = " << jamDistThreshold
+        << std::endl;
+    }
 #endif
 
     myStartPos = myStartPos < 0 ? lanes[0]->getLength() + myStartPos : myStartPos;
@@ -230,12 +232,14 @@ MSE2Collector::checkPositioning(bool posGiven, double desiredLength) {
     recalculateDetectorLength();
 
 #ifdef DEBUG_E2_CONSTRUCTOR
+    if DEBUG_COND {
     std::stringstream ss;
-//    ss << std::setprecision(32) << myEndPos << " : " << POSITION_EPS;
-//    std::cout << ss.str() << std::endl;
+    //    ss << std::setprecision(32) << myEndPos << " : " << POSITION_EPS;
+    //    std::cout << ss.str() << std::endl;
     std::cout << "myStartPos = " << myStartPos << std::endl;
     std::cout << "myEndPos = " << myEndPos << std::endl;
     std::cout << "myLastLane->getLength() = " << myLastLane->getLength() << std::endl;
+    }
 #endif
 
 
@@ -268,12 +272,12 @@ MSE2Collector::recalculateDetectorLength() {
 
     // sum up their lengths
     std::vector<MSLane*>::const_iterator j;
-    MSLane* previous = 0;
+    MSLane* previous = nullptr;
     myDetectorLength = 0;
     for (j = lanes.begin(); j != lanes.end(); ++j) {
         // lane length
         myDetectorLength += (*j)->getLength();
-        if (previous != 0 && !MSGlobals::gUsingInternalLanes) {
+        if (previous != nullptr && !MSGlobals::gUsingInternalLanes) {
             // eventually link length
             myDetectorLength += previous->getLinkTo(*j)->getLength();
         }
@@ -284,7 +288,9 @@ MSE2Collector::recalculateDetectorLength() {
     myDetectorLength -= myLastLane->getLength() - myEndPos;
 
 #ifdef DEBUG_E2_CONSTRUCTOR
+    if DEBUG_COND {
     std::cout << "Total detector length after recalculation = " << myDetectorLength << std::endl;
+}
 #endif
 }
 
@@ -313,7 +319,9 @@ MSE2Collector::selectLanes(MSLane* lane, double length, std::string dir) {
     bool substractedLinkLength = false; // whether linkLength was substracted during the last iteration.
 
 #ifdef DEBUG_E2_CONSTRUCTOR
+    if DEBUG_COND {
     std::cout << "\n" << "selectLanes()" << (fw ? "(forward)" : "(backward)") << std::endl;
+    }
 #endif
     std::vector<MSLane*> lanes;
     // Selected lanes are stacked into vector 'lanes'. If dir == "bw" lanes will be reversed after this is done.
@@ -328,13 +336,15 @@ MSE2Collector::selectLanes(MSLane* lane, double length, std::string dir) {
         length += lane->getLength() - myEndPos;
     }
     length = MAX2(POSITION_EPS, length); // this assures to add at least one lane to lanes
-    while (length >= POSITION_EPS && lane != 0) {
+    while (length >= POSITION_EPS && lane != nullptr) {
         // Break loop for length <= NUMERICAL_EPS to avoid placement of very small
         // detector piece on the end or beginning of one lane due to numerical rounding errors.
         lanes.push_back(lane);
 #ifdef DEBUG_E2_CONSTRUCTOR
+        if DEBUG_COND {
         std::cout << "Added lane " << lane->getID()
-                  << " (length: " << lane->getLength() << ")" << std::endl;
+            << " (length: " << lane->getLength() << ")" << std::endl;
+        }
 #endif
 
         length -= lane->getLength();
@@ -348,7 +358,7 @@ MSE2Collector::selectLanes(MSLane* lane, double length, std::string dir) {
 
 
         substractedLinkLength = false;
-        if (lane != 0 && !MSGlobals::gUsingInternalLanes && length > POSITION_EPS) {
+        if (lane != nullptr && !MSGlobals::gUsingInternalLanes && length > POSITION_EPS) {
             // In case wher no internal lanes are used,
             // take into account the link length for the detector range
             linkLength = 0;
@@ -363,10 +373,12 @@ MSE2Collector::selectLanes(MSLane* lane, double length, std::string dir) {
 
 
 #ifdef DEBUG_E2_CONSTRUCTOR
+        if DEBUG_COND {
         if (lane != 0) {
-            std::cout << (fw ? "Successor lane: " : "Predecessor lane: ") << "'" << lane->getID() << "'";
+                std::cout << (fw ? "Successor lane: " : "Predecessor lane: ") << "'" << lane->getID() << "'";
+            }
+            std::cout << std::endl;
         }
-        std::cout << std::endl;
 #endif
     }
 
@@ -411,12 +423,16 @@ MSE2Collector::selectLanes(MSLane* lane, double length, std::string dir) {
 void
 MSE2Collector::addDetectorToLanes(std::vector<MSLane*>& lanes) {
 #ifdef DEBUG_E2_CONSTRUCTOR
+    if DEBUG_COND {
     std::cout << "\n" << "Adding detector " << myID << " to lanes:" << std::endl;
+}
 #endif
-    for (std::vector<MSLane*>::iterator l = lanes.begin(); l != lanes.end(); ++l) {
+for (std::vector<MSLane*>::iterator l = lanes.begin(); l != lanes.end(); ++l) {
         (*l)->addMoveReminder(this);
 #ifdef DEBUG_E2_CONSTRUCTOR
+        if DEBUG_COND {
         std::cout << (*l)->getID() << std::endl;
+        }
 #endif
     }
 }
@@ -428,10 +444,12 @@ MSE2Collector::initAuxiliaries(std::vector<MSLane*>& lanes) {
     myLastLane = lanes[lanes.size() - 1];
 
 #ifdef DEBUG_E2_CONSTRUCTOR
+    if DEBUG_COND {
     std::cout << "\n" << "Initializing auxiliaries:"
-              << "\nFirst lane: " << myFirstLane->getID() << " (startPos = " << myStartPos << ")"
-              << "\nLast lane: " << myLastLane->getID() << " (endPos = " << myEndPos << ")"
-              << std::endl;
+    << "\nFirst lane: " << myFirstLane->getID() << " (startPos = " << myStartPos << ")"
+        << "\nLast lane: " << myLastLane->getID() << " (endPos = " << myEndPos << ")"
+        << std::endl;
+    }
 #endif
 
     // Init myOffsets and myDetectorLength.
@@ -452,28 +470,32 @@ MSE2Collector::initAuxiliaries(std::vector<MSLane*>& lanes) {
     // start on an internal lane?
     // (This may happen if specifying the detector by its upstream
     //  length starting from a given end position)
-    const MSLane* internal = (*il)->isInternal() ? *il : 0;
+    const MSLane* internal = (*il)->isInternal() ? *il : nullptr;
 
 #ifdef DEBUG_E2_CONSTRUCTOR
+    if DEBUG_COND {
     std::cout << "\n" << "Initializing offsets:" << std::endl;
+}
 #endif
 
 #ifdef _MSC_VER
 #pragma warning(push)
 #pragma warning(disable: 4127) // do not warn about constant conditional expression
 #endif
-    while (true) {
+while (true) {
 #ifdef _MSC_VER
 #pragma warning(pop)
 #endif
         // Consider the next internal lanes
-        while (internal != 0) {
+        while (internal != nullptr) {
             myLanes.push_back(internal->getID());
             myOffsets.push_back(myDetectorLength);
 
 #ifdef DEBUG_E2_CONSTRUCTOR
+            if DEBUG_COND {
             std::cout << "Offset for lane " << internal->getID() << " = " << myDetectorLength
-                      << std::endl;
+                << std::endl;
+            }
 #endif
 
             myDetectorLength += internal->getLength();
@@ -487,7 +509,7 @@ MSE2Collector::initAuxiliaries(std::vector<MSLane*>& lanes) {
             internal = internal->getLinkCont()[0]->getViaLaneOrLane();
             if (!internal->isInternal()) {
                 // passed the junction
-                internal = 0;
+                internal = nullptr;
                 break;
             }
         }
@@ -509,8 +531,10 @@ MSE2Collector::initAuxiliaries(std::vector<MSLane*>& lanes) {
         myLanes.push_back(lane->getID());
 
 #ifdef DEBUG_E2_CONSTRUCTOR
+        if DEBUG_COND {
         std::cout << "Offset for lane " << lane->getID() << " = " << myDetectorLength
-                  << std::endl;
+            << std::endl;
+        }
 #endif
 
         // Offset to detector start for this lane
@@ -532,7 +556,7 @@ MSE2Collector::initAuxiliaries(std::vector<MSLane*>& lanes) {
 
         // find the connection to next
         const MSLink* link = lane->getLinkTo(*il);
-        if (link == 0) {
+        if (link == nullptr) {
             throw InvalidArgument("Lanes '" + lane->getID() + "' and '" + (*il)->getID() + "' are not consecutive in defintion of e2Detector '" + getID() + "'");
         }
 
@@ -552,11 +576,13 @@ MSE2Collector::initAuxiliaries(std::vector<MSLane*>& lanes) {
     }
 
 #ifdef DEBUG_E2_CONSTRUCTOR
+    if DEBUG_COND {
     std::cout << "Total detector length after initAuxiliaries() = " << myDetectorLength << std::endl;
+}
 #endif
 
-    // make lanes a complete list including internal lanes
-    lanes = getLanes();
+// make lanes a complete list including internal lanes
+lanes = getLanes();
 }
 
 
@@ -586,21 +612,25 @@ MSE2Collector::notifyMove(SUMOVehicle& veh, double oldPos,
     vehInfo.distToDetectorEnd = myDetectorLength - relPos;
 
 #ifdef DEBUG_E2_NOTIFY_MOVE
+    if DEBUG_COND {
     std::cout << "\n" << SIMTIME
-              << " MSE2Collector::notifyMove() (detID = " << myID << "on lane '" << myLane->getID() << "')"
-              << " called by vehicle '" << vehID << "'"
-              << " at relative position " << relPos
-              << ", distToDetectorEnd = " << vehInfo.distToDetectorEnd << std::endl;
+    << " MSE2Collector::notifyMove() (detID = " << myID << "on lane '" << myLane->getID() << "')"
+        << " called by vehicle '" << vehID << "'"
+        << " at relative position " << relPos
+        << ", distToDetectorEnd = " << vehInfo.distToDetectorEnd << std::endl;
+    }
 #endif
 
     // Check whether vehicle has reached the detector begin
     if (relPos <= 0) {
         // detector not yet reached, request being informed further
 #ifdef DEBUG_E2_NOTIFY_MOVE
+        if DEBUG_COND {
         std::cout << "Vehicle has not yet reached the detector start position." << std::endl;
+    }
 #endif
-        return true;
-    } else if (!vehInfo.hasEntered) {
+    return true;
+} else if (!vehInfo.hasEntered) {
         vehInfo.hasEntered = true;
         myNumberOfEnteredVehicles++;
         myNumberOfSeenVehicles++;
@@ -615,19 +645,23 @@ MSE2Collector::notifyMove(SUMOVehicle& veh, double oldPos,
     // ... if not, dont create any notification at all
     if (vehicleEnteredLaneAfterDetector) {
 #ifdef DEBUG_E2_NOTIFY_MOVE
+        if DEBUG_COND {
         std::cout << "Vehicle entered lane behind detector." << std::endl;
+    }
 #endif
-    } else {
-        myMoveNotifications.push_back(makeMoveNotification(veh, oldPos, newPos, newSpeed, vehInfo));
+} else {
+    myMoveNotifications.push_back(makeMoveNotification(veh, oldPos, newPos, newSpeed, vehInfo));
     }
 
 
     if (vehPassedDetectorEnd) {
 #ifdef DEBUG_E2_NOTIFY_MOVE
+        if DEBUG_COND {
         std::cout << "Vehicle has left the detector longitudinally." << std::endl;
+    }
 #endif
-        // Vehicle is beyond the detector, unsubscribe and register removal from myVehicleInfos
-        myLeftVehicles.insert(vehID);
+    // Vehicle is beyond the detector, unsubscribe and register removal from myVehicleInfos
+    myLeftVehicles.insert(vehID);
         return false;
     } else {
         // Receive further notifications
@@ -638,25 +672,31 @@ MSE2Collector::notifyMove(SUMOVehicle& veh, double oldPos,
 bool
 MSE2Collector::notifyLeave(SUMOVehicle& veh, double /* lastPos */, MSMoveReminder::Notification reason, const MSLane* enteredLane) {
 #ifdef DEBUG_E2_NOTIFY_ENTER_AND_LEAVE
+    if DEBUG_COND {
     std::cout << "\n" << SIMTIME << " notifyLeave() (detID = " << myID << "on lane '" << myLane->getID() << "')"
-              << "called by vehicle '" << veh.getID() << "'" << std::endl;
+        << "called by vehicle '" << veh.getID() << "'" << std::endl;
+    }
 #endif
 
     if (reason == MSMoveReminder::NOTIFICATION_JUNCTION) {
         // vehicle left lane via junction, unsubscription and registering in myLeftVehicles when
         // moving beyond the detector end is controlled in notifyMove.
 #ifdef DEBUG_E2_NOTIFY_ENTER_AND_LEAVE
+        if DEBUG_COND {
         std::cout << SIMTIME << " Left longitudinally (along junction) -> keep subscription [handle exit in notifyMove()]" << std::endl;
+    }
 #endif
 
-        if (std::find(myLanes.begin(), myLanes.end(), enteredLane->getID()) == myLanes.end()) {
+    if (std::find(myLanes.begin(), myLanes.end(), enteredLane->getID()) == myLanes.end()) {
             // Entered lane is not part of the detector
             VehicleInfoMap::iterator vi = myVehicleInfos.find(veh.getID());
             // Determine exit offset, where vehicle left the detector
             double exitOffset = vi->second->entryOffset - myOffsets[vi->second->currentOffsetIndex] - vi->second->currentLane->getLength();
             vi->second->exitOffset = MAX2(vi->second->exitOffset, exitOffset);
 #ifdef DEBUG_E2_NOTIFY_ENTER_AND_LEAVE
+            if DEBUG_COND {
             std::cout << SIMTIME << " Vehicle '" << veh.getID() << "' leaves the detector. Exit offset = " << vi->second->exitOffset << std::endl;
+            }
 #endif
         }
 
@@ -664,23 +704,29 @@ MSE2Collector::notifyLeave(SUMOVehicle& veh, double /* lastPos */, MSMoveReminde
     } else {
         VehicleInfoMap::iterator vi = myVehicleInfos.find(veh.getID());
         // erase vehicle, which leaves in a non-longitudinal way, immediately
+        if (vi->second->hasEntered) {
+            myNumberOfLeftVehicles++;
+        }
         delete vi->second;
         myVehicleInfos.erase(vi);
-        myNumberOfLeftVehicles++;
 #ifdef DEBUG_E2_NOTIFY_ENTER_AND_LEAVE
+        if DEBUG_COND {
         std::cout << SIMTIME << " Left non-longitudinally (lanechange, teleport, parking, etc) -> discard subscription" << std::endl;
-#endif
-        return false;
     }
+#endif
+    return false;
+}
 }
 
 
 bool
-MSE2Collector::notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification /* reason */, const MSLane* enteredLane) {
+MSE2Collector::notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification reason, const MSLane* enteredLane) {
 #ifdef DEBUG_E2_NOTIFY_ENTER_AND_LEAVE
-    std::cout << "\n" << SIMTIME << " notifyEnter() (detID = " << myID << "on lane '" << myLane->getID() << "')"
-              << "called by vehicle '" << veh.getID()
-              << "' entering lane '" << (enteredLane != 0 ? enteredLane->getID() : "NULL") << "'" << std::endl;
+    if DEBUG_COND {
+    std::cout << std::endl << SIMTIME << " notifyEnter() (detID = " << myID << " on lane '" << myLane->getID() << "')"
+        << " called by vehicle '" << veh.getID()
+        << "' entering lane '" << (enteredLane != 0 ? enteredLane->getID() : "NULL") << "'" << std::endl;
+    }
 #endif
 
     // notifyEnter() should only be called for lanes of the detector
@@ -692,10 +738,31 @@ MSE2Collector::notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification /* rea
         // That's not my type...
         return false;
     }
+
+    // determine whether the vehicle entered the lane behind the detector end
+    // e.g. due to lane change manoeuver
+    if (reason != NOTIFICATION_JUNCTION) {
+        const double vehBackPos = veh.getBackPositionOnLane(enteredLane);
+        bool vehEnteredBehindDetectorEnd = myEndPos <= vehBackPos;
+        if (vehEnteredBehindDetectorEnd) {
+            // this vehicle cannot influence detector readings, do not subscribe
+            // to move notifications
 #ifdef DEBUG_E2_NOTIFY_ENTER_AND_LEAVE
+            if DEBUG_COND {
+            std::cout << "Vehicle entered the lane behind the detector, ignoring it." << std::endl;
+            std::cout << "(myEndPos = " << this->myEndPos << ", veh.getBackPositionOnLane() = " << vehBackPos << ")" << std::endl;
+        }
+#endif
+        return false;
+    }
+}
+
+#ifdef DEBUG_E2_NOTIFY_ENTER_AND_LEAVE
+if DEBUG_COND {
     if (!veh.isOnRoad()) {
-        // Vehicle is teleporting over the edge
-        std::cout << "Vehicle is off road (teleporting over edge)..." << std::endl;
+            // Vehicle is teleporting over the edge
+            std::cout << "Vehicle is off road (teleporting over edge)..." << std::endl;
+        }
     }
 #endif
 
@@ -707,10 +774,12 @@ MSE2Collector::notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification /* rea
         vi->second->currentLane = enteredLane;
 
 #ifdef DEBUG_E2_NOTIFY_ENTER_AND_LEAVE
+        if DEBUG_COND {
         std::cout << SIMTIME << " Vehicle '" << veh.getID() << "' on lane '" << veh.getLane()->getID()
-                  << "' already known. No new VehicleInfo is created.\n"
-                  << "enteredLane = " << enteredLane->getID() << "\nmyLanes[vi->offset] = " << myLanes[vi->second->currentOffsetIndex]
-                  << std::endl;
+            << "' already known. No new VehicleInfo is created.\n"
+            << "enteredLane = " << enteredLane->getID() << "\nmyLanes[vi->offset] = " << myLanes[vi->second->currentOffsetIndex]
+            << std::endl;
+        }
 #endif
         assert(myLanes[vi->second->currentOffsetIndex] == enteredLane->getID());
 
@@ -721,7 +790,9 @@ MSE2Collector::notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification /* rea
 
 
 #ifdef DEBUG_E2_NOTIFY_ENTER_AND_LEAVE
+    if DEBUG_COND {
     std::cout << SIMTIME << " Adding VehicleInfo for vehicle '" << veh.getID() << "'." << std::endl;
+    }
 #endif
 
     // Add vehicle info
@@ -740,11 +811,13 @@ MSE2Collector::makeVehicleInfo(const SUMOVehicle& veh, const MSLane* enteredLane
     bool onDetector = -entryOffset < veh.getPositionOnLane() && distToDetectorEnd > -veh.getVehicleType().getLength();
 
 #ifdef DEBUG_E2_MAKE_VEHINFO
+    if DEBUG_COND {
     std::cout << SIMTIME << " Making VehicleInfo for vehicle '" << veh.getID() << "'."
-              << "\ndistToDetectorEnd = " << distToDetectorEnd
-              << "\nveh.getPositionOnLane() = " << veh.getPositionOnLane()
-              << "\nentry lane offset (lane begin from detector begin) = " << entryOffset
-              << std::endl;
+        << "\ndistToDetectorEnd = " << distToDetectorEnd
+        << "\nveh.getPositionOnLane() = " << veh.getPositionOnLane()
+        << "\nentry lane offset (lane begin from detector begin) = " << entryOffset
+        << std::endl;
+    }
 #endif
     return new VehicleInfo(veh.getID(), veh.getVehicleType().getID(), veh.getVehicleType().getLength(), veh.getVehicleType().getMinGap(), enteredLane, entryOffset, j,
                            myOffsets[j] - myDetectorLength, distToDetectorEnd, onDetector);
@@ -754,18 +827,20 @@ void
 MSE2Collector::detectorUpdate(const SUMOTime /* step */) {
 
 #ifdef DEBUG_E2_DETECTOR_UPDATE
+    if DEBUG_COND {
     std::cout << "\n" << SIMTIME << " detectorUpdate() for detector '" << myID << "'"
-              << "\nmyCurrentMeanSpeed = " << myCurrentMeanSpeed
-              << "\nmyCurrentMeanLength = " << myCurrentMeanLength
-              << "\nmyNumberOfEnteredVehicles = " << myNumberOfEnteredVehicles
-              << "\nmyNumberOfLeftVehicles = " << myNumberOfLeftVehicles
-              << "\nmyNumberOfSeenVehicles = " << myNumberOfSeenVehicles
-              << std::endl;
+    << "\nmyCurrentMeanSpeed = " << myCurrentMeanSpeed
+    << "\nmyCurrentMeanLength = " << myCurrentMeanLength
+    << "\nmyNumberOfEnteredVehicles = " << myNumberOfEnteredVehicles
+    << "\nmyNumberOfLeftVehicles = " << myNumberOfLeftVehicles
+    << "\nmyNumberOfSeenVehicles = " << myNumberOfSeenVehicles
+    << std::endl;
+}
 #endif
 
-    // sort myMoveNotifications (required for jam processing) ascendingly according to vehicle's distance to the detector end
-    // (min = myMoveNotifications[0].distToDetectorEnd)
-    std::sort(myMoveNotifications.begin(), myMoveNotifications.end(), compareMoveNotification);
+// sort myMoveNotifications (required for jam processing) ascendingly according to vehicle's distance to the detector end
+// (min = myMoveNotifications[0].distToDetectorEnd)
+std::sort(myMoveNotifications.begin(), myMoveNotifications.end(), compareMoveNotification);
 
     // reset values concerning current time step (these are updated in integrateMoveNotification() and aggregateOutputValues())
     myCurrentMeanSpeed = 0;
@@ -773,7 +848,7 @@ MSE2Collector::detectorUpdate(const SUMOTime /* step */) {
     myCurrentStartedHalts = 0;
     myCurrentHaltingsNumber = 0;
 
-    JamInfo* currentJam = 0;
+    JamInfo* currentJam = nullptr;
     std::vector<JamInfo*> jams;
     std::map<std::string, SUMOTime> haltingVehicles;
     std::map<std::string, SUMOTime> intervalHaltingVehicles;
@@ -786,7 +861,7 @@ MSE2Collector::detectorUpdate(const SUMOTime /* step */) {
 
         if (vi == myVehicleInfos.end()) {
             // The vehicle has already left the detector by lanechange, teleport, etc. (not longitudinal)
-            integrateMoveNotification(0, *i);
+            integrateMoveNotification(nullptr, *i);
         } else {
             // Add move notification infos to detector values and VehicleInfo
             integrateMoveNotification(vi->second, *i);
@@ -807,33 +882,41 @@ MSE2Collector::detectorUpdate(const SUMOTime /* step */) {
     myIntervalHaltingVehicleDurations = intervalHaltingVehicles;
 
 #ifdef DEBUG_E2_DETECTOR_UPDATE
-    std::cout << "\n" << SIMTIME << " Current lanes for vehicles still on the detector:" << std::endl;
+    if DEBUG_COND {
+    std::cout << "\n" << SIMTIME << " Current lanes for vehicles still on or approaching the detector:" << std::endl;
+}
 #endif
-    // update current and entered lanes for remaining vehicles
-    VehicleInfoMap::iterator iv;
-    for (iv = myVehicleInfos.begin(); iv != myVehicleInfos.end(); ++iv) {
+// update current and entered lanes for remaining vehicles
+VehicleInfoMap::iterator iv;
+for (iv = myVehicleInfos.begin(); iv != myVehicleInfos.end(); ++iv) {
 #ifdef DEBUG_E2_DETECTOR_UPDATE
+        if DEBUG_COND {
         std::cout << " Vehicle '" << iv->second->id << "'" << ": '"
-                  << iv->second->currentLane->getID() << "'"
-                  << std::endl;
+        << iv->second->currentLane->getID() << "'"
+            << std::endl;
+        }
 #endif
     }
 
 #ifdef DEBUG_E2_DETECTOR_UPDATE
+    if DEBUG_COND {
     std::cout << SIMTIME << " Discarding vehicles that have left the detector:" << std::endl;
+}
 #endif
-    // Remove the vehicles that have left the detector
-    std::set<std::string>::const_iterator i;
-    for (i = myLeftVehicles.begin(); i != myLeftVehicles.end(); ++i) {
+// Remove the vehicles that have left the detector
+std::set<std::string>::const_iterator i;
+for (i = myLeftVehicles.begin(); i != myLeftVehicles.end(); ++i) {
         VehicleInfoMap::iterator j = myVehicleInfos.find(*i);
         delete j->second;
         myVehicleInfos.erase(*i);
         myNumberOfLeftVehicles++;
 #ifdef DEBUG_E2_DETECTOR_UPDATE
+        if DEBUG_COND {
         std::cout << "Erased vehicle '" << *i << "'" << std::endl;
-#endif
     }
-    myLeftVehicles.clear();
+#endif
+}
+myLeftVehicles.clear();
 
     // reset move notifications
     for (std::vector<MoveNotificationInfo*>::iterator j = myMoveNotifications.begin(); j != myMoveNotifications.end(); ++j) {
@@ -871,22 +954,24 @@ void
 MSE2Collector::integrateMoveNotification(VehicleInfo* vi, const MoveNotificationInfo* mni) {
 
 #ifdef DEBUG_E2_DETECTOR_UPDATE
+    if DEBUG_COND {
     std::cout << SIMTIME << " integrateMoveNotification() for vehicle '" << mni->id << "'"
-              << "\ntimeOnDetector = " << mni->timeOnDetector
-              << "\nlengthOnDetector = " << mni->lengthOnDetector
-              << "\ntimeLoss = " << mni->timeLoss
-              << "\nspeed = " << mni->speed
-              << std::endl;
+    << "\ntimeOnDetector = " << mni->timeOnDetector
+    << "\nlengthOnDetector = " << mni->lengthOnDetector
+    << "\ntimeLoss = " << mni->timeLoss
+    << "\nspeed = " << mni->speed
+    << std::endl;
+}
 #endif
 
-    // Accumulate detector values
-    myVehicleSamples += mni->timeOnDetector;
-    myTotalTimeLoss += mni->timeLoss;
-    mySpeedSum += mni->speed * mni->timeOnDetector;
-    myCurrentMeanSpeed += mni->speed * mni->timeOnDetector;
-    myCurrentMeanLength += mni->lengthOnDetector;
+// Accumulate detector values
+myVehicleSamples += mni->timeOnDetector;
+myTotalTimeLoss += mni->timeLoss;
+mySpeedSum += mni->speed * mni->timeOnDetector;
+myCurrentMeanSpeed += mni->speed * mni->timeOnDetector;
+myCurrentMeanLength += mni->lengthOnDetector;
 
-    if (vi != 0) {
+if (vi != nullptr) {
         // Accumulate individual values for the vehicle.
         // @note vi==0 occurs, if the vehicle info has been erased at
         //       notifyLeave() in case of a non-longitudinal exit (lanechange, teleport, etc.)
@@ -904,9 +989,11 @@ MSE2Collector::integrateMoveNotification(VehicleInfo* vi, const MoveNotification
 MSE2Collector::MoveNotificationInfo*
 MSE2Collector::makeMoveNotification(const SUMOVehicle& veh, double oldPos, double newPos, double newSpeed, const VehicleInfo& vehInfo) const {
 #ifdef DEBUG_E2_NOTIFY_MOVE
+    if DEBUG_COND {
     std::cout << SIMTIME << " makeMoveNotification() for vehicle '" << veh.getID() << "'"
-              << " oldPos = " << oldPos << " newPos = " << newPos << " newSpeed = " << newSpeed
-              << std::endl;
+        << " oldPos = " << oldPos << " newPos = " << newPos << " newSpeed = " << newSpeed
+        << std::endl;
+    }
 #endif
 
     // Timefraction in [0,TS] the vehicle has spend on the detector in the last step
@@ -930,28 +1017,34 @@ MSE2Collector::makeMoveNotification(const SUMOVehicle& veh, double oldPos, doubl
     bool stillOnDetector = -distToExit < vehInfo.length;
 
 #ifdef DEBUG_E2_NOTIFY_MOVE
+    if DEBUG_COND {
     std::cout << SIMTIME << " lengthOnDetector = " << lengthOnDetector
-              << "\nvehInfo.exitOffset = " << vehInfo.exitOffset
-              << " vehInfo.entryOffset = " << vehInfo.entryOffset
-              << " distToExit = " << distToExit
-              << std::endl;
+    << "\nvehInfo.exitOffset = " << vehInfo.exitOffset
+    << " vehInfo.entryOffset = " << vehInfo.entryOffset
+    << " distToExit = " << distToExit
+    << std::endl;
+}
 #endif
 
-    /* Store new infos */
-    return new MoveNotificationInfo(veh.getID(), oldPos, newPos, newSpeed, veh.getAcceleration(), myDetectorLength - (vehInfo.entryOffset + newPos), timeOnDetector, lengthOnDetector, timeLoss, stillOnDetector);
+/* Store new infos */
+return new MoveNotificationInfo(veh.getID(), oldPos, newPos, newSpeed, veh.getAcceleration(), myDetectorLength - (vehInfo.entryOffset + newPos), timeOnDetector, lengthOnDetector, timeLoss, stillOnDetector);
 }
 
 void
 MSE2Collector::buildJam(bool isInJam, std::vector<MoveNotificationInfo*>::const_iterator mni, JamInfo*& currentJam, std::vector<JamInfo*>& jams) {
 #ifdef DEBUG_E2_JAMS
+    if DEBUG_COND {
     std::cout << SIMTIME << " buildJam() for vehicle '" << (*mni)->id << "'" << std::endl;
+    }
 #endif
     if (isInJam) {
         // The vehicle is in a jam;
         //  it may be a new one or already an existing one
-        if (currentJam == 0) {
+        if (currentJam == nullptr) {
 #ifdef DEBUG_E2_JAMS
+            if DEBUG_COND {
             std::cout << SIMTIME << " vehicle '" << (*mni)->id << "' forms the start of the first jam" << std::endl;
+            }
 #endif
             // the vehicle is the first vehicle in a jam
             currentJam = new JamInfo();
@@ -964,7 +1057,9 @@ MSE2Collector::buildJam(bool isInJam, std::vector<MoveNotificationInfo*>::const_
             MoveNotificationInfo* currVeh = *mni;
             if (lastVeh->distToDetectorEnd - currVeh->distToDetectorEnd > myJamDistanceThreshold) {
 #ifdef DEBUG_E2_JAMS
+                if DEBUG_COND {
                 std::cout << SIMTIME << " vehicle '" << (*mni)->id << "' forms the start of a new jam" << std::endl;
+                }
 #endif
                 // yep, yep, yep - it's a new one...
                 //  close the frist, build a new
@@ -977,12 +1072,14 @@ MSE2Collector::buildJam(bool isInJam, std::vector<MoveNotificationInfo*>::const_
     } else {
         // the vehicle is not part of a jam...
         //  maybe we have to close an already computed jam
-        if (currentJam != 0) {
+        if (currentJam != nullptr) {
 #ifdef DEBUG_E2_JAMS
+            if DEBUG_COND {
             std::cout << SIMTIME << " Closing current jam." << std::endl;
+        }
 #endif
-            jams.push_back(currentJam);
-            currentJam = 0;
+        jams.push_back(currentJam);
+            currentJam = nullptr;
         }
     }
 }
@@ -991,7 +1088,9 @@ MSE2Collector::buildJam(bool isInJam, std::vector<MoveNotificationInfo*>::const_
 bool
 MSE2Collector::checkJam(std::vector<MoveNotificationInfo*>::const_iterator mni, std::map<std::string, SUMOTime>& haltingVehicles, std::map<std::string, SUMOTime>& intervalHaltingVehicles) {
 #ifdef DEBUG_E2_JAMS
+    if DEBUG_COND {
     std::cout << SIMTIME << " CheckJam() for vehicle '" << (*mni)->id << "'" << std::endl;
+    }
 #endif
     // jam-checking begins
     bool isInJam = false;
@@ -1006,7 +1105,9 @@ MSE2Collector::checkJam(std::vector<MoveNotificationInfo*>::const_iterator mni,
             intervalHaltingVehicles[(*mni)->id] = myIntervalHaltingVehicleDurations[(*mni)->id] + DELTA_T;
         } else {
 #ifdef DEBUG_E2_JAMS
+            if DEBUG_COND {
             std::cout << SIMTIME << " vehicle '" << (*mni)->id << "' starts halting." << std::endl;
+            }
 #endif
             haltingVehicles[(*mni)->id] = DELTA_T;
             intervalHaltingVehicles[(*mni)->id] = DELTA_T;
@@ -1032,7 +1133,9 @@ MSE2Collector::checkJam(std::vector<MoveNotificationInfo*>::const_iterator mni,
         }
     }
 #ifdef DEBUG_E2_JAMS
+    if DEBUG_COND {
     std::cout << SIMTIME << " vehicle '" << (*mni)->id << "'" << (isInJam ? "is jammed." : "is not jammed.") << std::endl;
+    }
 #endif
     return isInJam;
 }
@@ -1041,14 +1144,16 @@ MSE2Collector::checkJam(std::vector<MoveNotificationInfo*>::const_iterator mni,
 void
 MSE2Collector::processJams(std::vector<JamInfo*>& jams, JamInfo* currentJam) {
     // push last jam
-    if (currentJam != 0) {
+    if (currentJam != nullptr) {
         jams.push_back(currentJam);
-        currentJam = 0;
+        currentJam = nullptr;
     }
 
 #ifdef DEBUG_E2_JAMS
+    if DEBUG_COND {
     std::cout << "\n" << SIMTIME << " processJams()"
-              << "\nNumber of jams: " << jams.size() << std::endl;
+    << "\nNumber of jams: " << jams.size() << std::endl;
+    }
 #endif
 
     // process jam information
@@ -1072,10 +1177,12 @@ MSE2Collector::processJams(std::vector<JamInfo*>& jams, JamInfo* currentJam) {
         myCurrentJamLengthInMeters += jamLengthInMeters;
         myCurrentJamLengthInVehicles += jamLengthInVehicles;
 #ifdef DEBUG_E2_JAMS
+        if DEBUG_COND {
         std::cout << SIMTIME << " processing jam nr." << ((int) distance((std::vector<JamInfo*>::const_iterator) jams.begin(), i) + 1)
-                  << "\njamLengthInMeters = " << jamLengthInMeters
-                  << " jamLengthInVehicles = " << jamLengthInVehicles
-                  << std::endl;
+            << "\njamLengthInMeters = " << jamLengthInMeters
+            << " jamLengthInVehicles = " << jamLengthInVehicles
+            << std::endl;
+        }
 #endif
     }
     myCurrentJamNo = (int) jams.size();
@@ -1134,12 +1241,14 @@ MSE2Collector::calculateTimeLossAndTimeOnDetector(const SUMOVehicle& veh, double
     timeLoss = MAX2(0., timeOnDetector * (vmax - (entrySpeed + exitSpeed) / 2) / vmax);
 
 #ifdef DEBUG_E2_TIME_ON_DETECTOR
+    if DEBUG_COND {
     std::cout << SIMTIME << " calculateTimeLoss() for vehicle '" << veh.getID() << "'"
-              << " oldPos = " << oldPos << " newPos = " << newPos
-              << " entryPos = " << entryPos << " exitPos = " << exitPos
-              << " timeOnDetector = " << timeOnDetector
-              << " timeLoss = " << timeLoss
-              << std::endl;
+        << " oldPos = " << oldPos << " newPos = " << newPos
+        << " entryPos = " << entryPos << " exitPos = " << exitPos
+        << " timeOnDetector = " << timeOnDetector
+        << " timeLoss = " << timeLoss
+        << std::endl;
+    }
 #endif
 }
 
@@ -1191,14 +1300,16 @@ MSE2Collector::writeXMLOutput(OutputDevice& dev, SUMOTime startTime, SUMOTime st
     const SUMOTime intervalMeanHaltingDuration = intervalHaltingNo != 0 ? intervalHaltingDurationSum / intervalHaltingNo : 0;
 
 #ifdef DEBUG_E2_XML_OUT
+    if DEBUG_COND {
     std::stringstream ss;
     ss  << "sampledSeconds=\"" << myVehicleSamples << "\" "
-        << "myTimeSamples=\"" << myTimeSamples << "\" "
-        << "myOccupancySum=\"" << myOccupancySum << "\" "
-        << "myMeanVehicleNumber=\"" << myMeanVehicleNumber << "\" "
-        << "nVehEntered=\"" << myNumberOfEnteredVehicles << "\" "
-        << "meanSpeed=\"" << meanSpeed << "\"";
+    << "myTimeSamples=\"" << myTimeSamples << "\" "
+    << "myOccupancySum=\"" << myOccupancySum << "\" "
+    << "myMeanVehicleNumber=\"" << myMeanVehicleNumber << "\" "
+    << "nVehEntered=\"" << myNumberOfEnteredVehicles << "\" "
+    << "meanSpeed=\"" << meanSpeed << "\"";
     std::cout << ss.str() << std::endl;
+    }
 #endif
 
 
