@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2003-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2003-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSE3Collector.h
 /// @author  Christian Roessel
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <vector>
@@ -79,6 +73,17 @@ public:
 
         /// @name Methods inherited from MSMoveReminder.
         /// @{
+        /** @brief Checks whether the reminder is activated by a vehicle entering the lane
+         *
+         * Lane change means in this case that the vehicle changes to the lane
+         *  the reminder is placed at.
+         *
+         * @param[in] veh The entering vehicle.
+         * @param[in] reason how the vehicle enters the lane
+         * @return True if vehicle enters the reminder.
+         * @see Notification
+         */
+        bool notifyEnter(SUMOVehicle& veh, Notification reason, const MSLane* enteredLane);
 
         /** @brief Checks whether the vehicle enters
          *
@@ -146,6 +151,17 @@ public:
 
         /// @name methods from MSMoveReminder
         //@{
+        /** @brief Checks whether the reminder is activated by a vehicle entering the lane
+         *
+         * Lane change means in this case that the vehicle changes to the lane
+         *  the reminder is placed at.
+         *
+         * @param[in] veh The entering vehicle.
+         * @param[in] reason how the vehicle enters the lane
+         * @return True if vehicle enters the reminder.
+         * @see Notification
+         */
+        bool notifyEnter(SUMOVehicle& veh, Notification reason, const MSLane* enteredLane);
 
         /** @brief Checks whether the vehicle leaves
          *
@@ -208,7 +224,7 @@ public:
                   const CrossSectionVector& entries, const CrossSectionVector& exits,
                   double haltingSpeedThreshold,
                   SUMOTime haltingTimeThreshold,
-                  const std::string& vTypes);
+                  const std::string& vTypes, bool openEntry);
 
 
     /// @brief Destructor
@@ -228,7 +244,7 @@ public:
      *  @param[in] entryTimestep The time in seconds the vehicle entered the area
      *  @param[in] fractionTimeOnDet The interpolated time in seconds the vehicle already spent on the detector
      */
-    void enter(const SUMOVehicle& veh, const double entryTimestep, const double fractionTimeOnDet);
+    void enter(const SUMOVehicle& veh, const double entryTimestep, const double fractionTimeOnDet, MSE3EntryReminder* entryReminder);
 
 
     /** @brief Called if a vehicle front passes a leave-cross-section.
@@ -363,7 +379,7 @@ protected:
         /// @brief The sum of haltings the vehicle has/had within the area
         int haltings;
         /// @brief Begin time of last halt begin
-        double haltingBegin;
+        SUMOTime haltingBegin;
         /// @brief The sum of registered speeds the vehicle has/had inside the area during the current interval
         double intervalSpeedSum;
         /// @brief The sum of haltings the vehicle has/had within the area during the current interval
@@ -374,13 +390,15 @@ protected:
         SUMOTime intervalTimeLoss;
         /// @brief An internal information whether the update step was performed
         bool hadUpdate;
+        /// @brief the reminder on which the vehicle entered the detector
+        MSE3EntryReminder* entryReminder;
     };
 
     /// @brief Container for vehicles that have entered the area
     std::map<const SUMOVehicle*, E3Values> myEnteredContainer;
 
     /// @brief Container for vehicles that have left the area
-    std::map<const SUMOVehicle*, E3Values> myLeftContainer;
+    std::vector<E3Values> myLeftContainer;
 
 
     /// @name Storages for current values
@@ -397,6 +415,8 @@ protected:
     /// @brief Information when the last reset has been done
     SUMOTime myLastResetTime;
 
+    /// @brief whether this dector is declared as having incomplete entry detectors
+    const bool myOpenEntry;
 
 private:
     /// @brief Invalidated copy constructor.
