@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSVTypeProbe.cpp
 /// @author  Tino Morenz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <utils/common/WrappingCommand.h>
@@ -74,7 +68,7 @@ MSVTypeProbe::execute(SUMOTime currentTime) {
                 Position pos = veh->getPosition();
                 myOutputDevice.openTag(SUMO_TAG_VEHICLE);
                 myOutputDevice.writeAttr(SUMO_ATTR_ID, veh->getID());
-                if (microVeh != 0) {
+                if (microVeh != nullptr) {
                     myOutputDevice.writeAttr(SUMO_ATTR_LANE, microVeh->getLane()->getID());
                 }
                 myOutputDevice.writeAttr(SUMO_ATTR_POSITION, veh->getPositionOnLane());
