@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2014-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2014-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSPModel_Striping.h
 /// @author  Jakob Erdmann
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <limits>
@@ -68,6 +62,9 @@ public:
     /// @brief register the given person as a pedestrian
     PedestrianState* add(MSPerson* person, MSPerson::MSPersonStage_Walking* stage, SUMOTime now);
 
+    /// @brief put the given state on lane
+    void add(PedestrianState* pState, const MSLane* lane);
+
     /// @brief remove the specified person from the pedestrian simulation
     void remove(PedestrianState* state);
 
@@ -86,6 +83,7 @@ public:
     bool hasPedestrians(const MSLane* lane);
 
     /// @brief whether movements on intersections are modelled
+    //// @note function declared as member for sake of inheritance (delegates to static function)
     bool usingInternalLanes();
 
     /// @brief returns the next pedestrian beyond minPos that is laterally between minRight and maxLeft or 0
@@ -305,6 +303,10 @@ protected:
         WalkingAreaPath* myWalkingAreaPath;
         /// @brief whether the person is jammed
         bool myAmJammed;
+        /// @brief remote-controlled position
+        Position myRemoteXYPos;
+        /// @brief cached angle
+        mutable double myAngle;
 
         /// @brief return the minimum position on the lane
         double getMinX(const bool includeMinGap = true) const;
@@ -347,6 +349,9 @@ protected:
         /// @brief replace obstacles in the first vector with obstacles from the second if they are closer to me
         void mergeObstacles(Obstacles& into, const Obstacles& obs2);
 
+        /// @brief replace obstacles in the first vector with obstacles from the second if they are closer in the given direction
+        static void mergeObstacles(Obstacles& into, const Obstacles& obs2, int dir, int offset);
+
         /// @brief whether the pedestrian may ignore a red light
         bool ignoreRed(const MSLink* link) const;
     };
@@ -443,11 +448,13 @@ private:
     static int getStripeOffset(int origStripes, int destStripes, bool addRemainder);
 
     ///@brief add vehicles driving across
-    static bool addCrossingVehs(const MSLane* crossing, int stripes, double lateral_offset, int dir, Obstacles& crossingVehs);
-private:
-    /// @brief the MovePedestrians command that is registered
-    MovePedestrians* myCommand;
+    static bool addCrossingVehs(const MSLane* crossing, int stripes, double lateral_offset, int dir, Obstacles& crossingVehs, bool prio);
 
+    ///@brief retrieve vehicle obstacles on the given lane
+    static Obstacles getVehicleObstacles(const MSLane* lane, int dir, PState* ped = 0);
+
+    static bool usingInternalLanesStatic();
+private:
     /// @brief the total number of active pedestrians
     int myNumActivePedestrians;
 
