@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSPerson.h
 /// @author  Daniel Krajzewicz
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <vector>
@@ -55,6 +49,7 @@ class SUMOVehicle;
 class MSVehicleType;
 class MSPModel;
 class PedestrianState;
+class DummyState;
 
 typedef std::vector<const MSEdge*> ConstMSEdgeVector;
 
@@ -111,18 +106,20 @@ public:
         std::string getStageDescription() const {
             return "walking";
         }
+        std::string getStageSummary() const;
 
         /** @brief Called on writing tripinfo output
          * @param[in] os The stream to write the information into
          * @exception IOError not yet implemented
          */
-        virtual void tripInfoOutput(OutputDevice& os, MSTransportable* transportable) const;
+        virtual void tripInfoOutput(OutputDevice& os, const MSTransportable* const transportable) const;
 
         /** @brief Called on writing vehroute output
          * @param[in] os The stream to write the information into
+         * @param[in] withRouteLength whether route length shall be written
          * @exception IOError not yet implemented
          */
-        virtual void routeOutput(OutputDevice& os) const;
+        virtual void routeOutput(OutputDevice& os, const bool withRouteLength) const;
 
         /** @brief Called for writing the events output
          * @param[in] os The stream to write the information into
@@ -137,11 +134,14 @@ public:
         virtual void endEventOutput(const MSTransportable& p, SUMOTime t, OutputDevice& os) const;
 
         /// @brief move forward and return whether the person arrived
-        bool moveToNextEdge(MSPerson* person, SUMOTime currentTime, MSEdge* nextInternal = 0);
+        bool moveToNextEdge(MSPerson* person, SUMOTime currentTime, MSEdge* nextInternal = nullptr);
+
+        /// @brief place person on a previously passed edge
+        void setRouteIndex(MSPerson* person, int routeOffset);
 
         /// @brief accessors to be used by MSPModel
         //@{
-        double getMaxSpeed(const MSPerson* person) const;
+        double getMaxSpeed(const MSTransportable* const person) const;
 
         inline double getDepartPos() const {
             return myDepartPos;
@@ -230,14 +230,15 @@ public:
     };
 
     /**
-     * A "real" stage performing the travelling by a transport system
-     * The given route will be chosen. The travel time is computed by the simulation
-     */
+    * A "real" stage performing the travelling by a transport system
+    * The given route will be chosen. The travel time is computed by the simulation
+    */
     class MSPersonStage_Driving : public MSTransportable::Stage_Driving {
     public:
         /// constructor
-        MSPersonStage_Driving(const MSEdge& destination, MSStoppingPlace* toStop,
-                              const double arrivalPos, const std::vector<std::string>& lines);
+        MSPersonStage_Driving(const MSEdge* destination, MSStoppingPlace* toStop,
+                              const double arrivalPos, const std::vector<std::string>& lines,
+                              const std::string& intendedVeh = "", SUMOTime intendedDepart = -1);
 
         /// destructor
         ~MSPersonStage_Driving();
@@ -247,20 +248,85 @@ public:
 
         /// @brief returns the stage description as a string
         std::string getStageDescription() const;
+        std::string getStageSummary() const;
 
         /** @brief Called on writing tripinfo output
-         *
-         * @param[in] os The stream to write the information into
-         * @exception IOError not yet implemented
-         */
-        virtual void tripInfoOutput(OutputDevice& os, MSTransportable* transportable) const;
+        *
+        * @param[in] os The stream to write the information into
+        * @param[in] transportable The person to write information about
+        * @exception IOError not yet implemented
+        */
+        virtual void tripInfoOutput(OutputDevice& os, const MSTransportable* const transportable) const;
 
         /** @brief Called on writing vehroute output
          *
          * @param[in] os The stream to write the information into
+         * @param[in] withRouteLength whether route length shall be written
          * @exception IOError not yet implemented
          */
-        virtual void routeOutput(OutputDevice& os) const;
+        virtual void routeOutput(OutputDevice& os, const bool withRouteLength) const;
+    };
+
+    /**
+     * An intermediate stage performing the access from or to public transport as given
+     * by the access elements of the public transport stop. The travel time is computed by the simulation
+     */
+    class MSPersonStage_Access : public MSTransportable::Stage {
+    public:
+        /// constructor
+        MSPersonStage_Access(const MSEdge* destination, MSStoppingPlace* toStop,
+                             const double arrivalPos, const double dist, const bool isExit);
+
+        /// destructor
+        ~MSPersonStage_Access();
+
+        /// proceeds to the next step
+        virtual void proceed(MSNet* net, MSTransportable* person, SUMOTime now, Stage* previous);
+
+        /// @brief returns the stage description as a string
+        std::string getStageDescription() const;
+        std::string getStageSummary() const;
+
+        Position getPosition(SUMOTime now) const;
+
+        double getAngle(SUMOTime now) const;
+
+        /** @brief Called on writing tripinfo output
+        *
+        * @param[in] os The stream to write the information into
+        * @param[in] transportable The person to write information about
+        * @exception IOError not yet implemented
+        */
+        void tripInfoOutput(OutputDevice& os, const MSTransportable* const transportable) const;
+
+        /// @brief Called on writing vehroute output. Currently does nothing.
+        void routeOutput(OutputDevice&, const bool) const {};
+
+        /// @brief Called on writing events output (begin of an action). Currently does nothing.
+        void beginEventOutput(const MSTransportable&, SUMOTime, OutputDevice&) const {};
+
+        /// @brief Called on writing events output (end of an action). Currently does nothing.
+        void endEventOutput(const MSTransportable&, SUMOTime, OutputDevice&) const {};
+
+    private:
+        class ProceedCmd : public Command {
+        public:
+            ProceedCmd(MSTransportable* person, MSEdge* edge) : myPerson(person), myStopEdge(edge) {}
+            ~ProceedCmd() {}
+            SUMOTime execute(SUMOTime currentTime);
+        private:
+            MSTransportable* const myPerson;
+            MSEdge* myStopEdge;
+        private:
+            /// @brief Invalidated assignment operator.
+            ProceedCmd& operator=(const ProceedCmd&);
+        };
+
+    private:
+        const double myDist;
+        const bool myAmExit;
+        SUMOTime myEstimatedArrival;
+        PositionVector myPath;
     };
 
 public:
@@ -285,14 +351,14 @@ public:
     * @param[in] os The stream to write the information into
     * @exception IOError not yet implemented
     */
-    virtual void tripInfoOutput(OutputDevice& os, MSTransportable* transportable) const;
+    virtual void tripInfoOutput(OutputDevice& os) const;
 
     /** @brief Called on writing vehroute output
     *
     * @param[in] os The stream to write the information into
     * @exception IOError not yet implemented
     */
-    virtual void routeOutput(OutputDevice& os) const;
+    virtual void routeOutput(OutputDevice& os, const bool withRouteLength) const;
 
     /// @brief whether this person is selected in the GUI
     virtual bool isSelected() const {
@@ -303,10 +369,9 @@ public:
         return myChosenSpeedFactor;
     }
 
-    /// @brief set new walk
-    void reroute(ConstMSEdgeVector& newEdges);
+    /// @brief set new walk and replace the stages with relative indices in the interval [firstIndex, nextIndex[
+    void reroute(ConstMSEdgeVector& newEdges, double departPos, int firstIndex, int nextIndex);
 
-#ifndef NO_TRACI
 
     /** @class Influencer
      * @brief Changes the wished person speed and position
@@ -366,11 +431,11 @@ public:
 private:
     /// @brief An instance of a speed/position influencing instance; built in "getInfluencer"
     Influencer* myInfluencer;
-#endif
 
-private:
     const double myChosenSpeedFactor;
 
+    static DummyState myDummyState;
+
 private:
     /// @brief Invalidated copy constructor.
     MSPerson(const MSPerson&);
