@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2010-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2010-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSDeterministicHiLevelTrafficLightLogic.cpp
 /// @author  Riccardo Belletti
@@ -21,9 +19,9 @@
 
 MSDeterministicHiLevelTrafficLightLogic::MSDeterministicHiLevelTrafficLightLogic(
     MSTLLogicControl& tlcontrol, const std::string& id,
-    const std::string& subid, const Phases& phases, int step,
+    const std::string& programID, const Phases& phases, int step,
     SUMOTime delay, const std::map<std::string, std::string>& parameters) :
-    MSSOTLHiLevelTrafficLightLogic(tlcontrol, id, subid, phases, step,
+    MSSOTLHiLevelTrafficLightLogic(tlcontrol, id, programID, TLTYPE_HILVL_DETERMINISTIC, phases, step,
                                    delay, parameters) {
 
     addPolicy(new MSSOTLPlatoonPolicy(new MSSOTLPolicy3DStimulus("PLATOON", parameters), parameters));
@@ -37,8 +35,7 @@ MSDeterministicHiLevelTrafficLightLogic::~MSDeterministicHiLevelTrafficLightLogi
 
 }
 
-void MSDeterministicHiLevelTrafficLightLogic::init(NLDetectorBuilder& nb)
-throw(ProcessError) {
+void MSDeterministicHiLevelTrafficLightLogic::init(NLDetectorBuilder& nb) {
     MSSOTLHiLevelTrafficLightLogic::init(nb);
     //Setting the startup policy
     choosePolicy(0, 0);
@@ -46,7 +43,7 @@ throw(ProcessError) {
         "*** Intersection " + getID()
         + " will run using MSDeterministicHiLevelTrafficLightLogic ***");
 
-    MSLane* currentLane = NULL;
+    MSLane* currentLane = nullptr;
     for (MSTrafficLightLogic::LaneVectorVector::const_iterator laneVector =
                 myLanes.begin(); laneVector != myLanes.end(); laneVector++) {
         for (MSTrafficLightLogic::LaneVector::const_iterator lane =
