@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSPhaseDefinition.h
 /// @author  Daniel Krajzewicz
@@ -33,11 +31,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <bitset>
 #include <string>
@@ -88,6 +82,9 @@ public:
     /// @brief Stores the timestep of the last on-switched of the phase
     SUMOTime myLastSwitch;
 
+    /// @brief The index of the phase that suceeds this one (or -1)
+    int nextPhase;
+
 private:
     /// @brief The phase definition
     std::string state;
@@ -107,19 +104,20 @@ private:
      */
     LaneIdVector targetLaneSet;
 
-    void init(SUMOTime durationArg, SUMOTime minDurationArg, SUMOTime maxDurationArg, const std::string& stateArg) {
+    void init(SUMOTime durationArg, const std::string& stateArg, SUMOTime minDurationArg, SUMOTime maxDurationArg, int nextPhase) {
         this->duration = durationArg;
+        this->state = stateArg;
         this->minDuration = minDurationArg < 0 ? durationArg : minDurationArg;
         this->maxDuration = (maxDurationArg < 0 || maxDurationArg < minDurationArg) ? durationArg : maxDurationArg;
         // assert(this->minDuration <= this->maxDuration); // not ensured by the previous lines
-        this->state = stateArg;
         this->myLastSwitch = string2time(OptionsCont::getOptions().getString("begin")); // SUMOTime-option
         //For SOTL phases
         //this->phaseType = phaseTypeArg;
+        this->nextPhase = nextPhase;
     }
 
-    void init(SUMOTime durationArg, SUMOTime minDurationArg, SUMOTime maxDurationArg, const std::string& stateArg, LaneIdVector& targetLaneSetArg) {
-        init(durationArg, minDurationArg, maxDurationArg, stateArg);
+    void init(SUMOTime durationArg, SUMOTime minDurationArg, SUMOTime maxDurationArg, const std::string& stateArg, int nextPhase, LaneIdVector& targetLaneSetArg) {
+        init(durationArg, stateArg, minDurationArg, maxDurationArg, nextPhase);
         //For SOTL target phases
         this->targetLaneSet = targetLaneSetArg;
     }
@@ -133,32 +131,32 @@ public:
      * @param[in] durationArg The duration of the phase
      * @param[in] stateArg The state in the phase
      */
-    MSPhaseDefinition(SUMOTime durationArg, const std::string& stateArg) {
+    MSPhaseDefinition(SUMOTime durationArg, const std::string& stateArg, int nextPhase) {
         //PhaseType phaseType;
         phaseType = PhaseType();
         phaseType[UNDEFINED_BIT] = 1;
         phaseType[TRANSIENT_NOTDECISIONAL_BIT] = 0;
         phaseType[TARGET_BIT] = 0;
         phaseType[COMMIT_BIT] = 0;
-        init(durationArg, durationArg, durationArg, stateArg);
+        init(durationArg, stateArg, durationArg, durationArg, nextPhase);
     }
 
 
     /** @brief Constructor
      * In this phase the duration is constrained between min and max duration
      * @param[in] durationArg The duration of the phase
+     * @param[in] stateArg The state in the phase
      * @param[in] minDurationArg The minimum duration of the phase
      * @param[in] maxDurationArg The maximum duration of the phase
-     * @param[in] stateArg The state in the phase
      */
-    MSPhaseDefinition(SUMOTime durationArg, SUMOTime minDurationArg, SUMOTime maxDurationArg, const std::string& stateArg) throw() {
+    MSPhaseDefinition(SUMOTime durationArg, const std::string& stateArg, SUMOTime minDurationArg=-1, SUMOTime maxDurationArg=-1, int nextPhase=-1) {
         //PhaseType phaseType;
         phaseType = PhaseType();
         phaseType[UNDEFINED_BIT] = 1;
         phaseType[TRANSIENT_NOTDECISIONAL_BIT] = 0;
         phaseType[TARGET_BIT] = 0;
         phaseType[COMMIT_BIT] = 0;
-        init(durationArg, minDurationArg, maxDurationArg, stateArg);
+        init(durationArg, stateArg, minDurationArg, maxDurationArg, nextPhase);
     }
 
     /*
@@ -169,7 +167,7 @@ public:
      * @param[in] targetLaneSet identifies the lane-set to be considered when deciding the target phase to jump to
      * @see MSPhaseDefinition::PhaseType
      */
-    MSPhaseDefinition(SUMOTime durationArg, const std::string& stateArg, bool transient_notdecisional, bool commit, LaneIdVector& targetLaneSetArg) throw() {
+    MSPhaseDefinition(SUMOTime durationArg, const std::string& stateArg, int nextPhase,  bool transient_notdecisional, bool commit, LaneIdVector& targetLaneSetArg) {
         if (targetLaneSetArg.size() == 0) {
             MsgHandler::getErrorInstance()->inform("MSPhaseDefinition::MSPhaseDefinition -> targetLaneSetArg cannot be empty for a target phase");
         }
@@ -179,7 +177,7 @@ public:
         phaseType[TRANSIENT_NOTDECISIONAL_BIT] = transient_notdecisional;
         phaseType[TARGET_BIT] = 1;
         phaseType[COMMIT_BIT] = commit;
-        init(durationArg, durationArg, durationArg, stateArg, targetLaneSetArg);
+        init(durationArg, durationArg, durationArg, stateArg, nextPhase, targetLaneSetArg);
     }
 
     /*
@@ -187,14 +185,14 @@ public:
      * In this phase the duration is fixed, because min and max duration are unspecified
      * @param[in] phaseType Indicates the type of the step
      */
-    MSPhaseDefinition(SUMOTime durationArg, const std::string& stateArg, bool transient_notdecisional, bool commit) throw() {
+    MSPhaseDefinition(SUMOTime durationArg, const std::string& stateArg, int nextPhase, bool transient_notdecisional, bool commit) {
         //PhaseType phaseType;
         phaseType = PhaseType();
         phaseType[UNDEFINED_BIT] = 0;
         phaseType[TRANSIENT_NOTDECISIONAL_BIT] = transient_notdecisional;
         phaseType[TARGET_BIT] = 0;
         phaseType[COMMIT_BIT] = commit;
-        init(durationArg, durationArg, durationArg, stateArg);
+        init(durationArg, stateArg, durationArg, durationArg, nextPhase);
     }
 
 
@@ -205,7 +203,7 @@ public:
      * @param[in] targetLaneSet If not null, specifies this MSPhaseDefinition is a target step
      * @see MSPhaseDefinition::PhaseType
      */
-    MSPhaseDefinition(SUMOTime durationArg, SUMOTime minDurationArg, SUMOTime maxDurationArg, const std::string& stateArg, bool transient_notdecisional, bool commit, LaneIdVector& targetLaneSetArg) throw() {
+    MSPhaseDefinition(SUMOTime durationArg, const std::string& stateArg, SUMOTime minDurationArg, SUMOTime maxDurationArg, int nextPhase, bool transient_notdecisional, bool commit, LaneIdVector& targetLaneSetArg) {
         if (targetLaneSetArg.size() == 0) {
             MsgHandler::getErrorInstance()->inform("MSPhaseDefinition::MSPhaseDefinition -> targetLaneSetArg cannot be empty for a target phase");
         }
@@ -216,7 +214,7 @@ public:
         phaseType[TRANSIENT_NOTDECISIONAL_BIT] = transient_notdecisional;
         phaseType[TARGET_BIT] = 1;
         phaseType[COMMIT_BIT] = commit;
-        init(durationArg, minDurationArg, maxDurationArg, stateArg, targetLaneSetArg);
+        init(durationArg, minDurationArg, maxDurationArg, stateArg, nextPhase, targetLaneSetArg);
     }
 
     /*
@@ -225,14 +223,14 @@ public:
      * @param[in] phaseType Indicates the type of the step
      * @see MSPhaseDefinition::PhaseType
      */
-    MSPhaseDefinition(SUMOTime durationArg, SUMOTime minDurationArg, SUMOTime maxDurationArg, const std::string& stateArg, bool transient_notdecisional, bool commit) throw() {
+    MSPhaseDefinition(SUMOTime durationArg, const std::string& stateArg, SUMOTime minDurationArg, SUMOTime maxDurationArg, int nextPhase, bool transient_notdecisional, bool commit) {
         //PhaseType phaseType;
         phaseType = PhaseType();
         phaseType[UNDEFINED_BIT] = 0;
         phaseType[TRANSIENT_NOTDECISIONAL_BIT] = transient_notdecisional;
         phaseType[TARGET_BIT] = 0;
         phaseType[COMMIT_BIT] = commit;
-        init(durationArg, minDurationArg, maxDurationArg, stateArg);
+        init(durationArg, stateArg, minDurationArg, maxDurationArg, nextPhase);
 
     }
 
@@ -248,10 +246,18 @@ public:
         return state;
     }
 
-    const LaneIdVector& getTargetLaneSet() const throw() {
+    void setState(const std::string& _state) {
+        state = _state;
+    }
+
+    const LaneIdVector& getTargetLaneSet() const {
         return targetLaneSet;
     }
 
+    int getNextPhase() const {
+        return nextPhase;
+    }
+
     /** @brief Returns whether this phase is a pure "green" phase
      *
      * "pure green" means in this case that at least one stream has green
@@ -293,35 +299,35 @@ public:
     /*
     * @return true if the phase type is undefined
     */
-    bool isUndefined() const throw() {
+    bool isUndefined() const {
         return phaseType[UNDEFINED_BIT];
     }
 
     /*
     * @return true if this is a target phase
     */
-    bool isTarget() const throw() {
+    bool isTarget() const {
         return phaseType[TARGET_BIT];
     }
 
     /*
     * @return true if this is a transient phase
     */
-    bool isTransient() const throw() {
+    bool isTransient() const {
         return phaseType[TRANSIENT_NOTDECISIONAL_BIT];
     }
 
     /*
     * @return true if this is a decisional phase
     */
-    bool isDecisional() const throw() {
+    bool isDecisional() const {
         return !phaseType[TRANSIENT_NOTDECISIONAL_BIT];
     }
 
     /*
     * @return true if this is a commit phase
     */
-    bool isCommit() const throw() {
+    bool isCommit() const {
         return phaseType[COMMIT_BIT];
     }
 
