@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSRailSignal.h
 /// @author  Melanie Weber
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 //#include <utility>
 //#include <vector>
@@ -55,11 +49,11 @@ public:
     /** @brief Constructor
      * @param[in] tlcontrol The tls control responsible for this tls
      * @param[in] id This tls' id
-     * @param[in] subid This tls' sub-id (program id)
+     * @param[in] programID This tls' sub-id (program id)
      * @param[in] parameters This tls' parameters
      */
     MSRailSignal(MSTLLogicControl& tlcontrol,
-                 const std::string& id, const std::string& subid,
+                 const std::string& id, const std::string& programID,
                  const std::map<std::string, std::string>& parameters);
 
 
@@ -134,13 +128,6 @@ public:
     * @see MSTrafficLightLogic::getPhase
     */
     const MSPhaseDefinition& getPhase(int givenstep) const;
-
-    /** @brief Returns the type of the logic as a string
-     * @return The type of the logic
-     */
-    const std::string getLogicType() const {
-        return "railSignal";
-    }
     /// @}
 
 
@@ -238,6 +225,8 @@ protected:
     /// @brief The current phase
     MSPhaseDefinition myCurrentPhase;
 
+    static int myNumWarnings;
+
 };
 
 
