@@ -1,39 +1,36 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    MSSOTLHiLevelTrafficLightLogic.cpp
 /// @author  Alessio Bonfietti
 /// @date    Jun 2013
-/// @version $Id: MSSOTLHiLevelTrafficLightLogic.cpp 22627 2017-01-18 12:56:36Z behrisch $
+/// @version $Id$
 ///
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2013-2017 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 #include "MSSOTLHiLevelTrafficLightLogic.h"
 
 MSSOTLHiLevelTrafficLightLogic::MSSOTLHiLevelTrafficLightLogic(MSTLLogicControl& tlcontrol,
-        const std::string& id, const std::string& subid, const Phases& phases,
+        const std::string& id, const std::string& programID, const TrafficLightType logicType, const Phases& phases,
         int step, SUMOTime delay,
         const std::map<std::string, std::string>& parameters) :
-    MSSOTLTrafficLightLogic(tlcontrol, id, subid, phases, step, delay,
+    MSSOTLTrafficLightLogic(tlcontrol, id, programID, logicType, phases, step, delay,
                             parameters) {
     // Setting default values
 
 }
 
 MSSOTLHiLevelTrafficLightLogic::MSSOTLHiLevelTrafficLightLogic(MSTLLogicControl& tlcontrol,
-        const std::string& id, const std::string& subid, const Phases& phases,
+        const std::string& id, const std::string& programID, const TrafficLightType logicType, const Phases& phases,
         int step, SUMOTime delay,
         const std::map<std::string, std::string>& parameters,
         MSSOTLSensors* sensors) :
-    MSSOTLTrafficLightLogic(tlcontrol, id, subid, phases, step, delay,
+    MSSOTLTrafficLightLogic(tlcontrol, id, programID, logicType, phases, step, delay,
                             parameters, sensors) {
     // Setting default values
 
@@ -49,7 +46,7 @@ void MSSOTLHiLevelTrafficLightLogic::addPolicy(MSSOTLPolicy* policy) {
     policies.push_back(policy);
 }
 
-void MSSOTLHiLevelTrafficLightLogic::init(NLDetectorBuilder& nb) throw(ProcessError) {
+void MSSOTLHiLevelTrafficLightLogic::init(NLDetectorBuilder& nb) {
     MSSOTLTrafficLightLogic::init(nb);
 }
 
