@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2010-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2010-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSSOTLPhaseTrafficLightLogic.cpp
 /// @author  Gianfilippo Slager
@@ -21,10 +19,10 @@
 
 MSSOTLPhaseTrafficLightLogic::MSSOTLPhaseTrafficLightLogic(
     MSTLLogicControl& tlcontrol, const std::string& id,
-    const std::string& subid, const Phases& phases, int step,
+    const std::string& programID, const Phases& phases, int step,
     SUMOTime delay,
-    const std::map<std::string, std::string>& parameters) throw() :
-    MSSOTLTrafficLightLogic(tlcontrol, id, subid, phases, step, delay,
+    const std::map<std::string, std::string>& parameters) :
+    MSSOTLTrafficLightLogic(tlcontrol, id, programID, TLTYPE_SOTL_PHASE, phases, step, delay,
                             parameters) {
     MsgHandler::getMessageInstance()->inform(
         "*** Intersection " + id
@@ -33,14 +31,14 @@ MSSOTLPhaseTrafficLightLogic::MSSOTLPhaseTrafficLightLogic(
 
 MSSOTLPhaseTrafficLightLogic::MSSOTLPhaseTrafficLightLogic(
     MSTLLogicControl& tlcontrol, const std::string& id,
-    const std::string& subid, const Phases& phases, int step,
+    const std::string& programID, const Phases& phases, int step,
     SUMOTime delay, const std::map<std::string, std::string>& parameters,
-    MSSOTLSensors* sensors) throw() :
-    MSSOTLTrafficLightLogic(tlcontrol, id, subid, phases, step, delay,
+    MSSOTLSensors* sensors) :
+    MSSOTLTrafficLightLogic(tlcontrol, id, programID, TLTYPE_SOTL_PHASE, phases, step, delay,
                             parameters, sensors) {
 }
 
-bool MSSOTLPhaseTrafficLightLogic::canRelease() throw() {
+bool MSSOTLPhaseTrafficLightLogic::canRelease() {
     if (getCurrentPhaseElapsed() >= getCurrentPhaseDef().minDuration) {
         return isThresholdPassed();
     }
