@@ -1,22 +1,19 @@
 /****************************************************************************/
-/// @file    MSSOTLPolicyStimulus.h
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
+/// @file    MSSOTLPolicy3DStimulus.h
 /// @author  Riccardo Belletti
 /// @date    Mar 2014
-/// @version $Id: MSSOTLPolicy3DStimulus.h 22628 2017-01-18 12:58:45Z behrisch $
+/// @version $Id$
 ///
 // The class the low-level policy stimulus
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2013-2017 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 
 #ifndef MSSOTLPOLICY3DSTIMULUS_H_
 #define MSSOTLPOLICY3DSTIMULUS_H_
@@ -24,17 +21,13 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 //#define SWARM_DEBUG
 #include <utils/common/SwarmDebug.h>
 #include <utils/common/MsgHandler.h>
 #include <sstream>
-#include <math.h>
+#include <cmath>
 #include "MSSOTLPolicy5DStimulus.h"
 
 /**
