@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2014-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2014-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSSOTLPolicy5DFamilyStimulus.cpp
 /// @author  Riccardo Belletti
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/common/StringTokenizer.h>
 #include "MSSOTLPolicy5DFamilyStimulus.h"
@@ -68,7 +62,7 @@ MSSOTLPolicy5DFamilyStimulus::MSSOTLPolicy5DFamilyStimulus(std::string keyPrefix
     params_names.push_back("_STIM_COX_EXP_DISPERSION_OUT");
 
 
-    int size_family = int(readParameter(keyPrefix + "_SIZE_FAMILY", 1));
+    int size_family = int(getDouble(keyPrefix + "_SIZE_FAMILY", 1));
     DBG(
 
         std::ostringstream str;
