@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2010-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2010-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSSOTLPolicyBasedTrafficLightLogic.h
 /// @author  Alessio Bonfietti
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 //#define SWARM_DEBUG
 #include <utils/common/SwarmDebug.h>
@@ -50,23 +44,25 @@ public:
      * @brief Constructor without sensors passed
      * @param[in] tlcontrol The tls control responsible for this tls
      * @param[in] id This traffic light id
-     * @param[in] subid This tls' sub-id (program id)
+     * @param[in] programID This tls' sub-id (program id)
+     * @param[in] logicType This tls' type (static, actuated etc.)
      * @param[in] phases Definitions of the phases
      * @param[in] step The initial phase index
      * @param[in] delay The time to wait before the first switch
      * @param[in] parameters Parameters defined for the tll
      */
     MSSOTLPolicyBasedTrafficLightLogic(MSTLLogicControl& tlcontrol,
-                                       const std::string& id, const std::string& subid,
+                                       const std::string& id, const std::string& programID, const TrafficLightType logicType,
                                        const Phases& phases, int step, SUMOTime delay,
                                        const std::map<std::string, std::string>& parameters,
-                                       MSSOTLPolicy* policy) throw();
+                                       MSSOTLPolicy* policy);
 
     /**
      * @brief Constructor with sensors passed
      * @param[in] tlcontrol The tls control responsible for this tls
      * @param[in] id This tls' id
-     * @param[in] subid This tls' sub-id (program id)
+     * @param[in] programID This tls' sub-id (program id)
+     * @param[in] logicType This tls' type (static, actuated etc.)
      * @param[in] phases Definitions of the phases
      * @param[in] step The initial phase index
      * @param[in] delay The time to wait before the first switch
@@ -74,10 +70,10 @@ public:
      * @param[in] sensors The already defined sensor logic
      */
     MSSOTLPolicyBasedTrafficLightLogic(MSTLLogicControl& tlcontrol,
-                                       const std::string& id, const std::string& subid,
+                                       const std::string& id, const std::string& programID, const TrafficLightType logicType,
                                        const Phases& phases, int step, SUMOTime delay,
                                        const std::map<std::string, std::string>& parameters,
-                                       MSSOTLPolicy* policy, MSSOTLSensors* sensors) throw();
+                                       MSSOTLPolicy* policy, MSSOTLSensors* sensors);
 
     ~MSSOTLPolicyBasedTrafficLightLogic();
 
@@ -100,7 +96,7 @@ protected:
     /*
      * @brief Contains the logic to decide the phase change
      */
-    bool canRelease() throw();
+    bool canRelease();
 
     /*
      * This member has to contain the switching logic for SOTL policies
