@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSSOTLPolicyDesirability.h
 /// @author  Riccardo Belletti
@@ -23,16 +21,12 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/common/SwarmDebug.h>
 #include <sstream>
 #include <utils/common/Parameterised.h>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 
 /**
  * \class MSSOTLPolicyDesirability
@@ -44,11 +38,6 @@ class MSSOTLPolicyDesirability: public Parameterised {
 private:
     std::string myKeyPrefix;
 
-protected:
-    double readParameter(std::string parName, double defValue) {
-        return TplConvert::_2doubleSec(getParameter(parName, "").c_str(), defValue);
-    }
-
 public:
 
     MSSOTLPolicyDesirability(std::string keyPrefix,
