@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSSOTLTrafficLightLogic.cpp
 /// @author  Gianfilippo Slager
@@ -35,14 +33,15 @@
 MSSOTLTrafficLightLogic::MSSOTLTrafficLightLogic(
     MSTLLogicControl& tlcontrol,
     const std::string& id,
-    const std::string& subid,
+    const std::string& programID,
+    const TrafficLightType logicType,
     const Phases& phases,
     int step,
     SUMOTime delay,
     const std::map<std::string, std::string>& parameters)
-    : MSPhasedTrafficLightLogic(tlcontrol, id, subid, phases, step, delay, parameters) {
-    this->mySensors = NULL;
-    this->myCountSensors = NULL;
+    : MSPhasedTrafficLightLogic(tlcontrol, id, programID, logicType, phases, step, delay, parameters) {
+    this->mySensors = nullptr;
+    this->myCountSensors = nullptr;
     sensorsSelfBuilt = true;
     checkPhases();
     setupCTS();
@@ -52,13 +51,14 @@ MSSOTLTrafficLightLogic::MSSOTLTrafficLightLogic(
 MSSOTLTrafficLightLogic::MSSOTLTrafficLightLogic(
     MSTLLogicControl& tlcontrol,
     const std::string& id,
-    const std::string& subid,
+    const std::string& programID,
+    const TrafficLightType logicType,
     const Phases& phases,
     int step,
     SUMOTime delay,
     const std::map<std::string, std::string>& parameters,
     MSSOTLSensors* sensors)
-    : MSPhasedTrafficLightLogic(tlcontrol, id, subid, phases, step, delay, parameters) {
+    : MSPhasedTrafficLightLogic(tlcontrol, id, programID, logicType, phases, step, delay, parameters) {
     this->mySensors = sensors;
     sensorsSelfBuilt = false;
     checkPhases();
@@ -119,7 +119,7 @@ MSSOTLTrafficLightLogic::setToATargetPhase() {
 
 
 void
-MSSOTLTrafficLightLogic::init(NLDetectorBuilder& nb) throw(ProcessError) {
+MSSOTLTrafficLightLogic::init(NLDetectorBuilder& nb) {
 
     MSTrafficLightLogic::init(nb);
 
