@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSSOTLTrafficLightLogic.h
 /// @author  Gianfilippo Slager
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/common/SwarmDebug.h>
 
@@ -37,7 +31,7 @@
 #include "MSPhasedTrafficLightLogic.h"
 #include "MSSOTLE2Sensors.h"
 #include <utils/common/RandHelper.h>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 
 
 // ===========================================================================
@@ -70,14 +64,15 @@ public:
      * @brief Constructor without sensors passed
      * @param[in] tlcontrol The tls control responsible for this tls
      * @param[in] id This traffic light id
-     * @param[in] subid This tls' sub-id (program id)
+     * @param[in] programID This tls' sub-id (program id)
+     * @param[in] logicType This tls' type (static, actuated etc.)
      * @param[in] phases Definitions of the phases
      * @param[in] step The initial phase index
      * @param[in] delay The time to wait before the first switch
      * @param[in] parameters Parameters defined for the tll
      */
     MSSOTLTrafficLightLogic(MSTLLogicControl& tlcontrol, const std::string& id,
-                            const std::string& subid, const Phases& phases, int step,
+                            const std::string& programID, const TrafficLightType logicType, const Phases& phases, int step,
                             SUMOTime delay,
                             const std::map<std::string, std::string>& parameters);
 
@@ -85,7 +80,8 @@ public:
      * @brief Constructor with sensors passed
      * @param[in] tlcontrol The tls control responsible for this tls
      * @param[in] id This tls' id
-     * @param[in] subid This tls' sub-id (program id)
+     * @param[in] programID This tls' sub-id (program id)
+     * @param[in] logicType This tls' type (static, actuated etc.)
      * @param[in] phases Definitions of the phases
      * @param[in] step The initial phase index
      * @param[in] delay The time to wait before the first switch
@@ -93,7 +89,7 @@ public:
      * @param[in] sensors The already defined sensor logic
      */
     MSSOTLTrafficLightLogic(MSTLLogicControl& tlcontrol, const std::string& id,
-                            const std::string& subid, const Phases& phases, int step,
+                            const std::string& programID, const TrafficLightType logicType, const Phases& phases, int step,
                             SUMOTime delay,
                             const std::map<std::string, std::string>& parameters,
                             MSSOTLSensors* sensors);
@@ -107,7 +103,7 @@ public:
      * @param[in] nb The detector builder
      * @exception ProcessError If something fails on initialisation
      */
-    void init(NLDetectorBuilder& nb) throw(ProcessError);
+    void init(NLDetectorBuilder& nb);
 
     /*
      * This member implements the base operations for all SOTL logics.
@@ -154,19 +150,19 @@ protected:
     bool isPushButtonPressed();
 
     int getThreshold() {
-        return TplConvert::_2int(getParameter("THRESHOLD", "10").c_str());
+        return StringUtils::toInt(getParameter("THRESHOLD", "10"));
     }
 
     double getSpeedThreshold() {
-        return TplConvert::_2double(getParameter("THRESHOLDSPEED", "2").c_str());
+        return StringUtils::toDouble(getParameter("THRESHOLDSPEED", "2"));
     }
 
     double getInputSensorsLength() {
-        return TplConvert::_2double(getParameter("INSENSORSLENGTH", "100").c_str());
+        return StringUtils::toDouble(getParameter("INSENSORSLENGTH", "100"));
     }
 
     double getOutputSensorsLength() {
-        return TplConvert::_2double(getParameter("OUTSENSORSLENGTH", "80").c_str());
+        return StringUtils::toDouble(getParameter("OUTSENSORSLENGTH", "80"));
     }
 
     /*
@@ -277,7 +273,7 @@ private:
      * 2-> queue length
      */
     int getMode() {
-        return TplConvert::_2int(getParameter("MODE", "0").c_str());
+        return StringUtils::toInt(getParameter("MODE", "0"));
     }
     /*
      * Decay threshold that should be used in case of penetration rate != 100%
@@ -285,11 +281,11 @@ private:
      * 1-> active
      */
     bool isDecayThresholdActivated() {
-        return TplConvert::_2bool(getParameter("DECAY_THRESHOLD", "0").c_str());
+        return StringUtils::toBool(getParameter("DECAY_THRESHOLD", "0"));
     }
 
     double getDecayConstant() {
-        return TplConvert::_2double(getParameter("DECAY_CONSTANT", "-0.001").c_str());
+        return StringUtils::toDouble(getParameter("DECAY_CONSTANT", "-0.001"));
     }
 
 };
