@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2010-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2010-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSSwarmTrafficLightLogic.cpp
 /// @author  Gianfilippo Slager
@@ -28,9 +26,9 @@
 #endif
 
 MSSwarmTrafficLightLogic::MSSwarmTrafficLightLogic(MSTLLogicControl& tlcontrol, const std::string& id,
-        const std::string& subid, const Phases& phases, int step, SUMOTime delay,
+        const std::string& programID, const Phases& phases, int step, SUMOTime delay,
         const std::map<std::string, std::string>& parameters) :
-    MSSOTLHiLevelTrafficLightLogic(tlcontrol, id, subid, phases, step, delay, parameters) {
+    MSSOTLHiLevelTrafficLightLogic(tlcontrol, id, programID, TLTYPE_SWARM_BASED, phases, step, delay, parameters) {
 
     std::string pols = getPoliciesParam();
     std::transform(pols.begin(), pols.end(), pols.begin(), ::tolower);
@@ -114,22 +112,22 @@ bool MSSwarmTrafficLightLogic::allowLine(MSLane* lane) {
     return true;
 }
 
-void MSSwarmTrafficLightLogic::init(NLDetectorBuilder& nb) throw(ProcessError) {
+void MSSwarmTrafficLightLogic::init(NLDetectorBuilder& nb) {
     MSSOTLHiLevelTrafficLightLogic::init(nb);
     //Setting the startup policy
     choosePolicy(0, 0, 0, 0);
     //Initializing the random number generator to a time-dependent seed
-    srand((int) time(NULL));
+    srand((int) time(nullptr));
     //Initializing pheromone maps according to input lanes
     //For each lane insert a pair into maps
-    MSLane* currentLane = NULL;
+    MSLane* currentLane = nullptr;
 
 //	Derivative
-    const int derivativeHistorySize = TplConvert::_2int(getParameter("PHERO_DERIVATIVE_HISTORY_SIZE", "3").c_str());
-    const int meanSpeedHistorySize = TplConvert::_2int(getParameter("PHERO_MEAN_SPEED_HISTORY_SIZE", "3").c_str());
-    m_derivativeAlpha = TplConvert::_2double(getParameter("PHERO_DERIVATIVE_ALPHA", "1").c_str());
+    const int derivativeHistorySize = StringUtils::toInt(getParameter("PHERO_DERIVATIVE_HISTORY_SIZE", "3"));
+    const int meanSpeedHistorySize = StringUtils::toInt(getParameter("PHERO_MEAN_SPEED_HISTORY_SIZE", "3"));
+    m_derivativeAlpha = StringUtils::toDouble(getParameter("PHERO_DERIVATIVE_ALPHA", "1"));
     m_losCounter = 0;
-    m_losMaxLimit = TplConvert::_2int(getParameter("LOSS_OF_SIGNAL_LIMIT", "10").c_str());
+    m_losMaxLimit = StringUtils::toInt(getParameter("LOSS_OF_SIGNAL_LIMIT", "10"));
 
     int index = 0;
     for (MSTrafficLightLogic::LaneVectorVector::const_iterator laneVector = myLanes.begin();
@@ -681,7 +679,7 @@ double MSSwarmTrafficLightLogic::calculatePhi(int factor) {
 
 double MSSwarmTrafficLightLogic::calculateEtaDiff() {
 
-    MSLane* currentLane = NULL;
+    MSLane* currentLane = nullptr;
     int count = 0, minIn = 0, minOut = 0, toSub, tmp;
     bool inInit = true, outInit = true;
     double eta, normalized, diff, phi, delta;
@@ -870,7 +868,7 @@ double MSSwarmTrafficLightLogic::calculateEtaDiff() {
 }
 
 double MSSwarmTrafficLightLogic::calculateEtaRatio() {
-    MSLane* currentLane = NULL;
+    MSLane* currentLane = nullptr;
     int count = 0, minIn = 0, minOut = 0, toSub, tmp;
     bool inInit = true, outInit = true;
     double eta, ratio, phi, normalized, delta;
@@ -1064,7 +1062,7 @@ double MSSwarmTrafficLightLogic::calculateEtaRatio() {
 
 void MSSwarmTrafficLightLogic::resetLaneCheck() {
 
-    MSLane* currentLane = NULL;
+    MSLane* currentLane = nullptr;
 
     // reset both the input and the output lanes.
     for (MSTrafficLightLogic::LaneVectorVector::const_iterator laneVector = myLanes.begin();
