@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSTriggeredRerouter.cpp
 /// @author  Daniel Krajzewicz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <algorithm>
@@ -38,7 +32,7 @@
 #include <utils/xml/SUMOXMLDefinitions.h>
 #include <utils/common/UtilExceptions.h>
 #include <utils/common/ToString.h>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include <utils/xml/SUMOSAXHandler.h>
 #include <utils/vehicle/DijkstraRouter.h>
 #include <utils/common/RandHelper.h>
@@ -50,16 +44,19 @@
 #include <microsim/MSEdge.h>
 #include <microsim/MSEventControl.h>
 #include <microsim/MSNet.h>
+#include <microsim/MSVehicleControl.h>
 #include <microsim/MSGlobals.h>
 #include <microsim/MSParkingArea.h>
+#include <microsim/MSTransportable.h>
 #include <microsim/devices/MSDevice_Routing.h>
+#include <microsim/devices/MSRoutingEngine.h>
 #include "MSTriggeredRerouter.h"
 
 #include <mesosim/MELoop.h>
 #include <mesosim/MESegment.h>
 
 //#define DEBUG_REROUTER
-//#define DEBUG_PARKING
+#define DEBUG_PARKING
 #define DEBUGCOND (veh.isSelected())
 
 // ===========================================================================
@@ -74,7 +71,8 @@ MSEdge MSTriggeredRerouter::mySpecialDest_terminateRoute("MSTriggeredRerouter_te
 MSTriggeredRerouter::MSTriggeredRerouter(const std::string& id,
         const MSEdgeVector& edges,
         double prob, const std::string& file, bool off,
-        SUMOTime timeThreshold) :
+        SUMOTime timeThreshold,
+        const std::string& vTypes) :
     MSTrigger(id),
     MSMoveReminder(id),
     SUMOSAXHandler(file),
@@ -98,6 +96,8 @@ MSTriggeredRerouter::MSTriggeredRerouter(const std::string& id,
         setUserMode(true);
         setUserUsageProbability(0);
     }
+    const std::vector<std::string> vt = StringTokenizer(vTypes).getVector();
+    myVehicleTypes.insert(vt.begin(), vt.end());
 }
 
 
@@ -110,8 +110,8 @@ MSTriggeredRerouter::myStartElement(int element,
                                     const SUMOSAXAttributes& attrs) {
     if (element == SUMO_TAG_INTERVAL) {
         bool ok = true;
-        myCurrentIntervalBegin = attrs.getOptSUMOTimeReporting(SUMO_ATTR_BEGIN, 0, ok, -1);
-        myCurrentIntervalEnd = attrs.getOptSUMOTimeReporting(SUMO_ATTR_END, 0, ok, -1);
+        myCurrentIntervalBegin = attrs.getOptSUMOTimeReporting(SUMO_ATTR_BEGIN, nullptr, ok, -1);
+        myCurrentIntervalEnd = attrs.getOptSUMOTimeReporting(SUMO_ATTR_END, nullptr, ok, -1);
     }
     if (element == SUMO_TAG_DEST_PROB_REROUTE) {
         // by giving probabilities of new destinations
@@ -121,7 +121,7 @@ MSTriggeredRerouter::myStartElement(int element,
             throw ProcessError("MSTriggeredRerouter " + getID() + ": No destination edge id given.");
         }
         MSEdge* to = MSEdge::dictionary(dest);
-        if (to == 0) {
+        if (to == nullptr) {
             if (dest == "keepDestination") {
                 to = &mySpecialDest_keepDestination;
             } else if (dest == "terminateRoute") {
@@ -148,7 +148,7 @@ MSTriggeredRerouter::myStartElement(int element,
         // by closing
         std::string closed_id = attrs.getStringSecure(SUMO_ATTR_ID, "");
         MSEdge* closed = MSEdge::dictionary(closed_id);
-        if (closed == 0) {
+        if (closed == nullptr) {
             throw ProcessError("MSTriggeredRerouter " + getID() + ": Edge '" + closed_id + "' to close is not known.");
         }
         myCurrentClosed.push_back(closed);
@@ -162,7 +162,7 @@ MSTriggeredRerouter::myStartElement(int element,
         // by closing lane
         std::string closed_id = attrs.getStringSecure(SUMO_ATTR_ID, "");
         MSLane* closed = MSLane::dictionary(closed_id);
-        if (closed == 0) {
+        if (closed == nullptr) {
             throw ProcessError("MSTriggeredRerouter " + getID() + ": Lane '" + closed_id + "' to close is not known.");
         }
         myCurrentClosedLanes.push_back(closed);
@@ -186,7 +186,7 @@ MSTriggeredRerouter::myStartElement(int element,
             throw ProcessError("MSTriggeredRerouter " + getID() + ": No route id given.");
         }
         const MSRoute* route = MSRoute::dictionary(routeStr);
-        if (route == 0) {
+        if (route == nullptr) {
             throw ProcessError("MSTriggeredRerouter " + getID() + ": Route '" + routeStr + "' does not exist.");
         }
 
@@ -211,7 +211,7 @@ MSTriggeredRerouter::myStartElement(int element,
             throw ProcessError("MSTriggeredRerouter " + getID() + ": No parking area id given.");
         }
         MSParkingArea* pa = static_cast<MSParkingArea*>(MSNet::getInstance()->getStoppingPlace(parkingarea, SUMO_TAG_PARKING_AREA));
-        if (pa == 0) {
+        if (pa == nullptr) {
             throw ProcessError("MSTriggeredRerouter " + getID() + ": Parking area '" + parkingarea + "' is not known.");
         }
         // get the probability to reroute
@@ -223,8 +223,9 @@ MSTriggeredRerouter::myStartElement(int element,
         if (prob < 0) {
             throw ProcessError("MSTriggeredRerouter " + getID() + ": Attribute 'probability' for destination '" + parkingarea + "' is negative (must not).");
         }
+        const bool visible = attrs.getOpt<bool>(SUMO_ATTR_VISIBLE, getID().c_str(), ok, false);
         // add
-        myCurrentParkProb.add(pa, prob);
+        myCurrentParkProb.add(std::make_pair(pa, visible), prob);
         //MSEdge* to = &(pa->getLane().getEdge());
         //myCurrentEdgeProb.add(prob, to);
     }
@@ -257,7 +258,7 @@ MSTriggeredRerouter::myEndElement(int element) {
         myCurrentRouteProb.clear();
         myCurrentParkProb.clear();
         myIntervals.push_back(ri);
-        myIntervals.back().id = (long)&myIntervals.back();
+        myIntervals.back().id = (long long)&myIntervals.back();
         if (!(ri.closed.empty() && ri.closedLanes.empty()) && ri.permissions != SVCAll) {
             MSNet::getInstance()->getBeginOfTimestepEvents()->addEvent(
                 new WrappingCommand<MSTriggeredRerouter>(this, &MSTriggeredRerouter::setPermissions), ri.begin);
@@ -324,7 +325,7 @@ MSTriggeredRerouter::getCurrentReroute(SUMOTime time, SUMOVehicle& veh) const {
             }
         }
     }
-    return 0;
+    return nullptr;
 }
 
 
@@ -337,7 +338,7 @@ MSTriggeredRerouter::getCurrentReroute(SUMOTime time) const {
             }
         }
     }
-    return 0;
+    return nullptr;
 }
 
 
@@ -357,10 +358,13 @@ MSTriggeredRerouter::notifyLeave(SUMOVehicle& /*veh*/, double /*lastPos*/,
 
 bool
 MSTriggeredRerouter::notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification /*reason*/, const MSLane* /* enteredLane */) {
+    if (!vehicleApplies(veh)) {
+        return false;
+    }
     // check whether the vehicle shall be rerouted
     const SUMOTime time = MSNet::getInstance()->getCurrentTimeStep();
     const MSTriggeredRerouter::RerouteInterval* rerouteDef = getCurrentReroute(time, veh);
-    if (rerouteDef == 0) {
+    if (rerouteDef == nullptr) {
         return true; // an active interval could appear later
     }
     double prob = myAmInUserMode ? myUserProbability : myProbability;
@@ -371,7 +375,7 @@ MSTriggeredRerouter::notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification
         return true; // waiting time may be reached later
     }
     // if we have a closingLaneReroute, only vehicles with a rerouting device can profit from rerouting (otherwise, edge weights will not reflect local jamming)
-    const bool hasReroutingDevice = veh.getDevice(typeid(MSDevice_Routing)) != 0;
+    const bool hasReroutingDevice = veh.getDevice(typeid(MSDevice_Routing)) != nullptr;
     if (rerouteDef->closedLanes.size() > 0 && !hasReroutingDevice) {
         return true; // an active interval could appear later
     }
@@ -387,11 +391,11 @@ MSTriggeredRerouter::notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification
     if (rerouteDef->parkProbs.getOverallProb() > 0) {
         bool newDestination = false;
         MSParkingArea* newParkingArea = rerouteParkingArea(rerouteDef, veh, newDestination);
-        if (newParkingArea != 0) {
+        if (newParkingArea != nullptr) {
             const MSEdge* newEdge = &(newParkingArea->getLane().getEdge());
 
             SUMOAbstractRouter<MSEdge, SUMOVehicle>& router = hasReroutingDevice
-                    ? MSDevice_Routing::getRouterTT(rerouteDef->closed)
+                    ? MSRoutingEngine::getRouterTT(rerouteDef->closed)
                     : MSNet::getInstance()->getRouterTT(rerouteDef->closed);
 
             // Compute the route from the current edge to the parking area edge
@@ -402,6 +406,11 @@ MSTriggeredRerouter::notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification
             ConstMSEdgeVector edgesFromPark;
             if (!newDestination) {
                 router.compute(newEdge, lastEdge, &veh, MSNet::getInstance()->getCurrentTimeStep(), edgesFromPark);
+            } else {
+                // adapt plans of any riders
+                for (MSTransportable* p : veh.getPersons()) {
+                    p->rerouteParkingArea(veh.getNextParkingArea(), newParkingArea);
+                }
             }
 
             // we have a new destination, let's replace the vehicle route
@@ -410,16 +419,28 @@ MSTriggeredRerouter::notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification
                 edges.insert(edges.end(), edgesFromPark.begin() + 1, edgesFromPark.end());
             }
 
-            veh.replaceRouteEdges(edges, false, false, false);
+            if (newDestination) {
+                SUMOVehicleParameter* newParameter = new SUMOVehicleParameter();
+                *newParameter = veh.getParameter();
+                newParameter->arrivalPosProcedure = ARRIVAL_POS_GIVEN;
+                newParameter->arrivalPos = newParkingArea->getEndLanePosition();
+                veh.replaceParameter(newParameter);
+            }
+            const double routeCost = router.recomputeCosts(edges, &veh, MSNet::getInstance()->getCurrentTimeStep());
+            ConstMSEdgeVector prevEdges(veh.getCurrentRouteEdge(), veh.getRoute().end());
+            const double previousCost = router.recomputeCosts(prevEdges, &veh, MSNet::getInstance()->getCurrentTimeStep());
+            const double savings = previousCost - routeCost;
+            //if (getID() == "ego") std::cout << SIMTIME << " pCost=" << previousCost << " cost=" << routeCost
+            //        << " prevEdges=" << toString(prevEdges)
+            //        << " newEdges=" << toString(edges)
+            //        << "\n";
+            veh.replaceRouteEdges(edges, routeCost, savings, getID(), false, false, false);
             std::string errorMsg;
             if (!veh.replaceParkingArea(newParkingArea, errorMsg)) {
                 WRITE_WARNING("Vehicle '" + veh.getID() + "' at rerouter '" + getID()
                               + "' could not reroute to new parkingArea '" + newParkingArea->getID()
                               + "' reason=" + errorMsg + ", time=" + time2string(MSNet::getInstance()->getCurrentTimeStep()) + ".");
             }
-            if (newDestination) {
-                veh.setArrivalPos(newParkingArea->getEndLanePosition());
-            }
         }
         return false;
     }
@@ -427,13 +448,13 @@ MSTriggeredRerouter::notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification
     // get rerouting params
     const MSRoute* newRoute = rerouteDef->routeProbs.getOverallProb() > 0 ? rerouteDef->routeProbs.get() : 0;
     // we will use the route if given rather than calling our own dijsktra...
-    if (newRoute != 0) {
+    if (newRoute != nullptr) {
 #ifdef DEBUG_REROUTER
         if (DEBUGCOND) {
             std::cout << "    replacedRoute from routeDist " << newRoute->getID() << "\n";
         }
 #endif
-        veh.replaceRoute(newRoute);
+        veh.replaceRoute(newRoute, getID());
         return false; // XXX another interval could appear later but we would have to track whether the currenty interval was already used
     }
     const MSEdge* newEdge = lastEdge;
@@ -457,7 +478,7 @@ MSTriggeredRerouter::notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification
             } else {
                 newEdge = lastEdge;
             }
-        } else if (newEdge == 0) {
+        } else if (newEdge == nullptr) {
 #ifdef DEBUG_REROUTER
             if (DEBUGCOND) {
                 std::cout << "   could not find new edge!\n";
@@ -471,11 +492,12 @@ MSTriggeredRerouter::notifyEnter(SUMOVehicle& veh, MSMoveReminder::Notification
     if (rerouteDef->closed.size() == 0 || destUnreachable || veh.getRoute().containsAnyOf(rerouteDef->closed)) {
         ConstMSEdgeVector edges;
         SUMOAbstractRouter<MSEdge, SUMOVehicle>& router = hasReroutingDevice
-                ? MSDevice_Routing::getRouterTT(rerouteDef->closed)
+                ? MSRoutingEngine::getRouterTT(rerouteDef->closed)
                 : MSNet::getInstance()->getRouterTT(rerouteDef->closed);
         router.compute(
             veh.getEdge(), newEdge, &veh, MSNet::getInstance()->getCurrentTimeStep(), edges);
-        const bool useNewRoute = veh.replaceRouteEdges(edges);
+        const double routeCost = router.recomputeCosts(edges, &veh, MSNet::getInstance()->getCurrentTimeStep());
+        const bool useNewRoute = veh.replaceRouteEdges(edges, routeCost, 0, getID());
 #ifdef DEBUG_REROUTER
         if (DEBUGCOND) std::cout << "   rerouting:  newEdge=" << newEdge->getID() << " useNewRoute=" << useNewRoute << " newArrivalPos=" << newArrivalPos << " numClosed=" << rerouteDef->closed.size()
                                      << " destUnreachable=" << destUnreachable << " containsClosed=" << veh.getRoute().containsAnyOf(rerouteDef->closed) << "\n";
@@ -524,7 +546,7 @@ MSTriggeredRerouter::getWeight(SUMOVehicle& veh, const std::string param, const
     // get custom vehicle parameter
     if (veh.getParameter().knowsParameter(param)) {
         try {
-            return TplConvert::_2double(veh.getParameter().getParameter(param, "-1").c_str());
+            return StringUtils::toDouble(veh.getParameter().getParameter(param, "-1"));
         } catch (...) {
             WRITE_WARNING("Invalid value '" + veh.getParameter().getParameter(param, "-1") + "' for vehicle parameter '" + param + "'");
         }
@@ -532,7 +554,7 @@ MSTriggeredRerouter::getWeight(SUMOVehicle& veh, const std::string param, const
         // get custom vType parameter
         if (veh.getVehicleType().getParameter().knowsParameter(param)) {
             try {
-                return TplConvert::_2double(veh.getVehicleType().getParameter().getParameter(param, "-1").c_str());
+                return StringUtils::toDouble(veh.getVehicleType().getParameter().getParameter(param, "-1"));
             } catch (...) {
                 WRITE_WARNING("Invalid value '" + veh.getVehicleType().getParameter().getParameter(param, "-1") + "' for vType parameter '" + param + "'");
             }
@@ -546,18 +568,37 @@ MSTriggeredRerouter::getWeight(SUMOVehicle& veh, const std::string param, const
 MSParkingArea*
 MSTriggeredRerouter::rerouteParkingArea(const MSTriggeredRerouter::RerouteInterval* rerouteDef,
                                         SUMOVehicle& veh, bool& newDestination) const {
+    // reroute destination from initial parking area to the near parking area
+    // if the next stop is a parking area, it is included in the current
+    // alternative set and if it can be observed to be full
 
-    MSParkingArea* nearParkArea = 0;
+    MSParkingArea* nearParkArea = nullptr;
+    std::vector<ParkingAreaVisible> parks = rerouteDef->parkProbs.getVals();
 
     // get vehicle params
     MSParkingArea* destParkArea = veh.getNextParkingArea();
     const MSRoute& route = veh.getRoute();
 
-    // I reroute destination from initial parking area to the near parking area
-    // if the next stop is a parking area and if it is full
-    if (destParkArea != 0 &&
-            destParkArea->getOccupancy() == destParkArea->getCapacity()) {
+    if (destParkArea == nullptr) {
+        // not driving towards a parkingArea
+        return nullptr;
+    }
 
+    bool destVisible = false;
+    for (auto paVis : parks) {
+        if (paVis.first == destParkArea
+                && (paVis.second
+                    // if the vehicle is on the destParkArea edge it is always visible
+                    || &(destParkArea->getLane().getEdge()) == veh.getEdge())) {
+            destVisible = true;
+            break;
+        }
+    }
+    if (!destVisible) {
+        // cannot determine destination occupancy
+        return nullptr;
+    }
+    if (destParkArea->getOccupancy() == destParkArea->getCapacity()) {
         // if the current route ends at the parking area, the new route will
         // also and at the new area
         newDestination = (&destParkArea->getLane().getEdge() == route.getLastEdge()
@@ -568,6 +609,7 @@ MSTriggeredRerouter::rerouteParkingArea(const MSTriggeredRerouter::RerouteInterv
         if (DEBUGCOND) {
             std::cout << SIMTIME << " veh=" << veh.getID()
                       << " rerouteParkingArea dest=" << destParkArea->getID()
+                      << " onDestEdge=" << (&(destParkArea->getLane().getEdge()) == veh.getEdge())
                       << " newDest=" << newDestination
                       << "\n";
         }
@@ -619,13 +661,17 @@ MSTriggeredRerouter::rerouteParkingArea(const MSTriggeredRerouter::RerouteInterv
 
         SUMOAbstractRouter<MSEdge, SUMOVehicle>& router = MSNet::getInstance()->getRouterTT(rerouteDef->closed);
 
-        std::vector<MSParkingArea*> parks = rerouteDef->parkProbs.getVals();
         std::vector<double> probs = rerouteDef->parkProbs.getProbs();
 
+        const double brakeGap = veh.getBrakeGap();
+
         for (int i = 0; i < (int)parks.size(); ++i) {
-            MSParkingArea* pa = parks[i];
+            MSParkingArea* pa = parks[i].first;
             const double prob = probs[i];
-            if (pa->getOccupancy() < pa->getCapacity()) {
+            // alternative occupancy is randomized (but never full) if invisible
+            // current destination must be visible at this point
+            int paOccupancy = parks[i].second || pa == destParkArea ? pa->getOccupancy() : RandHelper::rand(pa->getCapacity());
+            if (paOccupancy < pa->getCapacity()) {
 
                 // a map stores the parking values
                 ParkingParamMap_t parkValues;
@@ -656,7 +702,7 @@ MSTriggeredRerouter::rerouteParkingArea(const MSTriggeredRerouter::RerouteInterv
                         }
 
                         parkValues["capacity"] = (double)(pa->getCapacity());
-                        parkValues["absfreespace"] = (double)(pa->getCapacity() - pa->getOccupancy());
+                        parkValues["absfreespace"] = (double)(pa->getCapacity() - paOccupancy);
                         parkValues["relfreespace"] = parkValues["absfreespace"] / parkValues["capacity"];
 
                         if (parkValues["capacity"] > maxValues["capacity"]) {
@@ -671,11 +717,24 @@ MSTriggeredRerouter::rerouteParkingArea(const MSTriggeredRerouter::RerouteInterv
                             maxValues["relfreespace"] = parkValues["relfreespace"];
                         }
 
-                        MSRoute routeToPark(route.getID() + "!topark#1", edgesToPark, false, &c == &RGBColor::DEFAULT_COLOR ? 0 : new RGBColor(c), route.getStops());
+                        MSRoute routeToPark(route.getID() + "!topark#1", edgesToPark, false, &c == &RGBColor::DEFAULT_COLOR ? nullptr : new RGBColor(c), route.getStops());
 
                         // The distance from the current edge to the new parking area
                         parkValues["distanceto"] = routeToPark.getDistanceBetween(veh.getPositionOnLane(), pa->getBeginLanePosition(),
-                                                   routeToPark.begin(), routeToPark.end(), includeInternalLengths);
+                                                   routeToPark.begin(), routeToPark.end() - 1, includeInternalLengths);
+
+                        //std::cout << SIMTIME << " veh=" << veh.getID() << " candidate=" << pa->getID()
+                        //    << " distanceTo=" << parkValues["distanceto"]
+                        //    << " brakeGap=" << brakeGap
+                        //    << " routeToPark=" << toString(edgesToPark)
+                        //    << " fromPos=" << veh.getPositionOnLane()
+                        //    << " tPos=" << pa->getBeginLanePosition()
+                        //    << "\n";
+                        if (parkValues["distanceto"] < brakeGap) {
+                            //std::cout << "   removed: pa too close\n";
+                            // to close to stop for this parkingArea
+                            continue;
+                        }
 
                         // The time to reach the new parking area
                         parkValues["timeto"] = router.recomputeCosts(edgesToPark, &veh, MSNet::getInstance()->getCurrentTimeStep());
@@ -693,10 +752,10 @@ MSTriggeredRerouter::rerouteParkingArea(const MSTriggeredRerouter::RerouteInterv
                             parkValues["timefrom"] = 0;
                         } else {
                             MSRoute routeFromPark(route.getID() + "!frompark#1", edgesFromPark, false,
-                                                  &c == &RGBColor::DEFAULT_COLOR ? 0 : new RGBColor(c), route.getStops());
+                                                  &c == &RGBColor::DEFAULT_COLOR ? nullptr : new RGBColor(c), route.getStops());
                             // The distance from the new parking area to the end of the route
                             parkValues["distancefrom"] = routeFromPark.getDistanceBetween(pa->getBeginLanePosition(), routeFromPark.getLastEdge()->getLength(),
-                                                         routeFromPark.begin(), routeFromPark.end(), includeInternalLengths);
+                                                         routeFromPark.begin(), routeFromPark.end() - 1, includeInternalLengths);
                             // The time to reach this area
                             parkValues["timefrom"] = router.recomputeCosts(edgesFromPark, &veh, MSNet::getInstance()->getCurrentTimeStep());
                         }
@@ -757,7 +816,7 @@ MSTriggeredRerouter::rerouteParkingArea(const MSTriggeredRerouter::RerouteInterv
             }
 
             // get the parking area with minimum cost
-            if (nearParkArea == 0 || parkingCost < minParkingCost) {
+            if (nearParkArea == nullptr || parkingCost < minParkingCost) {
                 minParkingCost = parkingCost;
                 nearParkArea = it->first;
             }
@@ -779,5 +838,20 @@ MSTriggeredRerouter::rerouteParkingArea(const MSTriggeredRerouter::RerouteInterv
     return nearParkArea;
 }
 
+
+bool
+MSTriggeredRerouter::vehicleApplies(const SUMOVehicle& veh) const {
+    if (myVehicleTypes.empty() || myVehicleTypes.count(veh.getVehicleType().getID()) > 0) {
+        return true;
+    } else {
+        std::set<std::string> vTypeDists = MSNet::getInstance()->getVehicleControl().getVTypeDistributionMembership(veh.getVehicleType().getID());
+        for (auto vTypeDist : vTypeDists) {
+            if (myVehicleTypes.count(vTypeDist) > 0) {
+                return true;
+            }
+        }
+        return false;
+    }
+}
 /****************************************************************************/
 
