@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MSTriggeredRerouter.h
 /// @author  Daniel Krajzewicz
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <vector>
@@ -48,6 +42,7 @@ class MSNet;
 class MSLane;
 class MSRoute;
 class SUMOVehicle;
+class MSParkingArea;
 
 
 // ===========================================================================
@@ -81,12 +76,14 @@ public:
     MSTriggeredRerouter(const std::string& id,
                         const MSEdgeVector& edges,
                         double prob, const std::string& file, bool off,
-                        SUMOTime timeThreshold);
+                        SUMOTime timeThreshold,
+                        const std::string& vTypes);
 
 
     /** @brief Destructor */
     virtual ~MSTriggeredRerouter();
 
+    typedef std::pair<MSParkingArea*, bool> ParkingAreaVisible;
 
     /**
      * @struct RerouteInterval
@@ -94,7 +91,7 @@ public:
      */
     struct RerouteInterval {
         /// unique ID for this interval
-        long id;
+        long long id;
         /// The begin time these definitions are valid
         SUMOTime begin;
         /// The end time these definitions are valid
@@ -112,7 +109,7 @@ public:
         /// The permissions to use
         SVCPermissions permissions;
         /// The distributions of new parking areas to use as destinations
-        RandomDistributor<MSParkingArea*> parkProbs;
+        RandomDistributor<ParkingAreaVisible> parkProbs;
     };
 
     /** @brief Tries to reroute the vehicle
@@ -183,6 +180,7 @@ public:
     MSParkingArea* rerouteParkingArea(const MSTriggeredRerouter::RerouteInterval* rerouteDef,
                                       SUMOVehicle& veh, bool& newDestination) const;
 
+
 protected:
     /// @name inherited from GenericSAXHandler
     //@{
@@ -207,6 +205,14 @@ protected:
     virtual void myEndElement(int element);
     //@}
 
+    /** @brief Checks whether the detector measures vehicles of the given type.
+    *
+    * @param[in] veh the vehicle of which the type is checked.
+    * @return whether it should be measured
+    */
+    bool vehicleApplies(const SUMOVehicle& veh) const;
+
+
 protected:
     /// List of rerouting definition intervals
     std::vector<RerouteInterval> myIntervals;
@@ -220,6 +226,9 @@ protected:
     // @brief waiting time threshold for activation
     SUMOTime myTimeThreshold;
 
+    /// @brief The vehicle types to look for (empty means all)
+    std::set<std::string> myVehicleTypes;
+
     /// @name members used during loading
     //@{
 
@@ -232,7 +241,7 @@ protected:
     /// List of permissions for closed edges
     SVCPermissions myCurrentPermissions;
     /// new destinations with probabilities
-    RandomDistributor<MSParkingArea*> myCurrentParkProb;
+    RandomDistributor<ParkingAreaVisible> myCurrentParkProb;
     /// new destinations with probabilities
     RandomDistributor<MSEdge*> myCurrentEdgeProb;
     /// new routes with probabilities
