@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2012-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBAlgorithms.cpp
 /// @author  Daniel Krajzewicz
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <sstream>
 #include <iostream>
@@ -34,7 +28,10 @@
 #include <algorithm>
 #include <utils/common/MsgHandler.h>
 #include <utils/common/ToString.h>
+#include <utils/options/OptionsCont.h>
 #include "NBEdge.h"
+#include "NBOwnTLDef.h"
+#include "NBTrafficLightLogicCont.h"
 #include "NBNodeCont.h"
 #include "NBTypeCont.h"
 #include "NBNode.h"
@@ -60,7 +57,7 @@ NBTurningDirectionsComputer::computeTurnDirectionsForNode(NBNode* node, bool war
     const std::vector<NBEdge*>& outgoing = node->getOutgoingEdges();
     // reset turning directions since this may be called multiple times
     for (std::vector<NBEdge*>::const_iterator k = incoming.begin(); k != incoming.end(); ++k) {
-        (*k)->setTurningDestination(0);
+        (*k)->setTurningDestination(nullptr);
     }
     std::vector<Combination> combinations;
     for (std::vector<NBEdge*>::const_iterator j = outgoing.begin(); j != outgoing.end(); ++j) {
@@ -153,7 +150,8 @@ NBNodesEdgesSorter::swapWhenReversed(const NBNode* const n,
 // NBNodeTypeComputer
 // ---------------------------------------------------------------------------
 void
-NBNodeTypeComputer::computeNodeTypes(NBNodeCont& nc) {
+NBNodeTypeComputer::computeNodeTypes(NBNodeCont& nc, NBTrafficLightLogicCont& tlc) {
+    validateRailCrossings(nc, tlc);
     for (std::map<std::string, NBNode*>::const_iterator i = nc.begin(); i != nc.end(); ++i) {
         NBNode* n = (*i).second;
         // the type may already be set from the data
@@ -210,52 +208,63 @@ NBNodeTypeComputer::computeNodeTypes(NBNodeCont& nc) {
 
 
 void
-NBNodeTypeComputer::computeSingleNodeType(NBNode* node) {
-    // the type may already be set from the data
-    if (node->myType != NODETYPE_UNKNOWN && node->myType != NODETYPE_DEAD_END) {
-    }
-    // check whether the node is a waterway node. Set to unregulated by default
-    bool waterway = true;
-    for (EdgeVector::const_iterator i = node->getEdges().begin(); i != node->getEdges().end(); ++i) {
-        if (!isWaterway((*i)->getPermissions())) {
-            waterway = false;
-            break;
+NBNodeTypeComputer::validateRailCrossings(NBNodeCont& nc, NBTrafficLightLogicCont& tlc) {
+    for (std::map<std::string, NBNode*>::const_iterator i = nc.begin(); i != nc.end(); ++i) {
+        NBNode* n = (*i).second;
+        if (n->myType == NODETYPE_RAIL_CROSSING) {
+            // check if it really is a rail crossing
+            int numRailway = 0;
+            int numNonRailway = 0;
+            int numNonRailwayNonPed = 0;
+            for (NBEdge* e : n->getIncomingEdges()) {
+                if ((e->getPermissions() & ~SVC_RAIL_CLASSES) != 0) {
+                    numNonRailway++;
+                    if (e->getPermissions() != SVC_PEDESTRIAN) {
+                        numNonRailwayNonPed++;
+                    }
+                } else if ((e->getPermissions() & SVC_RAIL_CLASSES) != 0) {
+                    numRailway++;
+                }
+            }
+            for (NBEdge* e : n->getOutgoingEdges()) {
+                if (e->getPermissions() == SVC_PEDESTRIAN) {
+                    numNonRailway++;
+                }
+            }
+            if (numNonRailway == 0 || numRailway == 0) {
+                // not a crossing (maybe unregulated or rail_signal)
+                n->myType = NODETYPE_PRIORITY;
+            } else if (numNonRailwayNonPed > 2) {
+                // does not look like a rail crossing (roads in conflict). maybe a traffic light?
+                WRITE_WARNING("Converting invalid rail_crossing to traffic_light at junction '" + n->getID() + "'");
+                TrafficLightType type = SUMOXMLDefinitions::TrafficLightTypes.get(OptionsCont::getOptions().getString("tls.default-type"));
+                NBTrafficLightDefinition* tlDef = new NBOwnTLDef(n->getID(), n, 0, type);
+                n->myType = NODETYPE_TRAFFIC_LIGHT;
+                if (!tlc.insert(tlDef)) {
+                    // actually, nothing should fail here
+                    n->removeTrafficLight(tlDef);
+                    n->myType = NODETYPE_PRIORITY;
+                    delete tlDef;
+                    WRITE_WARNING("Could not allocate tls '" + n->getID() + "'.");
+                }
+            }
         }
     }
-    if (waterway && (node->myType == NODETYPE_UNKNOWN || node->myType == NODETYPE_DEAD_END)) {
-        node->myType = NODETYPE_NOJUNCTION;
-    }
+}
 
-    // check whether the junction is not a real junction
-    if (node->myIncomingEdges.size() == 1) {
-        node->myType = NODETYPE_PRIORITY;
-    }
-    // @todo "isSimpleContinuation" should be revalidated
-    if (node->isSimpleContinuation()) {
-        node->myType = NODETYPE_PRIORITY;
-    }
-    // determine the type
-    SumoXMLNodeType type = NODETYPE_RIGHT_BEFORE_LEFT;
-    for (EdgeVector::const_iterator i = node->myIncomingEdges.begin(); i != node->myIncomingEdges.end(); i++) {
-        for (EdgeVector::const_iterator j = i + 1; j != node->myIncomingEdges.end(); j++) {
-            // @todo "getOppositeIncoming" should probably be refactored into something the edge knows
-            if (node->getOppositeIncoming(*j) == *i && node->myIncomingEdges.size() > 2) {
-                continue;
-            }
-            // @todo check against a legal document
-            // @todo figure out when NODETYPE_PRIORITY_STOP is appropriate
-            const double s1 = (*i)->getSpeed() * (double) 3.6;
-            const double s2 = (*j)->getSpeed() * (double) 3.6;
-            const int p1 = (*i)->getPriority();
-            const int p2 = (*j)->getPriority();
-            if (fabs(s1 - s2) > (double) 9.5 || MAX2(s1, s2) >= (double) 49. || p1 != p2) {
-                type = NODETYPE_PRIORITY;
-                break;
-            }
+
+bool
+NBNodeTypeComputer::isRailwayNode(NBNode* n) {
+    int numRailway = 0;
+    int numNonRailway = 0;
+    for (NBEdge* e : n->getIncomingEdges()) {
+        if ((e->getPermissions() & ~SVC_RAIL_CLASSES) != 0) {
+            numNonRailway++;
+        } else if ((e->getPermissions() & SVC_RAIL_CLASSES) != 0) {
+            numRailway++;
         }
     }
-    // save type
-    node->myType = type;
+    return numRailway > 0 && numNonRailway == 0;
 }
 
 // ---------------------------------------------------------------------------
@@ -275,13 +284,20 @@ NBEdgePriorityComputer::computeEdgePrioritiesSingleNode(NBNode* node) {
     for (EdgeVector::iterator j = node->myAllEdges.begin(); j != node->myAllEdges.end(); ++j) {
         (*j)->setJunctionPriority(node, NBEdge::MINOR_ROAD);
     }
+    node->markBentPriority(false);
     // check if the junction is not a real junction
     if (node->myIncomingEdges.size() == 1 && node->myOutgoingEdges.size() == 1) {
         return;
     }
     // compute the priorities on junction when needed
     if (node->getType() != NODETYPE_RIGHT_BEFORE_LEFT) {
-        setPriorityJunctionPriorities(*node);
+        if (node->getRightOfWay() == RIGHT_OF_WAY_EDGEPRIORITY) {
+            for (NBEdge* e : node->getIncomingEdges()) {
+                e->setJunctionPriority(node, e->getPriority());
+            }
+        } else {
+            setPriorityJunctionPriorities(*node);
+        }
     }
 }
 
@@ -350,17 +366,19 @@ NBEdgePriorityComputer::setPriorityJunctionPriorities(NBNode& n) {
                 s->setJunctionPriority(&n, NBEdge::PRIORITY_ROAD);
             }
         }
+        markBestParallel(n, best1, nullptr);
         assert(bestOutgoing.size() != 0);
         // mark the best outgoing as the continuation
         sort(bestOutgoing.begin(), bestOutgoing.end(), NBContHelper::edge_similar_direction_sorter(best1));
         // assign extra priority if the priorities are unambiguous (regardless of geometry)
-        best1 = extractAndMarkFirst(n, bestOutgoing);
-        if (!mainDirectionExplicit && counterOutgoingEdges.find(best1) != counterOutgoingEdges.end()) {
-            NBEdge* s = counterOutgoingEdges.find(best1)->second;
-            if (GeomHelper::getMinAngleDiff(best1->getAngleAtNode(&n), s->getAngleAtNode(&n)) > 180 - 45) {
+        NBEdge* bestOut = extractAndMarkFirst(n, bestOutgoing);
+        if (!mainDirectionExplicit && counterOutgoingEdges.find(bestOut) != counterOutgoingEdges.end()) {
+            NBEdge* s = counterOutgoingEdges.find(bestOut)->second;
+            if (GeomHelper::getMinAngleDiff(bestOut->getAngleAtNode(&n), s->getAngleAtNode(&n)) > 180 - 45) {
                 s->setJunctionPriority(&n, 1);
             }
         }
+        n.markBentPriority(n.getDirection(best1, bestOut) != LINKDIR_STRAIGHT);
         return;
     }
 
@@ -369,8 +387,8 @@ NBEdgePriorityComputer::setPriorityJunctionPriorities(NBNode& n) {
     // This means, when several incoming roads have the same priority,
     //  we want a (any) straight connection to be more priorised than a turning
     double bestAngle = 0;
-    NBEdge* bestFirst = 0;
-    NBEdge* bestSecond = 0;
+    NBEdge* bestFirst = nullptr;
+    NBEdge* bestSecond = nullptr;
     bool hadBest = false;
     for (i = bestIncoming.begin(); i != bestIncoming.end(); ++i) {
         EdgeVector::iterator j;
@@ -404,13 +422,34 @@ NBEdgePriorityComputer::setPriorityJunctionPriorities(NBNode& n) {
     if (bestOutgoing.size() != 0) {
         extractAndMarkFirst(n, bestOutgoing);
     }
+    n.markBentPriority(GeomHelper::getMinAngleDiff(bestFirst->getAngleAtNode(&n), bestSecond->getAngleAtNode(&n)) < 135);
+    markBestParallel(n, bestFirst, bestSecond);
+}
+
+void
+NBEdgePriorityComputer::markBestParallel(const NBNode& n, NBEdge* bestFirst, NBEdge* bestSecond) {
+    // edges running parallel to the main direction should also be prioritised
+    const double a1 = bestFirst->getAngleAtNode(&n);
+    const double a2 = bestSecond == nullptr ? a1 : bestSecond->getAngleAtNode(&n);
+    SVCPermissions p1 = bestFirst->getPermissions();
+    SVCPermissions p2 = bestSecond == nullptr ? p1 : bestSecond->getPermissions();
+    for (NBEdge* e : n.getIncomingEdges()) {
+        // @note: this rule might also apply if there are common permissions but
+        // then we would not further rules to resolve the priority between the best edge and its parallel edge
+        SVCPermissions perm = e->getPermissions();
+        if (((GeomHelper::getMinAngleDiff(e->getAngleAtNode(&n), a1) < 10
+                || GeomHelper::getMinAngleDiff(e->getAngleAtNode(&n), a2) < 10))
+                && (p1 & perm) == 0 && (p2 & perm) == 0) {
+            e->setJunctionPriority(&n, 1);
+        }
+    }
 }
 
 
 NBEdge*
 NBEdgePriorityComputer::extractAndMarkFirst(NBNode& n, std::vector<NBEdge*>& s, int prio) {
     if (s.size() == 0) {
-        return 0;
+        return nullptr;
     }
     NBEdge* ret = s.front();
     s.erase(s.begin());
