@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2012-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBAlgorithms.h
 /// @author  Daniel Krajzewicz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <map>
 #include "NBEdgeCont.h"
@@ -121,7 +115,13 @@ public:
         explicit crossing_by_junction_angle_sorter(const NBNode* node, const EdgeVector& ordering);
 
         int operator()(const NBNode::Crossing* c1, const NBNode::Crossing* c2) const {
-            return (int)(getMinRank(c1->edges) < getMinRank(c2->edges));
+            const int r1 = getMinRank(c1->edges);
+            const int r2 = getMinRank(c2->edges);
+            if (r1 == r2) {
+                return c1->edges.size() > c2->edges.size();
+            } else {
+                return (int)(r1 < r2);
+            }
         }
 
     private:
@@ -205,12 +205,15 @@ public:
     /** @brief Computes node types
      * @param[in] nc The container of nodes to loop along
      */
-    static void computeNodeTypes(NBNodeCont& nc);
+    static void computeNodeTypes(NBNodeCont& nc, NBTrafficLightLogicCont& tlc);
 
-    /** @brief Computes a single node type
-     * @param[in] node the single node to compute node type
+    /** @brief Checks rail_crossing for validity
+     * @param[in] nc The container of nodes to loop along
      */
-    static void computeSingleNodeType(NBNode* node);
+    static void validateRailCrossings(NBNodeCont& nc, NBTrafficLightLogicCont& tlc);
+
+    /// @brief whether the given node only has rail edges
+    static bool isRailwayNode(NBNode* n);
 };
 
 
@@ -239,6 +242,9 @@ private:
      */
     static void setPriorityJunctionPriorities(NBNode& n);
 
+    /// @brief set priority for edges that are parallel to the best edges
+    static void markBestParallel(const NBNode& n, NBEdge* bestFirst, NBEdge* bestSecond);
+
     /** @brief Sets the priorites in case of a priority junction
      * @param[in] n The node to set edges' priorities
      * @param[in] s The vector of edges to get and mark the first from
