@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBConnection.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <sstream>
 #include <iostream>
@@ -41,7 +35,7 @@
 // static members
 // ===========================================================================
 const int NBConnection::InvalidTlIndex = -1;
-const NBConnection NBConnection::InvalidConnection("invalidFrom", 0, "invalidTo", 0);
+const NBConnection NBConnection::InvalidConnection("invalidFrom", nullptr, "invalidTo", nullptr);
 
 // ===========================================================================
 // method definitions
@@ -73,7 +67,7 @@ NBConnection::NBConnection(NBEdge* from, int fromLane,
     assert(myToLane<0||to->getNumLanes()>(int) myToLane);
     */
     myFromID = from->getID();
-    myToID = to != 0 ? to->getID() : "";
+    myToID = to != nullptr ? to->getID() : "";
 }
 
 
@@ -104,7 +98,7 @@ bool
 NBConnection::replaceFrom(NBEdge* which, NBEdge* by) {
     if (myFrom == which) {
         myFrom = by;
-        if (myFrom != 0) {
+        if (myFrom != nullptr) {
             myFromID = myFrom->getID();
         } else {
             myFromID = "invalidFrom";
@@ -120,7 +114,7 @@ NBConnection::replaceFrom(NBEdge* which, int whichLane,
                           NBEdge* by, int byLane) {
     if (myFrom == which && (myFromLane == whichLane || myFromLane < 0 || whichLane < 0)) {
         myFrom = by;
-        if (myFrom != 0) {
+        if (myFrom != nullptr) {
             myFromID = myFrom->getID();
         } else {
             myFromID = "invalidFrom";
@@ -138,7 +132,7 @@ bool
 NBConnection::replaceTo(NBEdge* which, NBEdge* by) {
     if (myTo == which) {
         myTo = by;
-        if (myTo != 0) {
+        if (myTo != nullptr) {
             myToID = myTo->getID();
         } else {
             myToID = "invalidTo";
@@ -154,7 +148,7 @@ NBConnection::replaceTo(NBEdge* which, int whichLane,
                         NBEdge* by, int byLane) {
     if (myTo == which && (myToLane == whichLane || myFromLane < 0 || whichLane < 0)) {
         myTo = by;
-        if (myTo != 0) {
+        if (myTo != nullptr) {
             myToID = myTo->getID();
         } else {
             myToID = "invalidTo";
@@ -196,7 +190,7 @@ bool
 NBConnection::check(const NBEdgeCont& ec) {
     myFrom = checkFrom(ec);
     myTo = checkTo(ec);
-    return myFrom != 0 && myTo != 0;
+    return myFrom != nullptr && myTo != nullptr;
 }
 
 
@@ -245,10 +239,10 @@ NBConnection::getToLane() const {
 
 
 void
-NBConnection::shiftLaneIndex(NBEdge* edge, int offset) {
-    if (myFrom == edge) {
+NBConnection::shiftLaneIndex(NBEdge* edge, int offset, int threshold) {
+    if (myFrom == edge && myFromLane > threshold) {
         myFromLane += offset;
-    } else if (myTo == edge) {
+    } else if (myTo == edge && myToLane > threshold) {
         myToLane += offset;
     }
 }
