@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBConnection.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include "NBEdge.h"
@@ -83,8 +77,9 @@ public:
     /// @brief replaces the to-edge by the one given
     bool replaceTo(NBEdge* which, int whichLane, NBEdge* by, int byLane);
 
-    /// @brief  patches lane indices refering to the given edge
-    void shiftLaneIndex(NBEdge* edge, int offset);
+    /** @brief  patches lane indices refering to the given edge and above the
+     * threshold by the given offset */
+    void shiftLaneIndex(NBEdge* edge, int offset, int threshold = -1);
 
     /// @brief checks whether the edges are still valid
     bool check(const NBEdgeCont& ec);
