@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBDistrictCont.cpp
 /// @author  Daniel Krajzewicz
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <iostream>
@@ -66,7 +60,7 @@ NBDistrict*
 NBDistrictCont::retrieve(const std::string& id) const {
     DistrictCont::const_iterator i = myDistricts.find(id);
     if (i == myDistricts.end()) {
-        return 0;
+        return nullptr;
     }
     return (*i).second;
 }
@@ -82,7 +76,7 @@ bool
 NBDistrictCont::addSource(const std::string& dist, NBEdge* const source,
                           double weight) {
     NBDistrict* o = retrieve(dist);
-    if (o == 0) {
+    if (o == nullptr) {
         return false;
     }
     return o->addSource(source, weight);
@@ -93,7 +87,7 @@ bool
 NBDistrictCont::addSink(const std::string& dist, NBEdge* const destination,
                         double weight) {
     NBDistrict* o = retrieve(dist);
-    if (o == 0) {
+    if (o == nullptr) {
         return false;
     }
     return o->addSink(destination, weight);
