@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBEdge.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <map>
 #include <vector>
@@ -58,6 +52,7 @@ class NBNodeCont;
 class NBEdgeCont;
 class OutputDevice;
 class GNELane;
+class NBVehicle;
 
 
 // ===========================================================================
@@ -137,6 +132,10 @@ public:
         /// @brief This lane's offset to the intersection begin
         double endOffset;
 
+        /// @brief stopOffsets.second - The stop offset for vehicles stopping at the lane's end.
+        ///        Applies if vClass is in in stopOffset.first bitset
+        std::map<int, double> stopOffsets;
+
         /// @brief This lane's width
         double width;
 
@@ -192,7 +191,7 @@ public:
         std::string tlID;
 
         /// @brief The index of this connection within the controlling traffic light
-        int tlLinkNo;
+        int tlLinkIndex;
 
         /// @brief Information about being definitely free to drive (on-ramps)
         bool mayDefinitelyPass;
@@ -218,7 +217,7 @@ public:
         /// @brief shape of Connection
         PositionVector shape;
 
-        /// @brief maximun velocity
+        /// @brief maximum velocity
         double vmax;
 
         /// @brief check if Connection have a Via
@@ -234,7 +233,7 @@ public:
         std::vector<int> foeInternalLinks;
 
         /// @brief FOE Incomings lanes
-        std::string foeIncomingLanes;
+        std::vector<std::string> foeIncomingLanes;
 
         /// @brief The lane index of this internal lane within the internal edge
         int internalLaneIndex;
@@ -247,8 +246,13 @@ public:
 
         /// @brief get string describing this connection
         std::string getDescription(const NBEdge* parent) const;
+
+        /// @brief computed length (average of all internal lane shape lengths that share an internal edge)
+        double length;
     };
 
+    /// @brief Dummy edge to use when a reference must be supplied in the no-arguments constructor (FOX technicality)
+    static NBEdge DummyEdge;
 
     /// @brief unspecified lane width
     static const double UNSPECIFIED_WIDTH;
@@ -273,9 +277,13 @@ public:
 
     /// @brief the distance at which to take the default angle
     static const double ANGLE_LOOKAHEAD;
+
     /// @brief internal lane computation not yet done
     static const int UNSPECIFIED_INTERNAL_LANE_INDEX;
 
+    /// @brief TLS-controlled despite its node controlled not specified.
+    static const bool UNSPECIFIED_CONNECTION_UNCONTROLLED;
+
     /// @brief junction priority values set by setJunctionPriority
     enum JunctionPriority {
         MINOR_ROAD = 0,
@@ -296,7 +304,7 @@ public:
      * @param[in] nolanes The number of lanes this edge has
      * @param[in] priority This edge's priority
      * @param[in] width This edge's lane width
-     * @param[in] offset Additional offset to the destination node
+     * @param[in] endOffset Additional offset to the destination node
      * @param[in] streetName The street name (need not be unique)
      * @param[in] spread How the lateral offset of the lanes shall be computed
      * @see init
@@ -305,7 +313,7 @@ public:
     NBEdge(const std::string& id,
            NBNode* from, NBNode* to, std::string type,
            double speed, int nolanes, int priority,
-           double width, double offset,
+           double width, double endOffset,
            const std::string& streetName = "",
            LaneSpreadFunction spread = LANESPREAD_RIGHT);
 
@@ -322,7 +330,7 @@ public:
      * @param[in] nolanes The number of lanes this edge has
      * @param[in] priority This edge's priority
      * @param[in] width This edge's lane width
-     * @param[in] offset Additional offset to the destination node
+     * @param[in] endOffset Additional offset to the destination node
      * @param[in] geom The edge's geomatry
      * @param[in] streetName The street name (need not be unique)
      * @param[in] origID The original ID in the source network (need not be unique)
@@ -334,7 +342,7 @@ public:
     NBEdge(const std::string& id,
            NBNode* from, NBNode* to, std::string type,
            double speed, int nolanes, int priority,
-           double width, double offset,
+           double width, double endOffset,
            PositionVector geom,
            const std::string& streetName = "",
            const std::string& origID = "",
@@ -354,7 +362,7 @@ public:
      */
     NBEdge(const std::string& id,
            NBNode* from, NBNode* to,
-           NBEdge* tpl,
+           const NBEdge* tpl,
            const PositionVector& geom = PositionVector(),
            int numLanes = -1);
 
@@ -373,14 +381,14 @@ public:
      * @param[in] priority This edge's priority
      * @param[in] geom The edge's geomatry
      * @param[in] width This edge's lane width
-     * @param[in] offset Additional offset to the destination node
+     * @param[in] endOffset Additional offset to the destination node
      * @param[in] streetName The street name (need not be unique)
      * @param[in] spread How the lateral offset of the lanes shall be computed
      * @param[in] tryIgnoreNodePositions Does not add node geometries if geom.size()>=2
      */
     void reinit(NBNode* from, NBNode* to, const std::string& type,
                 double speed, int nolanes, int priority,
-                PositionVector geom, double width, double offset,
+                PositionVector geom, double width, double endOffset,
                 const std::string& streetName,
                 LaneSpreadFunction spread = LANESPREAD_RIGHT,
                 bool tryIgnoreNodePositions = false);
@@ -548,11 +556,23 @@ public:
         return myEndOffset;
     }
 
+    /** @brief Returns the stopOffset to the end of the edge
+     * @return The offset to the end of the edge
+     */
+    const std::map<int, double>& getStopOffsets() const {
+        return myStopOffsets;
+    }
+
     /** @brief Returns the offset to the destination node a the specified lane
      * @return The offset to the destination node
      */
     double getEndOffset(int lane) const;
 
+    /** @brief Returns the stop offset to the specified lane's end
+     * @return The stop offset to the specified lane's end
+     */
+    const std::map<int, double>& getStopOffsets(int lane) const;
+
     /// @brief Returns the offset of a traffic signal from the end of this edge
     double getSignalOffset() const {
         return mySignalOffset;
@@ -664,7 +684,7 @@ public:
      *  but may differ in actual geomtric length.
      * @note Depends on previous call to NBNodeCont::computeNodeShapes
      */
-    void computeEdgeShape();
+    void computeEdgeShape(double smoothElevationThreshold=-1);
 
     /** @brief Returns the shape of the nth lane
      * @return The shape of the lane given by its index (counter from right)
@@ -751,7 +771,8 @@ public:
                                 double contPos = UNSPECIFIED_CONTPOS,
                                 double visibility = UNSPECIFIED_VISIBILITY_DISTANCE,
                                 double speed = UNSPECIFIED_SPEED,
-                                const PositionVector& customShape = PositionVector::EMPTY);
+                                const PositionVector& customShape = PositionVector::EMPTY,
+                                const bool uncontrolled = UNSPECIFIED_CONNECTION_UNCONTROLLED);
 
     /** @brief Builds no connections starting at the given lanes
      *
@@ -794,7 +815,8 @@ public:
                        double contPos = UNSPECIFIED_CONTPOS,
                        double visibility = UNSPECIFIED_VISIBILITY_DISTANCE,
                        double speed = UNSPECIFIED_SPEED,
-                       const PositionVector& customShape = PositionVector::EMPTY);
+                       const PositionVector& customShape = PositionVector::EMPTY,
+                       const bool uncontrolled = UNSPECIFIED_CONNECTION_UNCONTROLLED);
 
     /// @brief insert a previously created NBEdge::connection
     void insertConnection(NBEdge::Connection connection);
@@ -942,14 +964,14 @@ public:
     }
 
     /// @brief Marks this edge being within an intersection
-    void setIsInnerEdge() {
+    void setInternal() {
         myAmInnerEdge = true;
     }
 
     /** @brief Returns whether this edge was marked as being within an intersection
      * @return Whether this edge was marked as being within an intersection
      */
-    bool isInnerEdge() const {
+    bool isInternal() const {
         return myAmInnerEdge;
     }
     /// @}
@@ -1001,6 +1023,9 @@ public:
     /// @brief whether lanes differ in offset
     bool hasLaneSpecificEndOffset() const;
 
+    /// @brief whether lanes differ in stopOffsets
+    bool hasLaneSpecificStopOffsets() const;
+
     /// @brief whether one of the lanes is an acceleration lane
     bool hasAccelLane() const;
 
@@ -1027,7 +1052,7 @@ public:
      *  of this edge to the leftmost lane of myTurnDestination).
      * @param[in] noTLSControlled Whether the turnaround shall not be connected if this edge is controlled by a tls
      */
-    void appendTurnaround(bool noTLSControlled, bool checkPermissions);
+    void appendTurnaround(bool noTLSControlled, bool onlyDeadends, bool checkPermissions);
 
     /** @brief Returns the node at the given edges length (using an epsilon)
         @note When no node is existing at the given position, 0 is returned
@@ -1114,10 +1139,10 @@ public:
     void decLaneNo(int by);
 
     /// @brief delete lane
-    void deleteLane(int index, bool recompute = true);
+    void deleteLane(int index, bool recompute, bool shiftIndices);
 
     /// @brief add lane
-    void addLane(int index, bool recompute = true);
+    void addLane(int index, bool recomputeShape, bool recomputeConnections, bool shiftIndices);
 
     /// @brief mark edge as in lane to state lane
     void markAsInLane2LaneState();
@@ -1158,6 +1183,10 @@ public:
     /// @brief set lane specific speed (negative lane implies set for all lanes)
     void setSpeed(int lane, double speed);
 
+    /// @brief set lane and vehicle class specific stopOffset (negative lane implies set for all lanes)
+    /// @return Whether given stop offset was applied.
+    bool setStopOffsets(int lane, std::map<int, double> offsets, bool overwrite = false);
+
     /// @brief marks one lane as acceleration lane
     void setAcceleration(int lane, bool accelRamp);
 
@@ -1215,8 +1244,59 @@ public:
 
     /// @brief Set Node border
     void setNodeBorder(const NBNode* node, const Position& p, const Position& p2, bool rectangularCut);
+    const PositionVector& getNodeBorder(const NBNode* node);
     void resetNodeBorder(const NBNode* node);
 
+    /// @brief whether this edge is part of a bidirectional railway
+    bool isBidiRail(bool ignoreSpread = false) const;
+
+    /// @brief whether this edge is a railway edge that does not continue
+    bool isRailDeadEnd() const;
+
+    /// @brief debugging helper to print all connections
+    void debugPrintConnections(bool outgoing = true, bool incoming = false) const;
+
+    /// @brief compute the first intersection point between the given lane geometries considering their rspective widths
+    static double firstIntersection(const PositionVector& v1, const PositionVector& v2, double width2);
+
+    /** returns a modified version of laneShape which starts at the outside of startNode. laneShape may be shorted or extended
+     * @note see [wiki:Developer/Network_Building_Process]
+     */
+    static PositionVector startShapeAt(const PositionVector& laneShape, const NBNode* startNode, PositionVector nodeShape);
+
+    /// @name functions for router usage
+    //@{
+
+    static inline double getTravelTimeStatic(const NBEdge* const edge, const NBVehicle* const /*veh*/, double /*time*/) {
+        return edge->getLength() / edge->getSpeed();
+    }
+
+    static int getLaneIndexFromLaneID(const std::string laneID);
+
+    /// @brief sets the index of the edge in the list of all network edges
+    void setNumericalID(int index) {
+        myIndex = index;
+    }
+
+    /** @brief Returns the index (numeric id) of the edge
+     * @note This is only used in the context of routing
+     * @return This edge's numerical id
+     */
+    int getNumericalID() const {
+        return myIndex;
+    }
+
+    /** @brief Returns the following edges for the given vClass
+     */
+    const EdgeVector& getSuccessors(SUMOVehicleClass vClass = SVC_IGNORING) const;
+
+
+    /** @brief Returns the following edges for the given vClass
+     */
+    const NBConstEdgePairVector& getViaSuccessors(SUMOVehicleClass vClass = SVC_IGNORING) const;
+
+    //@}
+
 private:
     /** @class ToEdgeConnectionsAdder
      * @brief A class that being a bresenham-callback assigns the incoming lanes to the edges
@@ -1346,16 +1426,11 @@ private:
     bool canMoveConnection(const Connection& con, int newFromLane) const;
     /// @}
 
-    /** returns a modified version of laneShape which starts at the outside of startNode. laneShape may be shorted or extended
-     * @note see [wiki:Developer/Network_Building_Process]
-     */
-    PositionVector startShapeAt(const PositionVector& laneShape, const NBNode* startNode, PositionVector nodeShape) const;
-
     /// @brief computes the angle of this edge and stores it in myAngle
     void computeAngle();
 
-    /// @brief compute the first intersection point between the given lane geometries considering their rspective widths
-    static double firstIntersection(const PositionVector& v1, const PositionVector& v2, double width2);
+    /// @brief determine conflict between opposite left turns
+    bool bothLeftIntersect(const NBNode& n, const PositionVector& shape, LinkDirection dir, NBEdge* otherFrom, const NBEdge::Connection& otherCon, int numPoints, double width2) const;
 
     /// @brief add a lane of the given width, restricted to the given class and shift existing connections
     void addRestrictedLane(double width, SUMOVehicleClass vclass);
@@ -1363,6 +1438,9 @@ private:
     /// @brief restore a restricted lane
     void restoreRestrictedLane(SUMOVehicleClass vclass, std::vector<NBEdge::Lane> oldLanes, PositionVector oldGeometry, std::vector<NBEdge::Connection> oldConnections);
 
+    /// @brief assign length to all lanes of an internal edge
+    void assignInternalLaneLength(std::vector<Connection>::iterator i, int numLanes, double lengthSum);
+
 private:
     /** @brief The building step
      * @see EdgeBuildingStep
@@ -1420,6 +1498,12 @@ private:
     /// @brief This edges's offset to the intersection begin (will be applied to all lanes)
     double myEndOffset;
 
+    /// @brief A vClass specific stop offset - assumed of length 0 (unspecified) or 1.
+    ///        For the latter case the int is a bit set specifying the vClasses,
+    ///        the offset applies to (see SUMOVehicleClass.h), and the double is the
+    ///        stopping offset in meters from the lane end
+    std::map<int, double> myStopOffsets;
+
     /// @brief This width of this edge's lanes
     double myLaneWidth;
 
@@ -1462,6 +1546,16 @@ private:
     PositionVector myToBorder;
     /// @}
 
+
+    /// @brief the index of the edge in the list of all edges. Set by NBEdgeCont and requires re-set whenever the list of edges changes
+    int myIndex;
+
+    // @brief a static list of successor edges. Set by NBEdgeCont and requires reset when the network changes
+    mutable EdgeVector mySuccessors;
+
+    // @brief a static list of successor edges. Set by NBEdgeCont and requires reset when the network changes
+    mutable NBConstEdgePairVector myViaSuccessors;
+
 public:
     /// @class tls_disable_finder
     class tls_disable_finder {
@@ -1659,6 +1753,10 @@ private:
 
     /// @brief invalidated assignment operator
     NBEdge& operator=(const NBEdge& s);
+
+    /// @brief constructor for dummy edge
+    NBEdge();
+
 };
 
 
