@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBEdgeCont.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <map>
 #include <iostream>
@@ -46,14 +40,15 @@
 // ===========================================================================
 // class declarations
 // ===========================================================================
+class OptionsCont;
+class OutputDevice;
 class NBNodeCont;
 class NBTypeCont;
 class NBEdge;
 class NBNode;
-class OptionsCont;
 class NBDistrictCont;
 class NBTrafficLightLogicCont;
-class OutputDevice;
+class NBPTStopCont;
 
 
 // ===========================================================================
@@ -205,6 +200,35 @@ public:
     /// @name explicit edge manipulation methods
     /// @{
 
+    /** @struct Split
+     * @brief A structure which describes changes of lane number or speed along the road
+     */
+    struct Split {
+        Split() : offset(0), offsetFactor(1) {}
+        /// @brief The lanes after this change
+        std::vector<int> lanes;
+        /// @brief The position of this change
+        double pos;
+        /// @brief The speed after this change
+        double speed;
+        /// @brief The new node that is created for this split
+        NBNode* node;
+        /// @brief The id for the edge before the split
+        std::string idBefore;
+        /// @brief The id for the edge after the split
+        std::string idAfter;
+        /// @brief the default node id
+        std::string nameID;
+        /// @brief lateral offset to edge geometry
+        double offset;
+        /// @brief direction in which to apply the offset (used by netgenerate for lefthand networks)
+        int offsetFactor;
+    };
+
+    void processSplits(NBEdge* e, std::vector<Split> splits,
+                       NBNodeCont& nc, NBDistrictCont& dc, NBTrafficLightLogicCont& tlc);
+
+
     /** @brief Splits the edge at the position nearest to the given node
      *
      * Uses "splitAt(NBDistrictCont &, NBEdge *, NBNode *, const std::string &, const std::string &, int , int)"
@@ -389,10 +413,11 @@ public:
      * Calls "NBEdge::appendTurnaround" for all edges within the container.
      *
      * @param[in] noTLSControlled Whether the turnaround shall not be connected if the edge is controlled by a tls
+     * @param[in] exceptDeadends Whether the turnaround shall only be built at deadends
      * @todo Recheck whether a visitor-pattern should be used herefor
      * @see NBEdge::appendTurnaround
      */
-    void appendTurnarounds(bool noTLSControlled);
+    void appendTurnarounds(bool noTLSControlled, bool onlyDeadends);
 
 
     /** @brief Appends turnarounds to all edges stored in the container
@@ -403,6 +428,10 @@ public:
      */
     void appendTurnarounds(const std::set<std::string>& ids, bool noTLSControlled);
 
+    /** @brief Appends turnarounds to all bidiRail edges with stops
+     */
+    void appendRailwayTurnarounds(const NBPTStopCont& sc);
+
 
     /** @brief Computes the shapes of all edges stored in the container
      *
@@ -412,7 +441,7 @@ public:
      * @todo Recheck usage
      * @see NBEdge::computeEdgeShape
      */
-    void computeEdgeShapes();
+    void computeEdgeShapes(double smoothElevationThreshold=-1);
 
 
     /** @brief Computes the shapes of all lanes of all edges stored in the container
@@ -544,7 +573,7 @@ public:
     bool ignoreFilterMatch(NBEdge* edge);
 
     /// @brief remap node IDs accoring to options --numerical-ids and --reserved-ids
-    int remapIDs(bool numericaIDs, bool reservedIDs);
+    int remapIDs(bool numericaIDs, bool reservedIDs, const std::string& prefix, NBPTStopCont& sc);
 
     /// @brief check whether edges overlap
     void checkOverlap(double threshold, double zThreshold) const;
@@ -561,6 +590,9 @@ public:
      */
     EdgeVector getGeneratedFrom(const std::string& id) const;
 
+    /// @brief return all edges
+    EdgeVector getAllEdges() const;
+
 private:
     /// @brief compute the form factor for a loop of edges
     static double formFactor(const EdgeVector& loopEdges);
@@ -673,6 +705,21 @@ private:
     /// @brief Edges marked as belonging to a roundabout after guessing
     std::set<EdgeSet> myGuessedRoundabouts;
 
+    /** @class split_sorter
+     * @brief Sorts splits by their position (increasing)
+     */
+    class split_sorter {
+    public:
+        /// @brief Constructor
+        explicit split_sorter() { }
+
+        /// @brief Comparing operator
+        int operator()(const Split& e1, const Split& e2) const {
+            return e1.pos < e2.pos;
+        }
+    };
+
+
 private:
     /// @brief invalidated copy constructor
     NBEdgeCont(const NBEdgeCont& s);
