@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2011-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBHeightMapper.cpp
 /// @author  Jakob Erdmann
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <utils/common/MsgHandler.h>
@@ -63,7 +57,7 @@ NBHeightMapper NBHeightMapper::Singleton;
 
 
 NBHeightMapper::NBHeightMapper():
-    myRTree(&Triangle::addSelf), myRaster(0) {
+    myRTree(&Triangle::addSelf) {
 }
 
 
@@ -80,7 +74,7 @@ NBHeightMapper::get() {
 
 bool
 NBHeightMapper::ready() const {
-    return myRaster != 0 || myTriangles.size() > 0;
+    return myRasters.size() > 0 || myTriangles.size() > 0;
 }
 
 
@@ -90,23 +84,25 @@ NBHeightMapper::getZ(const Position& geo) const {
         WRITE_WARNING("Cannot supply height since no height data was loaded");
         return 0;
     }
-    if (myRaster != 0) {
+    for (auto& item : myRasters) {
+        const Boundary& boundary = item.first;
+        int16_t* raster = item.second;
         double result = -1e6;
-        if (myBoundary.around(geo)) {
-            const int xSize = int((myBoundary.xmax() - myBoundary.xmin()) / mySizeOfPixel.x() + .5);
-            const double normX = (geo.x() - myBoundary.xmin()) / mySizeOfPixel.x();
-            const double normY = (geo.y() - myBoundary.ymax()) / mySizeOfPixel.y();
+        if (boundary.around(geo)) {
+            const int xSize = int((boundary.xmax() - boundary.xmin()) / mySizeOfPixel.x() + .5);
+            const double normX = (geo.x() - boundary.xmin()) / mySizeOfPixel.x();
+            const double normY = (geo.y() - boundary.ymax()) / mySizeOfPixel.y();
             PositionVector corners;
-            corners.push_back(Position(floor(normX) + 0.5, floor(normY) + 0.5, myRaster[(int)normY * xSize + (int)normX]));
+            corners.push_back(Position(floor(normX) + 0.5, floor(normY) + 0.5, raster[(int)normY * xSize + (int)normX]));
             if (normX - floor(normX) > 0.5) {
-                corners.push_back(Position(floor(normX) + 1.5, floor(normY) + 0.5, myRaster[(int)normY * xSize + (int)normX + 1]));
+                corners.push_back(Position(floor(normX) + 1.5, floor(normY) + 0.5, raster[(int)normY * xSize + (int)normX + 1]));
             } else {
-                corners.push_back(Position(floor(normX) - 0.5, floor(normY) + 0.5, myRaster[(int)normY * xSize + (int)normX - 1]));
+                corners.push_back(Position(floor(normX) - 0.5, floor(normY) + 0.5, raster[(int)normY * xSize + (int)normX - 1]));
             }
             if (normY - floor(normY) > 0.5) {
-                corners.push_back(Position(floor(normX) + 0.5, floor(normY) + 1.5, myRaster[((int)normY + 1) * xSize + (int)normX]));
+                corners.push_back(Position(floor(normX) + 0.5, floor(normY) + 1.5, raster[((int)normY + 1) * xSize + (int)normX]));
             } else {
-                corners.push_back(Position(floor(normX) + 0.5, floor(normY) - 0.5, myRaster[((int)normY - 1) * xSize + (int)normX]));
+                corners.push_back(Position(floor(normX) + 0.5, floor(normY) - 0.5, raster[((int)normY - 1) * xSize + (int)normX]));
             }
             result = Triangle(corners).getZ(Position(normX, normY));
         }
@@ -254,7 +250,7 @@ NBHeightMapper::loadShapeFile(const std::string& file) {
                 break;
             }
             default:
-                WRITE_WARNING("Unsupported shape type occured");
+                WRITE_WARNING("Unsupported shape type occurred");
             break;
         }
         */
@@ -265,10 +261,11 @@ NBHeightMapper::loadShapeFile(const std::string& file) {
 #else
     GDALClose(ds);
 #endif
-    OCTDestroyCoordinateTransformation(toWGS84);
+    OCTDestroyCoordinateTransformation(reinterpret_cast<OGRCoordinateTransformationH>(toWGS84));
     OGRCleanupAll();
     return numFeatures;
 #else
+    UNUSED_PARAMETER(file);
     WRITE_ERROR("Cannot load shape file since SUMO was compiled without GDAL support.");
     return 0;
 #endif
@@ -284,6 +281,7 @@ NBHeightMapper::loadTiff(const std::string& file) {
         WRITE_ERROR("Cannot load GeoTIFF file.");
         return 0;
     }
+    Boundary boundary;
     const int xSize = poDataset->GetRasterXSize();
     const int ySize = poDataset->GetRasterYSize();
     double adfGeoTransform[6];
@@ -292,14 +290,14 @@ NBHeightMapper::loadTiff(const std::string& file) {
         mySizeOfPixel.set(adfGeoTransform[1], adfGeoTransform[5]);
         const double horizontalSize = xSize * mySizeOfPixel.x();
         const double verticalSize = ySize * mySizeOfPixel.y();
-        myBoundary.add(topLeft);
-        myBoundary.add(topLeft.x() + horizontalSize, topLeft.y() + verticalSize);
+        boundary.add(topLeft);
+        boundary.add(topLeft.x() + horizontalSize, topLeft.y() + verticalSize);
     } else {
         WRITE_ERROR("Could not parse geo information from " + file + ".");
         return 0;
     }
     const int picSize = xSize * ySize;
-    myRaster = (int16_t*)CPLMalloc(sizeof(int16_t) * picSize);
+    int16_t* raster = (int16_t*)CPLMalloc(sizeof(int16_t) * picSize);
     for (int i = 1; i <= poDataset->GetRasterCount(); i++) {
         GDALRasterBand* poBand = poDataset->GetRasterBand(i);
         if (poBand->GetColorInterpretation() != GCI_GrayIndex) {
@@ -313,15 +311,17 @@ NBHeightMapper::loadTiff(const std::string& file) {
             break;
         }
         assert(xSize == poBand->GetXSize() && ySize == poBand->GetYSize());
-        if (poBand->RasterIO(GF_Read, 0, 0, xSize, ySize, myRaster, xSize, ySize, GDT_Int16, 0, 0) == CE_Failure) {
+        if (poBand->RasterIO(GF_Read, 0, 0, xSize, ySize, raster, xSize, ySize, GDT_Int16, 0, 0) == CE_Failure) {
             WRITE_ERROR("Failure in reading " + file + ".");
             clearData();
             break;
         }
     }
     GDALClose(poDataset);
+    myRasters.push_back(std::make_pair(boundary, raster));
     return picSize;
 #else
+    UNUSED_PARAMETER(file);
     WRITE_ERROR("Cannot load GeoTIFF file since SUMO was compiled without GDAL support.");
     return 0;
 #endif
@@ -335,10 +335,10 @@ NBHeightMapper::clearData() {
     }
     myTriangles.clear();
 #ifdef HAVE_GDAL
-    if (myRaster != 0) {
-        CPLFree(myRaster);
-        myRaster = 0;
+    for (auto& item : myRasters) {
+        CPLFree(item.second);
     }
+    myRasters.clear();
 #endif
     myBoundary.reset();
 }
