@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2011-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBHeightMapper.h
 /// @author  Jakob Erdmann
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #ifdef _MSC_VER
 typedef __int16 int16_t;
@@ -139,8 +133,8 @@ private:
     /// @brief The RTree for spatial queries
     TRIANGLE_RTREE_QUAL myRTree;
 
-    /// @brief raster height information in m
-    int16_t* myRaster;
+    /// @brief raster height information in m for all loaded files
+    std::vector<std::pair<Boundary, int16_t*> > myRasters;
 
     /// @brief dimensions of one pixel in raster data
     Position mySizeOfPixel;
