@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2011-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBLoadedSUMOTLDef.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <set>
@@ -40,6 +34,7 @@
 #include "NBOwnTLDef.h"
 #include "NBTrafficLightDefinition.h"
 #include "NBLoadedSUMOTLDef.h"
+#include "NBNetBuilder.h"
 #include "NBOwnTLDef.h"
 #include "NBNode.h"
 
@@ -52,7 +47,7 @@
 NBLoadedSUMOTLDef::NBLoadedSUMOTLDef(const std::string& id, const std::string& programID,
                                      SUMOTime offset, TrafficLightType type) :
     NBTrafficLightDefinition(id, programID, offset, type),
-    myTLLogic(0),
+    myTLLogic(nullptr),
     myReconstructAddedConnections(false),
     myReconstructRemovedConnections(false),
     myPhasesLoaded(false) {
@@ -66,11 +61,18 @@ NBLoadedSUMOTLDef::NBLoadedSUMOTLDef(NBTrafficLightDefinition* def, NBTrafficLig
     myTLLogic(new NBTrafficLightLogic(logic)),
     myOriginalNodes(def->getNodes().begin(), def->getNodes().end()),
     myReconstructAddedConnections(false),
-    myReconstructRemovedConnections(false) {
+    myReconstructRemovedConnections(false),
+    myPhasesLoaded(false) {
     assert(def->getOffset() == logic->getOffset());
     assert(def->getType() == logic->getType());
     myControlledLinks = def->getControlledLinks();
     myControlledNodes = def->getNodes();
+    NBLoadedSUMOTLDef* sumoDef = dynamic_cast<NBLoadedSUMOTLDef*>(def);
+    updateParameter(def->getParametersMap());
+    if (sumoDef != nullptr) {
+        myReconstructAddedConnections = sumoDef->myReconstructAddedConnections;
+        myReconstructRemovedConnections = sumoDef->myReconstructRemovedConnections;
+    }
 }
 
 
@@ -100,7 +102,9 @@ NBLoadedSUMOTLDef::addConnection(NBEdge* from, NBEdge* to, int fromLane, int toL
     }
     NBConnection conn(from, fromLane, to, toLane, linkIndex);
     // avoid duplicates
-    remove_if(myControlledLinks.begin(), myControlledLinks.end(), connection_equal(conn));
+    auto newEnd = remove_if(myControlledLinks.begin(), myControlledLinks.end(), connection_equal(conn));
+    // remove_if does not remove, only re-order
+    myControlledLinks.erase(newEnd, myControlledLinks.end());
     myControlledLinks.push_back(conn);
     addNode(from->getToNode());
     addNode(to->getFromNode());
@@ -141,7 +145,7 @@ NBLoadedSUMOTLDef::setTLControllingInformation() const {
                                "' with " + toString(myTLLogic->getNumLinks()) + " links.");
         }
         NBEdge* edge = c.getFrom();
-        if (edge != 0 && edge->getNumLanes() > c.getFromLane()) {
+        if (edge != nullptr && edge->getNumLanes() > c.getFromLane()) {
             // logic may have yet to be reconstructed
             edge->setControllingTLInformation(c, getID());
         }
@@ -175,6 +179,7 @@ NBLoadedSUMOTLDef::amInvalid() const {
     }
     // make sure that myControlledNodes are the original nodes
     if (myControlledNodes.size() != myOriginalNodes.size()) {
+        //std::cout << " myControlledNodes=" << myControlledNodes.size() << " myOriginalNodes=" << myOriginalNodes.size() << "\n";
         return true;
     }
     if (myIncomingEdges.size() == 0) {
@@ -182,6 +187,7 @@ NBLoadedSUMOTLDef::amInvalid() const {
     }
     for (std::vector<NBNode*>::const_iterator i = myControlledNodes.begin(); i != myControlledNodes.end(); i++) {
         if (myOriginalNodes.count(*i) != 1) {
+            //std::cout << " node " << (*i)->getID() << " missing from myOriginalNodes\n";
             return true;
         }
     }
@@ -258,7 +264,7 @@ NBLoadedSUMOTLDef::collectEdges() {
                     myControlledInnerEdges.insert(edge->getID());
                 } else {
                     myEdgesWithin.push_back(edge);
-                    (*j)->setIsInnerEdge();
+                    (*j)->setInternal();
                     ++j; //j = myIncomingEdges.erase(j);
                     continue;
                 }
@@ -282,13 +288,13 @@ NBLoadedSUMOTLDef::collectLinks() {
 
 /// @brief patches signal plans by modifying lane indices
 void
-NBLoadedSUMOTLDef::shiftTLConnectionLaneIndex(NBEdge* edge, int offset) {
+NBLoadedSUMOTLDef::shiftTLConnectionLaneIndex(NBEdge* edge, int offset, int threshold) {
     // avoid shifting twice if the edge is incoming and outgoing to a joined TLS
     if (myShifted.count(edge) == 0) {
         /// XXX what if an edge should really be shifted twice?
         myShifted.insert(edge);
         for (NBConnectionVector::iterator it = myControlledLinks.begin(); it != myControlledLinks.end(); it++) {
-            (*it).shiftLaneIndex(edge, offset);
+            (*it).shiftLaneIndex(edge, offset, threshold);
         }
     }
 }
@@ -306,33 +312,34 @@ NBLoadedSUMOTLDef::patchIfCrossingsAdded() {
     const int numNormalLinks = noLinksAll;
     int oldCrossings = 0;
     // collect crossings
+    bool customIndex = false;
     std::vector<NBNode::Crossing*> crossings;
     for (std::vector<NBNode*>::iterator i = myControlledNodes.begin(); i != myControlledNodes.end(); i++) {
         const std::vector<NBNode::Crossing*>& c = (*i)->getCrossings();
         // set tl indices for crossings
-        (*i)->setCrossingTLIndices(getID(), noLinksAll);
+        customIndex |= (*i)->setCrossingTLIndices(getID(), noLinksAll);
         copy(c.begin(), c.end(), std::back_inserter(crossings));
         noLinksAll += (int)c.size();
         oldCrossings += (*i)->numCrossingsFromSumoNet();
     }
     if ((int)crossings.size() != oldCrossings) {
         std::vector<NBTrafficLightLogic::PhaseDefinition> phases = myTLLogic->getPhases();
-        if (phases.size() > 0 && (int)(phases.front().state.size()) != noLinksAll) {
+        // do not rebuilt crossing states there are custom indices and the state string is long enough
+        if (phases.size() > 0 && (
+                    (int)(phases.front().state.size()) < noLinksAll ||
+                    ((int)(phases.front().state.size()) > noLinksAll && !customIndex))) {
             // collect edges
-            EdgeVector fromEdges(size, (NBEdge*)0);
-            EdgeVector toEdges(size, (NBEdge*)0);
+            EdgeVector fromEdges(size, (NBEdge*)nullptr);
+            EdgeVector toEdges(size, (NBEdge*)nullptr);
             std::vector<int> fromLanes(size, 0);
             collectEdgeVectors(fromEdges, toEdges, fromLanes);
             const std::string crossingDefaultState(crossings.size(), 'r');
 
             // rebuild the logic (see NBOwnTLDef.cpp::myCompute)
             NBTrafficLightLogic* newLogic = new NBTrafficLightLogic(getID(), getProgramID(), 0, myOffset, myType);
-            SUMOTime brakingTime = TIME2STEPS(3);
+            SUMOTime brakingTime = TIME2STEPS(computeBrakingTime(OptionsCont::getOptions().getFloat("tls.yellow.min-decel")));
             //std::cout << "patchIfCrossingsAdded for " << getID() << " numPhases=" << phases.size() << "\n";
             for (std::vector<NBTrafficLightLogic::PhaseDefinition>::const_iterator it = phases.begin(); it != phases.end(); it++) {
-                if ((*it).state.find_first_of("yY") != std::string::npos) {
-                    brakingTime = MAX2(brakingTime, it->duration);
-                }
                 const std::string state = it->state.substr(0, numNormalLinks) + crossingDefaultState;
                 NBOwnTLDef::addPedestrianPhases(newLogic, it->duration, it->minDur, it->maxDur, state, crossings, fromEdges, toEdges);
             }
@@ -380,7 +387,7 @@ NBLoadedSUMOTLDef::initNeedsContRelation() const {
             for (NBConnectionVector::const_iterator it1 = myControlledLinks.begin(); it1 != myControlledLinks.end(); it1++) {
                 const NBConnection& c1 = *it1;
                 const int i1 = c1.getTLIndex();
-                if (i1 == NBConnection::InvalidTlIndex || (state[i1] != 'g' && state[i1] != 's') || c1.getFrom() == 0 || c1.getTo() == 0) {
+                if (i1 == NBConnection::InvalidTlIndex || (state[i1] != 'g' && state[i1] != 's') || c1.getFrom() == nullptr || c1.getTo() == nullptr) {
                     continue;
                 }
                 for (NBConnectionVector::const_iterator it2 = myControlledLinks.begin(); it2 != myControlledLinks.end(); it2++) {
@@ -389,7 +396,7 @@ NBLoadedSUMOTLDef::initNeedsContRelation() const {
                     if (i2 != NBConnection::InvalidTlIndex
                             && i2 != i1
                             && (state[i2] == 'G' || state[i2] == 'g')
-                            && c2.getFrom() != 0 && c2.getTo() != 0) {
+                            && c2.getFrom() != nullptr && c2.getTo() != nullptr) {
                         const bool rightTurnConflict = NBNode::rightTurnConflict(
                                                            c1.getFrom(), c1.getTo(), c1.getFromLane(), c2.getFrom(), c2.getTo(), c2.getFromLane());
                         const bool forbidden = forbids(c2.getFrom(), c2.getTo(), c1.getFrom(), c1.getTo(), true, controlledWithin);
@@ -432,16 +439,18 @@ NBLoadedSUMOTLDef::registerModifications(bool addedConnections, bool removedConn
 
 void
 NBLoadedSUMOTLDef::reconstructLogic() {
+    const bool netedit = NBNetBuilder::runningNetedit();
 #ifdef DEBUG_RECONSTRUCTION
     bool debugPrintModified = myReconstructAddedConnections || myReconstructRemovedConnections;
-    std::cout << " reconstructLogic added=" << myReconstructAddedConnections << " removed=" << myReconstructRemovedConnections << " oldLInks\n";
+    std::cout << " reconstructLogic added=" << myReconstructAddedConnections << " removed=" << myReconstructRemovedConnections << " valid=" << hasValidIndices() << " oldLinks:\n";
     for (NBConnectionVector::iterator it = myControlledLinks.begin(); it != myControlledLinks.end(); ++it) {
         std::cout << "    " << *it << "\n";
     }
 #endif
     if (myReconstructAddedConnections) {
         myReconstructAddedConnections = false;
-        if (!myPhasesLoaded) {
+        // do not rebuild the logic when running netedit and all links are already covered by the program
+        if (!myPhasesLoaded && !(netedit && hasValidIndices())) {
             // rebuild the logic from scratch
             // XXX if a connection with the same from- and to-edge already exisits, its states could be copied instead
             NBOwnTLDef dummy(DummyID, myControlledNodes, 0, TLTYPE_STATIC);
@@ -456,11 +465,18 @@ NBLoadedSUMOTLDef::reconstructLogic() {
             }
             delete myTLLogic;
             myTLLogic = newLogic;
-            if (newLogic != 0) {
+            if (newLogic != nullptr) {
                 newLogic->setID(getID());
                 newLogic->setType(getType());
                 newLogic->setOffset(getOffset());
                 setTLControllingInformation();
+                // reset crossing custom indices
+                for (NBNode* n : myControlledNodes) {
+                    for (NBNode::Crossing* c : n->getCrossings()) {
+                        c->customTLIndex = NBConnection::InvalidTlIndex;
+                    }
+                }
+
             }
         } else {
             setTLControllingInformation();
@@ -470,7 +486,7 @@ NBLoadedSUMOTLDef::reconstructLogic() {
         myReconstructRemovedConnections = false;
         // for each connection, check whether it is still valid
         for (NBConnectionVector::iterator it = myControlledLinks.begin(); it != myControlledLinks.end();) {
-            const NBConnection& con = (*it);
+            const NBConnection con = (*it);
             if (// edge still exists
                 find(myIncomingEdges.begin(), myIncomingEdges.end(), con.getFrom()) != myIncomingEdges.end()
                 // connection still exists
@@ -482,24 +498,42 @@ NBLoadedSUMOTLDef::reconstructLogic() {
                 // remove connection
                 const int removed = con.getTLIndex();
                 it = myControlledLinks.erase(it);
-                if (!myPhasesLoaded) {
-                    // shift index off successive connections and remove entry from all phases
-                    for (NBConnectionVector::iterator j = myControlledLinks.begin(); j != myControlledLinks.end(); j++) {
-                        NBConnection& other = *j;
-                        if (other.getTLIndex() > removed) {
-                            other.setTLIndex(other.getTLIndex() - 1);
+                // no automatic modificaions when running netedit
+                if (!myPhasesLoaded && !(netedit && hasValidIndices())) {
+                    // shift index off successive connections and remove entry from all phases if the tlIndex was only used by this connection
+                    bool exclusive = true;
+                    for (NBConnection& other : myControlledLinks) {
+                        if (other != con && other.getTLIndex() == removed) {
+                            exclusive = false;
+                            break;
                         }
                     }
-                    // rebuild the logic
-                    const std::vector<NBTrafficLightLogic::PhaseDefinition> phases = myTLLogic->getPhases();
-                    NBTrafficLightLogic* newLogic = new NBTrafficLightLogic(getID(), getProgramID(), 0, myOffset, myType);
-                    for (std::vector<NBTrafficLightLogic::PhaseDefinition>::const_iterator it = phases.begin(); it != phases.end(); it++) {
-                        std::string newState = it->state;
-                        newState.erase(newState.begin() + removed);
-                        newLogic->addStep(it->duration, newState);
+                    if (exclusive) {
+                        // shift indices above the removed index downward
+                        for (NBConnection& other : myControlledLinks) {
+                            if (other.getTLIndex() > removed) {
+                                other.setTLIndex(other.getTLIndex() - 1);
+                            }
+                        }
+                        // shift crossing custom indices above the removed index downward
+                        for (NBNode* n : myControlledNodes) {
+                            for (NBNode::Crossing* c : n->getCrossings()) {
+                                if (c->customTLIndex > removed) {
+                                    c->customTLIndex--;
+                                }
+                            }
+                        }
+                        // rebuild the logic
+                        const std::vector<NBTrafficLightLogic::PhaseDefinition> phases = myTLLogic->getPhases();
+                        NBTrafficLightLogic* newLogic = new NBTrafficLightLogic(getID(), getProgramID(), 0, myOffset, myType);
+                        for (std::vector<NBTrafficLightLogic::PhaseDefinition>::const_iterator it = phases.begin(); it != phases.end(); it++) {
+                            std::string newState = it->state;
+                            newState.erase(newState.begin() + removed);
+                            newLogic->addStep(it->duration, newState);
+                        }
+                        delete myTLLogic;
+                        myTLLogic = newLogic;
                     }
-                    delete myTLLogic;
-                    myTLLogic = newLogic;
                 }
             }
         }
@@ -515,12 +549,51 @@ NBLoadedSUMOTLDef::reconstructLogic() {
 #endif
 }
 
-bool
-NBLoadedSUMOTLDef::cleanupStates() {
+
+int
+NBLoadedSUMOTLDef::getMaxIndex() {
     int maxIndex = -1;
-    for (NBConnection& c : myControlledLinks) {
+    for (const NBConnection& c : myControlledLinks) {
         maxIndex = MAX2(maxIndex, c.getTLIndex());
     }
+    for (NBNode* n : myControlledNodes) {
+        for (NBNode::Crossing* c : n->getCrossings()) {
+            maxIndex = MAX2(maxIndex, c->tlLinkIndex);
+            maxIndex = MAX2(maxIndex, c->tlLinkIndex2);
+        }
+    }
+    return maxIndex;
+}
+
+
+int
+NBLoadedSUMOTLDef::getMaxValidIndex() {
+    return myTLLogic->getNumLinks() - 1;
+}
+
+
+bool
+NBLoadedSUMOTLDef::hasValidIndices() const {
+    for (const NBConnection& c : myControlledLinks) {
+        if (c.getTLIndex() == NBConnection::InvalidTlIndex) {
+            return false;
+        }
+    }
+    for (NBNode* n : myControlledNodes) {
+        for (NBNode::Crossing* c : n->getCrossings()) {
+            if (c->tlLinkIndex == NBConnection::InvalidTlIndex) {
+                return false;
+            }
+        }
+    }
+    // method getMaxIndex() is const but cannot be declare as such due to inheritance
+    return const_cast<NBLoadedSUMOTLDef*>(this)->getMaxIndex() < myTLLogic->getNumLinks();
+}
+
+
+bool
+NBLoadedSUMOTLDef::cleanupStates() {
+    const int maxIndex = getMaxIndex();
     if (maxIndex >= 0 && maxIndex + 1 < myTLLogic->getNumLinks()) {
         myTLLogic->setStateLength(maxIndex + 1);
         return true;
@@ -528,5 +601,36 @@ NBLoadedSUMOTLDef::cleanupStates() {
     return false;
 }
 
+void
+NBLoadedSUMOTLDef::joinLogic(NBTrafficLightDefinition* def) {
+    def->setParticipantsInformation();
+    def->compute(OptionsCont::getOptions());
+    const int maxIndex = MAX2(getMaxIndex(), def->getMaxIndex());
+    myTLLogic->setStateLength(maxIndex + 1);
+    myControlledLinks.insert(myControlledLinks.end(), def->getControlledLinks().begin(), def->getControlledLinks().end());
+    myOriginalNodes.insert(def->getNodes().begin(), def->getNodes().end());
+}
+
+bool
+NBLoadedSUMOTLDef::usingSignalGroups() const {
+    // count how often each index is used
+    std::map<int, int> indexUsage;
+    for (const NBConnection& c : myControlledLinks) {
+        indexUsage[c.getTLIndex()]++;
+    }
+    for (NBNode* n : myControlledNodes) {
+        for (NBNode::Crossing* c : n->getCrossings()) {
+            indexUsage[c->tlLinkIndex]++;
+            indexUsage[c->tlLinkIndex2]++;
+        }
+    }
+    for (auto it : indexUsage) {
+        if (it.first >= 0 && it.second > 1) {
+            return true;
+        }
+    }
+    return false;
+}
+
 /****************************************************************************/
 
