@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2011-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBLoadedSUMOTLDef.h
 /// @author  Jakob Erdmann
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <string>
@@ -91,8 +85,10 @@ public:
     void replaceRemoved(NBEdge* removed, int removedLane,
                         NBEdge* by, int byLane);
 
-    /// @brief patches signal plans by modifying lane indices
-    void shiftTLConnectionLaneIndex(NBEdge* edge, int offset);
+    /** @brief patches signal plans by modifying lane indices
+     * with the given offset, only indices with a value above threshold are modified
+     */
+    void shiftTLConnectionLaneIndex(NBEdge* edge, int offset, int threshold = -1);
 
     /** @brief Adds a phase to the logic
      * the new phase is inserted at the end of the list of already added phases
@@ -146,6 +142,12 @@ public:
     */
     bool cleanupStates();
 
+    /// @brief whether this definition uses signal group (multiple connections with the same link index)
+    bool usingSignalGroups() const;
+
+    /// @brief join nodes and states from the given logic (append red state)
+    void joinLogic(NBTrafficLightDefinition* def);
+
 protected:
     /** @brief Collects the links participating in this traffic light
      *    (only if not previously loaded)
@@ -167,6 +169,12 @@ protected:
     /* initialize myNeedsContRelation and set myNeedsContRelationReady to true */
     void initNeedsContRelation() const;
 
+    /// @brief return the highest known tls link index used by any controlled connection or crossing
+    int getMaxIndex();
+
+    ///@brief Returns the maximum index controlled by this traffic light
+    int getMaxValidIndex();
+
 private:
 
     /** @brief phases are added directly to myTLLogic which is then returned in myCompute() */
@@ -196,6 +204,9 @@ private:
     /// @brief adapt to removal or addition of connections
     void reconstructLogic();
 
+    /// @brief return whether all tls link indices are valid
+    bool hasValidIndices() const;
+
 private:
     /// @brief class for identifying connections
     class connection_equal {
