@@ -1,23 +1,20 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    NBLoadedTLDef.h
 /// @author  Daniel Krajzewicz
 /// @author  Sascha Krieg
 /// @date    Fri, 29.04.2005
-/// @version $Id: NBLoadedTLDef.h 23150 2017-02-27 12:08:30Z behrisch $
+/// @version $Id$
 ///
 // A loaded (complete) traffic light logic
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 #ifndef NBLoadedTLDef_h
 #define NBLoadedTLDef_h
 
@@ -25,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <string>
@@ -314,6 +307,10 @@ public:
 
     /* initialize myNeedsContRelation and set myNeedsContRelationReady to true */
     void initNeedsContRelation() const;
+
+    ///@brief Returns the maximum index controlled by this traffic light
+    int getMaxIndex();
+
     /// @}
 
 
@@ -328,6 +325,11 @@ protected:
      */
     NBTrafficLightLogic* myCompute(int brakingTimeSeconds);
 
+    /** @brief Builds the list of participating nodes/edges/links
+     * @see NBTrafficLightDefinition::setParticipantsInformation
+     */
+    void setParticipantsInformation();
+
 
     /** @brief Collects the nodes participating in this traffic light
      * @see NBTrafficLightDefinition::collectNodes
