@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBNetBuilder.cpp
 /// @author  Daniel Krajzewicz
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <fstream>
@@ -52,6 +46,7 @@
 #include <utils/geom/GeoConvHelper.h>
 #include "NBAlgorithms.h"
 #include "NBAlgorithms_Ramps.h"
+#include "NBAlgorithms_Railway.h"
 #include "NBHeightMapper.h"
 
 
@@ -60,7 +55,6 @@
 // ===========================================================================
 NBNetBuilder::NBNetBuilder() :
     myEdgeCont(myTypeCont),
-    myHaveLoadedNetworkWithoutInternalEdges(false),
     myNetworkHaveCrossings(false) {
 }
 
@@ -150,6 +144,19 @@ NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurn
         PROGRESS_TIME_MESSAGE(before);
     }
 
+    // analyse and fix railway topology
+    if (oc.exists("railway.topology.all-bidi") && oc.getBool("railway.topology.all-bidi")) {
+        NBTurningDirectionsComputer::computeTurnDirections(myNodeCont, false);
+        NBRailwayTopologyAnalyzer::makeAllBidi(*this);
+    } else if (oc.exists("railway.topology.repair") && oc.getBool("railway.topology.repair")) {
+        NBTurningDirectionsComputer::computeTurnDirections(myNodeCont, false);
+        NBRailwayTopologyAnalyzer::repairTopology(*this);
+    }
+    if (oc.exists("railway.topology.output") && oc.isSet("railway.topology.output")) {
+        NBTurningDirectionsComputer::computeTurnDirections(myNodeCont, false); // recompute after new edges were added
+        NBRailwayTopologyAnalyzer::analyzeTopology(*this);
+    }
+
     if (oc.getBool("junctions.join") || (oc.exists("ramps.guess") && oc.getBool("ramps.guess"))) {
         // preliminary geometry computations to determine the length of edges
         // This depends on turning directions and sorting of edge list
@@ -172,6 +179,7 @@ NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurn
             }
             myNodeCont.addJoinExclusion(nodeIDs);
         }
+        NBNodeTypeComputer::validateRailCrossings(myNodeCont, myTLLCont);
     }
     // join junctions (may create new "geometry"-nodes so it needs to come before removing these
     if (mayAddOrRemove && oc.exists("junctions.join-exclude") && oc.isSet("junctions.join-exclude")) {
@@ -253,15 +261,43 @@ NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurn
     NBTurningDirectionsComputer::computeTurnDirections(myNodeCont);
     PROGRESS_TIME_MESSAGE(before);
     // correct edge geometries to avoid overlap
-    myNodeCont.avoidOverlap();
-    // guess ramps
+    if (oc.exists("geometry.avoid-overlap") && oc.getBool("geometry.avoid-overlap")) {
+        myNodeCont.avoidOverlap();
+    }
+
+    // GUESS TLS POSITIONS
+    before = SysUtils::getCurrentMillis();
+    PROGRESS_BEGIN_MESSAGE("Assigning nodes to traffic lights");
+    if (oc.isSet("tls.set")) {
+        std::vector<std::string> tlControlledNodes = oc.getStringVector("tls.set");
+        TrafficLightType type = SUMOXMLDefinitions::TrafficLightTypes.get(oc.getString("tls.default-type"));
+        for (std::vector<std::string>::const_iterator i = tlControlledNodes.begin(); i != tlControlledNodes.end(); ++i) {
+            NBNode* node = myNodeCont.retrieve(*i);
+            if (node == nullptr) {
+                WRITE_WARNING("Building a tl-logic for junction '" + *i + "' is not possible." + "\n The junction '" + *i + "' is not known.");
+            } else {
+                myNodeCont.setAsTLControlled(node, myTLLCont, type);
+            }
+        }
+    }
+    myNodeCont.guessTLs(oc, myTLLCont);
+    PROGRESS_TIME_MESSAGE(before);
+
+    // guess ramps (after guessing tls because ramps should not be build at traffic lights)
     if (mayAddOrRemove) {
-        if ((oc.exists("ramps.guess") && oc.getBool("ramps.guess")) || (oc.exists("ramps.set") && oc.isSet("ramps.set"))) {
+        const bool modifyRamps = (oc.exists("ramps.guess") && oc.getBool("ramps.guess"))
+                                 || (oc.exists("ramps.set") && oc.isSet("ramps.set"));
+        if (modifyRamps
+                || (oc.exists("ramps.guess-acceleration-lanes") && oc.getBool("ramps.guess-acceleration-lanes"))) {
             before = SysUtils::getCurrentMillis();
-            PROGRESS_BEGIN_MESSAGE("Guessing and setting on-/off-ramps");
+            if (modifyRamps) {
+                PROGRESS_BEGIN_MESSAGE("Guessing and setting on-/off-ramps");
+            }
             NBNodesEdgesSorter::sortNodesEdges(myNodeCont);
             NBRampsComputer::computeRamps(*this, oc);
-            PROGRESS_TIME_MESSAGE(before);
+            if (modifyRamps) {
+                PROGRESS_TIME_MESSAGE(before);
+            }
         }
     }
     // guess sidewalks
@@ -277,8 +313,8 @@ NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurn
     myEdgeCont.recheckPostProcessConnections();
 
     // remap ids if wished
-    int numChangedEdges = myEdgeCont.remapIDs(oc.getBool("numerical-ids"), oc.isSet("reserved-ids"));
-    int numChangedNodes = myNodeCont.remapIDs(oc.getBool("numerical-ids"), oc.isSet("reserved-ids"));
+    int numChangedEdges = myEdgeCont.remapIDs(oc.getBool("numerical-ids"), oc.isSet("reserved-ids"), oc.getString("prefix"), myPTStopCont);
+    int numChangedNodes = myNodeCont.remapIDs(oc.getBool("numerical-ids"), oc.isSet("reserved-ids"), oc.getString("prefix"));
     if (numChangedEdges + numChangedNodes > 0) {
         WRITE_MESSAGE("Remapped " + toString(numChangedEdges) + " edge IDs and " + toString(numChangedNodes) + " node IDs.");
     }
@@ -310,7 +346,7 @@ NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurn
     //
     before = SysUtils::getCurrentMillis();
     PROGRESS_BEGIN_MESSAGE("Computing edge shapes");
-    myEdgeCont.computeEdgeShapes();
+    myEdgeCont.computeEdgeShapes(oc.getBool("geometry.max-grade.fix") ? oc.getFloat("geometry.max-grade") / 100 : -1);
     PROGRESS_TIME_MESSAGE(before);
     // resort edges based on the node and edge shapes
     NBNodesEdgesSorter::sortNodesEdges(myNodeCont, true);
@@ -320,8 +356,8 @@ NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurn
     if (oc.exists("speed.offset")) {
         const double speedOffset = oc.getFloat("speed.offset");
         const double speedFactor = oc.getFloat("speed.factor");
-        if (speedOffset != 0 || speedFactor != 1) {
-            const double speedMin = oc.getFloat("speed.minimum");
+        const double speedMin = oc.getFloat("speed.minimum");
+        if (speedOffset != 0 || speedFactor != 1 || speedMin > 0) {
             before = SysUtils::getCurrentMillis();
             PROGRESS_BEGIN_MESSAGE("Applying speed modifications");
             for (std::map<std::string, NBEdge*>::const_iterator i = myEdgeCont.begin(); i != myEdgeCont.end(); ++i) {
@@ -335,7 +371,7 @@ NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurn
     //
     before = SysUtils::getCurrentMillis();
     PROGRESS_BEGIN_MESSAGE("Computing node types");
-    NBNodeTypeComputer::computeNodeTypes(myNodeCont);
+    NBNodeTypeComputer::computeNodeTypes(myNodeCont, myTLLCont);
     PROGRESS_TIME_MESSAGE(before);
     //
     myNetworkHaveCrossings = oc.getBool("walkingareas");
@@ -357,9 +393,7 @@ NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurn
         }
     }
 
-    if (oc.isDefault("no-internal-links") && !myNetworkHaveCrossings && myHaveLoadedNetworkWithoutInternalEdges) {
-        oc.set("no-internal-links", "true");
-    } else if (!mayAddOrRemove && myNetworkHaveCrossings) {
+    if (!mayAddOrRemove && myNetworkHaveCrossings) {
         // crossings added via netedit
         oc.resetWritable();
         oc.set("no-internal-links", "false");
@@ -376,7 +410,7 @@ NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurn
     myEdgeCont.computeEdge2Edges(oc.getBool("no-left-connections"));
     PROGRESS_TIME_MESSAGE(before);
     //
-    if (mayAddOrRemove && oc.getBool("roundabouts.guess")) {
+    if (oc.getBool("roundabouts.guess")) {
         before = SysUtils::getCurrentMillis();
         PROGRESS_BEGIN_MESSAGE("Guessing and setting roundabouts");
         const int numGuessed = myEdgeCont.guessRoundabouts();
@@ -401,10 +435,15 @@ NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurn
     before = SysUtils::getCurrentMillis();
     PROGRESS_BEGIN_MESSAGE("Processing turnarounds");
     if (!oc.getBool("no-turnarounds")) {
-        myEdgeCont.appendTurnarounds(oc.getBool("no-turnarounds.tls"));
+        myEdgeCont.appendTurnarounds(oc.getBool("no-turnarounds.tls"), oc.getBool("no-turnarounds.except-deadend"));
     } else {
         myEdgeCont.appendTurnarounds(explicitTurnarounds, oc.getBool("no-turnarounds.tls"));
     }
+    if (oc.exists("railway.topology.repair") && oc.getBool("railway.topology.repair")
+            && myPTStopCont.getStops().size() > 0) {
+        // allow direction reversal at all bidi-edges with stops
+        myEdgeCont.appendRailwayTurnarounds(myPTStopCont);
+    }
     PROGRESS_TIME_MESSAGE(before);
     //
     before = SysUtils::getCurrentMillis();
@@ -416,30 +455,19 @@ NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurn
         for (std::map<std::string, NBNode*>::const_iterator i = myNodeCont.begin(); i != myNodeCont.end(); ++i) {
             i->second->buildCrossingsAndWalkingAreas();
         }
-    } else if (oc.getBool("no-internal-links")) {
+    } else {
         for (std::map<std::string, NBNode*>::const_iterator i = myNodeCont.begin(); i != myNodeCont.end(); ++i) {
-            i->second->discardAllCrossings(false);
+            // needed by netedit if the last crossings was deleted from the network
+            // and walkingareas have been invalidated since the last call to compute()
+            i->second->discardWalkingareas();
         }
-    }
-
-    // GUESS TLS POSITIONS
-    before = SysUtils::getCurrentMillis();
-    PROGRESS_BEGIN_MESSAGE("Assigning nodes to traffic lights");
-    if (oc.isSet("tls.set")) {
-        std::vector<std::string> tlControlledNodes = oc.getStringVector("tls.set");
-        TrafficLightType type = SUMOXMLDefinitions::TrafficLightTypes.get(oc.getString("tls.default-type"));
-        for (std::vector<std::string>::const_iterator i = tlControlledNodes.begin(); i != tlControlledNodes.end(); ++i) {
-            NBNode* node = myNodeCont.retrieve(*i);
-            if (node == 0) {
-                WRITE_WARNING("Building a tl-logic for junction '" + *i + "' is not possible." + "\n The junction '" + *i + "' is not known.");
-            } else {
-                myNodeCont.setAsTLControlled(node, myTLLCont, type);
+        if (oc.getBool("no-internal-links")) {
+            for (std::map<std::string, NBNode*>::const_iterator i = myNodeCont.begin(); i != myNodeCont.end(); ++i) {
+                i->second->discardAllCrossings(false);
             }
         }
     }
-    myNodeCont.guessTLs(oc, myTLLCont);
-    PROGRESS_TIME_MESSAGE(before);
-    //
+    // join traffic lights (after building connections)
     if (oc.getBool("tls.join")) {
         before = SysUtils::getCurrentMillis();
         PROGRESS_BEGIN_MESSAGE("Joining traffic light nodes");
@@ -447,7 +475,6 @@ NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurn
         PROGRESS_TIME_MESSAGE(before);
     }
 
-
     // COMPUTING RIGHT-OF-WAY AND TRAFFIC LIGHT PROGRAMS
     //
     before = SysUtils::getCurrentMillis();
@@ -503,6 +530,9 @@ NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurn
         }
         PROGRESS_TIME_MESSAGE(before);
     }
+    // compute lane-to-lane node logics (require traffic lights and inner edges to be done)
+    myNodeCont.computeLogics2(myEdgeCont, oc);
+
     if (lefthand) {
         mirrorX();
     };
@@ -513,7 +543,7 @@ NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurn
         myEdgeCont.checkOverlap(oc.getFloat("geometry.check-overlap"), oc.getFloat("geometry.check-overlap.vertical-threshold"));
         PROGRESS_TIME_MESSAGE(before);
     }
-    if (oc.exists("geometry.max-grade") && oc.getFloat("geometry.max-grade") > 0 && geoConvHelper.getConvBoundary().getZRange() > 0) {
+    if (geoConvHelper.getConvBoundary().getZRange() > 0 && oc.getFloat("geometry.max-grade") > 0) {
         before = SysUtils::getCurrentMillis();
         PROGRESS_BEGIN_MESSAGE("Checking edge grade");
         // user input is in %
@@ -521,14 +551,21 @@ NBNetBuilder::compute(OptionsCont& oc, const std::set<std::string>& explicitTurn
         PROGRESS_TIME_MESSAGE(before);
     }
 
-    //find accesses for pt rail stops
+    //find accesses for pt rail stops and add bidi-stops
     if (oc.exists("ptstop-output") && oc.isSet("ptstop-output")) {
         before = SysUtils::getCurrentMillis();
+        const int numBidiStops = myPTStopCont.generateBidiStops(myEdgeCont);
         PROGRESS_BEGIN_MESSAGE("Find accesses for pt rail stops");
-        double maxRadius = oc.getFloat("osm.stop-output.footway-access-distance");
-        int maxCount = oc.getInt("osm.stop-output.footway-max-accesses");
-        myPTStopCont.findAccessEdgesForRailStops(myEdgeCont, maxRadius, maxCount);
+        double maxRadius = oc.getFloat("railway.access-distance");
+        double accessFactor = oc.getFloat("railway.access-factor");
+        int maxCount = oc.getInt("railway.max-accesses");
+        myPTStopCont.findAccessEdgesForRailStops(myEdgeCont, maxRadius, maxCount, accessFactor);
         PROGRESS_TIME_MESSAGE(before);
+        if (numBidiStops > 0) {
+            if (oc.exists("ptline-output") && oc.isSet("ptline-output")) {
+                myPTLineCont.fixBidiStops(myEdgeCont);
+            }
+        }
     }
 
     // report
@@ -581,7 +618,7 @@ NBNetBuilder::moveToOrigin(GeoConvHelper& geoConvHelper, bool lefthand) {
         (*i).second->reshiftPosition(x, y);
     }
     for (std::map<std::string, NBPTStop*>::const_iterator i = myPTStopCont.begin(); i != myPTStopCont.end(); ++i) {
-        (*i).second->reshiftPostion(x, y);
+        (*i).second->reshiftPosition(x, y);
     }
     geoConvHelper.moveConvertedBy(x, y);
     PROGRESS_TIME_MESSAGE(before);
@@ -606,11 +643,20 @@ NBNetBuilder::mirrorX() {
 bool
 NBNetBuilder::transformCoordinate(Position& from, bool includeInBoundary, GeoConvHelper* from_srs) {
     Position orig(from);
-    bool ok = GeoConvHelper::getProcessing().x2cartesian(from, includeInBoundary);
+    bool ok = true;
+    if (GeoConvHelper::getNumLoaded() > 1
+            && GeoConvHelper::getLoaded().usingGeoProjection()
+            && from_srs != nullptr
+            && from_srs->usingGeoProjection()
+            && *from_srs != GeoConvHelper::getLoaded()) {
+        from_srs->cartesian2geo(from);
+        ok &= GeoConvHelper::getLoaded().x2cartesian(from, false);
+    }
+    ok &= GeoConvHelper::getProcessing().x2cartesian(from, includeInBoundary);
     if (ok) {
         const NBHeightMapper& hm = NBHeightMapper::get();
         if (hm.ready()) {
-            if (from_srs != 0 && from_srs->usingGeoProjection()) {
+            if (from_srs != nullptr && from_srs->usingGeoProjection()) {
                 from_srs->cartesian2geo(orig);
             }
             double z = hm.getZ(orig);
@@ -657,4 +703,11 @@ NBNetBuilder::transformCoordinates(PositionVector& from, bool includeInBoundary,
 }
 
 
+bool
+NBNetBuilder::runningNetedit() {
+    // see GNELoadThread::fillOptions
+    return OptionsCont::getOptions().exists("new");
+}
+
+
 /****************************************************************************/
