@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBNetBuilder.h
 /// @author  Daniel Krajzewicz
@@ -27,11 +25,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <iostream>
@@ -193,11 +187,6 @@ public:
         return myParkingCont;
     }
 
-    /// @brief notify about style of loaded network (Without internal edges
-    void haveLoadedNetworkWithoutInternalEdges() {
-        myHaveLoadedNetworkWithoutInternalEdges = true;
-    }
-
     /// @brief notify about style of loaded network (Without Crossings)
     bool haveNetworkCrossings() {
         return myNetworkHaveCrossings;
@@ -219,6 +208,9 @@ public:
     static bool transformCoordinate(Position& from, bool includeInBoundary = true, GeoConvHelper* from_srs = 0);
     static bool transformCoordinates(PositionVector& from, bool includeInBoundary = true, GeoConvHelper* from_srs = 0);
 
+    /// @brief whether netbuilding takes place in the context of NETEDIT
+    static bool runningNetedit();
+
 
 protected:
     /**
@@ -260,9 +252,6 @@ protected:
 
     NBParkingCont myParkingCont;
 
-    /// @brief whether a .net.xml without internal edges was loaded
-    bool myHaveLoadedNetworkWithoutInternalEdges;
-
     /// @brief flag to indicate that network has crossings
     bool myNetworkHaveCrossings;
 
