@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBNodeShapeComputer.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/geom/PositionVector.h>
 
@@ -59,6 +53,11 @@ public:
     /// Computes the shape of the assigned junction
     PositionVector compute();
 
+    /// @brief get computed radius for node
+    double getRadius() const {
+        return myRadius;
+    }
+
 private:
     typedef std::map<NBEdge*, PositionVector> GeomsMap;
 
@@ -138,16 +137,24 @@ private:
                               double& ccad);
 
     /// @return whether trying to intersect these edges would probably fail
-    bool badIntersection(const NBEdge* e1, const NBEdge* e2,
-                         const PositionVector& e1cw, const PositionVector& e2ccw, double distance);
+    bool badIntersection(const NBEdge* e1, const NBEdge* e2, double distance);
 
     /// @brief return the intersection point closest to the given offset
     double closestIntersection(const PositionVector& geom1, const PositionVector& geom2, double offset);
 
+    /// @brief determine the default radius appropriate for the current junction
+    double getDefaultRadius(const OptionsCont& oc);
+
+    /// @brief compute with of rightmost lanes that exlude the given permissions
+    static double getExtraWidth(const NBEdge* e, SVCPermissions exclude);
+
 private:
     /// The node to compute the geometry for
     const NBNode& myNode;
 
+    /// @brief the computed node radius
+    double myRadius;
+
 private:
     /// @brief Invalidated assignment operator
     NBNodeShapeComputer& operator=(const NBNodeShapeComputer& s);
