@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBOwnTLDef.cpp
 /// @author  Daniel Krajzewicz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <cassert>
@@ -127,7 +121,7 @@ NBOwnTLDef::computeUnblockedWeightedStreamNumber(const NBEdge* const e1, const N
 
 std::pair<NBEdge*, NBEdge*>
 NBOwnTLDef::getBestCombination(const EdgeVector& edges) {
-    std::pair<NBEdge*, NBEdge*> bestPair(static_cast<NBEdge*>(0), static_cast<NBEdge*>(0));
+    std::pair<NBEdge*, NBEdge*> bestPair(static_cast<NBEdge*>(nullptr), static_cast<NBEdge*>(nullptr));
     double bestValue = -1;
     for (EdgeVector::const_iterator i = edges.begin(); i != edges.end(); ++i) {
         for (EdgeVector::const_iterator j = i + 1; j != edges.end(); ++j) {
@@ -156,7 +150,7 @@ std::pair<NBEdge*, NBEdge*>
 NBOwnTLDef::getBestPair(EdgeVector& incoming) {
     if (incoming.size() == 1) {
         // only one there - return the one
-        std::pair<NBEdge*, NBEdge*> ret(*incoming.begin(), static_cast<NBEdge*>(0));
+        std::pair<NBEdge*, NBEdge*> ret(*incoming.begin(), static_cast<NBEdge*>(nullptr));
         incoming.clear();
         return ret;
     }
@@ -204,6 +198,7 @@ NBOwnTLDef::computeLogicAndConts(int brakingTimeSeconds, bool onlyConts) {
     const EdgeVector& incoming = getIncomingEdges();
     EdgeVector fromEdges, toEdges;
     std::vector<bool> isTurnaround;
+    std::vector<bool> hasTurnLane;
     std::vector<int> fromLanes;
     int noLanesAll = 0;
     int noLinksAll = 0;
@@ -214,6 +209,7 @@ NBOwnTLDef::computeLogicAndConts(int brakingTimeSeconds, bool onlyConts) {
             NBEdge* fromEdge = incoming[i1];
             std::vector<NBEdge::Connection> approached = fromEdge->getConnectionsFromLane(i2);
             noLinksAll += (int) approached.size();
+            bool hasStraight = false;
             for (int i3 = 0; i3 < (int)approached.size(); i3++) {
                 if (!fromEdge->mayBeTLSControlled(i2, approached[i3].toEdge, approached[i3].toLane)) {
                     --noLinksAll;
@@ -224,11 +220,17 @@ NBOwnTLDef::computeLogicAndConts(int brakingTimeSeconds, bool onlyConts) {
                 fromEdges.push_back(fromEdge);
                 fromLanes.push_back((int)i2);
                 toEdges.push_back(toEdge);
-                if (toEdge != 0) {
+                if (toEdge != nullptr) {
                     isTurnaround.push_back(fromEdge->isTurningDirectionAt(toEdge));
                 } else {
                     isTurnaround.push_back(true);
                 }
+                if (fromEdge->getToNode()->getDirection(fromEdge, toEdge) == LINKDIR_STRAIGHT) {
+                    hasStraight = true;
+                }
+            }
+            for (int i3 = 0; i3 < (int)approached.size(); i3++) {
+                hasTurnLane.push_back(!hasStraight);
             }
         }
     }
@@ -248,24 +250,31 @@ NBOwnTLDef::computeLogicAndConts(int brakingTimeSeconds, bool onlyConts) {
     EdgeVector toProc = getConnectedOuterEdges(incoming);
     const SUMOTime greenTime = TIME2STEPS(OptionsCont::getOptions().getInt("tls.green.time"));
     const SUMOTime allRedTime = TIME2STEPS(OptionsCont::getOptions().getInt("tls.allred.time"));
+    const double minorLeftSpeedThreshold = OptionsCont::getOptions().getFloat("tls.minor-left.max-speed");
+    const double groupOpposites = OptionsCont::getOptions().getString("tls.layout") == "opposites";
     // build all phases
     std::vector<int> greenPhases; // indices of green phases
     std::vector<bool> hadGreenMajor(noLinksAll, false);
     while (toProc.size() > 0) {
         std::pair<NBEdge*, NBEdge*> chosen;
-        if (incoming.size() == 2) {
-            // if there are only 2 incoming edges we need to decide whether they are a crossing or a "continuation"
-            // @node: this heuristic could be extended to also check the number of outgoing edges
-            double angle = fabs(NBHelpers::relAngle(incoming[0]->getAngleAtNode(incoming[0]->getToNode()), incoming[1]->getAngleAtNode(incoming[1]->getToNode())));
-            // angle would be 180 for straight opposing incoming edges
-            if (angle < 135) {
-                chosen = std::pair<NBEdge*, NBEdge*>(toProc[0], static_cast<NBEdge*>(0));
-                toProc.erase(toProc.begin());
+        if (groupOpposites) {
+            if (incoming.size() == 2) {
+                // if there are only 2 incoming edges we need to decide whether they are a crossing or a "continuation"
+                // @node: this heuristic could be extended to also check the number of outgoing edges
+                double angle = fabs(NBHelpers::relAngle(incoming[0]->getAngleAtNode(incoming[0]->getToNode()), incoming[1]->getAngleAtNode(incoming[1]->getToNode())));
+                // angle would be 180 for straight opposing incoming edges
+                if (angle < 135) {
+                    chosen = std::pair<NBEdge*, NBEdge*>(toProc[0], static_cast<NBEdge*>(nullptr));
+                    toProc.erase(toProc.begin());
+                } else {
+                    chosen = getBestPair(toProc);
+                }
             } else {
                 chosen = getBestPair(toProc);
             }
         } else {
-            chosen = getBestPair(toProc);
+            chosen = std::pair<NBEdge*, NBEdge*>(toProc[0], static_cast<NBEdge*>(nullptr));
+            toProc.erase(toProc.begin());
         }
         int pos = 0;
         std::string state((int) noLinksAll, 'r');
@@ -293,19 +302,21 @@ NBOwnTLDef::computeLogicAndConts(int brakingTimeSeconds, bool onlyConts) {
         //std::cout << " state after plain straight movers=" << state << "\n";
         // correct behaviour for those that are not in chosen, but may drive, though
         state = allowFollowersOfChosen(state, fromEdges, toEdges);
-        for (int i1 = 0; i1 < pos; ++i1) {
-            if (state[i1] == 'G') {
-                continue;
-            }
-            bool isForbidden = false;
-            for (int i2 = 0; i2 < pos && !isForbidden; ++i2) {
-                if (state[i2] == 'G' && !isTurnaround[i2] &&
-                        (forbids(fromEdges[i2], toEdges[i2], fromEdges[i1], toEdges[i1], true) || forbids(fromEdges[i1], toEdges[i1], fromEdges[i2], toEdges[i2], true))) {
-                    isForbidden = true;
+        if (groupOpposites || chosen.first->getToNode()->getType() == NODETYPE_TRAFFIC_LIGHT_RIGHT_ON_RED) {
+            for (int i1 = 0; i1 < pos; ++i1) {
+                if (state[i1] == 'G') {
+                    continue;
+                }
+                bool isForbidden = false;
+                for (int i2 = 0; i2 < pos && !isForbidden; ++i2) {
+                    if (state[i2] == 'G' && !isTurnaround[i2] &&
+                            (forbids(fromEdges[i2], toEdges[i2], fromEdges[i1], toEdges[i1], true) || forbids(fromEdges[i1], toEdges[i1], fromEdges[i2], toEdges[i2], true))) {
+                        isForbidden = true;
+                    }
+                }
+                if (!isForbidden && !hasCrossing(fromEdges[i1], toEdges[i1], crossings)) {
+                    state[i1] = 'G';
                 }
-            }
-            if (!isForbidden && !hasCrossing(fromEdges[i1], toEdges[i1], crossings)) {
-                state[i1] = 'G';
             }
         }
         //std::cout << " state after finding additional 'G's=" << state << "\n";
@@ -319,6 +330,32 @@ NBOwnTLDef::computeLogicAndConts(int brakingTimeSeconds, bool onlyConts) {
             }
         }
         //std::cout << " state after correcting left movers=" << state << "\n";
+
+        std::vector<bool> leftGreen(pos, false);
+        // check whether at least one left-turn lane exist
+        bool foundLeftTurnLane = false;
+        for (int i1 = 0; i1 < pos; ++i1) {
+            if (state[i1] == 'g' && !rightTurnConflicts[i1] && hasTurnLane[i1]) {
+                foundLeftTurnLane = true;
+            }
+        }
+        const bool buildLeftGreenPhase = haveForbiddenLeftMover && !myHaveSinglePhase && leftTurnTime > 0 && foundLeftTurnLane;
+
+        // find indices for exclusive left green phase and apply option minor-left.max-speed
+        for (int i1 = 0; i1 < pos; ++i1) {
+            if (state[i1] == 'g' && !rightTurnConflicts[i1]) {
+                leftGreen[i1] = true;
+                if (fromEdges[i1]->getSpeed() > minorLeftSpeedThreshold) {
+                    if (buildLeftGreenPhase) {
+                        state[i1] = 'r';
+                    } else if (!isTurnaround[i1]) {
+                        WRITE_WARNING("Minor green from edge '" + fromEdges[i1]->getID() + "' to edge '" + toEdges[i1]->getID() + "' exceeds "
+                                      + toString(minorLeftSpeedThreshold) + "m/s. Maybe a left-turn lane is missing.");
+                    }
+                }
+            }
+        }
+
         const std::string vehicleState = state; // backup state before pedestrian modifications
         greenPhases.push_back((int)logic->getPhases().size());
         state = addPedestrianPhases(logic, greenTime, minDur, maxDur, state, crossings, fromEdges, toEdges);
@@ -326,7 +363,6 @@ NBOwnTLDef::computeLogicAndConts(int brakingTimeSeconds, bool onlyConts) {
         for (int i1 = pos; i1 < pos + (int)crossings.size(); ++i1) {
             state[i1] = 'r';
         }
-        const bool buildLeftGreenPhase = haveForbiddenLeftMover && !myHaveSinglePhase && leftTurnTime > 0;
         if (brakingTime > 0) {
             // build yellow (straight)
             for (int i1 = 0; i1 < pos; ++i1) {
@@ -352,7 +388,7 @@ NBOwnTLDef::computeLogicAndConts(int brakingTimeSeconds, bool onlyConts) {
                     state[i1] = 'r';
                     continue;
                 }
-                if (state[i1] == 'g') {
+                if (state[i1] == 'g' || leftGreen[i1]) {
                     state[i1] = 'G';
                 }
             }
@@ -387,6 +423,10 @@ NBOwnTLDef::computeLogicAndConts(int brakingTimeSeconds, bool onlyConts) {
         const SUMOTime redTime = TIME2STEPS(OptionsCont::getOptions().getInt("tls.red.time"));
         logic->addStep(redTime, std::string(noLinksAll, 'r'));
     }
+    // fix states to account for custom crossing link indices
+    if (crossings.size() > 0 && !onlyConts) {
+        checkCustomCrossingIndices(logic);
+    }
 
     SUMOTime totalDuration = logic->getDuration();
     if (OptionsCont::getOptions().isDefault("tls.green.time") || !OptionsCont::getOptions().isDefault("tls.cycle.time")) {
@@ -431,7 +471,7 @@ NBOwnTLDef::computeLogicAndConts(int brakingTimeSeconds, bool onlyConts) {
         return logic;
     } else {
         delete logic;
-        return 0;
+        return nullptr;
     }
 }
 
@@ -459,8 +499,10 @@ std::string
 NBOwnTLDef::addPedestrianPhases(NBTrafficLightLogic* logic, SUMOTime greenTime,
                                 SUMOTime minDur, SUMOTime maxDur,
                                 std::string state, const std::vector<NBNode::Crossing*>& crossings, const EdgeVector& fromEdges, const EdgeVector& toEdges) {
-    const SUMOTime pedClearingTime = TIME2STEPS(5); // compute based on length of the crossing
-    const SUMOTime minPedTime = TIME2STEPS(4); // compute: must be able to reach the middle of the second "Richtungsfahrbahn"
+    // compute based on length of the crossing if not set by the user
+    const SUMOTime pedClearingTime = TIME2STEPS(OptionsCont::getOptions().getInt("tls.crossing-clearance.time"));
+    // compute if not set by user: must be able to reach the middle of the second "Richtungsfahrbahn"
+    const SUMOTime minPedTime = TIME2STEPS(OptionsCont::getOptions().getInt("tls.crossing-min.time"));
     const std::string orig = state;
     state = patchStateForCrossings(state, crossings, fromEdges, toEdges);
     if (orig == state) {
@@ -584,7 +626,7 @@ EdgeVector
 NBOwnTLDef::getConnectedOuterEdges(const EdgeVector& incoming) {
     EdgeVector result = incoming;
     for (EdgeVector::iterator it = result.begin(); it != result.end();) {
-        if ((*it)->getConnections().size() == 0 || (*it)->isInnerEdge()) {
+        if ((*it)->getConnections().size() == 0 || (*it)->isInternal()) {
             it = result.erase(it);
         } else {
             ++it;
@@ -711,7 +753,9 @@ NBOwnTLDef::addPedestrianScramble(NBTrafficLightLogic* logic, int noLinksAll, SU
                     logic->addStep(brakingTime, state);
                 }
             }
-            addPedestrianPhases(logic, TIME2STEPS(10), UNSPECIFIED_DURATION, UNSPECIFIED_DURATION, std::string(noLinksAll, 'r'), crossings, fromEdges, toEdges);
+            const SUMOTime pedClearingTime = TIME2STEPS(OptionsCont::getOptions().getInt("tls.crossing-clearance.time"));
+            const SUMOTime scrambleTime = TIME2STEPS(OptionsCont::getOptions().getInt("tls.scramble.time"));
+            addPedestrianPhases(logic, scrambleTime + pedClearingTime, UNSPECIFIED_DURATION, UNSPECIFIED_DURATION, std::string(noLinksAll, 'r'), crossings, fromEdges, toEdges);
             break;
         }
     }
@@ -732,5 +776,38 @@ NBOwnTLDef::buildAllRedState(SUMOTime allRedTime, NBTrafficLightLogic* logic, co
     }
 }
 
+void
+NBOwnTLDef::checkCustomCrossingIndices(NBTrafficLightLogic* logic) const {
+    int minCustomIndex = -1;
+    int maxCustomIndex = -1;
+    // collect crossings
+    for (std::vector<NBNode*>::const_iterator i = myControlledNodes.begin(); i != myControlledNodes.end(); i++) {
+        const std::vector<NBNode::Crossing*>& c = (*i)->getCrossings();
+        for (auto crossing : c) {
+            minCustomIndex = MIN2(minCustomIndex, crossing->customTLIndex);
+            minCustomIndex = MIN2(minCustomIndex, crossing->customTLIndex2);
+            maxCustomIndex = MAX2(maxCustomIndex, crossing->customTLIndex);
+            maxCustomIndex = MAX2(maxCustomIndex, crossing->customTLIndex2);
+        }
+    }
+    // custom crossing linkIndex could lead to longer states. ensure that every index has a state
+    if (maxCustomIndex >= logic->getNumLinks()) {
+        logic->setStateLength(maxCustomIndex + 1);
+    }
+    // XXX shorter state vectors are possible as well
+    // XXX if the indices are shuffled the guessed crossing states should be shuffled correspondingly
+    // XXX initialize the backward index to the same state as the forward index
+}
 
+
+int
+NBOwnTLDef::getMaxIndex() {
+    setParticipantsInformation();
+    NBTrafficLightLogic* logic = compute(OptionsCont::getOptions());
+    if (logic != nullptr) {
+        return logic->getNumLinks() - 1;
+    } else {
+        return -1;
+    }
+}
 /****************************************************************************/
