@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBPTLine.h
 /// @author  Gregor Laemmel
@@ -36,18 +34,32 @@ class NBEdgeCont;
 class NBPTLine {
 
 public:
-    explicit NBPTLine(const std::string& name, const std::string& type);
+    explicit NBPTLine(const std::string& name, const std::string& type, const std::string& ref, int interval, const std::string& nightService);
 
     void addPTStop(NBPTStop* pStop);
     long long int getLineID() const;
     const std::string& getName() const ;
+
+    const std::string& getType() const {
+        return myType;
+    }
+
     std::vector<NBPTStop*> getStops();
     void write(OutputDevice& device, NBEdgeCont& ec);
     void setId(long long int id);
     void addWayNode(long long int way, long long int node);
-    void setRef(std::string basic_string);
 
     void setMyNumOfStops(int numStops);
+
+    /// @brief get line reference (not unique)
+    const std::string& getRef() const {
+        return myRef;
+    }
+
+    void replaceStops(std::vector<NBPTStop*> stops) {
+        myPTStops = stops;
+    }
+
 private:
     std::string myName;
     std::string myType;
@@ -64,6 +76,8 @@ private:
     std::string myCurrentWay;
     long long int myPTLineId;
     std::string myRef;
+    int myInterval;
+    std::string myNightService;
 
 public:
     void addEdgeVector(std::vector<NBEdge*>::iterator fr, std::vector<NBEdge*>::iterator to);
