@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBPTLineCont.h
 /// @author  Gregor Laemmel
@@ -22,6 +20,7 @@
 
 
 #include <vector>
+#include "utils/vehicle/SUMOAbstractRouter.h"
 #include "NBPTLine.h"
 #include "NBEdgeCont.h"
 
@@ -51,28 +50,35 @@ public:
         return myPTLines.end();
     }
 
+    const std::vector<NBPTLine*>& getLines() const {
+        return myPTLines;
+    }
+
     void process(NBEdgeCont& cont);
 
     /// @brief add edges that must be kept
     void addEdges2Keep(const OptionsCont& oc, std::set<std::string>& into);
 
+    /// @brief select the correct stop on superposed rail edges
+    void fixBidiStops(const NBEdgeCont& ec);
+
     std::set<std::string>& getServedPTStops();
 private:
 
     static const int FWD;
     static const int BWD;
 
-    /// @brief Definition of the map of names to pt lines
-    typedef std::vector<NBPTLine*> PTLinesCont;
-
     /// @brief The map of names to pt lines
-    PTLinesCont myPTLines;
+    std::vector<NBPTLine*> myPTLines;
 
     long long int myIdCnt;
     void reviseStops(NBPTLine* myPTLine, NBEdgeCont& cont);
     void constructRoute(NBPTLine* myPTLine, NBEdgeCont& cont);
 
     std::set<std::string> myServedPTStops;
+
+    static double getCost(const NBEdgeCont& ec, SUMOAbstractRouter<NBEdge, NBVehicle>& router,
+                          const NBPTStop* from, const NBPTStop* to, const NBVehicle* veh);
 };
 
 
