@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBPTPlatform.h
 /// @author  Gregor Laemmel
@@ -23,15 +21,14 @@
 
 #include <utils/geom/Position.h>
 class NBPTPlatform {
-
 public:
     NBPTPlatform(Position position, double d);
+public:
+    const Position& getPos() const;
+    void reshiftPosition(const double offsetX, const double offsetY);
+    double getLength() const;
 private:
     Position myPos;
-public:
-    Position* getMyPos();
-    double getMyLength() const;
-private:
     double myLength;
 };
 
