@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBPTStopCont.cpp
 /// @author  Gregor Laemmel
@@ -112,16 +110,65 @@ void NBPTStopCont::assignLanes(NBEdgeCont& cont) {
 }
 
 
+int
+NBPTStopCont::generateBidiStops(NBEdgeCont& ec) {
+    //scnd pass set correct lane
+    std::vector<NBPTStop*> toAdd;
+    for (auto i = myPTStops.begin(); i != myPTStops.end(); i++) {
+        NBPTStop* stop = i->second;
+        NBEdge* edge = ec.getByID(stop->getEdgeId());
+        if (edge != nullptr && edge->isBidiRail()) {
+            NBEdge* bidiEdge = edge->getTurnDestination(true);
+            assert(bidiEdge != 0);
+            const std::string id = getReverseID(stop->getID());
+            if (myPTStops.count(id) > 0) {
+                if (myPTStops[id]->getEdgeId() != bidiEdge->getID()) {
+                    WRITE_WARNING("Could not create reverse-direction stop for superposed edge '" + bidiEdge->getID()
+                                  + "' (origStop '" + i->first + "'). Stop id '" + id
+                                  + "' already in use by stop on edge '" + myPTStops[id]->getEdgeId() + "'.");
+                }
+                continue;
+            }
+            NBPTStop* bidiStop = new NBPTStop(id,
+                                              stop->getPosition(),
+                                              bidiEdge->getID(),
+                                              stop->getOrigEdgeId(),
+                                              stop->getLength(),
+                                              stop->getName(),
+                                              stop->getPermissions());
+            if (bidiStop->findLaneAndComputeBusStopExtend(ec)) {
+                toAdd.push_back(bidiStop);
+                stop->setBidiStop(bidiStop);
+                bidiStop->setBidiStop(stop);
+            } else {
+                // should not happen
+                assert(false);
+            }
+        }
+    }
+    for (NBPTStop* newStop : toAdd) {
+        myPTStops[newStop->getID()] = newStop;
+    }
+    if (toAdd.size() > 0) {
+        WRITE_MESSAGE("Added " + toString(toAdd.size()) + " stops for superposed rail edges.");
+    }
+    return (int)toAdd.size();
+}
+
+
 NBPTStop*
 NBPTStopCont::getReverseStop(NBPTStop* pStop, NBEdgeCont& cont) {
     std::string edgeId = pStop->getEdgeId();
     NBEdge* edge = cont.getByID(edgeId);
     NBEdge* reverse = NBPTStopCont::getReverseEdge(edge);
     if (reverse != nullptr) {
-        Position* pos = new Position(pStop->getPosition());
-        NBPTStop* ret = new NBPTStop("-" + pStop->getID(), *pos, reverse->getID(), reverse->getID(),
-                                     pStop->getLength(), pStop->getName(), pStop->getPermissions());
-        return ret;
+        const std::string reverseID = getReverseID(pStop->getID());
+        if (myPTStops.count(reverseID) == 0) {
+            return new NBPTStop(reverseID, pStop->getPosition(), reverse->getID(), reverse->getID(),
+                                pStop->getLength(), pStop->getName(), pStop->getPermissions());
+        } else {
+            return myPTStops[reverseID];
+        }
     }
     return nullptr;
 }
@@ -131,35 +178,30 @@ NBPTStop*
 NBPTStopCont::assignAndCreatNewPTStopAsNeeded(NBPTStop* pStop, NBEdgeCont& cont) {
     std::string edgeId = pStop->getEdgeId();
     NBEdge* edge = cont.getByID(edgeId);
-
-
     bool rightOfEdge = false;
     bool leftOfEdge = false;
-    NBPTPlatform* left = nullptr;
-    for (auto it = pStop->getPlatformCands().begin(); it != pStop->getPlatformCands().end(); it++) {
-        NBPTPlatform* platform = &(*it);
-        double crossProd = computeCrossProductEdgePosition(edge, platform->getMyPos());
-
+    const NBPTPlatform* left = nullptr;
+    for (const NBPTPlatform& platform : pStop->getPlatformCands()) {
+        double crossProd = computeCrossProductEdgePosition(edge, platform.getPos());
         //TODO consider driving on the left!!! [GL May '17]
         if (crossProd > 0) {
             leftOfEdge = true;
-            left = platform;
+            left = &platform;
         } else {
             rightOfEdge = true;
-            pStop->setMyPTStopLength(platform->getMyLength());
+            pStop->setMyPTStopLength(platform.getLength());
         }
-
     }
 
     if (leftOfEdge && rightOfEdge) {
         NBPTStop* leftStop = getReverseStop(pStop, cont);
-        leftStop->setMyPTStopLength(left->getMyLength());
+        leftStop->setMyPTStopLength(left->getLength());
         return leftStop;
     } else if (leftOfEdge) {
         NBEdge* reverse = getReverseEdge(edge);
         if (reverse != nullptr) {
             pStop->setEdgeId(reverse->getID(), cont);
-            pStop->setMyPTStopLength(left->getMyLength());
+            pStop->setMyPTStopLength(left->getLength());
         }
     }
 
@@ -172,15 +214,15 @@ NBPTStopCont::assignPTStopToEdgeOfClosestPlatform(NBPTStop* pStop, NBEdgeCont& c
     std::string edgeId = pStop->getEdgeId();
     NBEdge* edge = cont.getByID(edgeId);
     NBEdge* reverse = NBPTStopCont::getReverseEdge(edge);
-    NBPTPlatform* closestPlatform = getClosestPlatformToPTStopPosition(pStop);
-    pStop->setMyPTStopLength(closestPlatform->getMyLength());
+    const NBPTPlatform* closestPlatform = getClosestPlatformToPTStopPosition(pStop);
+    pStop->setMyPTStopLength(closestPlatform->getLength());
     if (reverse != nullptr) {
 
         //TODO make isLeft in PositionVector static [GL May '17]
 //        if (PositionVector::isLeft(edge->getFromNode()->getPosition(),edge->getToNode()->getPosition(),closestPlatform)){
 //
 //        }
-        double crossProd = computeCrossProductEdgePosition(edge, closestPlatform->getMyPos());
+        double crossProd = computeCrossProductEdgePosition(edge, closestPlatform->getPos());
 
         //TODO consider driving on the left!!! [GL May '17]
         if (crossProd > 0) { //pt stop is on the left of the orig edge
@@ -191,10 +233,10 @@ NBPTStopCont::assignPTStopToEdgeOfClosestPlatform(NBPTStop* pStop, NBEdgeCont& c
 
 
 double
-NBPTStopCont::computeCrossProductEdgePosition(const NBEdge* edge, const Position* closestPlatform) const {
+NBPTStopCont::computeCrossProductEdgePosition(const NBEdge* edge, const Position& closestPlatform) const {
     PositionVector geom = edge->getGeometry();
-    int idxTmp = geom.indexOfClosest(*closestPlatform);
-    double offset = geom.nearest_offset_to_point2D(*closestPlatform, true);
+    int idxTmp = geom.indexOfClosest(closestPlatform);
+    double offset = geom.nearest_offset_to_point2D(closestPlatform, true);
     double offset2 = geom.offsetAtIndex2D(idxTmp);
     int idx1, idx2;
     if (offset2 < offset) {
@@ -215,27 +257,23 @@ NBPTStopCont::computeCrossProductEdgePosition(const NBEdge* edge, const Position
     double y0 = p1.y();
     double x1 = p2.x();
     double y1 = p2.y();
-    double x2 = closestPlatform->x();
-    double y2 = closestPlatform->y();
+    double x2 = closestPlatform.x();
+    double y2 = closestPlatform.y();
     double crossProd = (x1 - x0) * (y2 - y0) - (y1 - y0) * (x2 - x0);
     return crossProd;
 }
 
 
-NBPTPlatform*
+const NBPTPlatform*
 NBPTStopCont::getClosestPlatformToPTStopPosition(NBPTStop* pStop) {
     Position stopPosition = pStop->getPosition();
-    NBPTPlatform* closest = nullptr;
+    const NBPTPlatform* closest = nullptr;
     double minSqrDist = std::numeric_limits<double>::max();
-
-    for (auto it = pStop->getPlatformCands().begin();
-            it != pStop->getPlatformCands().end();
-            it++) {
-        NBPTPlatform platform = *it;
-        double sqrDist = stopPosition.distanceSquaredTo2D(*platform.getMyPos());
+    for (const NBPTPlatform& platform : pStop->getPlatformCands()) {
+        double sqrDist = stopPosition.distanceSquaredTo2D(platform.getPos());
         if (sqrDist < minSqrDist) {
             minSqrDist = sqrDist;
-            closest = &(*it);
+            closest = &platform;
         }
     }
     return closest;
@@ -254,12 +292,12 @@ NBPTStopCont::getReverseEdge(NBEdge* edge) {
             }
         }
     }
-    return 0;
+    return nullptr;
 }
 
 
 void
-NBPTStopCont::reviseStops(NBEdgeCont& cont) {
+NBPTStopCont::cleanupDeleted(NBEdgeCont& cont) {
     for (auto i = myPTStops.begin(); i != myPTStops.end();) {
         if (cont.getByID((*i).second->getEdgeId()) == nullptr) {
             WRITE_WARNING("Removing pt stop:" + (*i).first + " on non existing edge: " + (*i).second->getEdgeId());
@@ -293,27 +331,29 @@ NBPTStopCont::postprocess(std::set<std::string>& usedStops) {
     }
 }
 
+std::string
+NBPTStopCont::getReverseID(const std::string& id) {
+    return id.size() > 0 && id[0] == '-' ? id.substr(1) : "-" + id;
+}
 
 void
 NBPTStopCont::alignIdSigns() {
-    for (auto& i : myPTStops) {
+    PTStopsCont stops = myPTStops;
+    for (auto& i : stops) {
         const std::string& stopId = i.second->getID();
         const char edgeSign = i.second->getEdgeId().at(0);
         const char stopSign = stopId.at(0);
         if (edgeSign != stopSign && (edgeSign == '-' || stopSign == '-')) {
-            if (edgeSign == '-') {
-                i.second->setMyPTStopId("-" + stopId);
-            } else {
-                i.second->setMyPTStopId(stopId.substr(1, stopId.length()));
-            }
-            // TODO the map should be modified as well to hold the correct id
+            i.second->setMyPTStopId(getReverseID(stopId));
+            myPTStops.erase(stopId);
+            myPTStops[i.second->getID()] = i.second;
         }
     }
 }
 
 
 void
-NBPTStopCont::findAccessEdgesForRailStops(NBEdgeCont& cont, double maxRadius, int maxCount) {
+NBPTStopCont::findAccessEdgesForRailStops(NBEdgeCont& cont, double maxRadius, int maxCount, double accessFactor) {
     NamedRTree r;
     for (auto edge : cont) {
         const Boundary& bound = edge.second->getGeometry().getBoxBoundary();
@@ -325,7 +365,8 @@ NBPTStopCont::findAccessEdgesForRailStops(NBEdgeCont& cont, double maxRadius, in
         const std::string& stopEdgeID = ptStop.second->getEdgeId();
         NBEdge* stopEdge = cont.getByID(stopEdgeID);
         //std::cout << "findAccessEdgesForRailStops edge=" << stopEdgeID << " exists=" << (stopEdge != 0) << "\n";
-        if (stopEdge != 0 && isRailway(stopEdge->getPermissions())) {
+        if (stopEdge != nullptr && (stopEdge->getPermissions() & SVC_PEDESTRIAN) == 0) {
+            //if (stopEdge != 0 && isRailway(stopEdge->getPermissions())) {
             std::set<std::string> ids;
             Named::StoringVisitor visitor(ids);
             const Position& pos = ptStop.second->getPosition();
@@ -338,7 +379,7 @@ NBPTStopCont::findAccessEdgesForRailStops(NBEdgeCont& cont, double maxRadius, in
                 edgCants.push_back(e);
             }
             std::sort(edgCants.begin(), edgCants.end(), [pos](NBEdge * a, NBEdge * b) {
-                return a->getGeometry().distance2D(pos, false) < b->getGeometry().distance2D(pos, false);
+                return a->getLaneShape(0).distance2D(pos, false) < b->getLaneShape(0).distance2D(pos, false);
             });
             int cnt = 0;
             for (auto edge : edgCants) {
@@ -348,7 +389,8 @@ NBPTStopCont::findAccessEdgesForRailStops(NBEdgeCont& cont, double maxRadius, in
                         double offset = lane.shape.nearest_offset_to_point2D(pos, false);
                         double finalLength = edge->getFinalLength();
                         double laneLength = lane.shape.length();
-                        ptStop.second->addAccess(edge->getLaneID(laneIdx), offset * finalLength / laneLength);
+                        double accessLength = pos.distanceTo2D(lane.shape.positionAtOffset2D(offset)) * accessFactor;
+                        ptStop.second->addAccess(edge->getLaneID(laneIdx), offset * finalLength / laneLength, accessLength);
                         cnt++;
                         break;
                     }
