@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBPTStopCont.h
 /// @author  Gregor Laemmel
@@ -54,7 +52,6 @@ public:
         return myPTStops.begin();
     }
 
-
     /** @brief Returns the pointer to the end of the stored pt stops
      * @return The iterator to the end of stored pt stops
      */
@@ -62,17 +59,25 @@ public:
         return myPTStops.end();
     }
 
-    /** @brief revise pt stops and remove stops on non existing (removed) edges
+    const std::map<std::string, NBPTStop*>& getStops() const {
+        return myPTStops;
+    }
+
+
+    /** @brief remove stops on non existing (removed) edges
      *
      * @param cont
      */
-    void reviseStops(NBEdgeCont& cont);
+    void cleanupDeleted(NBEdgeCont& cont);
 
     void assignLanes(NBEdgeCont& cont);
 
+    /// @brief duplicate stops for superposed rail edges and return the number of generated stops
+    int generateBidiStops(NBEdgeCont& cont);
+
     void localizePTStops(NBEdgeCont& cont);
 
-    void findAccessEdgesForRailStops(NBEdgeCont& cont, double d, int i);
+    void findAccessEdgesForRailStops(NBEdgeCont& cont, double maxRadius, int maxCount, double accessFactor);
 
     void postprocess(std::set<std::string>& usedStops);
 
@@ -90,9 +95,11 @@ private:
 
 
     void assignPTStopToEdgeOfClosestPlatform(NBPTStop* pStop, NBEdgeCont& cont);
-    NBPTPlatform* getClosestPlatformToPTStopPosition(NBPTStop* pStop);
+    const NBPTPlatform* getClosestPlatformToPTStopPosition(NBPTStop* pStop);
     NBPTStop* assignAndCreatNewPTStopAsNeeded(NBPTStop* pStop, NBEdgeCont& cont);
-    double computeCrossProductEdgePosition(const NBEdge* edge, const Position* closestPlatform) const;
+    double computeCrossProductEdgePosition(const NBEdge* edge, const Position& closestPlatform) const;
+
+    static std::string getReverseID(const std::string& id);
 
 public:
     static NBEdge* getReverseEdge(NBEdge* edge);
