@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBRequest.h
 /// @author  Daniel Krajzewicz
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <vector>
@@ -76,14 +70,13 @@ public:
               const EdgeVector& outgoing,
               const NBConnectionProhibits& loadedProhibits);
 
-    /** destructor */
+    /// @brief destructor
     ~NBRequest();
 
-    /** builds the bitset-representation of the logic */
+    /// @brief builds the bitset-representation of the logic
     void buildBitfieldLogic();
 
-    /** @brief returns the number of the junction's lanes and the number
-        of the junction's links in respect. @note: only connected lanes are counted */
+    /// @brief @brief returns the number of the junction's lanes and the number of the junction's links in respect. @note: only connected lanes are counted
     std::pair<int, int> getSizes() const;
 
     /** @brief Returns the information whether "prohibited" flow must let "prohibitor" flow pass
@@ -138,19 +131,27 @@ public:
                  const NBEdge* const possProhibitedFrom, const NBEdge* const possProhibitedTo,
                  bool regardNonSignalisedLowerPriority) const;
 
-    /** writes the XML-representation of the logic as a bitset-logic
-        XML representation */
-    void writeLogic(std::string key, OutputDevice& into, const bool checkLaneFoes) const;
+    /// @brief writes the XML-representation of the logic as a bitset-logic XML representation
+    void computeLogic(const bool checkLaneFoes);
 
-    /// prints the request
+    void writeLogic(OutputDevice& into) const;
+
+    const std::string& getFoes(int linkIndex) const;
+    const std::string& getResponse(int linkIndex) const;
+
+    /// @brief prints the request
     friend std::ostream& operator<<(std::ostream& os, const NBRequest& r);
 
-    /// reports warnings if any occured
+    /// @brief reports warnings if any occurred
     static void reportWarnings();
 
     /// @brief whether multple connections from the same edge target the same lane
-    static bool mergeConflict(const NBEdge* from, const NBEdge::Connection& con,
-                              const NBEdge* prohibitorFrom,  const NBEdge::Connection& prohibitorCon, bool foes);
+    bool mergeConflict(const NBEdge* from, const NBEdge::Connection& con,
+                       const NBEdge* prohibitorFrom,  const NBEdge::Connection& prohibitorCon, bool foes) const;
+
+    /// @brief whether opposite left turns intersect
+    bool oppositeLeftTurnConflict(const NBEdge* from, const NBEdge::Connection& con,
+                                  const NBEdge* prohibitorFrom,  const NBEdge::Connection& prohibitorCon, bool foes) const;
 
 
 private:
@@ -158,14 +159,13 @@ private:
         from2->to2 (is higher priorised than this) */
     void setBlocking(NBEdge* from1, NBEdge* to1, NBEdge* from2, NBEdge* to2);
 
-    /** @brief writes the response of a certain lane
+    /** @brief computes the response of a certain lane
         Returns the next link index within the junction */
-    int writeLaneResponse(OutputDevice& od, NBEdge* from, int lane,
-                          int pos, const bool checkLaneFoes) const;
+    int computeLaneResponse(NBEdge* from, int lane, int pos, const bool checkLaneFoes);
 
-    /** @brief writes the response of a certain crossing
+    /** @brief computes the response of a certain crossing
         Returns the next link index within the junction */
-    int writeCrossingResponse(OutputDevice& od, const NBNode::Crossing& crossing, int pos) const;
+    int computeCrossingResponse(const NBNode::Crossing& crossing, int pos);
 
     /** @brief Writes the response of a certain link
      *
@@ -186,8 +186,7 @@ private:
      * @return the response string
      * @exception IOError not yet implemented
      */
-    std::string getResponseString(int tlIndex, const NBEdge* const from, const NBEdge* const to,
-                                  int fromLane, int toLane, bool mayDefinitelyPass, const bool checkLaneFoes) const;
+    std::string getResponseString(const NBEdge* const from, const NBEdge::Connection& c, const bool checkLaneFoes) const;
 
 
     /** writes which participating links are foes to the given */
@@ -206,73 +205,73 @@ private:
     int getIndex(const NBEdge* const from, const NBEdge* const to) const;
 
 
-    /** returns the distance between the incoming (from) and the outgoing (to)
-        edge clockwise in edges */
+    /// @brief returns the distance between the incoming (from) and the outgoing (to) edge clockwise in edges
     int distanceCounterClockwise(NBEdge* from, NBEdge* to);
 
-    /** computes the relationships between links outgoing right of the given
-        link */
+    /// @brief computes the relationships between links outgoing right of the given link */
     void computeRightOutgoingLinkCrossings(NBEdge* from, NBEdge* to);
 
-    /** computes the relationships between links outgoing left of the given
-        link */
+    /// @brief computes the relationships between links outgoing left of the given link
     void computeLeftOutgoingLinkCrossings(NBEdge* from, NBEdge* to);
 
 
     void resetSignalised();
 
-
     /// @brief reset foes it the number of lanes matches (or exceeds) the number of incoming connections for an edge
     void resetCooperating();
 
+    /// @brief whether the given connections must be checked for lane conflicts due to the vClasses involved
+    bool checkLaneFoesByClass(const NBEdge::Connection& con,
+                              const NBEdge* prohibitorFrom,  const NBEdge::Connection& prohibitorCon) const;
+
+    /// @brief whether the given connections must be checked for lane conflicts due to disjunct target lanes
+    bool checkLaneFoesByCooperation(const NBEdge* from, const NBEdge::Connection& con, 
+            const NBEdge* prohibitorFrom,  const NBEdge::Connection& prohibitorCon) const;
+
     /** @brief return whether the given laneToLane connections prohibit each other
      * under the assumption that the edge2edge connections are in conflict
      */
     bool laneConflict(const NBEdge* from, const NBEdge* to, int toLane, const NBEdge* prohibitorFrom, const NBEdge* prohibitorTo, int prohibitorToLane) const;
 
+
     /// @brief return to total number of edge-to-edge connections of this request-logic
     inline int numLinks() const;
 
-
 private:
-    /// the node the request is assigned to
+    /// @brief the node the request is assigned to
     NBNode* myJunction;
 
-    /** all (icoming and outgoing) of the junctions edges */
+    /// @brief all (icoming and outgoing) of the junctions edges
     const EdgeVector& myAll;
 
-    /** edges incoming to the junction */
+    /// @brief edges incoming to the junction
     const EdgeVector& myIncoming;
 
-    /** edges outgoing from the junction */
+    /// @brief edges outgoing from the junction
     const EdgeVector& myOutgoing;
 
-    /** edges outgoing from the junction */
-    std::vector<NBNode::Crossing*> myCrossings;
-
-    /** definition of a container to store boolean informations about a link
-        into */
+    /// @brief definition of a container to store boolean informations about a link into
     typedef std::vector<bool> LinkInfoCont;
 
-    /** definition of a container for link(edge->edge) X link(edge->edge)
-        combinations (size = |myIncoming|*|myOutgoing|) */
+    /// @brief definition of a container for link(edge->edge) X link(edge->edge) combinations (size = |myIncoming|*|myOutgoing|)
     typedef std::vector<LinkInfoCont> CombinationsCont;
 
-    /** a container for approached lanes of a certain edge */
-    typedef std::map<NBEdge*, LaneVector> OccupiedLanes;
-
-    /** the link X link blockings */
+    /// @brief the link X link blockings
     CombinationsCont  myForbids;
 
-    /** the link X link is done-checks */
+    /// @brief the link X link is done-checks
     CombinationsCont  myDone;
 
+    /// @brief precomputed right-of-way matrices for each lane-to-lane link
+    std::vector<std::string> myFoes;
+    std::vector<std::string> myResponse;
+    std::vector<bool> myHaveVia;
+
 private:
     static int myGoodBuilds, myNotBuild;
 
-private:
     /// @brief Invalidated assignment operator
-    NBRequest& operator=(const NBRequest& s);
+    NBRequest& operator=(const NBRequest& s) = delete;
 };
 
 #endif
