@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NBTrafficLightDefinition.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <string>
@@ -285,9 +279,10 @@ public:
                                 NBEdge* by, int byLane) = 0;
 
     /// @brief patches (loaded) signal plans by modifying lane indices
-    virtual void shiftTLConnectionLaneIndex(NBEdge* edge, int offset) {
+    virtual void shiftTLConnectionLaneIndex(NBEdge* edge, int offset, int threshold = -1) {
         UNUSED_PARAMETER(edge);
         UNUSED_PARAMETER(offset);
+        UNUSED_PARAMETER(threshold);
     }
 
     /** @brief Returns the list of incoming edges (must be build first)
@@ -347,7 +342,7 @@ public:
      */
     bool needsCont(const NBEdge* fromE, const NBEdge* toE, const NBEdge* otherFromE, const NBEdge* otherToE) const;
 
-    /// @brief whether the given index must yield to the foeIndex while turing right on a red light
+    /// @brief whether the given index must yield to the foeIndex while turning right on a red light
     virtual bool rightOnRedConflict(int index, int foeIndex) const;
 
     /* initialize myNeedsContRelation and set myNeedsContRelationReady to true
@@ -355,6 +350,30 @@ public:
      * subclasses instantiate a private instance of NBOwnTLDef to answer this query */
     virtual void initNeedsContRelation() const;
 
+    ///@brief Returns the maximum index controlled by this traffic light and assigned to a connection
+    virtual int getMaxIndex() = 0;
+
+    ///@brief Returns the maximum index controlled by this traffic light
+    virtual int getMaxValidIndex() {
+        return getMaxIndex();
+    }
+
+    /** @brief Computes the time vehicles may need to brake
+     *
+     * This time depends on the maximum speed allowed on incoming junctions.
+     * It is computed as max_speed_allowed / minimum_vehicle_decleration
+     */
+    int computeBrakingTime(double minDecel) const;
+
+    /// @brief whether this definition uses signal group (multiple connections with the same link index)
+    virtual bool usingSignalGroups() const {
+        return false;
+    };
+
+    /// @brief get ID and programID together (for convenient debugging)
+    std::string getDescription() const;
+
+
 protected:
     /// @brief id for temporary definitions
     static const std::string DummyID;
@@ -377,14 +396,6 @@ protected:
     virtual void collectEdges();
 
 
-    /** @brief Computes the time vehicles may need to brake
-     *
-     * This time depends on the maximum speed allowed on incoming junctions.
-     * It is computed as max_speed_allowed / minimum_vehicle_decleration
-     */
-    int computeBrakingTime(double minDecel) const;
-
-
     // @return whether this traffic light is invalid and should be computed
     virtual bool amInvalid() const;
 
