@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GNEApplicationWindow.h
 /// @author  Jakob Erdmann
@@ -23,23 +21,17 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
-#include <string>
-#include <vector>
-#include <iostream>
-#include <fx.h>
-#include <utils/foxtools/MFXEventQue.h>
+#include <utils/common/SUMOTime.h>
 #include <utils/foxtools/FXThreadEvent.h>
+#include <utils/foxtools/MFXEventQue.h>
 #include <utils/foxtools/MFXInterThreadEventClient.h>
-#include <utils/shapes/ShapeHandler.h>
-#include <utils/gui/windows/GUIMainWindow.h>
-#include <utils/gui/windows/GUISUMOAbstractView.h>
+#include <utils/geom/Position.h>
 #include <utils/gui/div/GUIMessageWindow.h>
+#include <utils/gui/windows/GUIMainWindow.h>
+#include <utils/shapes/ShapeHandler.h>
+
 
 // ===========================================================================
 // class declarations
@@ -49,8 +41,6 @@ class GNEUndoList;
 class GNENet;
 class GNEViewNet;
 class GUIEvent;
-class GUIParameterTracker;
-class GUIParameterTableWindow;
 
 
 // ===========================================================================
@@ -131,16 +121,28 @@ public:
     /// @brief set shapes file
     void setShapesFile(const std::string& shapesFile);
 
+    /// @brief set TLS Programs file
+    void setTLSProgramsFile(const std::string& TLSProgramsFile);
+
     /// @brief enable save additionals
     void enableSaveAdditionalsMenu();
 
+    /// @brief disable save additionals
+    void disableSaveAdditionalsMenu();
+
     /// @brief enable save shapes
     void enableSaveShapesMenu();
 
+    /// @brief disable save shapes
+    void disableSaveShapesMenu();
+
+    /// @brief enable save TLS Programs
+    void enableSaveTLSProgramsMenu();
+
     /// @name Inter-thread event handling
     /// @{
-    /// @brief called when an event occured
-    virtual void eventOccured();
+    /// @brief called when an event occurred
+    virtual void eventOccurred();
 
     /// @brief handle event of type Network loaded
     void handleEvent_NetworkLoaded(GUIEvent* e);
@@ -169,6 +171,9 @@ public:
     /// @brief called when the command/FXCall open additionals is executed
     long onCmdOpenAdditionals(FXObject*, FXSelector, void*);
 
+    /// @brief called when the command/FXCall open additionals is executed
+    long onCmdOpenTLSPrograms(FXObject*, FXSelector, void*);
+
     /// @brief called when the command/FXCall reload is executed
     long onCmdReload(FXObject*, FXSelector, void*);
 
@@ -178,6 +183,12 @@ public:
     /// @brief called when the command/FXCall close is executed
     long onCmdClose(FXObject*, FXSelector, void*);
 
+    /// @brief Called on menu Edit->Visualization
+    long onCmdEditViewScheme(FXObject*, FXSelector, void*);
+
+    /// @brief Called on menu Edit->Viewport
+    long onCmdEditViewport(FXObject*, FXSelector, void*);
+
     /// @brief called when the command/FXCall locate is executed
     long onCmdLocate(FXObject*, FXSelector, void*);
 
@@ -190,6 +201,12 @@ public:
     /// @brief called when the command/FXCall save additionals as is executed
     long onCmdSaveAdditionalsAs(FXObject*, FXSelector, void*);
 
+    /// @brief called when the command/FXCall save TLSPrograms is executed
+    long onCmdSaveTLSPrograms(FXObject*, FXSelector, void*);
+
+    /// @brief called when the command/FXCall save TLSPrograms as is executed
+    long onCmdSaveTLSProgramsAs(FXObject*, FXSelector, void*);
+
     /// @brief called when the update/FXCall save network is executed
     long onUpdSaveNetwork(FXObject*, FXSelector, void*);
 
@@ -255,6 +272,9 @@ public:
     /// @brief called if the user hits an edit-mode hotkey
     long onCmdSetMode(FXObject* sender, FXSelector sel, void* ptr);
 
+    /// @brief called if the user hints ctrl + T
+    long onCmdOpenSUMOGUI(FXObject* sender, FXSelector sel, void* ptr);
+
     /// @brief called if the user hits esc
     long onCmdAbort(FXObject* sender, FXSelector sel, void* ptr);
 
@@ -267,8 +287,8 @@ public:
     /// @brief called if the user hits f
     long onCmdFocusFrame(FXObject* sender, FXSelector sel, void* ptr);
 
-    /// @brief called if the user press key v to open zoom editor
-    long onCmdEditViewport(FXObject*, FXSelector, void*);
+    /// @brief called if the user press key combination Ctrl + G to toogle grid
+    long onCmdToogleGrid(FXObject*, FXSelector, void*);
 
     /// @brief called if the user selects help->Documentation
     long onCmdHelp(FXObject* sender, FXSelector sel, void* ptr);
@@ -330,6 +350,9 @@ protected:
 
     /// @brief the submenus
     FXMenuPane* myFileMenu,
+                *myFileMenuShapes,
+                *myFileMenuAdditionals,
+                *myFileMenuTLS,
                 *myEditMenu,
                 *myProcessingMenu,
                 *myLocatorMenu,
@@ -389,13 +412,25 @@ protected:
     /// @brief filename for load/save shapes
     std::string myShapesFile;
 
+    /// @brief filename for load/save TLS Programs
+    std::string myTLSProgramsFile;
+
 private:
     /// @brief FXMenuCommand for enable or disable save additionals
     FXMenuCommand* mySaveAdditionalsMenuCommand;
 
+    /// @brief FXMenuCommand for enable or disable save additionals As
+    FXMenuCommand* mySaveAdditionalsMenuCommandAs;
+
     /// @brief FXMenuCommand for enable or disable save shapes
     FXMenuCommand* mySaveShapesMenuCommand;
 
+    /// @brief FXMenuCommand for enable or disable save shapes
+    FXMenuCommand* mySaveShapesMenuCommandAs;
+
+    /// @brief FXMenuCommand for enable or disable save additionals
+    FXMenuCommand* mySaveTLSProgramsMenuCommand;
+
     /// @brief starts to load a netimport configuration or a network */
     void loadConfigOrNet(const std::string file, bool isNet, bool isReload = false, bool useStartupOptions = false, bool newNet = false);
 
