@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GNELoadThread.cpp
 /// @author  Jakob Erdmann
@@ -22,37 +20,22 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
-#include <config.h>
-#endif
-
-#include <iostream>
-#include <ctime>
-#include <utils/xml/XMLSubSys.h>
-#include <utils/gui/events/GUIEvent_Message.h>
-#include <utils/gui/windows/GUIAppEnum.h>
-#include <utils/gui/globjects/GUIGlObjectStorage.h>
-#include <utils/common/RandHelper.h>
-#include <utils/common/UtilExceptions.h>
-#include <utils/common/MsgHandler.h>
-#include <utils/common/MsgRetrievingFunction.h>
-#include <utils/common/SystemFrame.h>
-#include <utils/options/OptionsCont.h>
-#include <utils/options/Option.h>
-#include <utils/options/OptionsIO.h>
-#include <utils/geom/GeoConvHelper.h>
 #include <netbuild/NBFrame.h>
-#include <netimport/NILoader.h>
+#include <netbuild/NBNetBuilder.h>
 #include <netimport/NIFrame.h>
+#include <netimport/NILoader.h>
 #include <netwrite/NWFrame.h>
-#include <netbuild/NBFrame.h>
+#include <utils/common/MsgRetrievingFunction.h>
+#include <utils/common/RandHelper.h>
+#include <utils/common/SystemFrame.h>
+#include <utils/gui/events/GUIEvent_Message.h>
+#include <utils/options/OptionsCont.h>
+#include <utils/options/OptionsIO.h>
+#include <utils/xml/XMLSubSys.h>
 
+#include "GNEEvent_NetworkLoaded.h"
 #include "GNELoadThread.h"
 #include "GNENet.h"
-#include "GNEEvent_NetworkLoaded.h"
-#include "GNEAdditionalHandler.h"
 
 
 // ===========================================================================
@@ -61,6 +44,8 @@
 GNELoadThread::GNELoadThread(FXApp* app, MFXInterThreadEventClient* mw, MFXEventQue<GUIEvent*>& eq, FXEX::FXThreadEvent& ev) :
     FXSingleEventThread(app, mw), myParent(mw), myEventQue(eq),
     myEventThrow(ev) {
+    myDebugRetriever = new MsgRetrievingFunction<GNELoadThread>(this, &GNELoadThread::retrieveMessage, MsgHandler::MT_DEBUG);
+    myGLDebugRetriever = new MsgRetrievingFunction<GNELoadThread>(this, &GNELoadThread::retrieveMessage, MsgHandler::MT_GLDEBUG);
     myErrorRetriever = new MsgRetrievingFunction<GNELoadThread>(this, &GNELoadThread::retrieveMessage, MsgHandler::MT_ERROR);
     myMessageRetriever = new MsgRetrievingFunction<GNELoadThread>(this, &GNELoadThread::retrieveMessage, MsgHandler::MT_MESSAGE);
     myWarningRetriever = new MsgRetrievingFunction<GNELoadThread>(this, &GNELoadThread::retrieveMessage, MsgHandler::MT_WARNING);
@@ -69,6 +54,8 @@ GNELoadThread::GNELoadThread(FXApp* app, MFXInterThreadEventClient* mw, MFXEvent
 
 
 GNELoadThread::~GNELoadThread() {
+    delete myDebugRetriever;
+    delete myGLDebugRetriever;
     delete myErrorRetriever;
     delete myMessageRetriever;
     delete myWarningRetriever;
@@ -79,17 +66,21 @@ FXint
 GNELoadThread::run() {
     // register message callbacks
     MsgHandler::getMessageInstance()->addRetriever(myMessageRetriever);
+    MsgHandler::getDebugInstance()->addRetriever(myDebugRetriever);
+    MsgHandler::getGLDebugInstance()->addRetriever(myGLDebugRetriever);
     MsgHandler::getErrorInstance()->addRetriever(myErrorRetriever);
     MsgHandler::getWarningInstance()->addRetriever(myWarningRetriever);
 
-    GNENet* net = 0;
+    GNENet* net = nullptr;
 
     // try to load the given configuration
     OptionsCont& oc = OptionsCont::getOptions();
-    oc.clear();
-    if (!initOptions()) {
-        submitEndAndCleanup(net);
-        return 0;
+    if (myFile != "" || oc.getString("sumo-net-file") != "") {
+        oc.clear();
+        if (!initOptions()) {
+            submitEndAndCleanup(net);
+            return 0;
+        }
     }
     MsgHandler::initOutputOptions();
     if (!(NIFrame::checkOptions() &&
@@ -101,6 +92,8 @@ GNELoadThread::run() {
         submitEndAndCleanup(net);
         return 0;
     }
+    MsgHandler::getGLDebugInstance()->clear();
+    MsgHandler::getDebugInstance()->clear();
     MsgHandler::getErrorInstance()->clear();
     MsgHandler::getWarningInstance()->clear();
     MsgHandler::getMessageInstance()->clear();
@@ -112,6 +105,10 @@ GNELoadThread::run() {
         return 0;
     }
     XMLSubSys::setValidation(oc.getString("xml-validation"), oc.getString("xml-validation.net"));
+    // check if Debug has to be enabled
+    MsgHandler::enableDebugMessages(oc.getBool("gui-testing-debug"));
+    // check if GL Debug has to be enabled
+    MsgHandler::enableDebugGLMessages(oc.getBool("gui-testing-debug-gl"));
     // this netbuilder instance becomes the responsibility of the GNENet
     NBNetBuilder* netBuilder = new NBNetBuilder();
 
@@ -139,7 +136,7 @@ GNELoadThread::run() {
                 MsgHandler::getErrorInstance()->clear();
             }
 
-            // check whether any errors occured
+            // check whether any errors occurred
             if (MsgHandler::getErrorInstance()->wasInformed()) {
                 throw ProcessError();
             } else {
@@ -149,6 +146,13 @@ GNELoadThread::run() {
                     net->computeAndUpdate(oc, false);
                 }
             }
+            if (myFile == "") {
+                if (oc.isSet("configuration-file")) {
+                    myFile = oc.getString("configuration-file");
+                } else if (oc.isSet("sumo-net-file")) {
+                    myFile = oc.getString("sumo-net-file");
+                }
+            }
 
         } catch (ProcessError& e) {
             if (std::string(e.what()) != std::string("Process Error") && std::string(e.what()) != std::string("")) {
@@ -157,7 +161,7 @@ GNELoadThread::run() {
             WRITE_ERROR("Failed to build network.");
             delete net;
             delete netBuilder;
-            net = 0;
+            net = nullptr;
         } catch (std::exception& e) {
             WRITE_ERROR(e.what());
 #ifdef _DEBUG
@@ -165,7 +169,7 @@ GNELoadThread::run() {
 #endif
             delete net;
             delete netBuilder;
-            net = 0;
+            net = nullptr;
         }
     }
     // only a single setting file is supported
@@ -178,6 +182,8 @@ GNELoadThread::run() {
 void
 GNELoadThread::submitEndAndCleanup(GNENet* net, const std::string& guiSettingsFile, const bool viewportFromRegistry) {
     // remove message callbacks
+    MsgHandler::getDebugInstance()->removeRetriever(myDebugRetriever);
+    MsgHandler::getGLDebugInstance()->removeRetriever(myGLDebugRetriever);
     MsgHandler::getErrorInstance()->removeRetriever(myErrorRetriever);
     MsgHandler::getWarningInstance()->removeRetriever(myWarningRetriever);
     MsgHandler::getMessageInstance()->removeRetriever(myMessageRetriever);
@@ -191,35 +197,44 @@ GNELoadThread::submitEndAndCleanup(GNENet* net, const std::string& guiSettingsFi
 void
 GNELoadThread::fillOptions(OptionsCont& oc) {
     oc.clear();
-    oc.addCallExample("", "start plain GUI with empty net");
+    oc.addCallExample("--new", "start plain GUI with empty net");
+    oc.addCallExample("-s <SUMO_NET>", "edit SUMO network");
     oc.addCallExample("-c <CONFIGURATION>", "edit net with options read from file");
 
     SystemFrame::addConfigurationOptions(oc); // this subtopic is filled here, too
     oc.addOptionSubTopic("Input");
     oc.addOptionSubTopic("Output");
     GeoConvHelper::addProjectionOptions(oc);
+    oc.addOptionSubTopic("Processing");
+    oc.addOptionSubTopic("Building Defaults");
     oc.addOptionSubTopic("TLS Building");
     oc.addOptionSubTopic("Ramp Guessing");
     oc.addOptionSubTopic("Edge Removal");
     oc.addOptionSubTopic("Unregulated Nodes");
-    oc.addOptionSubTopic("Processing");
-    oc.addOptionSubTopic("Building Defaults");
+    oc.addOptionSubTopic("Junctions");
+    oc.addOptionSubTopic("Pedestrian");
+    oc.addOptionSubTopic("Railway");
+    oc.addOptionSubTopic("Formats");
+    oc.addOptionSubTopic("Netedit");
     oc.addOptionSubTopic("Visualisation");
 
     oc.doRegister("new", new Option_Bool(false)); // !!!
     oc.addDescription("new", "Input", "Start with a new network");
 
-    oc.doRegister("sumo-additionals-file", new Option_String());
-    oc.addDescription("sumo-additionals-file", "Input", "file in which additionals are loaded");
+    oc.doRegister("sumo-additionals-file", 'a', new Option_String());
+    oc.addDescription("sumo-additionals-file", "Netedit", "file in which additionals are loaded");
 
     oc.doRegister("additionals-output", new Option_String());
-    oc.addDescription("additionals-output", "Output", "file in which additionals must be saved");
+    oc.addDescription("additionals-output", "Netedit", "file in which additionals must be saved");
 
     oc.doRegister("sumo-shapes-file", new Option_String());
-    oc.addDescription("sumo-shapes-file", "Input", "file in which shapes are loaded");
+    oc.addDescription("sumo-shapes-file", "Netedit", "file in which shapes are loaded");
 
     oc.doRegister("shapes-output", new Option_String());
-    oc.addDescription("shapes-output", "Output", "file in which shapes must be saved");
+    oc.addDescription("shapes-output", "Netedit", "file in which shapes must be saved");
+
+    oc.doRegister("TLSPrograms-output", new Option_String());
+    oc.addDescription("TLSPrograms-output", "Netedit", "file in which TLS Programs must be saved");
 
     oc.doRegister("disable-laneIcons", new Option_Bool(false));
     oc.addDescription("disable-laneIcons", "Visualisation", "Disable icons of special lanes");
@@ -227,7 +242,7 @@ GNELoadThread::fillOptions(OptionsCont& oc) {
     oc.doRegister("disable-textures", 'T', new Option_Bool(false)); // !!!
     oc.addDescription("disable-textures", "Visualisation", "");
 
-    oc.doRegister("gui-settings-file", new Option_FileName());
+    oc.doRegister("gui-settings-file", 'g', new Option_FileName());
     oc.addDescription("gui-settings-file", "Visualisation", "Load visualisation settings from FILE");
 
     oc.doRegister("registry-viewport", new Option_Bool(false));
@@ -240,11 +255,14 @@ GNELoadThread::fillOptions(OptionsCont& oc) {
     oc.addDescription("window-pos", "Visualisation", "Create initial window at the given x,y position");
 
     oc.doRegister("gui-testing", new Option_Bool(false));
-    oc.addDescription("gui-testing", "Visualisation", "Enable ovelay for screen recognition");
+    oc.addDescription("gui-testing", "Visualisation", "Enable overlay for screen recognition");
 
     oc.doRegister("gui-testing-debug", new Option_Bool(false));
     oc.addDescription("gui-testing-debug", "Visualisation", "Enable output messages during GUI-Testing");
 
+    oc.doRegister("gui-testing-debug-gl", new Option_Bool(false));
+    oc.addDescription("gui-testing-debug-gl", "Visualisation", "Enable output messages during GUI-Testing specific of gl functions");
+
     SystemFrame::addReportOptions(oc); // this subtopic is filled here, too
 
     NIFrame::fillOptions();
@@ -264,7 +282,9 @@ GNELoadThread::setDefaultOptions(OptionsCont& oc) {
 bool
 GNELoadThread::initOptions() {
     OptionsCont& oc = OptionsCont::getOptions();
+    // fill all optiones
     fillOptions(oc);
+    // set manually the net file
     if (myFile != "") {
         if (myLoadNet) {
             oc.set("sumo-net-file", myFile);
@@ -272,9 +292,14 @@ GNELoadThread::initOptions() {
             oc.set("configuration-file", myFile);
         }
     }
+    // set default options defined in GNELoadThread::setDefaultOptions(...)
     setDefaultOptions(oc);
     try {
+        // set all values writables, because certain attributes already setted can be updated throught console
+        oc.resetWritable();
+        // load options from console
         OptionsIO::getOptions();
+        // if output file wasn't defined in the command line manually, set value of "sumo-net-file"
         if (!oc.isSet("output-file")) {
             oc.set("output-file", oc.getString("sumo-net-file"));
         }
@@ -284,8 +309,8 @@ GNELoadThread::initOptions() {
             WRITE_ERROR(e.what());
         }
         WRITE_ERROR("Failed to parse options.");
+        return false;
     }
-    return false;
 }
 
 
@@ -294,7 +319,7 @@ GNELoadThread::loadConfigOrNet(const std::string& file, bool isNet, bool useStar
     myFile = file;
     myLoadNet = isNet;
     if (myFile != "" && !useStartupOptions) {
-        OptionsIO::setArgs(0, 0);
+        OptionsIO::setArgs(0, nullptr);
     }
     myNewNet = newNet;
     start();
