@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GNELoadThread.h
 /// @author  Jakob Erdmann
@@ -24,23 +22,17 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
-#include <utils/common/SUMOTime.h>
-#include <utils/foxtools/FXSingleEventThread.h>
-#include <utils/foxtools/FXThreadEvent.h>
-#include <utils/foxtools/MFXEventQue.h>
 #include <utils/common/MsgHandler.h>
+#include <utils/foxtools/FXSingleEventThread.h>
+#include <utils/foxtools/MFXEventQue.h>
+#include <utils/foxtools/MFXInterThreadEventClient.h>
 
 
 // ===========================================================================
 // class declarations
 // ===========================================================================
-class MFXInterThreadEventClient;
 class GNENet;
 class GUIEvent;
 
@@ -94,11 +86,11 @@ protected:
     /// @brief the parent window to inform about the loading
     MFXInterThreadEventClient* myParent;
 
-    /// @brief the path to load the simulation from
+    /// @brief the path to load the network from
     std::string myFile;
 
     /// @brief @brief The instances of message retriever encapsulations Needed to be deleted from the handler later on
-    OutputDevice* myErrorRetriever, *myMessageRetriever, *myWarningRetriever;
+    OutputDevice* myErrorRetriever, *myMessageRetriever, *myWarningRetriever, *myDebugRetriever, *myGLDebugRetriever;
 
     /// @brief event Queue
     MFXEventQue<GUIEvent*>& myEventQue;
