@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GNENet.h
 /// @author  Jakob Erdmann
@@ -32,41 +30,31 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
-#include <string>
-#include <utility>
-#include <utils/gui/globjects/GLIncludes.h>
-#include <netbuild/NBNetBuilder.h>
-#include <utils/geom/Boundary.h>
-#include <utils/geom/Position.h>
+#include <fx.h>
 #include <foreign/rtree/SUMORTree.h>
-#include <utils/gui/globjects/GUIGlObjectStorage.h>
-#include <utils/gui/globjects/GUIGLObjectPopupMenu.h>
+#include <netbuild/NBTrafficLightLogicCont.h>
+#include <netedit/changes/GNEChange.h>
+#include <utils/common/IDSupplier.h>
+#include <utils/common/SUMOVehicleClass.h>
+#include <utils/geom/Boundary.h>
+#include <utils/geom/PositionVector.h>
 #include <utils/gui/globjects/GUIGlObject.h>
 #include <utils/gui/globjects/GUIShapeContainer.h>
-#include <utils/common/StringUtils.h>
-#include <utils/common/RGBColor.h>
-#include <utils/common/IDSupplier.h>
-#include <utils/options/OptionsCont.h>
-#include <utils/iodevices/OutputDevice.h>
-#include "GNEChange.h"
+#include <utils/gui/settings/GUIVisualizationSettings.h>
+#include <utils/shapes/ShapeContainer.h>
+#include <utils/xml/SUMOXMLDefinitions.h>
 
 
 // ===========================================================================
 // class declarations
 // ===========================================================================
 
+class NBNetBuilder;
 class GNEAdditional;
 class GNEApplicationWindow;
 class GNEAttributeCarrier;
-class GNECalibratorFlow;
-class GNECalibratorRoute;
-class GNECalibratorVehicleType;
 class GNEConnection;
 class GNECrossing;
 class GNEEdge;
@@ -74,9 +62,7 @@ class GNEJunction;
 class GNELane;
 class GNENetElement;
 class GNEPOI;
-class GNEPOILane;
 class GNEPoly;
-class GNERerouterInterval;
 class GNEShape;
 class GNEUndoList;
 class GNEViewNet;
@@ -101,21 +87,6 @@ class GNENet : public GUIGlObject, public ShapeContainer {
     friend class GNEChange_Additional;
 
 public:
-    /// @name color of selected objects
-    /// @{
-    /// @brief color of selection
-    static const RGBColor selectionColor;
-
-    /// @brief color of selected lane
-    static const RGBColor selectedLaneColor;
-
-    /// @brief color of selected connection
-    static const RGBColor selectedConnectionColor;
-
-    /// @brief color of selected additionals
-    static const RGBColor selectedAdditionalColor;
-    /// @}
-
     /**@brief Constructor
      * @param[in] netbuilder the netbuilder which may already have been filled
      * GNENet becomes responsible for cleaning this up
@@ -172,14 +143,16 @@ public:
     * @param[in] layer The layer of the polygon
     * @param[in] angle The rotation of the polygon
     * @param[in] imgFile The raster image of the polygon
+    * @param[in] relativePath set image file as relative path
     * @param[in] shape The shape of the polygon
     * @param[in] geo specify if shape was loaded as GEO coordinate
     * @param[in] fill Whether the polygon shall be filled
+    * @param[in] lineWidth The widht for drawing unfiled polygon
     * @return whether the polygon could be added
     */
     bool addPolygon(const std::string& id, const std::string& type, const RGBColor& color, double layer,
-                    double angle, const std::string& imgFile, const PositionVector& shape, bool fill,
-                    bool geo, bool ignorePruning = false);
+                    double angle, const std::string& imgFile, bool relativePath, const PositionVector& shape, 
+                    bool geo, bool fill, double lineWidth, bool ignorePruning = false);
 
     /**@brief Builds a POI using the given values and adds it to the container
     * @param[in] id The name of the POI
@@ -193,13 +166,14 @@ public:
     * @param[in] layer The layer of the POI
     * @param[in] angle The rotation of the POI
     * @param[in] imgFile The raster image of the POI
+    * @param[in] relativePath set image file as relative path
     * @param[in] width The width of the POI image
     * @param[in] height The height of the POI image
     * @return whether the poi could be added
     */
     bool addPOI(const std::string& id, const std::string& type, const RGBColor& color, const Position& pos, bool geo,
                 const std::string& lane, double posOverLane, double posLat, double layer, double angle,
-                const std::string& imgFile, double width, double height, bool ignorePruning = false);
+                const std::string& imgFile, bool relativePath, double width, double height, bool ignorePruning = false);
     /// @}
 
     /// @brief returns the bounder of the network
@@ -231,10 +205,12 @@ public:
      * @param[in] suggestedName
      * @param[in] wasSplit Whether the edge was created from a split
      * @param[in] allowDuplicateGeom Whether to create the edge even though another edge with the same geometry exists
+     * @param[in] recomputeConnections Whether connections on the affected junctions must be recomputed
      * @return The newly created edge or 0 if no edge was created
      */
     GNEEdge* createEdge(GNEJunction* src, GNEJunction* dest, GNEEdge* tpl, GNEUndoList* undoList,
-                        const std::string& suggestedName = "", bool wasSplit = false, bool allowDuplicateGeom = false);
+                        const std::string& suggestedName = "", bool wasSplit = false, bool allowDuplicateGeom = false,
+                        bool recomputeConnections = true);
 
     /**@brief removes junction and all incident edges
      * @param[in] junction The junction to be removed
@@ -246,7 +222,7 @@ public:
      * @param[in] edge The edge to be removed
      * @param[in] undoList The undolist in which to mark changes
      */
-    void deleteEdge(GNEEdge* edge, GNEUndoList* undoList);
+    void deleteEdge(GNEEdge* edge, GNEUndoList* undoList, bool recomputeConnections);
 
     /**@brief replaces edge
      * @param[in] which The edge to be replaced
@@ -259,7 +235,7 @@ public:
      * @param[in] lane The lane to be removed
      * @param[in] undoList The undolist in which to mark changes
      */
-    void deleteLane(GNELane* lane, GNEUndoList* undoList);
+    void deleteLane(GNELane* lane, GNEUndoList* undoList, bool recomputeConnections);
 
     /**@brief remove connection
      * @param[in] connection The connection to be removed
@@ -283,7 +259,7 @@ public:
      * @param[in] lane The lane to be duplicated
      * @param[in] undoList The undolist in which to mark changes
      */
-    void duplicateLane(GNELane* lane, GNEUndoList* undoList);
+    void duplicateLane(GNELane* lane, GNEUndoList* undoList, bool recomputeConnections);
 
     /**@brief transform lane to restricted lane
      * @param[in] vclass vehicle class to restrict
@@ -297,7 +273,7 @@ public:
      * @param[in] edge The edge in which insert restricted lane
      * @param[in] undoList The undolist in which to mark changes
      */
-    bool addSRestrictedLane(SUMOVehicleClass vclass, GNEEdge& edge, GNEUndoList* undoList);
+    bool addRestrictedLane(SUMOVehicleClass vclass, GNEEdge& edge, int index, GNEUndoList* undoList);
 
     /**@brief remove restricted lane
      * @param[in] vclass vehicle class to restrict
@@ -314,10 +290,11 @@ public:
     GNEJunction* splitEdge(GNEEdge* edge, const Position& pos, GNEUndoList* undoList, GNEJunction* newJunction = 0);
 
     /**@brief split all edges at position by inserting one new junction
-     * @param[in] edges The edges to be split
+     * @param[in] edge The edge to be split
+     * @param[in] oppositeEdge The oppositeEdge to be split
      * @param[in] pos The position on which to insert the new junction
      */
-    void splitEdgesBidi(const std::set<GNEEdge*>& edges, const Position& pos, GNEUndoList* undoList);
+    void splitEdgesBidi(GNEEdge* edge, GNEEdge* oppositeEdge, const Position& pos, GNEUndoList* undoList);
 
     /**@brief reverse edge
      * @param[in] edge The edge to be reversed
@@ -373,12 +350,29 @@ public:
     */
     GNEPOI* retrievePOI(const std::string& id, bool failHard = true) const;
 
-    /**@brief get POILane by id
-    * @param[in] id The id of the desired POILane
-    * @param[in] failHard Whether attempts to retrieve a nonexisting POILane should result in an exception
+    /**@brief get Connection by id
+    * @param[in] id The id of the desired Connection
+    * @param[in] failHard Whether attempts to retrieve a nonexisting Connection should result in an exception
     * @throws UnknownElement
     */
-    GNEPOILane* retrievePOILane(const std::string& id, bool failHard = true) const;
+    GNEConnection* retrieveConnection(const std::string& id, bool failHard = true) const;
+
+    /**@brief return all connections
+    * @param[in] onlySelected Whether to return only selected connections
+    */
+    std::vector<GNEConnection*> retrieveConnections(bool onlySelected = false) const;
+
+    /**@brief get Crossing by id
+    * @param[in] id The id of the desired Crossing
+    * @param[in] failHard Whether attempts to retrieve a nonexisting Crossing should result in an exception
+    * @throws UnknownElement
+    */
+    GNECrossing* retrieveCrossing(const std::string& id, bool failHard = true) const;
+
+    /**@brief return all crossings
+    * @param[in] onlySelected Whether to return only selected crossings
+    */
+    std::vector<GNECrossing*> retrieveCrossings(bool onlySelected = false) const;
 
     /**@brief get a single attribute carrier based on a GLID
     * @param[in] ids the GL IDs for which to retrive the AC
@@ -387,12 +381,10 @@ public:
     */
     GNEAttributeCarrier* retrieveAttributeCarrier(const GUIGlID id, bool failHard = true);
 
-    /**@brief get the attribute carriers based on GlIDs
-     * @param[in] ids The set of ids for which to retrive the ACs
-     * @param[in] type The GUI-type of the objects with the given ids.
-     * @throws InvalidArgument if any given id does not match the declared type
+    /**@brief get the attribute carriers based on Type
+     * @param[in] type The GUI-type of the AC. SUMO_TAG_NOTHING returns all elements (Warning: bottleneck)
      */
-    std::vector<GNEAttributeCarrier*> retrieveAttributeCarriers(const std::set<GUIGlID>& ids, GUIGlObjectType type);
+    std::vector<GNEAttributeCarrier*> retrieveAttributeCarriers(SumoXMLTag type = SUMO_TAG_NOTHING);
 
     /**@brief return all edges
      * @param[in] onlySelected Whether to return only selected edges
@@ -417,11 +409,22 @@ public:
     */
     std::vector<GNEJunction*> retrieveJunctions(bool onlySelected = false);
 
-    /**@brief return all shapes
-    * @param[in] shapeTag Type of shape. SUMO_TAG_NOTHING returns all shapes
+    /**@brief return shape by type shapes
+    * @param[in] shapeTag Type of shape.
     * @param[in] onlySelected Whether to return only selected junctions
     */
-    std::vector<GNEShape*> retrieveShapes(SumoXMLTag shapeTag = SUMO_TAG_NOTHING, bool onlySelected = false);
+    std::vector<GNEShape*> retrieveShapes(SumoXMLTag shapeTag, bool onlySelected = false);
+
+    /**@brief return all shapes
+    * @param[in] onlySelected Whether to return only selected junctions
+    */
+    std::vector<GNEShape*> retrieveShapes(bool onlySelected = false);
+
+    /// @brief inform that net has to be saved
+    void requiereSaveNet(bool value);
+
+    /// @brief return if net has to be saved
+    bool isNetSaved() const;
 
     /**@brief save the network
      * @param[in] oc The OptionsCont which knows how and where to save
@@ -441,11 +444,11 @@ public:
     /// @brief Set the viewNet to be notified of network changes
     void setViewNet(GNEViewNet* viewNet);
 
-    /// @brief refreshes boundary information for o and update
-    void refreshElement(GUIGlObject* o);
+    /// @brief add GL Object into net
+    void addGLObjectIntoGrid(GUIGlObject* o);
 
-    /// @brief generate an ID for vaporizers
-    std::string generateVaporizerID() const;
+    /// @brief add GL Object into net
+    void removeGLObjectFromGrid(GUIGlObject* o);
 
     /// @brief updates the map and reserves new id
     void renameEdge(GNEEdge* edge, const std::string& newID);
@@ -459,13 +462,14 @@ public:
     /// @brief get view net
     GNEViewNet* getViewNet() const;
 
+    /// @brief get all selected attribute carriers
+    std::vector<GNEAttributeCarrier*> getSelectedAttributeCarriers();
+
     /// @brief returns the tllcont of the underlying netbuilder
     NBTrafficLightLogicCont& getTLLogicCont();
 
-    /**@brief get ids of currently active objects
-     * @param[in] type If type != GLO_MAX, get active ids of that type, otherwise get all active ids
-     */
-    std::set<GUIGlID> getGlIDs(GUIGlObjectType type = GLO_MAX);
+    /// @brief returns the NBEdgeCont of the underlying netbuilder
+    NBEdgeCont& getEdgeCont();
 
     /// @brief initialize GNEConnections
     void initGNEConnections();
@@ -499,6 +503,9 @@ public:
     /// @brief replace the selected junction by geometry node(s) and merge the edges
     void replaceJunctionByGeometry(GNEJunction* junction, GNEUndoList* undoList);
 
+    /// @brief replace the selected junction by a list of junctions for each unique edge endpoint
+    void splitJunction(GNEJunction* junction, GNEUndoList* undoList);
+
     /// @brief clear junction's connections
     void clearJunctionConnections(GNEJunction* junction, GNEUndoList* undoList);
 
@@ -532,34 +539,22 @@ public:
     /// @{
 
     /**@brief Returns the named additional
+     * @param[in] type tag with the type of additional
      * @param[in] id The id of the additional to return.
      * @param[in] failHard Whether attempts to retrieve a nonexisting additional should result in an exception
      */
-    GNEAdditional* retrieveAdditional(const std::string& id, bool hardFail = true) const;
+    GNEAdditional* retrieveAdditional(SumoXMLTag type, const std::string& id, bool hardFail = true) const;
 
     /**@brief return all additionals
      * @param[in] onlySelected Whether to return only selected additionals
      */
-    std::vector<GNEAdditional*> retrieveAdditionals(bool onlySelected = false);
+    std::vector<GNEAdditional*> retrieveAdditionals(bool onlySelected = false) const;
 
-    /**@brief Returns the named additional
-     * @param[in] type tag with the type of additional
-     * @param[in] id The id of the additional to return.
-     * @return The named additional, or 0 if don't exists
-     */
-    GNEAdditional* getAdditional(SumoXMLTag type, const std::string& id) const;
-
-    /**@brief get vector with additionals
+    /**@brief get map with IDs and pointers to additionals
      * @param[in] type type of additional to get. SUMO_TAG_NOTHING will get all additionals
-     * @return vector with pointers to additionals.
+     * @return map with IDs and pointers to additionals.
      */
-    std::vector<GNEAdditional*> getAdditionals(SumoXMLTag type = SUMO_TAG_NOTHING) const;
-
-    /* @brief retrieve Rerouter Interval
-     * @param rerouterIntervalID ID of rerouter interval
-     * @param rerouter interval if was found, or NULL in other case
-     */
-    GNERerouterInterval* getRerouterInterval(const std::string& rerouterIntervalID) const;
+    const std::map<std::string, GNEAdditional*>& getAdditionalByType(SumoXMLTag type) const;
 
     /**@brief Returns the number of additionals of the net
      * @param[in] type type of additional to count. SUMO_TAG_NOTHING will count all additionals
@@ -573,54 +568,15 @@ public:
     void updateAdditionalID(const std::string& oldID, GNEAdditional* additional);
 
     /// @brief inform that additionals has to be saved
-    void requiereSaveAdditionals();
+    void requiereSaveAdditionals(bool value);
 
     /**@brief save additional elements of the network
     * @param[in] filename name of the file in wich save additionals
     */
     void saveAdditionals(const std::string& filename);
 
-    /// @}
-
-    /// @name Functions related to Calibrator Items
-    /// @note all three duplicates functions will be unified using GNERoute class
-    /// @{
-
-    /**@brief Returns the named calibrator route
-    * @param[in] id The id of the calibrator route to return.
-    * @param[in] failHard Whether attempts to retrieve a nonexisting calibrator route should result in an exception
-    */
-    GNECalibratorRoute* retrieveCalibratorRoute(const std::string& id, bool hardFail = true) const;
-
-    /**@brief Returns the named calibrator vehicle type
-    * @param[in] id The id of the calibrator vehicle type to return.
-    * @param[in] failHard Whether attempts to retrieve a nonexisting calibrator vehicle type should result in an exception
-    */
-    GNECalibratorVehicleType* retrieveCalibratorVehicleType(const std::string& id, bool hardFail = true) const;
-
-    /**@brief Returns the named calibrator flow
-    * @param[in] id The id of the calibrator flow to return.
-    * @param[in] failHard Whether attempts to retrieve a nonexisting calibrator flow should result in an exception
-    */
-    GNECalibratorFlow* retrieveCalibratorFlow(const std::string& id, bool hardFail = true) const;
-
-    /// @brief generate a new Calibrator Route ID
-    std::string generateCalibratorRouteID() const;
-
-    /// @brief generate a new Calibrator Vehicle Type ID
-    std::string generateCalibratorVehicleTypeID() const;
-
-    /// @brief generate a new Calibrator Flow ID
-    std::string generateCalibratorFlowID() const;
-
-    /// @brief change Calibrator Route ID
-    void changeCalibratorRouteID(GNECalibratorRoute* route, const std::string& oldID);
-
-    /// @brief change Calibrator Vehicle Type ID
-    void changeCalibratorVehicleTypeID(GNECalibratorVehicleType* vehicleType, const std::string& oldID);
-
-    /// @brief change Calibrator Flow ID
-    void changeCalibratorFlowID(GNECalibratorFlow* flow, const std::string& oldID);
+    /// @brief generate additional id
+    std::string generateAdditionalID(SumoXMLTag type) const;
 
     /// @}
 
@@ -631,10 +587,11 @@ public:
      * @param[in] netElement GNENetElement to be edited
      * @param[in] shape shape to be edited
      * @param[in] fill enable or disable fill polygon
+     * @param[in] col The color for drawing the polygon
      * @throw processError if shape is empty
      * @return created GNEPoly
      */
-    GNEPoly* addPolygonForEditShapes(GNENetElement* netElement, const PositionVector& shape, bool fill);
+    GNEPoly* addPolygonForEditShapes(GNENetElement* netElement, const PositionVector& shape, bool fill, RGBColor col);
 
     /// @brief remove Polygon for edit shapes
     void removePolygonForEditShapes(GNEPoly* polygon);
@@ -646,7 +603,7 @@ public:
     void changeShapeID(GNEShape* s, const std::string& OldID);
 
     /// @brief inform that shapes has to be saved
-    void requiereSaveShapes();
+    void requiereSaveShapes(bool value);
 
     /**@brief save shapes elements of the network
      * @param[in] filename name of the file in wich save shapes
@@ -657,7 +614,33 @@ public:
     int getNumberOfShapes() const;
     /// @}
 
+    /// @name Functions related to TLS Programs
+    /// @{
+    /// @brief inform that TLS Programs has to be saved
+    void requiereSaveTLSPrograms();
+
+    /**@brief save TLS Programs elements of the network
+     * @param[in] filename name of the file in wich save TLS Programs
+     */
+    void saveTLSPrograms(const std::string& filename);
+
+    /// @brief get number of TLS Programs
+    int getNumberOfTLSPrograms() const;
+    /// @}
+
 protected:
+    /// @brief struct used for saving all attribute carriers of net, in different formats
+    struct AttributeCarriers {
+        /// @brief map with the name and pointer to junctions of net
+        std::map<std::string, GNEJunction*> junctions;
+
+        /// @brief map with the name and pointer to edges of net
+        std::map<std::string, GNEEdge*> edges;
+
+        /// @brief map with the name and pointer to additional elements of net
+        std::map<SumoXMLTag, std::map<std::string, GNEAdditional*> > additionals;
+    };
+
     /// @brief the rtree which contains all GUIGlObjects (so named for historical reasons)
     SUMORTree myGrid;
 
@@ -667,23 +650,8 @@ protected:
     /// @brief The internal netbuilder
     NBNetBuilder* myNetBuilder;
 
-    /// @brief map with the name and pointer to junctions of net
-    std::map<std::string, GNEJunction*> myJunctions;
-
-    /// @brief map with the name and pointer to edges of net
-    std::map<std::string, GNEEdge*> myEdges;
-
-    /// @brief map with the name and pointer to additional elements of net
-    std::map<std::pair<std::string, SumoXMLTag>, GNEAdditional*> myAdditionals;
-
-    /// @brief map with the name and pointer to Calibrator Routes of net
-    std::map<std::string, GNECalibratorRoute*> myCalibratorRoutes;
-
-    /// @brief map with the name and pointer to Calibrator Vehicle Types of net
-    std::map<std::string, GNECalibratorVehicleType*> myCalibratorVehicleTypes;
-
-    /// @brief map with the name and pointer to Calibrator Flows of net
-    std::map<std::string, GNECalibratorFlow*> myCalibratorFlows;
+    /// @brief AttributeCarriers of net
+    AttributeCarriers myAttributeCarriers;
 
     /// @name ID Suppliers for newly created edges and junctions
     // @{
@@ -697,15 +665,24 @@ protected:
     /// @brief whether the net needs recomputation
     bool myNeedRecompute;
 
+    /// @brief Flag to check if net has to be saved
+    bool myNetSaved;
+
     /// @brief Flag to check if additionals has to be saved
     bool myAdditionalsSaved;
 
-    /// @brief Flag to check if shapes hast o be saved
+    /// @brief Flag to check if shapes has to be saved
     bool myShapesSaved;
 
+    /// @brief Flag to check if shapes has to be saved
+    bool myTLSProgramsSaved;
+
     /// @name Insertion and erasing of GNEAdditionals items
     /// @{
 
+    /// @brief return true if additional exist (use pointer instead ID)
+    bool additionalExist(GNEAdditional* additional);
+
     /**@brief Insert a additional element int GNENet container.
      * @throw processError if route was already inserted
      */
@@ -714,42 +691,7 @@ protected:
     /**@brief delete additional element of GNENet container
      * @throw processError if additional wasn't previously inserted
      */
-    void deleteAdditional(GNEAdditional* additional);
-
-    /// @}
-
-    /// @name Insertion and erasing of GNECalibrator items
-    /// @{
-
-    /**@brief insert Calibrator Route in net
-     * @throw processError if route was already inserted
-     */
-    void insertCalibratorRoute(GNECalibratorRoute* route);
-
-    /**@brief delete Calibrator Route in net
-    * @throw processError if route wasn't previously inserted
-    */
-    void deleteCalibratorRoute(GNECalibratorRoute* route);
-
-    /**@brief insert Calibrator Flow in net
-    * @throw processError if flow was already inserted
-    */
-    void insertCalibratorFlow(GNECalibratorFlow* flow);
-
-    /**@brief delete Calibrator Flow in net
-    * @throw processError if flow wasn't previously inserted
-    */
-    void deleteCalibratorFlow(GNECalibratorFlow* flow);
-
-    /**@brief insert Calibrator VehicleType in net
-    * @throw processError if vehicleType was already inserted
-    */
-    void insertCalibratorVehicleType(GNECalibratorVehicleType* vehicleType);
-
-    /**@brief delete Calibrator VehicleType in net
-    * @throw processError if vehicleType wasn't previously inserted
-    */
-    void deleteCalibratorVehicleType(GNECalibratorVehicleType* vehicleType);
+    bool deleteAdditional(GNEAdditional* additional);
 
     /// @}
 
@@ -790,14 +732,12 @@ private:
     /// @brief reserve junction ID (To avoid duplicates)
     void reserveJunctionID(const std::string& id);
 
-    /* @brief helper function for changing the endpoints of a junction
-     * @param[in] keepEndpoints Whether to keep the original edge endpoints (influences junction shape)
-     */
-    void remapEdge(GNEEdge* oldEdge, GNEJunction* from, GNEJunction* to, GNEUndoList* undoList, bool preserveShapeStart, bool preserveShapeEnd);
-
     /// @brief return true if there are already a Junction in the given position, false in other case
     bool checkJunctionPosition(const Position& pos);
 
+    /// @brief save additionals after confirming invalid objects
+    void saveAdditionalsConfirmed(const std::string& filename);
+
     static void replaceInListAttribute(GNEAttributeCarrier* ac, SumoXMLAttr key, const std::string& which, const std::string& by, GNEUndoList* undoList);
 
     /// @brief the z boundary (stored in the x-coordinate), values of 0 are ignored
@@ -809,6 +749,9 @@ private:
     /// @brief map with the Edges and their number of lanes
     std::map<std::string, int> myEdgesAndNumberOfLanes;
 
+    /// @brief flag used to indicate if shaped created can be undo
+    bool myAllowUndoShapes;
+
     /// @brief class for GNEChange_ReplaceEdgeInTLS
     class GNEChange_ReplaceEdgeInTLS : public GNEChange {
         FXDECLARE_ABSTRACT(GNEChange_ReplaceEdgeInTLS)
