@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GNEUndoList.cpp
 /// @author  Jakob Erdmann
@@ -27,20 +25,11 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
-#include <config.h>
-#endif
-
-#include <iostream>
-#include <utils/common/UtilExceptions.h>
+#include <netedit/changes/GNEChange_Attribute.h>
 #include <utils/common/MsgHandler.h>
-#include <utils/options/OptionsCont.h>
 
-#include "GNEUndoList.h"
-#include "GNEChange_Attribute.h"
 #include "GNEApplicationWindow.h"
+#include "GNEUndoList.h"
 
 
 // ===========================================================================
@@ -124,9 +113,7 @@ GNEUndoList::p_abortLastCommandGroup() {
 void
 GNEUndoList::undo() {
     //std::cout << undoName().text() << "\n";
-    if (OptionsCont::getOptions().getBool("gui-testing-debug")) {
-        WRITE_WARNING("Keys Ctrl + Z (Undo) pressed");
-    }
+    WRITE_DEBUG("Keys Ctrl + Z (Undo) pressed");
     FXUndoList::undo();
     myParent->updateControls();
 }
@@ -136,9 +123,7 @@ void
 GNEUndoList::redo() {
     //std::cout << redoName().text() << "\n";
     //std::cout << undoName().text() << "\n";
-    if (OptionsCont::getOptions().getBool("gui-testing-debug")) {
-        WRITE_WARNING("Keys Ctrl + Y (Redo) pressed");
-    }
+    WRITE_DEBUG("Keys Ctrl + Y (Redo) pressed");
     FXUndoList::redo();
     myParent->updateControls();
 }
@@ -167,7 +152,7 @@ GNEUndoList::currentCommandGroupSize() const {
 long
 GNEUndoList::p_onUpdUndo(FXObject* sender, FXSelector, void*) {
     bool enable = canUndo() && !hasCommandGroup();
-    sender->handle(this, enable ? FXSEL(SEL_COMMAND, FXWindow::ID_ENABLE) : FXSEL(SEL_COMMAND, FXWindow::ID_DISABLE), 0);
+    sender->handle(this, enable ? FXSEL(SEL_COMMAND, FXWindow::ID_ENABLE) : FXSEL(SEL_COMMAND, FXWindow::ID_DISABLE), nullptr);
     FXString caption = undoName();
     if (hasCommandGroup()) {
         caption = ("Cannot Undo in the middle of " + myCommandGroups.top()->getDescription()).c_str();
@@ -185,7 +170,7 @@ GNEUndoList::p_onUpdUndo(FXObject* sender, FXSelector, void*) {
 long
 GNEUndoList::p_onUpdRedo(FXObject* sender, FXSelector, void*) {
     bool enable = canRedo() && !hasCommandGroup();
-    sender->handle(this, enable ? FXSEL(SEL_COMMAND, FXWindow::ID_ENABLE) : FXSEL(SEL_COMMAND, FXWindow::ID_DISABLE), 0);
+    sender->handle(this, enable ? FXSEL(SEL_COMMAND, FXWindow::ID_ENABLE) : FXSEL(SEL_COMMAND, FXWindow::ID_DISABLE), nullptr);
     FXString caption = redoName();
     if (hasCommandGroup()) {
         caption = ("Cannot Redo in the middle of " + myCommandGroups.top()->getDescription()).c_str();
