@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GNEViewParent.h
 /// @author  Jakob Erdmann
@@ -26,35 +24,28 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
-#include <string>
-#include <vector>
-#include <fx.h>
-#include <utils/geom/Position.h>
-#include <utils/geom/Boundary.h>
-#include <utils/gui/globjects/GUIGlObjectTypes.h>
 #include <utils/gui/windows/GUIGlChildWindow.h>
 
+
 // ===========================================================================
 // class declarations
 // ===========================================================================
-class GUISUMOAbstractView;
+class GNEDialogACChooser;
 class GNENet;
+class GNEUndoList;
 class GNEApplicationWindow;
-class GNEFrame;
 class GNEInspectorFrame;
 class GNESelectorFrame;
 class GNEConnectorFrame;
 class GNETLSEditorFrame;
 class GNEAdditionalFrame;
 class GNECrossingFrame;
+class GNETAZFrame;
 class GNEDeleteFrame;
 class GNEPolygonFrame;
+class GNEProhibitionFrame;
 
 // ===========================================================================
 // class declarations
@@ -93,7 +84,7 @@ public:
     GNEViewParent(FXMDIClient* p, FXMDIMenu* mdimenu,
                   const FXString& name, GNEApplicationWindow* parentWindow,
                   FXGLCanvas* share, GNENet* net, GNEUndoList* undoList,
-                  FXIcon* ic = NULL, FXuint opts = 0, FXint x = 0, FXint y = 0, FXint w = 0, FXint h = 0);
+                  FXIcon* ic = nullptr, FXuint opts = 0, FXint x = 0, FXint y = 0, FXint w = 0, FXint h = 0);
 
     /// @brief Destructor
     ~GNEViewParent();
@@ -119,12 +110,18 @@ public:
     /// @brief get frame for GNE_MODE_CROSSING
     GNECrossingFrame* getCrossingFrame() const;
 
+    /// @brief get frame for GNE_MODE_TAZ
+    GNETAZFrame* getTAZFrame() const;
+
     /// @brief get frame for GNE_MODE_DELETE
     GNEDeleteFrame* getDeleteFrame() const;
 
     /// @brief get frame for GNE_MODE_POLYGON
     GNEPolygonFrame* getPolygonFrame() const;
 
+    /// @brief get frame for GNE_MODE_PROHIBITION
+    GNEProhibitionFrame* getProhibitionFrame() const;
+
     /// @brief show frames area if at least a GNEFrame is showed
     /// @note this function is called in GNEFrame::Show();
     void showFramesArea();
@@ -133,12 +130,15 @@ public:
     /// @note this function is called in GNEFrame::Show();
     void hideFramesArea();
 
-    /// @brief get App (GUIMainWindow)
-    GUIMainWindow* getApp() const;
+    /// @brief get GUIMainWindow App
+    GUIMainWindow* getGUIMainWindow() const;
 
     /// @brief get GNE Application Windows
     GNEApplicationWindow* getGNEAppWindows() const;
 
+    /// @brief remove created chooser dialog
+    void eraseACChooserDialog(GNEDialogACChooser* chooserDialog);
+
     /// @name FOX-callbacks
     /// @{
     /// @brief Called if the user wants to make a snapshot (screenshot)
@@ -168,6 +168,81 @@ protected:
     GNEViewParent() {}
 
 private:
+    /// @brief struct for Frames
+    struct Frames {
+        /// @brief constructor
+        Frames();
+
+        /// @brief hide frames
+        void hideFrames();
+
+        /// @brief set new width in all frames
+        void setWidth(int frameWidth);
+
+        /// @brief return true if at least there is a frame shown
+        bool isFrameShown() const;
+
+        /// @brief frame for GNE_MODE_INSPECT
+        GNEInspectorFrame* inspectorFrame;
+
+        /// @brief frame for GNE_MODE_SELECT
+        GNESelectorFrame* selectorFrame;
+
+        /// @brief frame for GNE_MODE_CONNECT
+        GNEConnectorFrame* connectorFrame;
+
+        /// @brief frame for GNE_MODE_TLS
+        GNETLSEditorFrame* TLSEditorFrame;
+
+        /// @brief frame for GNE_MODE_ADDITIONAL
+        GNEAdditionalFrame* additionalFrame;
+
+        /// @brief frame for GNE_MODE_CROSSING
+        GNECrossingFrame* crossingFrame;
+
+        /// @brief frame for GNE_MODE_TAZ
+        GNETAZFrame* TAZFrame;
+
+        /// @brief frame for GNE_MODE_DELETE
+        GNEDeleteFrame* deleteFrame;
+
+        /// @brief frame for GNE_MODE_POLYGON
+        GNEPolygonFrame* polygonFrame;
+
+        /// @brief frame for GNE_MODE_PROHIBITION
+        GNEProhibitionFrame* prohibitionFrame;
+    };
+
+    /// @brief struct for ACChoosers dialog
+    struct ACChoosers {
+        /// @brief constructor
+        ACChoosers();
+
+        /// @brief destructor
+        ~ACChoosers();
+
+        /// @brief pointer to ACChooser dialog
+        GNEDialogACChooser* ACChooserJunction;
+
+        /// @brief pointer to ACChooser dialog
+        GNEDialogACChooser* ACChooserEdges;
+
+        /// @brief pointer to ACChooser dialog
+        GNEDialogACChooser* ACChooserTLS;
+
+        /// @brief pointer to ACChooser dialog
+        GNEDialogACChooser* ACChooserAdditional;
+
+        /// @brief pointer to ACChooser dialog
+        GNEDialogACChooser* ACChooserPOI;
+
+        /// @brief pointer to ACChooser dialog
+        GNEDialogACChooser* ACChooserPolygon;
+
+        /// @brief pointer to ACChooser dialog
+        GNEDialogACChooser* ACChooserProhibition;
+    };
+
     /// @brief pointer to GNEApplicationWindow
     GNEApplicationWindow* myGNEAppWindows;
 
@@ -180,8 +255,11 @@ private:
     /// @brief Splitter to divide ViewNet und GNEFrames
     FXSplitter* myFramesSplitter;
 
-    /// @brief map with the Frames
-    std::map<int, GNEFrame*> myGNEFrames;
+    /// @brief struct for frames
+    Frames myFrames;
+
+    /// @brief struct for ACChoosers
+    ACChoosers myACChoosers;
 };
 
 
