@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    netedit_main.cpp
 /// @author  Jakob Erdmann
@@ -21,35 +19,19 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #ifdef HAVE_VERSION_H
 #include <version.h>
 #endif
 
-#include <ctime>
 #include <signal.h>
-#include <iostream>
-#include <utils/options/Option.h>
+#include <utils/common/SystemFrame.h>
+#include <utils/gui/settings/GUICompleteSchemeStorage.h>
+#include <utils/gui/windows/GUIAppEnum.h>
 #include <utils/options/OptionsCont.h>
 #include <utils/options/OptionsIO.h>
-#include <utils/common/UtilExceptions.h>
-#include <utils/common/FileHelpers.h>
-#include <utils/common/MsgHandler.h>
-#include <utils/common/SystemFrame.h>
-#include <utils/common/RandHelper.h>
 #include <utils/xml/XMLSubSys.h>
-#include <utils/gui/windows/GUIAppEnum.h>
-#include <utils/gui/images/GUITexturesHelper.h>
-#include <utils/gui/settings/GUICompleteSchemeStorage.h>
-#include <utils/geom/GeoConvHelper.h>
-#include <netimport/NIFrame.h>
-#include <netbuild/NBFrame.h>
-#include <netwrite/NWFrame.h>
 
 #include "GNEApplicationWindow.h"
 #include "GNELoadThread.h"
@@ -67,7 +49,7 @@ main(int argc, char** argv) {
     OptionsCont& oc = OptionsCont::getOptions();
     // give some application descriptions
     oc.setApplicationDescription("Graphical editor for SUMO networks.");
-    oc.setApplicationName("netedit", "Netedit Version " VERSION_STRING);
+    oc.setApplicationName("netedit", "Eclipse SUMO netedit Version " VERSION_STRING);
     int ret = 0;
 #ifndef _DEBUG
     try {
@@ -84,7 +66,7 @@ main(int argc, char** argv) {
             return 0;
         }
         // Make application
-        FXApp application("Netedit", "DLR");
+        FXApp application("SUMO netedit", "Eclipse");
         // Open display
         application.init(argc, argv);
         int minor, major;
