@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2003-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2003-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NGEdge.cpp
 /// @author  Markus Hartinger
@@ -24,13 +22,10 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <algorithm>
+#include <utils/common/RandHelper.h>
 #include <netbuild/NBNode.h>
 #include <netbuild/NBNodeCont.h>
 #include <netbuild/NBEdge.h>
@@ -68,12 +63,20 @@ NGEdge::~NGEdge() {
 
 NBEdge*
 NGEdge::buildNBEdge(NBNetBuilder& nb) const {
+    int priority = nb.getTypeCont().getPriority("");
+    if (priority > 1 && OptionsCont::getOptions().getBool("rand.random-priority")) {
+        priority = RandHelper::rand(priority) + 1;
+    }
+    int lanenumber = nb.getTypeCont().getNumLanes("");
+    if (lanenumber > 1 && OptionsCont::getOptions().getBool("rand.random-lanenumber")) {
+        lanenumber = RandHelper::rand(lanenumber) + 1;
+    }
     return new NBEdge(
                myID,
                nb.getNodeCont().retrieve(myStartNode->getID()), // from
                nb.getNodeCont().retrieve(myEndNode->getID()), // to
-               "", nb.getTypeCont().getSpeed(""), nb.getTypeCont().getNumLanes(""),
-               nb.getTypeCont().getPriority(""), nb.getTypeCont().getWidth(""), NBEdge::UNSPECIFIED_OFFSET
+               "", nb.getTypeCont().getSpeed(""), lanenumber,
+               priority, nb.getTypeCont().getWidth(""), NBEdge::UNSPECIFIED_OFFSET
            );
 }
 
