@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NGRandomNetBuilder.h
 /// @author  Markus Hartinger
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <map>
 #include <utils/distribution/RandomDistributor.h>
@@ -67,7 +61,7 @@ public:
      * @param[in] numNodes Number of iterations (node insertions) to perform
      * @todo Describe the algorithm
      */
-    void createNet(int numNodes);
+    void createNet(int numNodes, bool gridMode);
 
 
 private:
@@ -107,7 +101,7 @@ private:
      * @param[in] baseNode ?
      * @todo Describe better
      */
-    bool createNewNode(NGNode* baseNode);
+    bool createNewNode(NGNode* baseNode, bool gridMode);
 
 
     /** @brief finds possible connections between Node and OuterNodes complying with restrictions
