@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NIFrame.cpp
 /// @author  Daniel Krajzewicz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <iostream>
@@ -87,6 +81,11 @@ NIFrame::fillOptions() {
     oc.addSynonyme("type-files", "types");
     oc.addDescription("type-files", "Input", "Read XML-type defs from FILE");
 
+    oc.doRegister("ptstop-files", new Option_FileName());
+    oc.addDescription("ptstop-files", "Input", "Reads public transport stops from FILE");
+    oc.doRegister("ptline-files", new Option_FileName());
+    oc.addDescription("ptline-files", "Input", "Reads public transport lines from FILE");
+
     oc.doRegister("shapefile-prefix", new Option_FileName());
     oc.addSynonyme("shapefile-prefix", "shapefile");
     oc.addSynonyme("shapefile-prefix", "arcview", true);
@@ -136,20 +135,16 @@ NIFrame::fillOptions() {
     // register basic processing options
     oc.doRegister("ignore-errors", new Option_Bool(false));
     oc.addSynonyme("ignore-errors", "dismiss-loading-errors", true);
-    oc.addDescription("ignore-errors", "Processing", "Continue on broken input");
+    oc.addDescription("ignore-errors", "Report", "Continue on broken input");
 
     oc.doRegister("ignore-errors.connections", new Option_Bool(false));
-    oc.addDescription("ignore-errors.connections", "Processing", "Continue on invalid connections");
+    oc.addDescription("ignore-errors.connections", "Report", "Continue on invalid connections");
 
     oc.doRegister("show-errors.connections-first-try", new Option_Bool(false));
-    oc.addDescription("show-errors.connections-first-try", "Processing", "Show errors in connections at parsing");
+    oc.addDescription("show-errors.connections-first-try", "Report", "Show errors in connections at parsing");
 
     oc.doRegister("ignore-errors.edge-type", new Option_Bool(false));
-    oc.addDescription("ignore-errors.edge-type", "Processing", "Continue on unknown edge types");
-
-    oc.doRegister("lanes-from-capacity.norm", new Option_Float((double) 1800));
-    oc.addSynonyme("lanes-from-capacity.norm", "capacity-norm");
-    oc.addDescription("lanes-from-capacity.norm", "Processing", "The factor for flow to no. lanes conversion");
+    oc.addDescription("ignore-errors.edge-type", "Report", "Continue on unknown edge types");
 
     oc.doRegister("speed-in-kmh", new Option_Bool(false));
     oc.addDescription("speed-in-kmh", "Processing", "vmax is parsed as given in km/h (some)");
@@ -157,141 +152,169 @@ NIFrame::fillOptions() {
     oc.doRegister("construction-date", new Option_String());
     oc.addDescription("construction-date", "Processing", "Use YYYY-MM-DD date to determine the readiness of features under construction");
 
+    oc.doRegister("flatten", new Option_Bool(false));
+    oc.addDescription("flatten", "Processing", "Remove all z-data");
 
     // register xml options
     oc.doRegister("plain.extend-edge-shape", new Option_Bool(false));
     oc.addSynonyme("plain.extend-edge-shape", "xml.keep-shape", true);
     oc.addDescription("plain.extend-edge-shape", "Processing", "If edge shapes do not end at the node positions, extend them");
 
+    // register osm options
+    oc.doRegister("osm.skip-duplicates-check", new Option_Bool(false));
+    oc.addDescription("osm.skip-duplicates-check", "Formats", "Skips the check for duplicate nodes and edges");
+
+    oc.doRegister("osm.elevation", new Option_Bool(false));
+    oc.addDescription("osm.elevation", "Formats", "Imports elevation data");
+
+    oc.doRegister("osm.layer-elevation", new Option_Float(0));
+    oc.addDescription("osm.layer-elevation", "Formats", "Reconstruct (relative) elevation based on layer data. Each layer is raised by FLOAT m");
+
+    oc.doRegister("osm.layer-elevation.max-grade", new Option_Float(10));
+    oc.addDescription("osm.layer-elevation.max-grade", "Formats", "Maximum grade threshold in % at 50km/h when reconstrucing elevation based on layer data. The value is scaled according to road speed.");
+
+    oc.doRegister("osm.oneway-spread-right", new Option_Bool(false));
+    oc.addDescription("osm.oneway-spread-right", "Formats", "Whether one-way roads should be spread to the side instead of centered");
+
+    oc.doRegister("osm.stop-output.length", new Option_Float(25));
+    oc.addDescription("osm.stop-output.length", "Formats", "The default length of a public transport stop in FLOAT m");
+    oc.doRegister("osm.stop-output.length.bus", new Option_Float(15));
+    oc.addDescription("osm.stop-output.length.bus", "Formats", "The default length of a bus stop in FLOAT m");
+    oc.doRegister("osm.stop-output.length.tram", new Option_Float(25));
+    oc.addDescription("osm.stop-output.length.tram", "Formats", "The default length of a tram stop in FLOAT m");
+    oc.doRegister("osm.stop-output.length.train", new Option_Float(200));
+    oc.addDescription("osm.stop-output.length.train", "Formats", "The default length of a train stop in FLOAT m");
+
+    oc.doRegister("osm.all-attributes", new Option_Bool(false));
+    oc.addDescription("osm.all-attributes", "Formats", "Whether additional attributes shall be imported");
+
 
     // register matsim options
     oc.doRegister("matsim.keep-length", new Option_Bool(false));
-    oc.addDescription("matsim.keep-length", "Processing", "The edge lengths given in the MATSIM-file will be kept");
+    oc.addDescription("matsim.keep-length", "Formats", "The edge lengths given in the MATSIM-file will be kept");
 
     oc.doRegister("matsim.lanes-from-capacity", new Option_Bool(false));
-    oc.addDescription("matsim.lanes-from-capacity", "Processing", "The lane number will be computed from the capacity");
+    oc.addDescription("matsim.lanes-from-capacity", "Formats", "The lane number will be computed from the capacity");
 
 
     // register shapefile options
     oc.doRegister("shapefile.street-id", new Option_String());
     oc.addSynonyme("shapefile.street-id", "arcview.street-id", true);
-    oc.addDescription("shapefile.street-id", "Processing", "Read edge ids from column STR");
+    oc.addDescription("shapefile.street-id", "Formats", "Read edge ids from column STR");
 
     oc.doRegister("shapefile.from-id", new Option_String());
     oc.addSynonyme("shapefile.from-id", "arcview.from-id", true);
-    oc.addDescription("shapefile.from-id", "Processing", "Read from-node ids from column STR");
+    oc.addDescription("shapefile.from-id", "Formats", "Read from-node ids from column STR");
 
     oc.doRegister("shapefile.to-id", new Option_String());
     oc.addSynonyme("shapefile.to-id", "arcview.to-id", true);
-    oc.addDescription("shapefile.to-id", "Processing", "Read to-node ids from column STR");
+    oc.addDescription("shapefile.to-id", "Formats", "Read to-node ids from column STR");
 
     oc.doRegister("shapefile.type-id", new Option_String());
     oc.addSynonyme("shapefile.type-id", "arcview.type-id", true);
-    oc.addDescription("shapefile.type-id", "Processing", "Read type ids from column STR");
+    oc.addDescription("shapefile.type-id", "Formats", "Read type ids from column STR");
+
+    oc.doRegister("shapefile.laneNumber", new Option_String());
+    oc.addDescription("shapefile.laneNumber", "Formats", "Read lane number from column STR");
+
+    oc.doRegister("shapefile.speed", new Option_String());
+    oc.addDescription("shapefile.speed", "Formats", "Read speed from column STR");
+
+    oc.doRegister("shapefile.name", new Option_String());
+    oc.addDescription("shapefile.name", "Formats", "Read (non-unique) name from column STR");
+
+    oc.doRegister("shapefile.node-join-dist", new Option_Float(0));
+    oc.addDescription("shapefile.node-join-dist", "Formats", "Distance threshold for determining whether distinct shapes are connected (used when from-id and to-id are not available)");
+
+    oc.doRegister("shapefile.add-params", new Option_String());
+    oc.addDescription("shapefile.add-params", "Formats", "Add the list of field names as edge params");
 
     oc.doRegister("shapefile.use-defaults-on-failure", new Option_Bool(false));
     oc.addSynonyme("shapefile.use-defaults-on-failure", "arcview.use-defaults-on-failure", true);
-    oc.addDescription("shapefile.use-defaults-on-failure", "Processing", "Uses edge type defaults on problems");
+    oc.addDescription("shapefile.use-defaults-on-failure", "Formats", "Uses edge type defaults on problems");
 
     oc.doRegister("shapefile.all-bidirectional", new Option_Bool(false));
     oc.addSynonyme("shapefile.all-bidirectional", "shapefile.all-bidi");
     oc.addSynonyme("shapefile.all-bidirectional", "arcview.all-bidi", true);
-    oc.addDescription("shapefile.all-bidirectional", "Processing", "Insert edges in both directions");
+    oc.addDescription("shapefile.all-bidirectional", "Formats", "Insert edges in both directions");
 
     oc.doRegister("shapefile.guess-projection", new Option_Bool(false));
     oc.addSynonyme("shapefile.guess-projection", "arcview.guess-projection", true);
-    oc.addDescription("shapefile.guess-projection", "Processing", "Guess the proper projection");
+    oc.addDescription("shapefile.guess-projection", "Formats", "Guess the proper projection");
 
 
     // register vissim options
     oc.doRegister("vissim.join-distance", new Option_Float(5.0f));
     oc.addSynonyme("vissim.join-distance", "vissim.offset", true);
-    oc.addDescription("vissim.join-distance", "Processing", "Structure join offset");
+    oc.addDescription("vissim.join-distance", "Formats", "Structure join offset");
 
     oc.doRegister("vissim.default-speed", new Option_Float(50.0f));
-    oc.addDescription("vissim.default-speed", "Processing", "Use FLOAT as default speed");
+    oc.addDescription("vissim.default-speed", "Formats", "Use FLOAT as default speed");
 
     oc.doRegister("vissim.speed-norm", new Option_Float(1.0f));
-    oc.addDescription("vissim.speed-norm", "Processing", "Factor for edge velocity");
+    oc.addDescription("vissim.speed-norm", "Formats", "Factor for edge velocity");
 
     oc.doRegister("vissim.report-unset-speeds", new Option_Bool(false));
-    oc.addDescription("vissim.report-unset-speeds", "Processing", "Writes lanes without an explicit speed set");
+    oc.addDescription("vissim.report-unset-speeds", "Formats", "Writes lanes without an explicit speed set");
 
 
     // register visum options
     oc.doRegister("visum.use-type-priority", new Option_Bool(false));
-    oc.addDescription("visum.use-type-priority", "Processing", "Uses priorities from types");
+    oc.addDescription("visum.use-type-priority", "Formats", "Uses priorities from types");
 
     oc.doRegister("visum.use-type-laneno", new Option_Bool(false));
-    oc.addDescription("visum.use-type-laneno", "Processing", "Uses lane numbers from types");
+    oc.addDescription("visum.use-type-laneno", "Formats", "Uses lane numbers from types");
 
     oc.doRegister("visum.use-type-speed", new Option_Bool(false));
-    oc.addDescription("visum.use-type-speed", "Processing", "Uses speeds from types");
+    oc.addDescription("visum.use-type-speed", "Formats", "Uses speeds from types");
 
     oc.doRegister("visum.connector-speeds", new Option_Float(100.));
-    oc.addDescription("visum.connector-speeds", "Processing", "Sets connector speed");
+    oc.addDescription("visum.connector-speeds", "Formats", "Sets connector speed");
 
     oc.doRegister("visum.connectors-lane-number", new Option_Integer(3));
     oc.addSynonyme("visum.connectors-lane-number", "visum.connector-laneno", true);
-    oc.addDescription("visum.connectors-lane-number", "Processing", "Sets connector lane number");
+    oc.addDescription("visum.connectors-lane-number", "Formats", "Sets connector lane number");
 
     oc.doRegister("visum.no-connectors", new Option_Bool(false));
-    oc.addDescription("visum.no-connectors", "Processing", "Excludes connectors");
+    oc.addDescription("visum.no-connectors", "Formats", "Excludes connectors");
 
     oc.doRegister("visum.recompute-lane-number", new Option_Bool(false));
     oc.addSynonyme("visum.recompute-lane-number", "visum.recompute-laneno", true);
-    oc.addDescription("visum.recompute-lane-number", "Processing", "Computes the number of lanes from the edges' capacities");
+    oc.addDescription("visum.recompute-lane-number", "Formats", "Computes the number of lanes from the edges' capacities");
 
     oc.doRegister("visum.verbose-warnings", new Option_Bool(false));
-    oc.addDescription("visum.verbose-warnings", "Processing", "Prints all warnings, some of which are due to VISUM misbehaviour");
+    oc.addDescription("visum.verbose-warnings", "Formats", "Prints all warnings, some of which are due to VISUM misbehaviour");
 
+    oc.doRegister("visum.lanes-from-capacity.norm", new Option_Float((double) 1800));
+    oc.addSynonyme("visum.lanes-from-capacity.norm", "capacity-norm", true);
+    oc.addSynonyme("visum.lanes-from-capacity.norm", "lanes-from-capacity.norm");
+    oc.addDescription("visum.lanes-from-capacity.norm", "Formats", "The factor for flow to no. lanes conversion");
 
-    // register osm options
-    oc.doRegister("osm.skip-duplicates-check", new Option_Bool(false));
-    oc.addDescription("osm.skip-duplicates-check", "Processing", "Skips the check for duplicate nodes and edges");
-
-    oc.doRegister("osm.elevation", new Option_Bool(false));
-    oc.addDescription("osm.elevation", "Processing", "Imports elevation data");
-
-    oc.doRegister("osm.layer-elevation", new Option_Float(0));
-    oc.addDescription("osm.layer-elevation", "Processing", "Reconstruct (relative) elevation based on layer data. Each layer is raised by FLOAT m");
-
-    oc.doRegister("osm.layer-elevation.max-grade", new Option_Float(10));
-    oc.addDescription("osm.layer-elevation.max-grade", "Processing", "Maximum grade threshold in % at 50km/h when reconstrucing elevation based on layer data. The value is scaled according to road speed.");
-
-    oc.doRegister("osm.oneway-spread-right", new Option_Bool(false));
-    oc.addDescription("osm.oneway-spread-right", "Processing", "Whether one-way roads should be spread to the side instead of centered");
-
-    oc.doRegister("osm.stop-output.length", new Option_Float(25));
-    oc.addDescription("osm.stop-output.length", "Processing", "The default length of a public transport stop in FLOAT m");
-    oc.doRegister("osm.stop-output.length.bus", new Option_Float(15));
-    oc.addDescription("osm.stop-output.length.bus", "Processing", "The default length of a bus stop in FLOAT m");
-    oc.doRegister("osm.stop-output.length.tram", new Option_Float(25));
-    oc.addDescription("osm.stop-output.length.tram", "Processing", "The default length of a tram stop in FLOAT m");
-    oc.doRegister("osm.stop-output.length.train", new Option_Float(200));
-    oc.addDescription("osm.stop-output.length.train", "Processing", "The default length of a train stop in FLOAT m");
-
-    oc.doRegister("osm.all-attributes", new Option_Bool(false));
-    oc.addDescription("osm.all-attributes", "Processing", "Whether additional attributes shall be imported");
 
     // register opendrive options
     oc.doRegister("opendrive.import-all-lanes", new Option_Bool(false));
-    oc.addDescription("opendrive.import-all-lanes", "Processing", "Imports all lane types");
+    oc.addDescription("opendrive.import-all-lanes", "Formats", "Imports all lane types");
     oc.doRegister("opendrive.ignore-widths", new Option_Bool(false));
-    oc.addDescription("opendrive.ignore-widths", "Processing", "Whether lane widths shall be ignored.");
+    oc.addDescription("opendrive.ignore-widths", "Formats", "Whether lane widths shall be ignored.");
     oc.doRegister("opendrive.curve-resolution", new Option_Float(2.0));
-    oc.addDescription("opendrive.curve-resolution", "Processing", "The geometry resolution in m when importing curved geometries as line segments.");
+    oc.addDescription("opendrive.curve-resolution", "Formats", "The geometry resolution in m when importing curved geometries as line segments.");
     oc.doRegister("opendrive.advance-stopline", new Option_Float(12.0));
-    oc.addDescription("opendrive.advance-stopline", "Processing", "Allow stop lines to be built beyond the start of the junction if the geometries allow so");
+    oc.addDescription("opendrive.advance-stopline", "Formats", "Allow stop lines to be built beyond the start of the junction if the geometries allow so");
     oc.doRegister("opendrive.min-width", new Option_Float(1.8));
-    oc.addDescription("opendrive.min-width", "Processing", "The minimum lane width for determining start or end of variable-width lanes");
+    oc.addDescription("opendrive.min-width", "Formats", "The minimum lane width for determining start or end of variable-width lanes");
+    oc.doRegister("opendrive.internal-shapes", new Option_Bool(false));
+    oc.addDescription("opendrive.internal-shapes", "Formats", "Import internal lane shapes");
 
     // register some additional options
     oc.doRegister("tls.discard-loaded", new Option_Bool(false));
-    oc.addDescription("tls.discard-loaded", "TLS Building", "Does not instatiate traffic lights loaded from other formats than XML");
+    oc.addDescription("tls.discard-loaded", "TLS Building", "Does not instatiate traffic lights loaded from other formats than plain-XML");
 
     oc.doRegister("tls.discard-simple", new Option_Bool(false));
-    oc.addDescription("tls.discard-simple", "TLS Building", "Does not instatiate traffic lights at geometry-like nodes loaded from other formats than XML");
+    oc.addDescription("tls.discard-simple", "TLS Building", "Does not instatiate traffic lights at geometry-like nodes loaded from other formats than plain-XML");
+
+    // register railway options
+    oc.doRegister("railway.signals.discard", new Option_Bool(false));
+    oc.addDescription("railway.signals.discard", "Railway", "Discard all railway signal information loaded from other formats than plain-xml");
 }
 
 
@@ -326,10 +349,14 @@ NIFrame::checkOptions() {
             // changed default since we wish to preserve the network as far as possible
             oc.set("offset.disable-normalization", "true");
         }
+        if (oc.isWriteable("geometry.max-grade.fix")) {
+            // changed default since we wish to preserve the network as far as possible
+            oc.set("geometry.max-grade.fix", "false");
+        }
     }
     if (!oc.isSet("type-files")) {
         const char* sumoPath = std::getenv("SUMO_HOME");
-        if (sumoPath == 0) {
+        if (sumoPath == nullptr) {
             WRITE_WARNING("Environment variable SUMO_HOME is not set, using built in type maps.");
         } else {
             const std::string path = sumoPath + std::string("/data/typemap/");
@@ -350,6 +377,10 @@ NIFrame::checkOptions() {
             // a better interpretation of imported geometries
             oc.set("rectangular-lane-cut", "true");
         }
+        if (oc.isDefault("opendrive.advance-stopline") && oc.getBool("opendrive.internal-shapes")) {
+            // avoid mismatch between edge shapes and and internal edge shapes
+            oc.set("opendrive.advance-stopline", "0");
+        }
     }
     return ok;
 }
