@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NIImporter_ArcView.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 
@@ -141,6 +135,13 @@ private:
      * @param[out] into The read value/missing field is stored here
      */
     bool getStringEntry(OGRFeature* poFeature, const std::string& optionName, const char* defaultName, bool prune, std::string& into);
+
+    /// @brief return all fields support by the given feature
+    std::vector<std::string> getFieldNames(OGRFeature* poFeature) const;
+
+    /// @brief add list of parameters to edge
+    void addParams(NBEdge* edge, OGRFeature* poFeature, const std::vector<std::string>& params) const;
+
 #endif
 
 private:
@@ -165,7 +166,8 @@ private:
     /// @brief Whether the speed is given in km/h
     bool mySpeedInKMH;
 
-    /// @brief A running number to assure unique node ids
+    /// @brief A running number to assure unique ids (as fallback)
+    int myRunningEdgeID;
     int myRunningNodeID;
 
 
