@@ -1,34 +1,27 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    NIImporter_DlrNavteq.cpp
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Mon, 14.04.2008
-/// @version $Id: NIImporter_DlrNavteq.cpp 24108 2017-04-27 18:43:30Z behrisch $
+/// @version $Id$
 ///
 // Importer for networks stored in Elmar's format
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 
 
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <sstream>
@@ -37,7 +30,7 @@
 #include <utils/common/StringTokenizer.h>
 #include <utils/common/MsgHandler.h>
 #include <utils/common/UtilExceptions.h>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include <utils/common/ToString.h>
 #include <utils/common/StringUtils.h>
 #include <utils/options/OptionsCont.h>
@@ -58,7 +51,7 @@
 // ---------------------------------------------------------------------------
 // static members
 // ---------------------------------------------------------------------------
-const int NIImporter_DlrNavteq::GEO_SCALE = 5;
+const std::string NIImporter_DlrNavteq::GEO_SCALE("1e-5");
 const int NIImporter_DlrNavteq::EdgesHandler::MISSING_COLUMN = std::numeric_limits<int>::max();
 const std::string NIImporter_DlrNavteq::UNDEFINED("-1");
 
@@ -167,7 +160,7 @@ NIImporter_DlrNavteq::readVersion(const std::string& line, const std::string& fi
     const int vStart = (int)(lowerCase.find(marker) + marker.size());
     const int vEnd = (int)line.find(" ", vStart);
     try {
-        const double version = TplConvert::_2double(line.substr(vStart, vEnd - vStart).c_str());
+        const double version = StringUtils::toDouble(line.substr(vStart, vEnd - vStart));
         if (version < 0) {
             throw ProcessError("Invalid version number '" + toString(version) + "' in file '" + file + "'.");
         }
@@ -306,21 +299,21 @@ NIImporter_DlrNavteq::EdgesHandler::report(const std::string& result) {
     // form of way (for priority and permissions)
     int form_of_way;
     try {
-        form_of_way = TplConvert::_2int(getColumn(st, FORM_OF_WAY).c_str());
+        form_of_way = StringUtils::toInt(getColumn(st, FORM_OF_WAY));
     } catch (NumberFormatException&) {
         throw ProcessError("Non-numerical value for form_of_way of link '" + id + "'.");
     }
     // brunnel type (bridge/tunnel/ferry (for permissions)
     int brunnel_type;
     try {
-        brunnel_type = TplConvert::_2int(getColumn(st, BRUNNEL_TYPE).c_str());
+        brunnel_type = StringUtils::toInt(getColumn(st, BRUNNEL_TYPE));
     } catch (NumberFormatException&) {
         throw ProcessError("Non-numerical value for brunnel_type of link '" + id + "'.");
     }
     // priority based on street_type / frc
     int priority;
     try {
-        priority = -TplConvert::_2int(getColumn(st, FUNCTIONAL_ROAD_CLASS).c_str());
+        priority = -StringUtils::toInt(getColumn(st, FUNCTIONAL_ROAD_CLASS));
         // lower priority using form_of_way
         if (form_of_way == 11) {
             priority -= 1; // frontage road, very often with lowered curb
@@ -339,17 +332,17 @@ NIImporter_DlrNavteq::EdgesHandler::report(const std::string& result) {
     const std::string toID = getColumn(st, NODE_ID_TO);
     NBNode* from = myNodeCont.retrieve(fromID);
     NBNode* to = myNodeCont.retrieve(toID);
-    if (from == 0) {
+    if (from == nullptr) {
         throw ProcessError("The from-node '" + fromID + "' of link '" + id + "' could not be found");
     }
-    if (to == 0) {
+    if (to == nullptr) {
         throw ProcessError("The to-node '" + toID + "' of link '" + id + "' could not be found");
     }
     // speed
     double speed;
     try {
-        speed = TplConvert::_2int(getColumn(st, SPEED_RESTRICTION, "-1").c_str()) / 3.6;
-    } catch (NumberFormatException) {
+        speed = StringUtils::toInt(getColumn(st, SPEED_RESTRICTION, "-1")) / 3.6;
+    } catch (NumberFormatException&) {
         throw ProcessError("Non-numerical value for the SPEED_RESTRICTION of link '" + id + "'.");
     }
     if (speed < 0) {
@@ -360,18 +353,20 @@ NIImporter_DlrNavteq::EdgesHandler::report(const std::string& result) {
     int numLanes;
     try {
         // EXTENDED_NUMBER_OF_LANES is prefered but may not be defined
-        numLanes = TplConvert::_2int(getColumn(st, EXTENDED_NUMBER_OF_LANES, "-1").c_str());
+        numLanes = StringUtils::toInt(getColumn(st, EXTENDED_NUMBER_OF_LANES, "-1"));
         if (numLanes == -1) {
             numLanes = NINavTeqHelper::getLaneNumber(id, getColumn(st, NUMBER_OF_LANES), speed);
         }
     } catch (NumberFormatException&) {
         throw ProcessError("Non-numerical value for the number of lanes of link '" + id + "'.");
     }
+
+    const std::string navTeqTypeId = getColumn(st, VEHICLE_TYPE) + "_" + getColumn(st, FORM_OF_WAY);
     // build the edge
-    NBEdge* e = 0;
+    NBEdge* e = nullptr;
     const std::string interID = getColumn(st, BETWEEN_NODE_ID);
     if (interID == "-1") {
-        e = new NBEdge(id, from, to, "", speed, numLanes, priority,
+        e = new NBEdge(id, from, to, myTypeCont.knows(navTeqTypeId) ? navTeqTypeId : "", speed, numLanes, priority,
                        NBEdge::UNSPECIFIED_WIDTH, NBEdge::UNSPECIFIED_OFFSET, streetName);
     } else {
         PositionVector geoms = myGeoms[interID];
@@ -380,13 +375,12 @@ NIImporter_DlrNavteq::EdgesHandler::report(const std::string& result) {
         }
         geoms.insert(geoms.begin(), from->getPosition());
         geoms.push_back(to->getPosition());
-        e = new NBEdge(id, from, to, "", speed, numLanes, priority,
-                       NBEdge::UNSPECIFIED_WIDTH, NBEdge::UNSPECIFIED_OFFSET, geoms, streetName, id, LANESPREAD_CENTER);
+        const std::string origID = OptionsCont::getOptions().getBool("output.original-names") ? id : "";
+        e = new NBEdge(id, from, to, myTypeCont.knows(navTeqTypeId) ? navTeqTypeId : "", speed, numLanes, priority,
+                       NBEdge::UNSPECIFIED_WIDTH, NBEdge::UNSPECIFIED_OFFSET, geoms, streetName, origID, LANESPREAD_CENTER);
     }
 
     // NavTeq imports can be done with a typemap (if supplied), if not, the old defaults are used
-    const std::string navTeqTypeId = getColumn(st, VEHICLE_TYPE) + "_" + getColumn(st, FORM_OF_WAY);
-
     if (myTypeCont.knows(navTeqTypeId)) {
         e->setPermissions(myTypeCont.getPermissions(navTeqTypeId));
     } else {
@@ -491,7 +485,7 @@ NIImporter_DlrNavteq::TrafficlightsHandler::report(const std::string& result) {
     StringTokenizer st(result, StringTokenizer::WHITECHARS);
     const std::string edgeID = st.get(5);
     NBEdge* edge = myEdgeCont.retrieve(edgeID);
-    if (edge == 0) {
+    if (edge == nullptr) {
         WRITE_WARNING("The traffic light edge '" + edgeID + "' could not be found");
     } else {
         NBNode* node = edge->getToNode();
@@ -600,7 +594,7 @@ NIImporter_DlrNavteq::TimeRestrictionsHandler::report(const std::string& result)
             //std::cout << " duration=" << duration << " tEnd=" << tEnd << " translation=" << asctime(localtime(&tEnd)) << "\n";
             if (myConstructionTime < tEnd) {
                 NBEdge* edge = myEdgeCont.retrieve(id);
-                if (edge != 0) {
+                if (edge != nullptr) {
                     myRemovedEdges++;
                     myEdgeCont.extract(myDistrictCont, edge, true);
                 }
@@ -687,9 +681,9 @@ NIImporter_DlrNavteq::readDate(const std::string& yyyymmdd) {
             && yyyymmdd[4] == '-'
             && yyyymmdd[7] == '-') {
         try {
-            timeinfo.tm_year = TplConvert::_str2int(yyyymmdd.substr(0, 4)) - 1900;
-            timeinfo.tm_mon = TplConvert::_str2int(yyyymmdd.substr(5, 2)) - 1;
-            timeinfo.tm_mday = TplConvert::_str2int(yyyymmdd.substr(8, 2));
+            timeinfo.tm_year = StringUtils::toInt(yyyymmdd.substr(0, 4)) - 1900;
+            timeinfo.tm_mon = StringUtils::toInt(yyyymmdd.substr(5, 2)) - 1;
+            timeinfo.tm_mday = StringUtils::toInt(yyyymmdd.substr(8, 2));
             return mktime(&timeinfo);
         } catch (...) {
         }
@@ -747,12 +741,12 @@ NIImporter_DlrNavteq::ProhibitionHandler::report(const std::string& result) {
     const std::string endEdge = st.get(st.size() - 1);
 
     NBEdge* from = myEdgeCont.retrieve(startEdge);
-    if (from == 0) {
+    if (from == nullptr) {
         WRITE_WARNING("Ignoring prohibition from unknown start edge '" + startEdge + "'");
         return true;
     }
     NBEdge* to = myEdgeCont.retrieve(endEdge);
-    if (to == 0) {
+    if (to == nullptr) {
         WRITE_WARNING("Ignoring prohibition from unknown end edge '" + endEdge + "'");
         return true;
     }
@@ -792,21 +786,21 @@ NIImporter_DlrNavteq::ConnectedLanesHandler::report(const std::string& result) {
     const std::string endEdge = st.get(st.size() - 1);
 
     NBEdge* from = myEdgeCont.retrieve(startEdge);
-    if (from == 0) {
+    if (from == nullptr) {
         WRITE_WARNING("Ignoring prohibition from unknown start edge '" + startEdge + "'");
         return true;
     }
     NBEdge* to = myEdgeCont.retrieve(endEdge);
-    if (to == 0) {
+    if (to == nullptr) {
         WRITE_WARNING("Ignoring prohibition from unknown end edge '" + endEdge + "'");
         return true;
     }
-    int fromLane = TplConvert::_2int(fromLaneS.c_str()) - 1; // one based
+    int fromLane = StringUtils::toInt(fromLaneS) - 1; // one based
     if (fromLane < 0 || fromLane >= from->getNumLanes()) {
         WRITE_WARNING("Ignoring invalid lane index '" + fromLaneS + "' in connection from edge '" + startEdge + "' with " + toString(from->getNumLanes()) + " lanes");
         return true;
     }
-    int toLane = TplConvert::_2int(toLaneS.c_str()) - 1; // one based
+    int toLane = StringUtils::toInt(toLaneS) - 1; // one based
     if (toLane < 0 || toLane >= to->getNumLanes()) {
         WRITE_WARNING("Ignoring invalid lane index '" + toLaneS + "' in connection to edge '" + endEdge + "' with " + toString(to->getNumLanes()) + " lanes");
         return true;
@@ -819,7 +813,8 @@ NIImporter_DlrNavteq::ConnectedLanesHandler::report(const std::string& result) {
         // if this connection runs across a node cluster it may not be possible to set this
         const bool warnOnly = st.size() > 7;
         myEdgeCont.addPostProcessConnection(from->getID(), fromLane, to->getID(), toLane, false, true,
-                                            NBEdge::UNSPECIFIED_CONTPOS, NBEdge::UNSPECIFIED_VISIBILITY_DISTANCE, warnOnly);
+                                            NBEdge::UNSPECIFIED_CONTPOS, NBEdge::UNSPECIFIED_VISIBILITY_DISTANCE,
+                                            NBEdge::UNSPECIFIED_SPEED, PositionVector::EMPTY, warnOnly);
     }
     // ensure that connections for other lanes are guessed if not specified
     from->declareConnectionsAsLoaded(NBEdge::INIT);
