@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NIImporter_OpenDrive.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <map>
@@ -110,7 +104,8 @@ protected:
         OPENDRIVE_TAG_LANELINK,
         OPENDRIVE_TAG_WIDTH,
         OPENDRIVE_TAG_SPEED,
-        OPENDRIVE_TAG_ELEVATION
+        OPENDRIVE_TAG_ELEVATION,
+        OPENDRIVE_TAG_GEOREFERENCE
     };
 
 
@@ -369,10 +364,10 @@ protected:
          * @param[in] dynamicArg Whether the signal is dynamic
          * @param[in] sArg The offset from the start, counted from the begin
          */
-        OpenDriveSignal(int idArg, const std::string typeArg, const std::string nameArg, int orientationArg, bool dynamicArg, double sArg)
+        OpenDriveSignal(const std::string& idArg, const std::string typeArg, const std::string nameArg, int orientationArg, bool dynamicArg, double sArg)
             : id(idArg), type(typeArg), name(nameArg), orientation(orientationArg), dynamic(dynamicArg), s(sArg) { }
 
-        int id;
+        std::string id;
         std::string type;
         std::string name;
         int orientation;
@@ -395,6 +390,16 @@ protected:
         bool all;
         std::string origID;
         int origLane;
+        PositionVector shape;
+
+        std::string getDescription() const {
+            return "Connection from=" + fromEdge + "_" + toString(fromLane) 
+                + " to=" + toEdge + "_" + toString(toLane)
+                + " fromCP=" + (fromCP == OPENDRIVE_CP_START ? "start" : fromCP == OPENDRIVE_CP_END ? "end" : "unknown")
+                + " toCP=" + (toCP == OPENDRIVE_CP_START ? "start" : toCP == OPENDRIVE_CP_END ? "end" : "unknown")
+                + " all=" + toString(all);
+                //+ " origID=" + origID + " origLane=" + toString(origLane);
+        }
     };
 
 
@@ -504,6 +509,16 @@ protected:
      */
     void myStartElement(int element, const SUMOSAXAttributes& attrs);
 
+    /**
+     * @brief Callback method for characters to implement by derived classes
+     *
+     * Called by "endElement" (see there).
+     * @param[in] element The opened element, given as a int
+     * @param[in] chars The complete embedded character string
+     * @exceptions ProcessError These method may throw a ProcessError if something fails
+     */
+    void myCharacters(int element, const std::string& chars);
+
 
     /** @brief Called when a closing tag occurs
      *
@@ -539,6 +554,7 @@ private:
     static bool myImportAllTypes;
     static bool myImportWidths;
     static double myMinWidth;
+    static bool myImportInternalShapes;
 
 
 protected:
