@@ -1,25 +1,23 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    NIImporter_OpenStreetMap.h
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @author  Walter Bamberger
+/// @author  Gregor Laemmel
 /// @date    Mon, 14.04.2008
-/// @version $Id: NIImporter_OpenStreetMap.h 21738 2016-10-18 11:39:37Z namdre $
+/// @version $Id$
 ///
 // Importer for networks stored in OpenStreetMap format
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 #ifndef NIImporter_OpenStreetMap_h
 #define NIImporter_OpenStreetMap_h
 
@@ -27,16 +25,14 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <map>
 #include <utils/xml/SUMOSAXHandler.h>
 #include <utils/common/UtilExceptions.h>
+#include <utils/common/Parameterised.h>
+#include <netbuild/NBPTPlatform.h>
 
 
 // ===========================================================================
@@ -80,27 +76,48 @@ protected:
     /** @brief An internal representation of an OSM-node
      */
     struct NIOSMNode {
-        NIOSMNode(long long int _id, double _lon, double _lat) :
-            id(_id), lon(_lon), lat(_lat), ele(0), tlsControlled(false), railwayCrossing(false), node(0) {}
+        NIOSMNode(long long int _id, double _lon, double _lat)
+            :
+            id(_id), lon(_lon), lat(_lat), ele(0),
+            tlsControlled(false),
+            railwayCrossing(false),
+            railwaySignal(false),
+            railwayBufferStop(false),
+            ptStopPosition(false), ptStopLength(0), name(""),
+            permissions(SVC_RAIL | SVC_BUS | SVC_TRAM),
+            node(0) { }
 
         /// @brief The node's id
         const long long int id;
         /// @brief The longitude the node is located at
-        const SUMOReal lon;
+        const double lon;
         /// @brief The latitude the node is located at
-        const SUMOReal lat;
+        const double lat;
         /// @brief The elevation of this node
-        SUMOReal ele;
+        double ele;
         /// @brief Whether this is a tls controlled junction
         bool tlsControlled;
         /// @brief Whether this is a railway crossing
         bool railwayCrossing;
+        /// @brief Whether this is a railway (main) signal
+        bool railwaySignal;
+        /// @brief Whether this is a railway buffer stop
+        bool railwayBufferStop;
+        /// @brief Whether this is a public transport stop position
+        bool ptStopPosition;
+        /// @brief The length of the pt stop
+        double ptStopLength;
+        /// @brief The name of the node
+        std::string name;
+        /// @brief type of pt stop
+        SVCPermissions permissions;
         /// @brief the NBNode that was instantiated
         NBNode* node;
 
     private:
         /// invalidated assignment operator
-        NIOSMNode& operator=(const NIOSMNode& s);
+        NIOSMNode& operator=(const NIOSMNode& s) = delete;
+
 
     };
 
@@ -115,17 +132,33 @@ protected:
         WAY_UNKNOWN = 4
     };
 
+    enum ParkingType {
+        PARKING_NONE = 0,
+        PARKING_LEFT = 1,
+        PARKING_RIGHT = 2,
+        PARKING_BOTH = WAY_FORWARD | WAY_BACKWARD,
+        PARKING_UNKNOWN = 4,
+        PARKING_FORBIDDEN = 8,
+        PARKING_PERPENDICULAR = 16,
+        PARKING_DIAGONAL = 32
+    };
+
 
     /** @brief An internal definition of a loaded edge
      */
-    struct Edge {
+    struct Edge : public Parameterised {
 
-        Edge(long long int _id) :
+        explicit Edge(long long int _id)
+            :
             id(_id), myNoLanes(-1), myNoLanesForward(0), myMaxSpeed(MAXSPEED_UNGIVEN),
             myCyclewayType(WAY_UNKNOWN), // building of extra lane depends on bikelaneWidth of loaded typemap
             myBuswayType(WAY_NONE), // buslanes are always built when declared
+            mySidewalkType(WAY_UNKNOWN), // building of extra lanes depends on sidewalkWidth of loaded typemap
+            myParkingType(PARKING_NONE), // parking areas exported optionally
             myLayer(0), // layer is non-zero only in conflict areas
-            myCurrentIsRoad(false) {}
+            myCurrentIsRoad(false),
+            myCurrentIsPlatform(false) { }
+
 
         /// @brief The edge's id
         const long long int id;
@@ -140,21 +173,28 @@ protected:
         /// @brief The type, stored in "highway" key
         std::string myHighWayType;
         /// @brief Information whether this is an one-way road
-        std::string  myIsOneWay;
+        std::string myIsOneWay;
         /// @brief Information about the kind of cycleway along this road
         WayType myCyclewayType;
         /// @brief Information about the kind of busway along this road
         WayType myBuswayType;
+        /// @brief Information about the kind of sidwalk along this road
+        WayType mySidewalkType;
+        /// @brief Information about road-side parking
+        int myParkingType;
         /// @brief Information about the relative z-ordering of ways
         int myLayer;
         /// @brief The list of nodes this edge is made of
         std::vector<long long int> myCurrentNodes;
         /// @brief Information whether this is a road
         bool myCurrentIsRoad;
+        /// @brief Information whether this is a pt platform
+        bool myCurrentIsPlatform;
 
     private:
         /// invalidated assignment operator
-        Edge& operator=(const Edge& s);
+        Edge& operator=(const Edge& s) = delete;
+
 
     };
 
@@ -194,6 +234,9 @@ private:
     /** @brief the map from OSM way ids to edge objects */
     std::map<long long int, Edge*> myEdges;
 
+    /** @brief the map from OSM way ids to platform shapes */
+    std::map<long long int, Edge*> myPlatformShapes;
+
     /// @brief The compounds types that do not contain known types
     std::set<std::string> myUnusableTypes;
 
@@ -233,13 +276,14 @@ private:
                    const std::vector<long long int>& passed, NBNetBuilder& nb);
 
     /// @brief reconstruct elevation from layer info
-    void reconstructLayerElevation(SUMOReal layerElevation, NBNetBuilder& nb);
+    void reconstructLayerElevation(double layerElevation, NBNetBuilder& nb);
 
-    /// @brief collect neighboring nodes with their road distance
-    std::map<NBNode*, SUMOReal> getNeighboringNodes(NBNode* node, SUMOReal maxDist);
+    /// @brief collect neighboring nodes with their road distance and maximum between-speed. Search does not continue beyond knownElevation-nodes
+    std::map<NBNode*, std::pair<double, double> >
+    getNeighboringNodes(NBNode* node, double maxDist, const std::set<NBNode*>& knownElevation);
 
 protected:
-    static const SUMOReal MAXSPEED_UNGIVEN;
+    static const double MAXSPEED_UNGIVEN;
     static const long long int INVALID_ID;
 
     /**
@@ -254,13 +298,13 @@ protected:
          * @param[in, out] uniqueNodes The nodes container for ensuring uniqueness
          * @param[in] options The options to use
          */
-        NodesHandler(std::map<long long int, NIOSMNode*>& toFill,
-                     std::set<NIOSMNode*, CompareNodes>& uniqueNodes,
-                     bool importElevation);
+        NodesHandler(std::map<long long int, NIOSMNode*>& toFill, std::set<NIOSMNode*,
+                     CompareNodes>& uniqueNodes,
+                     const OptionsCont& cont);
 
 
         /// @brief Destructor
-        ~NodesHandler();
+        ~NodesHandler() override;
 
 
     protected:
@@ -274,7 +318,7 @@ protected:
          * @exception ProcessError If something fails
          * @see GenericSAXHandler::myStartElement
          */
-        void myStartElement(int element, const SUMOSAXAttributes& attrs);
+        void myStartElement(int element, const SUMOSAXAttributes& attrs) override;
 
 
         /** @brief Called when a closing tag occurs
@@ -283,7 +327,7 @@ protected:
          * @exception ProcessError If something fails
          * @see GenericSAXHandler::myEndElement
          */
-        void myEndElement(int element);
+        void myEndElement(int element) override;
         //@}
 
 
@@ -307,6 +351,9 @@ protected:
         /// @brief whether elevation data should be imported
         const bool myImportElevation;
 
+        /// @brief the options
+        const OptionsCont& myOptionsCont;
+
 
     private:
         /** @brief invalidated copy constructor */
@@ -318,7 +365,6 @@ protected:
     };
 
 
-
     /**
      * @class EdgesHandler
      * @brief A class which extracts OSM-edges from a parsed OSM-file
@@ -331,11 +377,11 @@ protected:
          * @param[in, out] toFill The edges container to fill with read edges
          */
         EdgesHandler(const std::map<long long int, NIOSMNode*>& osmNodes,
-                     std::map<long long int, Edge*>& toFill);
+                     std::map<long long int, Edge*>& toFill, std::map<long long int, Edge*>& platformShapes);
 
 
         /// @brief Destructor
-        ~EdgesHandler();
+        ~EdgesHandler() override;
 
 
     protected:
@@ -349,7 +395,7 @@ protected:
          * @exception ProcessError If something fails
          * @see GenericSAXHandler::myStartElement
          */
-        void myStartElement(int element, const SUMOSAXAttributes& attrs);
+        void myStartElement(int element, const SUMOSAXAttributes& attrs) override;
 
 
         /** @brief Called when a closing tag occurs
@@ -358,7 +404,7 @@ protected:
          * @exception ProcessError If something fails
          * @see GenericSAXHandler::myEndElement
          */
-        void myEndElement(int element);
+        void myEndElement(int element) override;
         //@}
 
 
@@ -369,6 +415,9 @@ protected:
         /// @brief A map of built edges
         std::map<long long int, Edge*>& myEdgeMap;
 
+        /// @brief A map of built edges
+        std::map<long long int, Edge*>& myPlatformShapesMap;
+
         /// @brief The currently built edge
         Edge* myCurrentEdge;
 
@@ -376,7 +425,10 @@ protected:
         std::vector<int> myParentElements;
 
         /// @brief A map of non-numeric speed descriptions to their numeric values
-        std::map<std::string, SUMOReal> mySpeedMap;
+        std::map<std::string, double> mySpeedMap;
+        
+        /// @brief whether additional way attributes shall be added to the edge
+        bool myAllAttributes;
 
     private:
         /** @brief invalidated copy constructor */
@@ -400,11 +452,13 @@ protected:
          * @param[in] osmEdges The previously parse OSM-edges
          */
         RelationHandler(const std::map<long long int, NIOSMNode*>& osmNodes,
-                        const std::map<long long int, Edge*>& osmEdges);
+                        const std::map<long long int, Edge*>& osmEdges, NBPTStopCont* nbptStopCont,
+                        const std::map<long long int, Edge*>& platfromShapes, NBPTLineCont* nbptLineCont,
+                        const OptionsCont& oc);
 
 
         /// @brief Destructor
-        ~RelationHandler();
+        ~RelationHandler() override;
 
 
     protected:
@@ -418,7 +472,7 @@ protected:
          * @exception ProcessError If something fails
          * @see GenericSAXHandler::myStartElement
          */
-        void myStartElement(int element, const SUMOSAXAttributes& attrs);
+        void myStartElement(int element, const SUMOSAXAttributes& attrs) override;
 
 
         /** @brief Called when a closing tag occurs
@@ -427,7 +481,7 @@ protected:
          * @exception ProcessError If something fails
          * @see GenericSAXHandler::myEndElement
          */
-        void myEndElement(int element);
+        void myEndElement(int element) override;
         //@}
 
 
@@ -438,6 +492,15 @@ protected:
         /// @brief The previously parsed edges
         const std::map<long long int, Edge*>& myOSMEdges;
 
+        /// @brief The previously parsed platform shapes
+        const std::map<long long int, Edge*>& myPlatformShapes;
+
+        /// @brief The previously filled pt stop container
+        NBPTStopCont* myNBPTStopCont;
+
+        /// @brief PT Line container to be filled
+        NBPTLineCont* myNBPTLineCont;
+
         /// @brief The currently parsed relation
         long long int myCurrentRelation;
 
@@ -458,6 +521,9 @@ protected:
         long long int myViaWay;
 
 
+        /// @brief the options cont
+        const OptionsCont& myOptionsCont;
+
         /** @enum RestrictionType
          * @brief whether the only allowed or the only forbidden connection is defined
          */
@@ -490,6 +556,41 @@ protected:
         /** @brief invalidated assignment operator */
         RelationHandler& operator=(const RelationHandler& s);
 
+        /// @brief bus stop references
+        std::vector<long long int> myStops;
+
+
+        struct NIIPTPlatform {
+            long long int ref;
+            bool isWay;
+        };
+
+        /// @brief bus stop platforms
+        std::vector<NIIPTPlatform> myPlatforms;
+
+        /// @brief ways in pt line references
+        std::vector<long long int> myWays;
+
+        /// @brief indicates whether current relation is a pt stop area
+        bool myIsStopArea;
+
+        /// @brief indicates whether current relation is a route
+        bool myIsRoute;
+
+        /// @brief indicates whether current relation is a pt route
+        std::string myPTRouteType;
+
+        /// @brief name of the relation
+        std::string myName;
+
+        /// @brief ref of the pt line
+        std::string myRef;
+
+        /// @brief service interval of the pt line in seconds
+        int myInterval;
+
+        /// @brief night service information of the pt line
+        std::string myNightService;
     };
 
 };
