@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NIImporter_SUMO.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <map>
@@ -140,6 +134,10 @@ private:
      */
     void addLane(const SUMOSAXAttributes& attrs);
 
+    /** @brief parses stop offsets for the current lane or edge
+     * @param[in] attrs The attributes to get the stop offset sepcifics from
+     */
+    void addStopOffsets(const SUMOSAXAttributes& attrs, bool& ok);
 
     /** @brief Parses a junction and saves it in the node control
      * @param[in] attrs The attributes to get the junction's values from
@@ -186,7 +184,7 @@ private:
         /// @brief The id of the traffic light that controls this connection
         std::string tlID;
         /// @brief The index of this connection within the controlling traffic light
-        int tlLinkNo;
+        int tlLinkIndex;
         /// @brief Information about being definitely free to drive (on-ramps)
         bool mayDefinitelyPass;
         /// @brief Whether the junction must be kept clear coming from this connection
@@ -199,6 +197,8 @@ private:
         double speed;
         /// @brief custom shape connection
         PositionVector customShape;
+        /// @brief if set to true, This connection will not be TLS-controlled despite its node being controlled.
+        bool uncontrolled;
     };
 
 
@@ -220,6 +220,8 @@ private:
         double width;
         /// @brief This lane's offset from the intersection
         double endOffset;
+        /// @brief This lane's vehicle specific stop offsets
+        std::map<SVCPermissions, double> stopOffsets;
         /// @brief Whether this lane is an acceleration lane
         bool accelRamp;
         /// @brief This lane's opposite lane
@@ -259,6 +261,8 @@ private:
         NBEdge* builtEdge;
         /// @brief The lane spread function
         LaneSpreadFunction lsf;
+        /// @brief This edge's vehicle specific stop offsets (used for lanes, that do not have a specified stopOffset)
+        std::map<SVCPermissions, double> stopOffsets;
     };
 
 
@@ -277,7 +281,7 @@ private:
      */
     struct Crossing {
         Crossing(const std::string& _edgeID) :
-            edgeID(_edgeID), customTLIndex(-1) {}
+            edgeID(_edgeID), customTLIndex(-1), customTLIndex2(-1) {}
 
         std::string edgeID;
         std::vector<std::string> crossingEdges;
@@ -285,6 +289,7 @@ private:
         bool priority;
         PositionVector customShape;
         int customTLIndex;
+        int customTLIndex2;
     };
 
     /** @struct WalkingAreaParsedCustomShape
@@ -366,6 +371,13 @@ private:
     /// @brief whether walkingareas must be built
     bool myWalkingAreas;
 
+    /// @brief whether turning speed was limited in the network
+    double myLimitTurnSpeed;
+
+    /// @brief whether foe-relationships where checked at lane-level
+    bool myCheckLaneFoesAll;
+    bool myCheckLaneFoesRoundabout;
+
     /// @brief loaded roundabout edges
     std::vector<std::vector<std::string> > myRoundabouts;
 
