@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NINavTeqHelper.cpp
 /// @author  Daniel Krajzewicz
@@ -24,14 +22,10 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "NINavTeqHelper.h"
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include <utils/common/MsgHandler.h>
 #include <utils/common/UtilExceptions.h>
 #include <netbuild/NBEdge.h>
@@ -43,7 +37,7 @@
 double
 NINavTeqHelper::getSpeed(const std::string& id, const std::string& speedClassS) {
     try {
-        int speedClass = TplConvert::_2int(speedClassS.c_str());
+        int speedClass = StringUtils::toInt(speedClassS);
         switch (speedClass) {
             case -1:
                 return (double) 1.0 / (double) 3.6;
@@ -67,7 +61,7 @@ NINavTeqHelper::getSpeed(const std::string& id, const std::string& speedClassS)
                 throw ProcessError("Invalid speed code (edge '" + id + "').");
         }
     } catch (NumberFormatException&) {
-        throw ProcessError("Non-numerical value for an edge's speed type occured (edge '" + id + "').");
+        throw ProcessError("Non-numerical value for an edge's speed type occurred (edge '" + id + "').");
     }
 }
 
@@ -75,7 +69,7 @@ NINavTeqHelper::getSpeed(const std::string& id, const std::string& speedClassS)
 int
 NINavTeqHelper::getLaneNumber(const std::string& id, const std::string& laneNoS, double speed) {
     try {
-        int nolanes = TplConvert::_2int(laneNoS.c_str());
+        int nolanes = StringUtils::toInt(laneNoS);
         if (nolanes < 0) {
             return 1;
         } else if (nolanes / 10 > 0) {
@@ -97,7 +91,7 @@ NINavTeqHelper::getLaneNumber(const std::string& id, const std::string& laneNoS,
             }
         }
     } catch (NumberFormatException&) {
-        throw ProcessError("Non-numerical value for an edge's lane number occured (edge '" + id + "'.");
+        throw ProcessError("Non-numerical value for an edge's lane number occurred (edge '" + id + "'.");
     }
 }
 
