@@ -2,12 +2,12 @@ const std::string opendriveTypemap =
 "<types xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:noNamespaceSchemaLocation=\"http://sumo.dlr.de/xsd/types_file.xsd\">\n"
 "    <type id=\"driving\"       priority=\"1\"  speed=\"13.89\" width=\"3.65\" disallow=\"pedestrian rail rail_urban rail_electric tram ship\"/>\n"
 "    <type id=\"stop\"          priority=\"1\"  speed=\"13.89\" width=\"3.65\" disallow=\"pedestrian rail rail_urban rail_electric tram ship\"/>\n"
-"    <type id=\"restricted\"    priority=\"0\"  speed=\"13.89\" width=\"3.65\" disallow=\"all\"/> <!-- best guess at semantics based on examples from http://www.opendrive.org -->\n"
+"    <type id=\"restricted\"    priority=\"0\"  speed=\"13.89\" width=\"3.65\" disallow=\"all\"/> <!-- ambiguous semantics. Could mean bus-lane as well as fully-area restricted (but surfaced) lane area (examples from http://www.opendrive.org -->\n"
 "    <type id=\"parking\"       priority=\"1\"  speed=\"1.39\"  width=\"2.50\" disallow=\"pedestrian rail rail_urban rail_electric tram ship\"/>\n"
 "    <type id=\"entry\"         priority=\"1\"  speed=\"22.22\" width=\"3.65\" disallow=\"pedestrian rail rail_urban rail_electric tram ship\"/>\n"
 "    <type id=\"exit\"          priority=\"1\"  speed=\"22.22\" width=\"3.65\" disallow=\"pedestrian rail rail_urban rail_electric tram ship\"/>\n"
-"    <type id=\"OffRamp\"       priority=\"1\"  speed=\"22.22\" width=\"3.65\" disallow=\"pedestrian bicycle moped rail rail_urban rail_electric tram ship\"/>\n"
-"    <type id=\"OnRamp\"        priority=\"1\"  speed=\"22.22\" width=\"3.65\" disallow=\"pedestrian bicycle moped rail rail_urban rail_electric tram ship\"/>\n"
+"    <type id=\"offRamp\"       priority=\"1\"  speed=\"22.22\" width=\"3.65\" disallow=\"pedestrian bicycle moped rail rail_urban rail_electric tram ship\"/>\n"
+"    <type id=\"onRamp\"        priority=\"1\"  speed=\"22.22\" width=\"3.65\" disallow=\"pedestrian bicycle moped rail rail_urban rail_electric tram ship\"/>\n"
 "    <type id=\"roadWorks\"     priority=\"0\"  speed=\"1.39\"  width=\"3.65\" allow=\"authority\"/>\n"
 "    <type id=\"tram\"          priority=\"2\"  speed=\"13.89\" width=\"3.65\" allow=\"tram\"/>\n"
 "    <type id=\"rail\"          priority=\"3\"  speed=\"33.33\" width=\"3.65\" allow=\"rail rail_urban rail_electric\"/>\n"
@@ -19,7 +19,7 @@ const std::string opendriveTypemap =
 "    -->\n"
 "\n"
 "    <!-- discarded -->\n"
-"    <type id=\"none\"          priority=\"0\"  speed=\"1.39\"  width=\"1.0\"  disallow=\"all\"          discard=\"true\"/>\n"
+"    <type id=\"none\"          priority=\"0\"  speed=\"1.39\" width=\"1.0\"   disallow=\"all\"          discard=\"true\"/> <!-- non-lane spacing. gives ugly junction shapes when present on the outside of edges (as seen in official examples) -->\n"
 "    <type id=\"shoulder\"      priority=\"0\"  speed=\"1.39\" width=\"1.0\"   disallow=\"all\"          discard=\"true\"/>\n"
 "    <type id=\"border\"        priority=\"0\"  speed=\"1.39\" width=\"0.1\"   disallow=\"all\"          discard=\"true\"/>\n"
 "    <type id=\"median\"        priority=\"0\"  speed=\"1.39\" width=\"0.1\"   disallow=\"all\"          discard=\"true\"/>\n"
@@ -52,7 +52,6 @@ const std::string osmTypemap =
 "    <type id=\"highway.living_street\"  numLanes=\"1\" speed=\"2.78\"  priority=\"3\"  oneway=\"false\" disallow=\"rail rail_urban rail_electric tram ship\"/>\n"
 "    <type id=\"highway.service\"        numLanes=\"1\" speed=\"5.56\"  priority=\"2\"  oneway=\"false\" allow=\"delivery pedestrian bicycle\"/>\n"
 "    <type id=\"highway.track\"          numLanes=\"1\" speed=\"5.56\"  priority=\"1\"  oneway=\"false\" disallow=\"rail rail_urban rail_electric tram ship\"/>\n"
-"    <type id=\"highway.services\"       numLanes=\"1\" speed=\"8.33\"  priority=\"1\"  oneway=\"false\" disallow=\"rail rail_urban rail_electric tram ship\"/>\n"
 "    <type id=\"highway.unsurfaced\"     numLanes=\"1\" speed=\"8.33\"  priority=\"1\"  oneway=\"false\" disallow=\"rail rail_urban rail_electric tram ship\"/>\n"
 "\n"
 "    <!-- everything which serves mainly pedestrians is oneway because all current pedestrian models do not care about direction -->\n"
@@ -60,12 +59,12 @@ const std::string osmTypemap =
 "    <type id=\"highway.pedestrian\"     numLanes=\"1\" speed=\"2.78\"  priority=\"1\"  oneway=\"true\"  width=\"2\" allow=\"pedestrian\"/>\n"
 "    <type id=\"highway.path\"           numLanes=\"1\" speed=\"2.78\"  priority=\"1\"  oneway=\"true\"  width=\"2\" allow=\"pedestrian bicycle\"/>\n"
 "    <type id=\"highway.bridleway\"      numLanes=\"1\" speed=\"2.78\"  priority=\"1\"  oneway=\"true\"  width=\"2\" allow=\"pedestrian\"/>\n"
-"    <type id=\"highway.cycleway\"       numLanes=\"1\" speed=\"5.56\"  priority=\"1\"  oneway=\"false\" width=\"1\" allow=\"bicycle\"/>\n"
+"    <type id=\"highway.cycleway\"       numLanes=\"1\" speed=\"8.33\"  priority=\"1\"  oneway=\"false\" width=\"1\" allow=\"bicycle\"/>\n"
 "    <type id=\"highway.step\"           numLanes=\"1\" speed=\"1.39\"  priority=\"1\"  oneway=\"true\"  width=\"2\" allow=\"pedestrian\"/>\n"
 "    <type id=\"highway.steps\"          numLanes=\"1\" speed=\"1.39\"  priority=\"1\"  oneway=\"true\"  width=\"2\" allow=\"pedestrian\"/>\n"
 "    <type id=\"highway.stairs\"         numLanes=\"1\" speed=\"1.39\"  priority=\"1\"  oneway=\"true\"  width=\"2\" allow=\"pedestrian\"/>\n"
 "\n"
-"    <type id=\"highway.bus_guideway\"   numLanes=\"1\" speed=\"8.33\"  priority=\"1\"  oneway=\"true\"  allow=\"bus\"/>\n"
+"    <type id=\"highway.bus_guideway\"   numLanes=\"1\" speed=\"27.78\" priority=\"1\"  oneway=\"true\"  allow=\"bus\"/>\n"
 "    <type id=\"highway.raceway\"        numLanes=\"2\" speed=\"83.33\" priority=\"14\" oneway=\"false\" allow=\"vip\"/>\n"
 "    <type id=\"highway.ford\"           numLanes=\"1\" speed=\"2.78\"  priority=\"1\"  oneway=\"false\" allow=\"army\"/>\n"
 "\n"
