@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NIImporter_Vissim.cpp
 /// @author  Daniel Krajzewicz
@@ -25,17 +23,13 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 
 #include <string>
 #include <fstream>
 #include <utils/common/StringUtils.h>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include <utils/common/MsgHandler.h>
 #include <utils/options/OptionsCont.h>
 #include <netbuild/NBNetBuilder.h>
@@ -241,23 +235,23 @@ NIImporter_Vissim::NIVissimXMLHandler_Streckendefinition::myStartElement(int ele
     if (element == VISSIM_TAG_LINK) {
         //parse all links
         bool ok = true;
-        int id = attrs.get<int>(VISSIM_ATTR_NO, 0, ok);
+        int id = attrs.get<int>(VISSIM_ATTR_NO, nullptr, ok);
         myLastNodeID = id;
 
         // !!! assuming empty myElemData
-        myElemData["id"].push_back(attrs.get<std::string>(VISSIM_ATTR_NO, 0, ok));
+        myElemData["id"].push_back(attrs.get<std::string>(VISSIM_ATTR_NO, nullptr, ok));
         // error ignored if name is empty
-        myElemData["name"].push_back(attrs.get<std::string>(VISSIM_ATTR_NAME, 0, ok, false));
-        myElemData["type"].push_back(attrs.get<std::string>(VISSIM_ATTR_LINKBEHAVETYPE, 0, ok));
-        myElemData["zuschlag1"].push_back(attrs.get<std::string>(VISSIM_ATTR_ZUSCHLAG1, 0, ok));
-        myElemData["zuschlag2"].push_back(attrs.get<std::string>(VISSIM_ATTR_ZUSCHLAG2, 0, ok));
+        myElemData["name"].push_back(attrs.get<std::string>(VISSIM_ATTR_NAME, nullptr, ok, false));
+        myElemData["type"].push_back(attrs.get<std::string>(VISSIM_ATTR_LINKBEHAVETYPE, nullptr, ok));
+        myElemData["zuschlag1"].push_back(attrs.get<std::string>(VISSIM_ATTR_ZUSCHLAG1, nullptr, ok));
+        myElemData["zuschlag2"].push_back(attrs.get<std::string>(VISSIM_ATTR_ZUSCHLAG2, nullptr, ok));
     }
 
     if (element == VISSIM_TAG_LANE) {
         bool ok = true;
         // appends empty element if no width found
         // error ignored if name is empty
-        myElemData["width"].push_back(attrs.get<std::string>(VISSIM_ATTR_WIDTH, 0, ok, false));
+        myElemData["width"].push_back(attrs.get<std::string>(VISSIM_ATTR_WIDTH, nullptr, ok, false));
     }
 
     if (element == VISSIM_TAG_FROM) {
@@ -266,8 +260,8 @@ NIImporter_Vissim::NIVissimXMLHandler_Streckendefinition::myStartElement(int ele
         }
         bool ok = true;
         std::vector<std::string> from(StringTokenizer(attrs.get<std::string>(
-                                          VISSIM_ATTR_LANE, 0, ok), " ").getVector());
-        myElemData["from_pos"].push_back(attrs.get<std::string>(VISSIM_ATTR_POS, 0, ok));
+                                          VISSIM_ATTR_LANE, nullptr, ok), " ").getVector());
+        myElemData["from_pos"].push_back(attrs.get<std::string>(VISSIM_ATTR_POS, nullptr, ok));
         myElemData["from_id"].push_back(from[0]);
         myElemData["from_lane"].push_back(from[1]);
     }
@@ -275,8 +269,8 @@ NIImporter_Vissim::NIVissimXMLHandler_Streckendefinition::myStartElement(int ele
     if (element == VISSIM_TAG_TO) {
         bool ok = true;
         std::vector<std::string> to(StringTokenizer(attrs.get<std::string>(
-                                        VISSIM_ATTR_LANE, 0, ok), " ").getVector());
-        myElemData["to_pos"].push_back(attrs.get<std::string>(VISSIM_ATTR_POS, 0, ok));
+                                        VISSIM_ATTR_LANE, nullptr, ok), " ").getVector());
+        myElemData["to_pos"].push_back(attrs.get<std::string>(VISSIM_ATTR_POS, nullptr, ok));
         myElemData["to_id"].push_back(to[0]);
         myElemData["to_lane"].push_back(to[1]);
     }
@@ -286,11 +280,11 @@ NIImporter_Vissim::NIVissimXMLHandler_Streckendefinition::myStartElement(int ele
         // create a <sep> separated string of coordinate data
         std::string sep(" ");
 
-        std::string posS(attrs.get<std::string>(VISSIM_ATTR_X, 0, ok));
+        std::string posS(attrs.get<std::string>(VISSIM_ATTR_X, nullptr, ok));
         posS += sep;
-        posS.append(attrs.get<std::string>(VISSIM_ATTR_Y, 0, ok));
+        posS.append(attrs.get<std::string>(VISSIM_ATTR_Y, nullptr, ok));
         // allow for no Z
-        std::string z(attrs.get<std::string>(VISSIM_ATTR_ZOFFSET, 0, ok, false));
+        std::string z(attrs.get<std::string>(VISSIM_ATTR_ZOFFSET, nullptr, ok, false));
         if (z.length() > 0) {
             posS += sep;
             posS.append(z);
@@ -308,7 +302,7 @@ NIImporter_Vissim::NIVissimXMLHandler_Streckendefinition::myEndElement(int eleme
 
         NIVissimClosedLanesVector clv;          //FIXME -> clv einlesen
         std::vector<int> assignedVehicles;      //FIXME -> assignedVehicles einlesen
-        int id(TplConvert::_str2int(myElemData["id"].front()));
+        int id(StringUtils::toInt(myElemData["id"].front()));
 
         PositionVector geom;
         // convert all position coordinate strings to PositionVectors
@@ -320,7 +314,7 @@ NIImporter_Vissim::NIVissimXMLHandler_Streckendefinition::myEndElement(int eleme
 
             // doing a transform with explicit hint on function signature
             std::transform(sPos_v.begin(), sPos_v.end(), pos_v.begin(),
-                           TplConvert::_str2double);
+                           StringUtils::toDouble);
             geom.push_back_noDoublePos(Position(pos_v[0], pos_v[1], pos_v[2]));
         }
         // FIXME: a length = 0 PosVec seems fatal -> segfault
@@ -332,8 +326,8 @@ NIImporter_Vissim::NIVissimXMLHandler_Streckendefinition::myEndElement(int eleme
                                                   myElemData["name"].front(),
                                                   myElemData["type"].front(),
                                                   (int)myElemData["width"].size(),   // numLanes,
-                                                  TplConvert::_str2double(myElemData["zuschlag1"].front()),
-                                                  TplConvert::_str2double(myElemData["zuschlag2"].front()),
+                                                  StringUtils::toDouble(myElemData["zuschlag1"].front()),
+                                                  StringUtils::toDouble(myElemData["zuschlag2"].front()),
                                                   length, geom, clv);
             NIVissimEdge::dictionary(id, edge);
             if (id == 85 || id == 91) {
@@ -349,30 +343,30 @@ NIImporter_Vissim::NIVissimXMLHandler_Streckendefinition::myEndElement(int eleme
 
             //NOTE: there should be only 1 lane number in XML
             // subtraction of 1 as in readExtEdgePointDef()
-            laneVec[0] = TplConvert::_str2int(myElemData["from_lane"].front()) - 1;
+            laneVec[0] = StringUtils::toInt(myElemData["from_lane"].front()) - 1;
             // then count up, building lane number vector
             for (std::vector<int>::iterator each = ++laneVec.begin(); each != laneVec.end(); ++each) {
                 *each = *(each - 1) + 1;
             }
 
             NIVissimExtendedEdgePoint from_def(
-                TplConvert::_str2int(myElemData["from_id"].front()),
+                StringUtils::toInt(myElemData["from_id"].front()),
                 laneVec,
-                TplConvert::_str2double(myElemData["from_pos"].front()),
+                StringUtils::toDouble(myElemData["from_pos"].front()),
                 assignedVehicles);
 
             //NOTE: there should be only 1 lane number in XML
             // subtraction of 1 as in readExtEdgePointDef()
-            laneVec[0] = TplConvert::_str2int(myElemData["to_lane"].front()) - 1;
+            laneVec[0] = StringUtils::toInt(myElemData["to_lane"].front()) - 1;
             // then count up, building lane number vector
             for (std::vector<int>::iterator each = ++laneVec.begin(); each != laneVec.end(); ++each) {
                 *each = *(each - 1) + 1;
             }
 
             NIVissimExtendedEdgePoint to_def(
-                TplConvert::_str2int(myElemData["to_id"].front()),
+                StringUtils::toInt(myElemData["to_id"].front()),
                 laneVec,
-                TplConvert::_str2double(myElemData["to_pos"].front()),
+                StringUtils::toDouble(myElemData["to_pos"].front()),
                 assignedVehicles);
 
             NIVissimConnection* connector = new
@@ -411,9 +405,9 @@ NIImporter_Vissim::NIVissimXMLHandler_Zuflussdefinition::myStartElement(int elem
     if (element == VISSIM_TAG_VEHICLE_INPUT) {
         //parse all flows
         bool ok = true;
-        std::string id = attrs.get<std::string>(VISSIM_ATTR_NO, 0, ok);
-        std::string edgeid = attrs.get<std::string>(VISSIM_ATTR_LINK, 0, ok);
-        std::string name = attrs.get<std::string>(VISSIM_ATTR_NAME, 0, ok, false);
+        std::string id = attrs.get<std::string>(VISSIM_ATTR_NO, nullptr, ok);
+        std::string edgeid = attrs.get<std::string>(VISSIM_ATTR_LINK, nullptr, ok);
+        std::string name = attrs.get<std::string>(VISSIM_ATTR_NAME, nullptr, ok, false);
 
         NIVissimSource::dictionary(id,
                                    name,
@@ -438,18 +432,18 @@ NIImporter_Vissim::NIVissimXMLHandler_Parkplatzdefinition::myStartElement(int el
     if (element == VISSIM_TAG_PARKINGLOT) {
         //parse all parkinglots
         bool ok = true;
-        int id = attrs.get<int>(VISSIM_ATTR_NO, 0, ok);
-        int edgeid = attrs.get<int>(VISSIM_ATTR_INTLINK, 0, ok);
-        std::string name = attrs.get<std::string>(VISSIM_ATTR_NAME, 0, ok, false);
-        double position = attrs.get<double>(VISSIM_ATTR_POS, 0, ok);
+        int id = attrs.get<int>(VISSIM_ATTR_NO, nullptr, ok);
+        int edgeid = attrs.get<int>(VISSIM_ATTR_INTLINK, nullptr, ok);
+        std::string name = attrs.get<std::string>(VISSIM_ATTR_NAME, nullptr, ok, false);
+        double position = attrs.get<double>(VISSIM_ATTR_POS, nullptr, ok);
         std::vector<std::pair<int, int> > assignedVehicles; // (vclass, vwunsch)
         //FIXME: vWunsch + Fahzeugklassen einlesen
         // There can be s
         std::vector<int> districts;
         //FIXME: Parkplatzdefinition für mehrere Zonen implementieren
         std::vector<double> percentages;
-        districts.push_back(attrs.get<int>(VISSIM_ATTR_DISTRICT, 0, ok));
-        percentages.push_back(attrs.get<double>(VISSIM_ATTR_PERCENTAGE, 0, ok));
+        districts.push_back(attrs.get<int>(VISSIM_ATTR_DISTRICT, nullptr, ok));
+        percentages.push_back(attrs.get<double>(VISSIM_ATTR_PERCENTAGE, nullptr, ok));
 
         NIVissimDistrictConnection::dictionary(id,
                                                name,
@@ -482,9 +476,9 @@ NIImporter_Vissim::NIVissimXMLHandler_Fahrzeugklassendefinition::myStartElement(
 
     if (element == VISSIM_TAG_VEHICLE_CLASS) {
         bool ok = true;
-        myElemData["id"].push_back(attrs.get<std::string>(VISSIM_ATTR_NO, 0, ok));
-        myElemData["name"].push_back(attrs.get<std::string>(VISSIM_ATTR_NAME, 0, ok, false));
-        std::string colorStr(attrs.get<std::string>(VISSIM_ATTR_COLOR, 0, ok));
+        myElemData["id"].push_back(attrs.get<std::string>(VISSIM_ATTR_NO, nullptr, ok));
+        myElemData["name"].push_back(attrs.get<std::string>(VISSIM_ATTR_NAME, nullptr, ok, false));
+        std::string colorStr(attrs.get<std::string>(VISSIM_ATTR_COLOR, nullptr, ok));
         for (int pos = (int)colorStr.size() - 2; pos > 0; pos -= 2) {
             colorStr.insert(pos, " ");
         }
@@ -492,7 +486,7 @@ NIImporter_Vissim::NIVissimXMLHandler_Fahrzeugklassendefinition::myStartElement(
     }
     if (element == VISSIM_TAG_INTOBJECTREF) {
         bool ok = true;
-        myElemData["types"].push_back(attrs.get<std::string>(VISSIM_ATTR_KEY, 0, ok));
+        myElemData["types"].push_back(attrs.get<std::string>(VISSIM_ATTR_KEY, nullptr, ok));
 
 
     }
@@ -506,8 +500,7 @@ NIImporter_Vissim::NIVissimXMLHandler_Fahrzeugklassendefinition::myEndElement(in
         std::vector<std::string> sCol_v(StringTokenizer(
                                             myElemData["color"].front(), " ").getVector());
         std::vector<int> myColorVector(sCol_v.size());
-        std::transform(sCol_v.begin(), sCol_v.end(), myColorVector.begin(),
-                       (TplConvert::_strHex2int));
+        std::transform(sCol_v.begin(), sCol_v.end(), myColorVector.begin(), StringUtils::hexToInt);
 
         color = RGBColor((unsigned char)myColorVector[0],
                          (unsigned char)myColorVector[1],
@@ -515,11 +508,11 @@ NIImporter_Vissim::NIVissimXMLHandler_Fahrzeugklassendefinition::myEndElement(in
                          (unsigned char)myColorVector[3]);
         std::vector<int> types;
         while (!myElemData["types"].empty()) {
-            types.push_back(TplConvert::_str2int(myElemData["types"].front()));
+            types.push_back(StringUtils::toInt(myElemData["types"].front()));
             myElemData["types"].pop_front();
         }
 
-        NIVissimVehTypeClass::dictionary(TplConvert::_str2int(myElemData["id"].front()),
+        NIVissimVehTypeClass::dictionary(StringUtils::toInt(myElemData["id"].front()),
                                          myElemData["name"].front(),
                                          color,
                                          types);
@@ -547,15 +540,15 @@ NIImporter_Vissim::NIVissimXMLHandler_Geschwindigkeitsverteilungsdefinition::myS
     myHierarchyLevel++;
     if (element == VISSIM_TAG_SPEED_DIST) {
         bool ok = true;
-        myElemData["id"].push_back(attrs.get<std::string>(VISSIM_ATTR_NO, 0, ok));
+        myElemData["id"].push_back(attrs.get<std::string>(VISSIM_ATTR_NO, nullptr, ok));
     }
 
     if (element == VISSIM_TAG_DATAPOINT) {
         bool ok = true;
         std::string sep(" ");
-        std::string posS(attrs.get<std::string>(VISSIM_ATTR_X, 0, ok));
+        std::string posS(attrs.get<std::string>(VISSIM_ATTR_X, nullptr, ok));
         posS += sep;
-        posS.append(attrs.get<std::string>(VISSIM_ATTR_FX, 0, ok));
+        posS.append(attrs.get<std::string>(VISSIM_ATTR_FX, nullptr, ok));
         myElemData["points"].push_back(posS);
 
     }
@@ -570,7 +563,7 @@ NIImporter_Vissim::NIVissimXMLHandler_Geschwindigkeitsverteilungsdefinition::myE
             std::vector<std::string> sPos_v(StringTokenizer(
                                                 myElemData["points"].front(), " ").getVector());
             myElemData["points"].pop_front();
-            points->add(TplConvert::_str2double(sPos_v[0]), TplConvert::_str2double(sPos_v[1]));
+            points->add(StringUtils::toDouble(sPos_v[0]), StringUtils::toDouble(sPos_v[1]));
         }
         DistributionCont::dictionary("speed", myElemData["id"].front(), points);
         myElemData.clear();
@@ -597,7 +590,7 @@ NIImporter_Vissim::NIVissimXMLHandler_VWunschentscheidungsdefinition::myStartEle
     myHierarchyLevel++;
     if (element == VISSIM_TAG_SPEED_DECISION) {
         bool ok = true;
-        myElemData["name"].push_back(attrs.get<std::string>(VISSIM_ATTR_NAME, 0, ok, false));
+        myElemData["name"].push_back(attrs.get<std::string>(VISSIM_ATTR_NAME, nullptr, ok, false));
         //FIXME: 2 vWunsch in the xml file, but only 1 of them is set???
     }
 
@@ -628,14 +621,14 @@ NIImporter_Vissim::NIVissimXMLHandler_Routenentscheidungsdefinition::myStartElem
     myHierarchyLevel++;
     if (element == VISSIM_TAG_DECISION_STATIC) {
         bool ok = true;
-        myElemData["startLink"].push_back(attrs.get<std::string>(VISSIM_ATTR_LINK, 0, ok));
-        myElemData["startPos"].push_back(attrs.get<std::string>(VISSIM_ATTR_POS, 0, ok));
+        myElemData["startLink"].push_back(attrs.get<std::string>(VISSIM_ATTR_LINK, nullptr, ok));
+        myElemData["startPos"].push_back(attrs.get<std::string>(VISSIM_ATTR_POS, nullptr, ok));
     }
     if (element == VISSIM_TAG_ROUTE_STATIC) {
         bool ok = true;
-        myElemData["destLink"].push_back(attrs.get<std::string>(VISSIM_ATTR_DESTLINK, 0, ok));
-        myElemData["destPos"].push_back(attrs.get<std::string>(VISSIM_ATTR_DESTPOS, 0, ok));
-        myElemData["id"].push_back(attrs.get<std::string>(VISSIM_ATTR_NO, 0, ok));
+        myElemData["destLink"].push_back(attrs.get<std::string>(VISSIM_ATTR_DESTLINK, nullptr, ok));
+        myElemData["destPos"].push_back(attrs.get<std::string>(VISSIM_ATTR_DESTPOS, nullptr, ok));
+        myElemData["id"].push_back(attrs.get<std::string>(VISSIM_ATTR_NO, nullptr, ok));
     }
     if (element == VISSIM_TAG_INTOBJECTREF) {
         // bool ok = true;
@@ -664,12 +657,12 @@ NIImporter_Vissim::NIVissimXMLHandler_ConflictArea::myStartElement(int element,
     if (element == VISSIM_TAG_CA) {
         //parse all flows
         bool ok = true;
-        std::string status = attrs.get<std::string>(VISSIM_ATTR_STATUS, 0, ok);
+        std::string status = attrs.get<std::string>(VISSIM_ATTR_STATUS, nullptr, ok);
         //get only the conflict areas which were set in VISSIM
         if (status != "PASSIVE") {
-            NIVissimConflictArea::dictionary(attrs.get<int>(VISSIM_ATTR_NO, 0, ok),
-                                             attrs.get<std::string>(VISSIM_ATTR_LINK1, 0, ok),
-                                             attrs.get<std::string>(VISSIM_ATTR_LINK2, 0, ok),
+            NIVissimConflictArea::dictionary(attrs.get<int>(VISSIM_ATTR_NO, nullptr, ok),
+                                             attrs.get<std::string>(VISSIM_ATTR_LINK1, nullptr, ok),
+                                             attrs.get<std::string>(VISSIM_ATTR_LINK2, nullptr, ok),
                                              status);
         }
 
@@ -784,7 +777,7 @@ NIImporter_Vissim::VissimSingleTypeParser::parseAssignedVehicleTypes(
         return ret;
     }
     while (tmp != "DATAEND" && tmp != next) {
-        ret.push_back(TplConvert::_2int(tmp.c_str()));
+        ret.push_back(StringUtils::toInt(tmp));
         tmp = readEndSecure(from);
     }
     return ret;
@@ -803,7 +796,7 @@ NIImporter_Vissim::VissimSingleTypeParser::readExtEdgePointDef(
     while (tag != "bei") {
         tag = readEndSecure(from);
         if (tag != "bei") {
-            int lane = TplConvert::_2int(tag.c_str());
+            int lane = StringUtils::toInt(tag);
             lanes.push_back(lane - 1);
         }
     }
