@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NIVissimConflictArea.cpp
 /// @author  Lukas Grohmann
@@ -21,17 +19,13 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iterator>
 #include <map>
 #include <string>
 #include <utils/common/ToString.h>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include "NIVissimConflictArea.h"
 #include "NIVissimConnection.h"
 #include <netbuild/NBEdgeCont.h>
@@ -91,7 +85,7 @@ NIVissimConflictArea*
 NIVissimConflictArea::dictionary(int id) {
     DictType::iterator i = myDict.find(id);
     if (i == myDict.end()) {
-        return 0;
+        return nullptr;
     }
     return (*i).second;
 }
@@ -107,7 +101,7 @@ NIVissimConflictArea::dict_findByLinks(const std::string& link1,
             return (*i).second;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 
@@ -125,9 +119,9 @@ NIVissimConflictArea::setPriorityRegulation(NBEdgeCont& ec) {
     std::map<int, NIVissimConflictArea*>::iterator it;
     for (it = myDict.begin(); it != myDict.end(); it++) {
         NIVissimConflictArea* const conflictArea = it->second;
-        NIVissimConnection* const firstLink = NIVissimConnection::dictionary(TplConvert::_str2int(conflictArea->getFirstLink()));
-        NIVissimConnection* const secondLink = NIVissimConnection::dictionary(TplConvert::_str2int(conflictArea->getSecondLink()));
-        if (firstLink == 0 || secondLink == 0) {
+        NIVissimConnection* const firstLink = NIVissimConnection::dictionary(StringUtils::toInt(conflictArea->getFirstLink()));
+        NIVissimConnection* const secondLink = NIVissimConnection::dictionary(StringUtils::toInt(conflictArea->getSecondLink()));
+        if (firstLink == nullptr || secondLink == nullptr) {
             continue;
         }
         // status == "TWOYIELDSONE"
@@ -147,7 +141,7 @@ NIVissimConflictArea::setPriorityRegulation(NBEdgeCont& ec) {
         NBEdge* const mustStopFrom =  ec.retrievePossiblySplit(mustStopFrom_id, true);
         NBEdge* const mustStopTo =  ec.retrievePossiblySplit(mustStopTo_id, false);
 
-        if (mayDriveFrom != 0 && mayDriveTo != 0 && mustStopFrom != 0 && mustStopTo != 0) {
+        if (mayDriveFrom != nullptr && mayDriveTo != nullptr && mustStopFrom != nullptr && mustStopTo != nullptr) {
             NBNode* node = mayDriveFrom->getToNode();
             node->addSortedLinkFoes(
                 NBConnection(mayDriveFrom, mayDriveTo),
