@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NIVissimDisturbance.cpp
 /// @author  Daniel Krajzewicz
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 
 #include <map>
@@ -100,7 +94,7 @@ NIVissimDisturbance*
 NIVissimDisturbance::dictionary(int id) {
     DictType::iterator i = myDict.find(id);
     if (i == myDict.end()) {
-        return 0;
+        return nullptr;
     }
     return (*i).second;
 }
@@ -121,10 +115,10 @@ void
 NIVissimDisturbance::computeBounding() {
     assert(myBoundary == 0);
     Boundary* bound = new Boundary();
-    if (NIVissimAbstractEdge::dictionary(myEdge.getEdgeID()) != 0) {
+    if (NIVissimAbstractEdge::dictionary(myEdge.getEdgeID()) != nullptr) {
         bound->add(myEdge.getGeomPosition());
     }
-    if (NIVissimAbstractEdge::dictionary(myDisturbance.getEdgeID()) != 0) {
+    if (NIVissimAbstractEdge::dictionary(myDisturbance.getEdgeID()) != nullptr) {
         bound->add(myDisturbance.getGeomPosition());
     }
     myBoundary = bound;
@@ -141,7 +135,7 @@ NIVissimDisturbance::addToNode(NBNode* node, NBDistrictCont& dc,
         NIVissimConnection::dictionary(myEdge.getEdgeID());
     NIVissimConnection* bc =
         NIVissimConnection::dictionary(myDisturbance.getEdgeID());
-    if (pc == 0 && bc == 0) {
+    if (pc == nullptr && bc == nullptr) {
         // This has not been tested completely, yet
         // Both competing abstract edges are normal edges
         // We have to find a crossing point, build a node here,
@@ -154,9 +148,9 @@ NIVissimDisturbance::addToNode(NBNode* node, NBDistrictCont& dc,
         std::string id2 = toString<int>(e2->getID()) + "x" + toString<int>(e1->getID());
         NBNode* node1 = nc.retrieve(id1);
         NBNode* node2 = nc.retrieve(id2);
-        NBNode* node = 0;
+        NBNode* node = nullptr;
         assert(node1 == 0 || node2 == 0);
-        if (node1 == 0 && node2 == 0) {
+        if (node1 == nullptr && node2 == nullptr) {
             refusedProhibits++;
             return false;
             /*            node = new NBNode(id1, pos.x(), pos.y(), "priority");
@@ -165,7 +159,7 @@ NIVissimDisturbance::addToNode(NBNode* node, NBDistrictCont& dc,
                             throw 1;
                         }*/
         } else {
-            node = node1 == 0 ? node2 : node1;
+            node = node1 == nullptr ? node2 : node1;
         }
         ec.splitAt(dc, ec.retrievePossiblySplit(toString<int>(e1->getID()), myEdge.getPosition()), node);
         ec.splitAt(dc, ec.retrievePossiblySplit(toString<int>(e2->getID()), myDisturbance.getPosition()), node);
@@ -175,7 +169,7 @@ NIVissimDisturbance::addToNode(NBNode* node, NBDistrictCont& dc,
         NBEdge* mayDriveTo = ec.retrieve(toString<int>(e1->getID()) + "[1]");
         NBEdge* mustStopFrom = ec.retrieve(toString<int>(e2->getID()) + "[0]");
         NBEdge* mustStopTo = ec.retrieve(toString<int>(e2->getID()) + "[1]");
-        if (mayDriveFrom != 0 && mayDriveTo != 0 && mustStopFrom != 0 && mustStopTo != 0) {
+        if (mayDriveFrom != nullptr && mayDriveTo != nullptr && mustStopFrom != nullptr && mustStopTo != nullptr) {
             node->addSortedLinkFoes(
                 NBConnection(mayDriveFrom, mayDriveTo),
                 NBConnection(mayDriveFrom, mayDriveTo));
@@ -185,14 +179,14 @@ NIVissimDisturbance::addToNode(NBNode* node, NBDistrictCont& dc,
             // !!! warning
         }
 //        }
-    } else if (pc != 0 && bc == 0) {
+    } else if (pc != nullptr && bc == nullptr) {
         // The prohibited abstract edge is a connection, the other
         //  is not;
         // The connection will be prohibitesd by all connections
         //  outgoing from the "real" edge
 
         NBEdge* e = ec.retrievePossiblySplit(toString<int>(myDisturbance.getEdgeID()), myDisturbance.getPosition());
-        if (e == 0) {
+        if (e == nullptr) {
             WRITE_WARNING("Could not prohibit '" + toString<int>(myEdge.getEdgeID()) + "' by '" + toString<int>(myDisturbance.getEdgeID()) + "'. Have not found disturbance.");
             refusedProhibits++;
             return false;
@@ -210,7 +204,7 @@ NIVissimDisturbance::addToNode(NBNode* node, NBDistrictCont& dc,
         NBEdge* pcie = ec.retrievePossiblySplit(id_pcie, id_pcoe, false);
         // check whether it's ending node is the node the prohibited
         //  edge end at
-        if (pcoe != 0 && pcie != 0 && pcoe->getToNode() == e->getToNode()) {
+        if (pcoe != nullptr && pcie != nullptr && pcoe->getToNode() == e->getToNode()) {
             // if so, simply prohibit the connections
             NBNode* node = e->getToNode();
             const EdgeVector& connected = e->getConnectedEdges();
@@ -239,14 +233,14 @@ NIVissimDisturbance::addToNode(NBNode* node, NBDistrictCont& dc,
             }
             */
         }
-    } else if (bc != 0 && pc == 0) {
+    } else if (bc != nullptr && pc == nullptr) {
         // The prohibiting abstract edge is a connection, the other
         //  is not;
         // We have to split the other one and add the prohibition
         //  description
 
         NBEdge* e = ec.retrievePossiblySplit(toString<int>(myEdge.getEdgeID()), myEdge.getPosition());
-        if (e == 0) {
+        if (e == nullptr) {
             WRITE_WARNING("Could not prohibit '" + toString<int>(myEdge.getEdgeID()) + "' - it was not built.");
             return false;
         }
@@ -265,7 +259,7 @@ NIVissimDisturbance::addToNode(NBNode* node, NBDistrictCont& dc,
         NBEdge* bcie = ec.retrievePossiblySplit(id_bcie, id_bcoe, false);
         // check whether it's ending node is the node the prohibited
         //  edge end at
-        if (bcoe != 0 && bcie != 0 && bcoe->getToNode() == e->getToNode()) {
+        if (bcoe != nullptr && bcie != nullptr && bcoe->getToNode() == e->getToNode()) {
             // if so, simply prohibit the connections
             NBNode* node = e->getToNode();
             const EdgeVector& connected = e->getConnectedEdges();
@@ -309,7 +303,7 @@ NIVissimDisturbance::addToNode(NBNode* node, NBDistrictCont& dc,
 
 NBConnection
 NIVissimDisturbance::getConnection(NBNode* node, int aedgeid) {
-    if (NIVissimEdge::dictionary(myEdge.getEdgeID()) == 0) {
+    if (NIVissimEdge::dictionary(myEdge.getEdgeID()) == nullptr) {
         NIVissimConnection* c = NIVissimConnection::dictionary(aedgeid);
         NBEdge* from =
             node->getPossiblySplittedIncoming(toString<int>(c->getFromEdgeID()));
