@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NIVissimNodeCluster.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 
 #include <map>
@@ -60,7 +54,7 @@ NIVissimNodeCluster::NIVissimNodeCluster(int id, int nodeid, int tlid,
         bool amEdgeSplitOnly)
     : myID(id), myNodeID(nodeid), myTLID(tlid),
       myConnectors(connectors), myDisturbances(disturbances),
-      myNBNode(0), myAmEdgeSplit(amEdgeSplitOnly) {}
+      myNBNode(nullptr), myAmEdgeSplit(amEdgeSplitOnly) {}
 
 
 NIVissimNodeCluster::~NIVissimNodeCluster() {}
@@ -100,7 +94,7 @@ NIVissimNodeCluster*
 NIVissimNodeCluster::dictionary(int id) {
     DictType::iterator i = myDict.find(id);
     if (i == myDict.end()) {
-        return 0;
+        return nullptr;
     }
     return (*i).second;
 }
@@ -206,7 +200,7 @@ NIVissimNodeCluster::getFromNode(int edgeid) {
         NIVissimNodeCluster* c = (*i).second;
         for (std::vector<int>::iterator j = c->myConnectors.begin(); j != c->myConnectors.end(); j++) {
             NIVissimConnection* conn = NIVissimConnection::dictionary(*j);
-            if (conn != 0 && conn->getToEdgeID() == edgeid) {
+            if (conn != nullptr && conn->getToEdgeID() == edgeid) {
 //                return (*i).first;
                 if (ret != -1 && (*i).first != ret) {
 //                     "NIVissimNodeCluster:DoubleNode:" << ret << endl;
@@ -228,7 +222,7 @@ NIVissimNodeCluster::getToNode(int edgeid) {
         NIVissimNodeCluster* c = (*i).second;
         for (std::vector<int>::iterator j = c->myConnectors.begin(); j != c->myConnectors.end(); j++) {
             NIVissimConnection* conn = NIVissimConnection::dictionary(*j);
-            if (conn != 0 && conn->getFromEdgeID() == edgeid) {
+            if (conn != nullptr && conn->getFromEdgeID() == edgeid) {
 //                return (*i).first;
                 if (ret != -1 && ret != (*i).first) {
 //                  << "NIVissimNodeCluster: multiple to-nodes" << endl;
