@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NIVissimSingleTypeParser_Fahrzeugklassendefinition.cpp
 /// @author  Daniel Krajzewicz
@@ -22,14 +20,10 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include <utils/common/ToString.h>
 #include <utils/common/VectorHelper.h>
 #include "../NIImporter_Vissim.h"
@@ -67,15 +61,15 @@ NIVissimSingleTypeParser_Fahrzeugklassendefinition::parse(std::istream& from) {
         color = (*i).second;
     } else {
         int r, g, b;
-        r = TplConvert::_2int(colorName.c_str());
+        r = StringUtils::toInt(colorName);
         if (!(from >> g)) {
-            throw NumberFormatException();
+            throw NumberFormatException("");
         }
         if (!(from >> b)) {
-            throw NumberFormatException();
+            throw NumberFormatException("");
         }
         if (r < 0 || r > 255 || g < 0 || g > 255 || b < 0 || b > 255) {
-            throw NumberFormatException();
+            throw NumberFormatException("");
         }
         color = RGBColor((unsigned char)r, (unsigned char)g, (unsigned char)b, 255);
     }
@@ -88,7 +82,7 @@ NIVissimSingleTypeParser_Fahrzeugklassendefinition::parse(std::istream& from) {
     std::vector<int> types;
     from >> tag;
     do {
-        types.push_back(TplConvert::_2int(tag.c_str()));
+        types.push_back(StringUtils::toInt(tag));
         tag = readEndSecure(from);
     } while (tag != "DATAEND");
     return NIVissimVehTypeClass::dictionary(id, name, color, types);
