@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NIVissimSingleTypeParser_Querverkehrsstoerungsdefinition.cpp
 /// @author  Daniel Krajzewicz
@@ -23,14 +21,10 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include <utils/common/MsgHandler.h>
 #include "../NIImporter_Vissim.h"
 #include "../tempstructs/NIVissimExtendedEdgePoint.h"
@@ -161,7 +155,7 @@ NIVissimSingleTypeParser_Querverkehrsstoerungsdefinition::parsePos(std::istream&
     if (tag == "ALLE") {
         //lanes.push_back(1); // !!!
     } else {
-        lanes.push_back(TplConvert::_2int(tag.c_str()));
+        lanes.push_back(StringUtils::toInt(tag));
     }
     //
     double position;
@@ -178,7 +172,7 @@ NIVissimSingleTypeParser_Querverkehrsstoerungsdefinition::parsePos(std::istream&
                 from >> tag;
                 tag = "alle";
             } else if (tag != "zeitluecke" && tag != "durch" && tag != "DATAEND") {
-                int tmp = TplConvert::_2int(tag.c_str());
+                int tmp = StringUtils::toInt(tag);
                 types.push_back(tmp);
             }
         }
