@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NIVissimSingleTypeParser_VWunschentscheidungsdefinition.cpp
 /// @author  Daniel Krajzewicz
@@ -22,16 +20,12 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include <vector>
 #include <cassert>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include "../NIImporter_Vissim.h"
 #include "../tempstructs/NIVissimEdge.h"
 #include "../tempstructs/NIVissimConnection.h"
@@ -85,11 +79,11 @@ NIVissimSingleTypeParser_VWunschentscheidungsdefinition::parse(std::istream& fro
         from >> tag;
         from >> tag;
     }
-    int numid = TplConvert::_2int(edgeid.c_str());
-    int numlane = TplConvert::_2int(lane.c_str()) - 1;
-    int numv = TplConvert::_2int(vwunsch.c_str());
+    int numid = StringUtils::toInt(edgeid);
+    int numlane = StringUtils::toInt(lane) - 1;
+    int numv = StringUtils::toInt(vwunsch);
     NIVissimEdge* e = NIVissimEdge::dictionary(numid);
-    if (e == 0) {
+    if (e == nullptr) {
         NIVissimConnection* c = NIVissimConnection::dictionary(numid);
         const std::vector<int>& lanes = c->getToLanes();
         e = NIVissimEdge::dictionary(c->getToEdgeID());
