@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NIVissimSingleTypeParser_Verbindungsdefinition.cpp
 /// @author  Daniel Krajzewicz
@@ -22,15 +20,11 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include <utils/geom/PositionVector.h>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include "../NIImporter_Vissim.h"
 #include "../tempstructs/NIVissimConnection.h"
 #include "NIVissimSingleTypeParser_Verbindungsdefinition.h"
@@ -69,12 +63,12 @@ NIVissimSingleTypeParser_Verbindungsdefinition::parse(std::istream& from) {
         if (y != "nach") {
             geom.push_back_noDoublePos(
                 Position(
-                    TplConvert::_2double(x.c_str()),
-                    TplConvert::_2double(y.c_str())
+                    StringUtils::toDouble(x),
+                    StringUtils::toDouble(y)
                 ));
             tag = myRead(from);
             try {
-                TplConvert::_2double(tag.c_str());
+                StringUtils::toDouble(tag);
                 tag = myRead(from);
             } catch (NumberFormatException&) {}
         } else {
@@ -121,7 +115,7 @@ NIVissimSingleTypeParser_Verbindungsdefinition::parse(std::istream& from) {
     if (tag == "fahrzeugklassen") {
         tag = readEndSecure(from);
         while (tag != "DATAEND" && tag != "sperrung" && tag != "auswertung") {
-            int classes = TplConvert::_2int(tag.c_str());
+            int classes = StringUtils::toInt(tag);
             assignedVehicles.push_back(classes);
             tag = readEndSecure(from, "auswertung");
         }
@@ -148,7 +142,7 @@ NIVissimSingleTypeParser_Verbindungsdefinition::parse(std::istream& from) {
                     tag = myRead(from);
                 }
                 while (tag != "DATAEND" && tag != "spur" && tag != "keinspurwechsel") {
-                    int classes = TplConvert::_2int(tag.c_str());
+                    int classes = StringUtils::toInt(tag);
                     assignedVehicles.push_back(classes);
                     tag = readEndSecure(from);
                 }
