@@ -1,48 +1,37 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    NIVissimSingleTypeParser_Zeitenverteilungsdefinition.cpp
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @date    Wed, 18 Dec 2002
-/// @version $Id: NIVissimSingleTypeParser_Zeitenverteilungsdefinition.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id$
 ///
 //
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 
 
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include <utils/geom/Position.h>
 #include <utils/geom/PositionVector.h>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include "../NIImporter_Vissim.h"
+#include <utils/distribution/Distribution_Parameterized.h>
 #include <utils/distribution/Distribution_Points.h>
-#include <utils/distribution/Distribution_MeanDev.h>
-#include <netbuild/NBDistribution.h>
+#include <utils/distribution/DistributionCont.h>
 #include "NIVissimSingleTypeParser_Zeitenverteilungsdefinition.h"
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 
 // ===========================================================================
 // method definitions
@@ -60,30 +49,28 @@ NIVissimSingleTypeParser_Zeitenverteilungsdefinition::parse(std::istream& from)
     std::string id;
     from >> id;
     // list of points
-    PositionVector points;
+    Distribution_Points* points = new Distribution_Points(id);
     std::string tag;
     do {
         tag = readEndSecure(from);
         if (tag == "mittelwert") {
-            SUMOReal mean, deviation;
+            double mean, deviation;
             from >> mean;
             from >> tag;
             from >> deviation;
-            return NBDistribution::dictionary("times", id,
-                                              new Distribution_MeanDev(id, mean, deviation));
+            delete points;
+            return DistributionCont::dictionary("times", id,
+                                                new Distribution_Parameterized(id, mean, deviation));
         }
         if (tag != "DATAEND") {
-            SUMOReal p1 = TplConvert::_2SUMOReal(tag.c_str());
+            double p1 = StringUtils::toDouble(tag);
             from >> tag;
-            SUMOReal p2 = TplConvert::_2SUMOReal(tag.c_str());
-            points.push_back(Position(p1, p2));
+            double p2 = StringUtils::toDouble(tag);
+            points->add(p1, p2);
         }
     } while (tag != "DATAEND");
-    return NBDistribution::dictionary("times",
-                                      id, new Distribution_Points(id, points));
+    return DistributionCont::dictionary("times", id, points);
 }
 
 
-
 /****************************************************************************/
-
