@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NLDiscreteEventBuilder.cpp
 /// @author  Daniel Krajzewicz
@@ -24,13 +22,8 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
-#include "NLDiscreteEventBuilder.h"
 #include <utils/xml/SUMOXMLDefinitions.h>
 #include <microsim/MSNet.h>
 #include <microsim/actions/Command_SaveTLSState.h>
@@ -42,6 +35,7 @@
 #include <utils/common/FileHelpers.h>
 #include <utils/common/UtilExceptions.h>
 #include <utils/iodevices/OutputDevice.h>
+#include "NLDiscreteEventBuilder.h"
 
 
 // ===========================================================================
@@ -62,7 +56,7 @@ void
 NLDiscreteEventBuilder::addAction(const SUMOSAXAttributes& attrs,
                                   const std::string& basePath) {
     bool ok = true;
-    const std::string type = attrs.getOpt<std::string>(SUMO_ATTR_TYPE, 0, ok, "");
+    const std::string type = attrs.getOpt<std::string>(SUMO_ATTR_TYPE, nullptr, ok, "");
     // check whether the type was given
     if (type == "" || !ok) {
         throw InvalidArgument("An action's type is not given.");
@@ -91,11 +85,11 @@ void
 NLDiscreteEventBuilder::buildSaveTLStateCommand(const SUMOSAXAttributes& attrs,
         const std::string& basePath) {
     bool ok = true;
-    const std::string dest = attrs.getOpt<std::string>(SUMO_ATTR_DEST, 0, ok, "");
-    const std::string source = attrs.getOpt<std::string>(SUMO_ATTR_SOURCE, 0, ok, "");
+    const std::string dest = attrs.getOpt<std::string>(SUMO_ATTR_DEST, nullptr, ok, "");
+    const std::string source = attrs.getOpt<std::string>(SUMO_ATTR_SOURCE, nullptr, ok, "");
     // check the parameter
     if (dest == "" || !ok) {
-        throw InvalidArgument("Incomplete description of an 'SaveTLSState'-action occured.");
+        throw InvalidArgument("Incomplete description of an 'SaveTLSState'-action occurred.");
     }
     if (source == "") {
         const std::vector<std::string> ids = myNet.getTLSControl().getAllTLIds();
@@ -119,11 +113,11 @@ void
 NLDiscreteEventBuilder::buildSaveTLSwitchesCommand(const SUMOSAXAttributes& attrs,
         const std::string& basePath) {
     bool ok = true;
-    const std::string dest = attrs.getOpt<std::string>(SUMO_ATTR_DEST, 0, ok, "");
-    const std::string source = attrs.getOpt<std::string>(SUMO_ATTR_SOURCE, 0, ok, "");
+    const std::string dest = attrs.getOpt<std::string>(SUMO_ATTR_DEST, nullptr, ok, "");
+    const std::string source = attrs.getOpt<std::string>(SUMO_ATTR_SOURCE, nullptr, ok, "");
     // check the parameter
     if (dest == "" || !ok) {
-        throw InvalidArgument("Incomplete description of an 'SaveTLSSwitchTimes'-action occured.");
+        throw InvalidArgument("Incomplete description of an 'SaveTLSSwitchTimes'-action occurred.");
     }
     if (source == "") {
         const std::vector<std::string> ids = myNet.getTLSControl().getAllTLIds();
@@ -147,11 +141,11 @@ void
 NLDiscreteEventBuilder::buildSaveTLSwitchStatesCommand(const SUMOSAXAttributes& attrs,
         const std::string& basePath) {
     bool ok = true;
-    const std::string dest = attrs.getOpt<std::string>(SUMO_ATTR_DEST, 0, ok, "");
-    const std::string source = attrs.getOpt<std::string>(SUMO_ATTR_SOURCE, 0, ok, "");
+    const std::string dest = attrs.getOpt<std::string>(SUMO_ATTR_DEST, nullptr, ok, "");
+    const std::string source = attrs.getOpt<std::string>(SUMO_ATTR_SOURCE, nullptr, ok, "");
     // check the parameter
     if (dest == "" || !ok) {
-        throw InvalidArgument("Incomplete description of an 'SaveTLSSwitchStates'-action occured.");
+        throw InvalidArgument("Incomplete description of an 'SaveTLSSwitchStates'-action occurred.");
     }
     if (source == "") {
         const std::vector<std::string> ids = myNet.getTLSControl().getAllTLIds();
