@@ -1,24 +1,21 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    NLJunctionControlBuilder.h
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Mon, 9 Jul 2001
-/// @version $Id: NLJunctionControlBuilder.h 21201 2016-07-19 11:57:22Z behrisch $
+/// @version $Id$
 ///
 // Builder of microsim-junctions and tls
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 #ifndef NLJunctionControlBuilder_h
 #define NLJunctionControlBuilder_h
 
@@ -26,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <vector>
@@ -86,7 +79,7 @@ public:
     /** @brief Destructor
      *
      * Deletes previously allocated "myLogicControl" and "myJunctions" if
-     *  they were not previously returned (this may happen if an error occured).
+     *  they were not previously returned (this may happen if an error occurred).
      */
     virtual ~NLJunctionControlBuilder();
 
@@ -105,7 +98,8 @@ public:
      * @todo Check why "key" is given
      */
     void openJunction(const std::string& id, const std::string& key,
-                      const SumoXMLNodeType type, SUMOReal x, SUMOReal y,
+                      const SumoXMLNodeType type,
+                      const Position pos,
                       const PositionVector& shape,
                       const std::vector<MSLane*>& incomingLanes,
                       const std::vector<MSLane*>& internalLanes);
@@ -179,7 +173,7 @@ public:
      * @todo min/max is used only by one junction type. Recheck
      * @todo min/max: maybe only one type of a phase definition should be built
      */
-    void addPhase(SUMOTime duration, const std::string& state,
+    void addPhase(SUMOTime duration, const std::string& state, int nextPhase,
                   SUMOTime min, SUMOTime max);
 
     /** @brief Adds a phase to the currently built traffic lights logic
@@ -191,7 +185,7 @@ public:
      * @param[in] transient_notdecisional Specifies if this is a transient phase (true) or a decisional one (false)
      * @param[in] commit Specifies if this is a commit phase
      */
-    void addPhase(SUMOTime duration, const std::string& state, SUMOTime minDuration, SUMOTime maxDuration, bool transient_notdecisional, bool commit) throw();
+    void addPhase(SUMOTime duration, const std::string& state, int nextPhase, SUMOTime minDuration, SUMOTime maxDuration, bool transient_notdecisional, bool commit);
 
 
     /** @brief Adds a phase to the currently built traffic lights logic
@@ -204,7 +198,7 @@ public:
      * @param[in] commit Specifies if this is a commit phase
      * @param[in] targetLanes A reference to the vector containing targeted sensor lanes for this phase, given by lane id
      */
-    void addPhase(SUMOTime duration, const std::string& state, SUMOTime minDuration, SUMOTime maxDuration, bool transient_notdecisional, bool commit, MSPhaseDefinition::LaneIdVector& targetLanes) throw();
+    void addPhase(SUMOTime duration, const std::string& state, int nextPhase, SUMOTime minDuration, SUMOTime maxDuration, bool transient_notdecisional, bool commit, MSPhaseDefinition::LaneIdVector& targetLanes);
 
 
     /** @brief Returns a previously build tls logic
@@ -333,7 +327,6 @@ protected:
     virtual MSJunction* buildLogicJunction();
 
 
-#ifdef HAVE_INTERNAL_LANES
     /** @brief Builds an internal junction
      *
      * Builds a MSInternalJunction
@@ -341,7 +334,6 @@ protected:
      * @return The built junction
      */
     virtual MSJunction* buildInternalJunction();
-#endif
     /// @}
 
 
@@ -382,10 +374,8 @@ protected:
     /// @brief The list of the incoming lanes of the currently chosen junction
     LaneVector myActiveIncomingLanes;
 
-#ifdef HAVE_INTERNAL_LANES
     /// @brief The list of the internal lanes of the currently chosen junction
     LaneVector myActiveInternalLanes;
-#endif
 
     /// @brief The id of the currently chosen junction
     std::string myActiveID;
