@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NLTriggerBuilder.h
 /// @author  Daniel Krajzewicz
@@ -27,11 +25,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <vector>
@@ -159,7 +153,8 @@ public:
                                   const std::string& id, const std::vector<std::string>& lines,
                                   MSLane* lane, double frompos, double topos,
                                   unsigned int capacity,
-                                  double width, double length, double angle);
+                                  double width, double length, double angle, const std::string& name,
+                                  bool onRoad);
 
 
     /** @brief Add a lot entry to current parking area
@@ -210,6 +205,12 @@ public:
      */
     virtual void endParkingArea();
 
+    /** @brief End a stopping place
+     *
+     * @exception InvalidArgument If the current stopping place is 0
+     */
+    virtual void endStoppingPlace();
+
 
     /** @brief Parses his values and builds a charging station
      *
@@ -273,22 +274,22 @@ protected:
     virtual void buildStoppingPlace(MSNet& net, std::string id, std::vector<std::string> lines, MSLane* lane,
                                     double frompos, double topos, const SumoXMLTag element, std::string string);
 
-    /** @brief Builds a charging Station
+    /** @brief Builds a charging station
      *
-     * Simply calls the MSBusStop constructor.
+     * Simply calls the MSChargingStation constructor and adds the result to the network.
      *
-     * @param[in] net The net the charging Station belongs to
-     * @param[in] id The id of the charging Station
-     * @param[in] lane The lane the charging Station is placed on
-     * @param[in] frompos Begin position of the charging Station on the lane
-     * @param[in] topos End position of the charging Station on the lane
-     * @param[in] chargingPower
-     * @param[in] efficiency
-     * @param[in] chargeInTransit
-     * @param[in] chargeDelay
-     * @exception InvalidArgument If the charging Station can not be added to the net (is duplicate)
+     * @param[in] net The net the charging station belongs to
+     * @param[in] id The id of the charging station
+     * @param[in] lane The lane the charging station is placed on
+     * @param[in] frompos Begin position of the charging station on the lane
+     * @param[in] topos End position of the charging station on the lane
+     * @param[in] chargingPower energy charged in every timeStep
+     * @param[in] efficiency efficiency of the charge
+     * @param[in] chargeInTransit enable or disable charge in transit
+     * @param[in] chargeDelay delay in the charge
+     * @exception InvalidArgument If the charging station can not be added to the net (is duplicate)
      */
-    virtual void buildChargingStation(MSNet& net, const std::string& id, MSLane* lane, double frompos, double topos,
+    virtual void buildChargingStation(MSNet& net, const std::string& id, MSLane* lane, double frompos, double topos, const std::string& name,
                                       double chargingPower, double efficiency, bool chargeInTransit, double chargeDelay);
 
     /** @brief builds a microscopic calibrator
@@ -337,7 +338,8 @@ protected:
     virtual MSTriggeredRerouter* buildRerouter(MSNet& net,
             const std::string& id, MSEdgeVector& edges,
             double prob, const std::string& file, bool off,
-            SUMOTime timeThreshold);
+            SUMOTime timeThreshold,
+            const std::string& vTypes);
     //@}
 
 
