@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NWFrame.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <utils/options/Option.h>
@@ -48,7 +42,7 @@
 // ===========================================================================
 // static members
 // ===========================================================================
-const std::string NWFrame::MAJOR_VERSION = "0.27";
+const std::string NWFrame::MAJOR_VERSION = "1.1";
 
 
 // ===========================================================================
@@ -72,6 +66,9 @@ NWFrame::fillOptions(bool forNetgen) {
     oc.addDescription("junctions.join-output", "Output",
                       "Writes information about joined junctions to FILE (can be loaded as additional node-file to reproduce joins");
 
+    oc.doRegister("prefix", new Option_String(""));
+    oc.addDescription("prefix", "Output", "Defines a prefix for edge and junction names");
+
 #ifdef HAVE_PROJ
     if (!forNetgen) {
         oc.doRegister("proj.plain-geo", new Option_Bool(false));
@@ -114,11 +111,8 @@ NWFrame::fillOptions(bool forNetgen) {
         oc.doRegister("parking-output", new Option_FileName());
         oc.addDescription("parking-output", "Output", "Writes parking areas to FILE");
 
-        oc.doRegister("osm.stop-output.footway-access-distance", new Option_Float(150.f));
-        oc.addDescription("osm.stop-output.footway-access-distance", "Output", "The search radius for finding suitable road accesses for rail stops");
-
-        oc.doRegister("osm.stop-output.footway-max-accesses", new Option_Integer(5));
-        oc.addDescription("osm.stop-output.footway-max-accesses", "Output", "The maximum roud accesses registered per rail stops");
+        oc.doRegister("railway.topology.output", new Option_FileName());
+        oc.addDescription("railway.topology.output", "Output", "Analyse topology of the railway network");
     }
 
     // register opendrive options
