@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2012-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NWWriter_DlrNavteq.cpp
 /// @author  Jakob Erdmann
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 #include <algorithm>
 #include <ctime>
 #include <cmath>
@@ -46,8 +40,6 @@
 #include "NWFrame.h"
 #include "NWWriter_DlrNavteq.h"
 
-#define OUTPUT_VERSION "6.5"
-
 
 // ---------------------------------------------------------------------------
 // static members
@@ -73,12 +65,7 @@ NWWriter_DlrNavteq::writeNetwork(const OptionsCont& oc, NBNetBuilder& nb) {
 
 
 void NWWriter_DlrNavteq::writeHeader(OutputDevice& device, const OptionsCont& oc) {
-    time_t rawtime;
-    time(&rawtime);
-    char buffer [80];
-    strftime(buffer, 80, "on %c", localtime(&rawtime));
-    device << "# Generated " << buffer << " by " << oc.getFullName() << "\n";
-    device << "# Format matches Extraction version: V" << OUTPUT_VERSION << " \n";
+    device << "# Format matches Extraction version: V6.5 \n";
     std::stringstream tmp;
     oc.writeConfiguration(tmp, true, false, false);
     tmp.seekg(std::ios_base::beg);
@@ -160,7 +147,7 @@ NWWriter_DlrNavteq::writeNodesUnsplitted(const OptionsCont& oc, NBNodeCont& nc,
             // the import NIImporter_DlrNavteq checks for the presence of a
             // negated edge id to determine spread type. We may need to do some
             // shifting to make this consistent
-            const bool hasOppositeID = ec.getOppositeByID(e->getID()) != 0;
+            const bool hasOppositeID = ec.getOppositeByID(e->getID()) != nullptr;
             if (e->getLaneSpreadFunction() == LANESPREAD_RIGHT && !hasOppositeID) {
                 // need to write center-line geometry instead
                 try {
@@ -179,7 +166,7 @@ NWWriter_DlrNavteq::writeNodesUnsplitted(const OptionsCont& oc, NBNodeCont& nc,
 
             std::string internalNodeID = e->getID();
             if (internalNodeID == UNDEFINED
-                    || (nc.retrieve(internalNodeID) != 0)
+                    || (nc.retrieve(internalNodeID) != nullptr)
                     || reservedNodeIDs.count(internalNodeID) > 0
                ) {
                 // need to invent a new name to avoid clashing with the id of a 'real' node or a reserved name
