@@ -1,18 +1,17 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NWWriter_SUMO.cpp
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
+/// @author  Leonhard Luecken
 /// @date    Tue, 04.05.2011
 /// @version $Id$
 ///
@@ -23,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 #include <cmath>
 #include <algorithm>
 #include <utils/options/OptionsCont.h>
@@ -36,6 +31,7 @@
 #include <utils/common/ToString.h>
 #include <utils/common/MsgHandler.h>
 #include <utils/common/StringUtils.h>
+#include <utils/common/SUMOVehicleClass.h>
 #include <utils/geom/GeomConvHelper.h>
 #include <netbuild/NBEdge.h>
 #include <netbuild/NBEdgeCont.h>
@@ -49,6 +45,7 @@
 #include "NWWriter_SUMO.h"
 
 
+//#define DEBUG_OPPOSITE_INTERNAL
 
 // ===========================================================================
 // method definitions
@@ -81,6 +78,15 @@ NWWriter_SUMO::writeNetwork(const OptionsCont& oc, NBNetBuilder& nb) {
     if (oc.getBool("crossings.guess") || oc.getBool("walkingareas")) {
         attrs[SUMO_ATTR_WALKINGAREAS] = "true";
     }
+    if (oc.getFloat("junctions.limit-turn-speed") > 0) {
+        attrs[SUMO_ATTR_LIMIT_TURN_SPEED] = toString(oc.getFloat("junctions.limit-turn-speed"));
+    }
+    if (!oc.isDefault("check-lane-foes.all")) {
+        attrs[SUMO_ATTR_CHECKLANEFOES_ALL] = toString(oc.getBool("check-lane-foes.all"));
+    }
+    if (!oc.isDefault("check-lane-foes.roundabout")) {
+        attrs[SUMO_ATTR_CHECKLANEFOES_ROUNDABOUT] = toString(oc.getBool("check-lane-foes.roundabout"));
+    }
     device.writeXMLHeader("net", "net_file.xsd", attrs); // street names may contain non-ascii chars
     device.lf();
     // get involved container
@@ -116,20 +122,8 @@ NWWriter_SUMO::writeNetwork(const OptionsCont& oc, NBNetBuilder& nb) {
     writeTrafficLights(device, nb.getTLLogicCont());
 
     // write the nodes (junctions)
-    std::set<NBNode*> roundaboutNodes;
-    const bool checkLaneFoesAll = oc.getBool("check-lane-foes.all");
-    const bool checkLaneFoesRoundabout = !checkLaneFoesAll && oc.getBool("check-lane-foes.roundabout");
-    if (checkLaneFoesRoundabout) {
-        const std::set<EdgeSet>& roundabouts = ec.getRoundabouts();
-        for (std::set<EdgeSet>::const_iterator i = roundabouts.begin(); i != roundabouts.end(); ++i) {
-            for (EdgeSet::const_iterator j = (*i).begin(); j != (*i).end(); ++j) {
-                roundaboutNodes.insert((*j)->getToNode());
-            }
-        }
-    }
     for (std::map<std::string, NBNode*>::const_iterator i = nc.begin(); i != nc.end(); ++i) {
-        const bool checkLaneFoes = checkLaneFoesAll || (checkLaneFoesRoundabout && roundaboutNodes.count((*i).second) > 0);
-        writeJunction(device, *(*i).second, checkLaneFoes);
+        writeJunction(device, *(*i).second);
     }
     device.lf();
     const bool includeInternal = !oc.getBool("no-internal-links");
@@ -172,23 +166,22 @@ NWWriter_SUMO::writeNetwork(const OptionsCont& oc, NBNetBuilder& nb) {
         // write connections from pedestrian crossings
         std::vector<NBNode::Crossing*> crossings = node->getCrossings();
         for (auto c : crossings) {
-            NWWriter_SUMO::writeInternalConnection(device, c->id, c->nextWalkingArea, 0, 0, "");
+            NWWriter_SUMO::writeInternalConnection(device, c->id, c->nextWalkingArea, 0, 0, "", LINKDIR_STRAIGHT, c->tlID, c->tlLinkIndex2);
         }
         // write connections from pedestrian walking areas
-        const std::vector<NBNode::WalkingArea>& WalkingAreas = node->getWalkingAreas();
-        for (std::vector<NBNode::WalkingArea>::const_iterator it = WalkingAreas.begin(); it != WalkingAreas.end(); it++) {
-            for (std::string cID : (*it).nextCrossings) {
+        for (const NBNode::WalkingArea& wa : node->getWalkingAreas()) {
+            for (const std::string& cID : wa.nextCrossings) {
                 const NBNode::Crossing& nextCrossing = *node->getCrossing(cID);
                 // connection to next crossing (may be tls-controlled)
                 device.openTag(SUMO_TAG_CONNECTION);
-                device.writeAttr(SUMO_ATTR_FROM, (*it).id);
+                device.writeAttr(SUMO_ATTR_FROM, wa.id);
                 device.writeAttr(SUMO_ATTR_TO, cID);
                 device.writeAttr(SUMO_ATTR_FROM_LANE, 0);
                 device.writeAttr(SUMO_ATTR_TO_LANE, 0);
                 if (nextCrossing.tlID != "") {
                     device.writeAttr(SUMO_ATTR_TLID, nextCrossing.tlID);
-                    assert(nextCrossing.tlLinkNo >= 0);
-                    device.writeAttr(SUMO_ATTR_TLLINKINDEX, nextCrossing.tlLinkNo);
+                    assert(nextCrossing.tlLinkIndex >= 0);
+                    device.writeAttr(SUMO_ATTR_TLLINKINDEX, nextCrossing.tlLinkIndex);
                 }
                 device.writeAttr(SUMO_ATTR_DIR, LINKDIR_STRAIGHT);
                 device.writeAttr(SUMO_ATTR_STATE, nextCrossing.priority ? LINKSTATE_MAJOR : LINKSTATE_MINOR);
@@ -197,13 +190,13 @@ NWWriter_SUMO::writeNetwork(const OptionsCont& oc, NBNetBuilder& nb) {
             // optional connections from/to sidewalk
             std::string edgeID;
             int laneIndex;
-            for (std::vector<std::string>::const_iterator it_sw = (*it).nextSidewalks.begin(); it_sw != (*it).nextSidewalks.end(); ++it_sw) {
-                NBHelpers::interpretLaneID(*it_sw, edgeID, laneIndex);
-                NWWriter_SUMO::writeInternalConnection(device, (*it).id, edgeID, 0, laneIndex, "");
+            for (const std::string& sw : wa.nextSidewalks) {
+                NBHelpers::interpretLaneID(sw, edgeID, laneIndex);
+                NWWriter_SUMO::writeInternalConnection(device, wa.id, edgeID, 0, laneIndex, "");
             }
-            for (std::vector<std::string>::const_iterator it_sw = (*it).prevSidewalks.begin(); it_sw != (*it).prevSidewalks.end(); ++it_sw) {
-                NBHelpers::interpretLaneID(*it_sw, edgeID, laneIndex);
-                NWWriter_SUMO::writeInternalConnection(device, edgeID, (*it).id, laneIndex, 0, "");
+            for (const std::string& sw : wa.prevSidewalks) {
+                NBHelpers::interpretLaneID(sw, edgeID, laneIndex);
+                NWWriter_SUMO::writeInternalConnection(device, edgeID, wa.id, laneIndex, 0, "");
             }
         }
     }
@@ -228,10 +221,14 @@ NWWriter_SUMO::writeNetwork(const OptionsCont& oc, NBNetBuilder& nb) {
 
 
 std::string
-NWWriter_SUMO::getOppositeInternalID(const NBEdgeCont& ec, const NBEdge* from, const NBEdge::Connection& con) {
+NWWriter_SUMO::getOppositeInternalID(const NBEdgeCont& ec, const NBEdge* from, const NBEdge::Connection& con, double& oppositeLength) {
     const NBEdge::Lane& succ = con.toEdge->getLanes()[con.toLane];
     const NBEdge::Lane& pred = from->getLanes()[con.fromLane];
+    const bool lefthand = OptionsCont::getOptions().getBool("lefthand");
     if (succ.oppositeID != "" && succ.oppositeID != "-" && pred.oppositeID != "" && pred.oppositeID != "-") {
+#ifdef DEBUG_OPPOSITE_INTERNAL
+        std::cout << "getOppositeInternalID con=" << con.getDescription(from) << " (" << con.getInternalLaneID() << ")\n";
+#endif
         // find the connection that connects succ.oppositeID to pred.oppositeID
         const NBEdge* succOpp = ec.retrieve(succ.oppositeID.substr(0, succ.oppositeID.rfind("_")));
         const NBEdge* predOpp = ec.retrieve(pred.oppositeID.substr(0, pred.oppositeID.rfind("_")));
@@ -240,13 +237,33 @@ NWWriter_SUMO::getOppositeInternalID(const NBEdgeCont& ec, const NBEdge* from, c
         const std::vector<NBEdge::Connection>& connections = succOpp->getConnections();
         for (std::vector<NBEdge::Connection>::const_iterator it_c = connections.begin(); it_c != connections.end(); it_c++) {
             const NBEdge::Connection& conOpp = *it_c;
-            if (succOpp != from && // turnaround
-                    succOpp->getLaneID(conOpp.fromLane) == succ.oppositeID &&
-                    predOpp == conOpp.toEdge &&
-                    predOpp->getLaneID(conOpp.toLane) == pred.oppositeID &&
-                    // same lengths (@note: averaging is not taken into account)
-                    con.shape.length() == conOpp.shape.length()) {
+            if (succOpp != from // turnaround
+                    && predOpp == conOpp.toEdge
+                    && succOpp->getLaneID(conOpp.fromLane) == succ.oppositeID
+                    && predOpp->getLaneID(conOpp.toLane) == pred.oppositeID
+                    && from->getToNode()->getDirection(from, con.toEdge, lefthand) == LINKDIR_STRAIGHT
+                    && from->getToNode()->getDirection(succOpp, predOpp, lefthand) == LINKDIR_STRAIGHT
+               ) {
+#ifdef DEBUG_OPPOSITE_INTERNAL
+                std::cout << "  found " << conOpp.getInternalLaneID() << "\n";
+#endif
+                oppositeLength = conOpp.length;
                 return conOpp.getInternalLaneID();
+            } else {
+                /*
+                #ifdef DEBUG_OPPOSITE_INTERNAL
+                std::cout << "  rejected " << conOpp.getInternalLaneID()
+                    << "\n     succ.oppositeID=" << succ.oppositeID
+                    << "\n         succOppLane=" << succOpp->getLaneID(conOpp.fromLane)
+                    << "\n     pred.oppositeID=" << pred.oppositeID
+                    << "\n         predOppLane=" << predOpp->getLaneID(conOpp.toLane)
+                    << "\n      predOpp=" << predOpp->getID()
+                    << "\n     conOppTo=" << conOpp.toEdge->getID()
+                    << "\n     len1=" << con.shape.length()
+                    << "\n     len2=" << conOpp.shape.length()
+                    << "\n";
+                #endif
+                */
             }
         }
         return "";
@@ -260,21 +277,37 @@ bool
 NWWriter_SUMO::writeInternalEdges(OutputDevice& into, const NBEdgeCont& ec, const NBNode& n) {
     bool ret = false;
     const EdgeVector& incoming = n.getIncomingEdges();
+    // first pass: determine opposite internal edges and average their length
+    std::map<std::string, std::string> oppositeLaneID;
+    std::map<std::string, double> oppositeLengths;
+    for (NBEdge* e : incoming) {
+        for (const NBEdge::Connection& c : e->getConnections()) {
+            double oppositeLength = 0;
+            const std::string op = getOppositeInternalID(ec, e, c, oppositeLength);
+            oppositeLaneID[c.getInternalLaneID()] = op;
+            if (op != "") {
+                oppositeLengths[c.id] = oppositeLength;
+            }
+        }
+    }
+    if (oppositeLengths.size() > 0) {
+        for (NBEdge* e : incoming) {
+            for (NBEdge::Connection& c : e->getConnections()) {
+                if (oppositeLengths.count(c.id) > 0) {
+                    c.length = (c.length + oppositeLengths[c.id]) / 2;
+                }
+            }
+        }
+    }
+
     for (EdgeVector::const_iterator i = incoming.begin(); i != incoming.end(); i++) {
         const std::vector<NBEdge::Connection>& elv = (*i)->getConnections();
         if (elv.size() > 0) {
             bool haveVia = false;
             std::string edgeID = "";
-            // first pass: compute average lengths of non-via edges
-            std::map<std::string, double> lengthSum;
-            std::map<std::string, int> numLanes;
-            for (std::vector<NBEdge::Connection>::const_iterator k = elv.begin(); k != elv.end(); ++k) {
-                lengthSum[(*k).id] += MAX2((*k).shape.length(), POSITION_EPS);
-                numLanes[(*k).id] += 1;
-            }
             // second pass: write non-via edges
             for (std::vector<NBEdge::Connection>::const_iterator k = elv.begin(); k != elv.end(); ++k) {
-                if ((*k).toEdge == 0) {
+                if ((*k).toEdge == nullptr) {
                     assert(false); // should never happen. tell me when it does
                     continue;
                 }
@@ -292,14 +325,11 @@ NWWriter_SUMO::writeInternalEdges(OutputDevice& into, const NBEdgeCont& ec, cons
                 // to avoid changing to an internal lane which has a successor
                 // with the wrong permissions we need to inherit them from the successor
                 const NBEdge::Lane& successor = (*k).toEdge->getLanes()[(*k).toLane];
-                const double length = lengthSum[edgeID] / numLanes[edgeID];
-                // @note the actual length should be used once sumo supports lanes of
-                // varying length within the same edge
-                //const double length = MAX2((*k).shape.length(), POSITION_EPS);
+                const double width = n.isConstantWidthTransition() && (*i)->getNumLanes() > (*k).toEdge->getNumLanes() ? (*i)->getLaneWidth((*k).fromLane) : successor.width;
                 writeLane(into, (*k).getInternalLaneID(), (*k).vmax,
                           successor.permissions, successor.preferred,
-                          NBEdge::UNSPECIFIED_OFFSET, successor.width, (*k).shape, &(*k),
-                          length, (*k).internalLaneIndex, getOppositeInternalID(ec, *i, *k));
+                          NBEdge::UNSPECIFIED_OFFSET, std::map<int, double>(), width, (*k).shape, &(*k),
+                          (*k).length, (*k).internalLaneIndex, oppositeLaneID[(*k).getInternalLaneID()]);
                 haveVia = haveVia || (*k).haveVia;
             }
             ret = true;
@@ -310,7 +340,7 @@ NWWriter_SUMO::writeInternalEdges(OutputDevice& into, const NBEdgeCont& ec, cons
                     if (!(*k).haveVia) {
                         continue;
                     }
-                    if ((*k).toEdge == 0) {
+                    if ((*k).toEdge == nullptr) {
                         assert(false); // should never happen. tell me when it does
                         continue;
                     }
@@ -318,8 +348,8 @@ NWWriter_SUMO::writeInternalEdges(OutputDevice& into, const NBEdgeCont& ec, cons
                     into.openTag(SUMO_TAG_EDGE);
                     into.writeAttr(SUMO_ATTR_ID, (*k).viaID);
                     into.writeAttr(SUMO_ATTR_FUNCTION, EDGEFUNC_INTERNAL);
-                    writeLane(into, (*k).viaID + "_0", (*k).vmax, SVCAll, SVCAll,
-                              NBEdge::UNSPECIFIED_OFFSET, successor.width, (*k).viaShape, &(*k),
+                    writeLane(into, (*k).viaID + "_0", (*k).vmax, successor.permissions, successor.preferred,
+                              NBEdge::UNSPECIFIED_OFFSET, std::map<int, double>(), successor.width, (*k).viaShape, &(*k),
                               MAX2((*k).viaShape.length(), POSITION_EPS), // microsim needs positive length
                               0, "");
                     into.closeTag();
@@ -334,7 +364,7 @@ NWWriter_SUMO::writeInternalEdges(OutputDevice& into, const NBEdgeCont& ec, cons
         into.writeAttr(SUMO_ATTR_FUNCTION, EDGEFUNC_CROSSING);
         into.writeAttr(SUMO_ATTR_CROSSING_EDGES, c->edges);
         writeLane(into, c->id + "_0", 1, SVC_PEDESTRIAN, 0,
-                  NBEdge::UNSPECIFIED_OFFSET, c->width, c->shape, 0, MAX2(c->shape.length(), POSITION_EPS), 0, "", false, c->customShape.size() != 0);
+                  NBEdge::UNSPECIFIED_OFFSET, std::map<int, double>(), c->width, c->shape, nullptr, MAX2(c->shape.length(), POSITION_EPS), 0, "", false, c->customShape.size() != 0);
         into.closeTag();
     }
     // write pedestrian walking areas
@@ -345,7 +375,7 @@ NWWriter_SUMO::writeInternalEdges(OutputDevice& into, const NBEdgeCont& ec, cons
         into.writeAttr(SUMO_ATTR_ID, wa.id);
         into.writeAttr(SUMO_ATTR_FUNCTION, EDGEFUNC_WALKINGAREA);
         writeLane(into, wa.id + "_0", 1, SVC_PEDESTRIAN, 0,
-                  NBEdge::UNSPECIFIED_OFFSET, wa.width, wa.shape, 0, wa.length, 0, "", false, wa.hasCustomShape);
+                  NBEdge::UNSPECIFIED_OFFSET, std::map<int, double>(), wa.width, wa.shape, nullptr, wa.length, 0, "", false, wa.hasCustomShape);
         into.closeTag();
     }
     return ret;
@@ -378,14 +408,25 @@ NWWriter_SUMO::writeEdge(OutputDevice& into, const NBEdge& e, bool noNames) {
     if (!e.hasDefaultGeometry()) {
         into.writeAttr(SUMO_ATTR_SHAPE, e.getGeometry());
     }
+    if (e.getStopOffsets().size() != 0) {
+        writeStopOffsets(into, e.getStopOffsets());
+    }
+    if (e.isBidiRail()) {
+        into.writeAttr(SUMO_ATTR_BIDI, e.getTurnDestination(true)->getID());
+    }
+
     // write the lanes
     const std::vector<NBEdge::Lane>& lanes = e.getLanes();
 
     const double length = e.getFinalLength();
     for (int i = 0; i < (int) lanes.size(); i++) {
         const NBEdge::Lane& l = lanes[i];
+        std::map<int, double> stopOffsets;
+        if (l.stopOffsets != e.getStopOffsets()) {
+            stopOffsets = l.stopOffsets;
+        }
         writeLane(into, e.getLaneID(i), l.speed,
-                  l.permissions, l.preferred, l.endOffset, l.width, l.shape, &l,
+                  l.permissions, l.preferred, l.endOffset, stopOffsets, l.width, l.shape, &l,
                   length, i, l.oppositeID, l.accelRamp, l.customShape.size() > 0);
     }
     // close the edge
@@ -397,7 +438,7 @@ NWWriter_SUMO::writeEdge(OutputDevice& into, const NBEdge& e, bool noNames) {
 void
 NWWriter_SUMO::writeLane(OutputDevice& into, const std::string& lID,
                          double speed, SVCPermissions permissions, SVCPermissions preferred,
-                         double endOffset, double width, PositionVector shape,
+                         double endOffset, std::map<SVCPermissions, double> stopOffsets, double width, PositionVector shape,
                          const Parameterised* params, double length, int index,
                          const std::string& oppositeID, bool accelRamp, bool customShape) {
     // output the lane's attributes
@@ -434,13 +475,18 @@ NWWriter_SUMO::writeLane(OutputDevice& into, const std::string& lID,
     }
     into.writeAttr(SUMO_ATTR_SHAPE, endOffset > 0 ?
                    shape.getSubpart(0, shape.length() - endOffset) : shape);
+
+    if (stopOffsets.size() != 0) {
+        writeStopOffsets(into, stopOffsets);
+    }
+
     if (oppositeID != "" && oppositeID != "-") {
         into.openTag(SUMO_TAG_NEIGH);
         into.writeAttr(SUMO_ATTR_LANE, oppositeID);
         into.closeTag();
     }
 
-    if (params != 0) {
+    if (params != nullptr) {
         params->writeParams(into);
     }
 
@@ -449,7 +495,7 @@ NWWriter_SUMO::writeLane(OutputDevice& into, const std::string& lID,
 
 
 void
-NWWriter_SUMO::writeJunction(OutputDevice& into, const NBNode& n, const bool checkLaneFoes) {
+NWWriter_SUMO::writeJunction(OutputDevice& into, const NBNode& n) {
     // write the attributes
     into.openTag(SUMO_TAG_JUNCTION).writeAttr(SUMO_ATTR_ID, n.getID());
     into.writeAttr(SUMO_ATTR_TYPE, n.getType());
@@ -483,7 +529,7 @@ NWWriter_SUMO::writeJunction(OutputDevice& into, const NBNode& n, const bool che
         for (EdgeVector::const_iterator i = incoming.begin(); i != incoming.end(); i++) {
             const std::vector<NBEdge::Connection>& elv = (*i)->getConnections();
             for (std::vector<NBEdge::Connection>::const_iterator k = elv.begin(); k != elv.end(); ++k) {
-                if ((*k).toEdge == 0) {
+                if ((*k).toEdge == nullptr) {
                     continue;
                 }
                 if (l != 0) {
@@ -514,9 +560,12 @@ NWWriter_SUMO::writeJunction(OutputDevice& into, const NBNode& n, const bool che
     if (n.hasCustomShape()) {
         into.writeAttr(SUMO_ATTR_CUSTOMSHAPE, true);
     }
+    if (n.getRightOfWay() != RIGHT_OF_WAY_DEFAULT) {
+        into.writeAttr<std::string>(SUMO_ATTR_RIGHT_OF_WAY, toString(n.getRightOfWay()));
+    }
     if (n.getType() != NODETYPE_DEAD_END) {
         // write right-of-way logics
-        n.writeLogic(into, checkLaneFoes);
+        n.writeLogic(into);
     }
     n.writeParams(into);
     into.closeTag();
@@ -529,11 +578,13 @@ NWWriter_SUMO::writeInternalNodes(OutputDevice& into, const NBNode& n) {
     const std::vector<NBEdge*>& incoming = n.getIncomingEdges();
     // build the list of internal lane ids
     std::vector<std::string> internalLaneIDs;
+    std::map<std::string, std::string> viaIDs;
     for (EdgeVector::const_iterator i = incoming.begin(); i != incoming.end(); i++) {
         const std::vector<NBEdge::Connection>& elv = (*i)->getConnections();
         for (std::vector<NBEdge::Connection>::const_iterator k = elv.begin(); k != elv.end(); ++k) {
-            if ((*k).toEdge != 0) {
+            if ((*k).toEdge != nullptr) {
                 internalLaneIDs.push_back((*k).getInternalLaneID());
+                viaIDs[(*k).getInternalLaneID()] = ((*k).viaID);
             }
         }
     }
@@ -544,7 +595,7 @@ NWWriter_SUMO::writeInternalNodes(OutputDevice& into, const NBNode& n) {
     for (std::vector<NBEdge*>::const_iterator i = incoming.begin(); i != incoming.end(); i++) {
         const std::vector<NBEdge::Connection>& elv = (*i)->getConnections();
         for (std::vector<NBEdge::Connection>::const_iterator k = elv.begin(); k != elv.end(); ++k) {
-            if ((*k).toEdge == 0 || !(*k).haveVia) {
+            if ((*k).toEdge == nullptr || !(*k).haveVia) {
                 continue;
             }
             Position pos = (*k).shape[-1];
@@ -552,12 +603,16 @@ NWWriter_SUMO::writeInternalNodes(OutputDevice& into, const NBNode& n) {
             into.writeAttr(SUMO_ATTR_TYPE, NODETYPE_INTERNAL);
             NWFrame::writePositionLong(pos, into);
             std::string incLanes = (*k).getInternalLaneID();
-            if ((*k).foeIncomingLanes.length() != 0) {
-                incLanes += " " + (*k).foeIncomingLanes;
+            std::vector<std::string> foeIDs;
+            for (std::string incLane : (*k).foeIncomingLanes) {
+                incLanes += " " + incLane;
+                if (incLane[0] == ':' && viaIDs[incLane] != "") {
+                    // intersecting left turns
+                    foeIDs.push_back(viaIDs[incLane] + "_0");
+                }
             }
             into.writeAttr(SUMO_ATTR_INCLANES, incLanes);
             const std::vector<int>& foes = (*k).foeInternalLinks;
-            std::vector<std::string> foeIDs;
             for (std::vector<int>::const_iterator it = foes.begin(); it != foes.end(); ++it) {
                 foeIDs.push_back(internalLaneIDs[*it]);
             }
@@ -597,6 +652,9 @@ NWWriter_SUMO::writeConnection(OutputDevice& into, const NBEdge& from, const NBE
     if (c.customShape.size() != 0 && style != TLL) {
         into.writeAttr(SUMO_ATTR_SHAPE, c.customShape);
     }
+    if (c.uncontrolled != false && style != TLL) {
+        into.writeAttr(SUMO_ATTR_UNCONTROLLED, c.uncontrolled);
+    }
     if (style != PLAIN) {
         if (includeInternal) {
             into.writeAttr(SUMO_ATTR_VIA, c.getInternalLaneID());
@@ -604,7 +662,7 @@ NWWriter_SUMO::writeConnection(OutputDevice& into, const NBEdge& from, const NBE
         // set information about the controlling tl if any
         if (c.tlID != "") {
             into.writeAttr(SUMO_ATTR_TLID, c.tlID);
-            into.writeAttr(SUMO_ATTR_TLLINKINDEX, c.tlLinkNo);
+            into.writeAttr(SUMO_ATTR_TLLINKINDEX, c.tlLinkIndex);
         }
         if (style == SUMONET) {
             // write the direction information
@@ -652,7 +710,7 @@ void
 NWWriter_SUMO::writeInternalConnection(OutputDevice& into,
                                        const std::string& from, const std::string& to,
                                        int fromLane, int toLane, const std::string& via,
-                                       LinkDirection dir) {
+                                       LinkDirection dir, const std::string& tlID, int linkIndex) {
     into.openTag(SUMO_TAG_CONNECTION);
     into.writeAttr(SUMO_ATTR_FROM, from);
     into.writeAttr(SUMO_ATTR_TO, to);
@@ -661,6 +719,11 @@ NWWriter_SUMO::writeInternalConnection(OutputDevice& into,
     if (via != "") {
         into.writeAttr(SUMO_ATTR_VIA, via);
     }
+    if (tlID != "" && linkIndex != NBConnection::InvalidTlIndex) {
+        // used for the reverse direction of pedestrian crossings
+        into.writeAttr(SUMO_ATTR_TLID, tlID);
+        into.writeAttr(SUMO_ATTR_TLLINKINDEX, linkIndex);
+    }
     into.writeAttr(SUMO_ATTR_DIR, dir);
     into.writeAttr(SUMO_ATTR_STATE, (via != "" ? "m" : "M"));
     into.closeTag();
@@ -701,7 +764,7 @@ NWWriter_SUMO::writeRoundabout(OutputDevice& into, const std::vector<std::string
     std::vector<std::string> nodeIDs;
     for (std::vector<std::string>::const_iterator i = edgeIDs.begin(); i != edgeIDs.end(); ++i) {
         const NBEdge* edge = ec.retrieve(*i);
-        if (edge != 0) {
+        if (edge != nullptr) {
             nodeIDs.push_back(edge->getToNode()->getID());
             validEdgeIDs.push_back(edge->getID());
         } else {
@@ -800,6 +863,9 @@ NWWriter_SUMO::writeTrafficLights(OutputDevice& into, const NBTrafficLightLogicC
         for (std::vector<NBTrafficLightLogic::PhaseDefinition>::const_iterator j = phases.begin(); j != phases.end(); ++j) {
             into.openTag(SUMO_TAG_PHASE);
             into.writeAttr(SUMO_ATTR_DURATION, writeSUMOTime(j->duration));
+            if (j->duration < TIME2STEPS(10)) {
+                into.writePadding(" ");
+            }
             into.writeAttr(SUMO_ATTR_STATE, j->state);
             if (varPhaseLength) {
                 if (j->minDur != NBTrafficLightDefinition::UNSPECIFIED_DURATION) {
@@ -819,5 +885,34 @@ NWWriter_SUMO::writeTrafficLights(OutputDevice& into, const NBTrafficLightLogicC
         into.lf();
     }
 }
+
+
+void
+NWWriter_SUMO::writeStopOffsets(OutputDevice& into, const std::map<SVCPermissions, double>& stopOffsets) {
+    if (stopOffsets.size() == 0) {
+        return;
+    }
+    assert(stopOffsets.size() == 1);
+    std::pair<int, double> offset = *stopOffsets.begin();
+    std::string ss_vclasses = getVehicleClassNames(offset.first);
+    if (ss_vclasses.length() == 0) {
+        // This stopOffset would have no effect...
+        return;
+    }
+    into.openTag(SUMO_TAG_STOPOFFSET);
+    std::string ss_exceptions = getVehicleClassNames(~offset.first);
+    if (ss_vclasses.length() <= ss_exceptions.length()) {
+        into.writeAttr(SUMO_ATTR_VCLASSES, ss_vclasses);
+    } else {
+        if (ss_exceptions.length() == 0) {
+            into.writeAttr(SUMO_ATTR_VCLASSES, "all");
+        } else {
+            into.writeAttr(SUMO_ATTR_EXCEPTIONS, ss_exceptions);
+        }
+    }
+    into.writeAttr(SUMO_ATTR_VALUE, offset.second);
+    into.closeTag();
+}
+
 /****************************************************************************/
 
