@@ -1,18 +1,17 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    NWWriter_XML.cpp
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
+/// @author  Leonhard Luecken
 /// @date    Tue, 11.05.2011
 /// @version $Id$
 ///
@@ -23,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 #include <algorithm>
 #include <utils/common/MsgHandler.h>
 #include <netbuild/NBEdge.h>
@@ -152,6 +147,9 @@ NWWriter_XML::writeNodes(const OptionsCont& oc, NBNodeCont& nc) {
         if (n->getKeepClear() == false) {
             device.writeAttr<bool>(SUMO_ATTR_KEEP_CLEAR, n->getKeepClear());
         }
+        if (n->getRightOfWay() != RIGHT_OF_WAY_DEFAULT) {
+            device.writeAttr<std::string>(SUMO_ATTR_RIGHT_OF_WAY, toString(n->getRightOfWay()));
+        }
         n->writeParams(device);
         device.closeTag();
     }
@@ -236,6 +234,9 @@ NWWriter_XML::writeEdgesAndConnections(const OptionsCont& oc, NBNodeCont& nc, NB
         if (!e->hasLaneSpecificPermissions()) {
             writePermissions(edevice, e->getPermissions(0));
         }
+        if (!e->hasLaneSpecificStopOffsets() && e->getStopOffsets().size() != 0) {
+            NWWriter_SUMO::writeStopOffsets(edevice, e->getStopOffsets());
+        }
         if (e->needsLaneSpecificOutput()) {
             for (int i = 0; i < (int)e->getLanes().size(); ++i) {
                 const NBEdge::Lane& lane = e->getLanes()[i];
@@ -268,6 +269,7 @@ NWWriter_XML::writeEdgesAndConnections(const OptionsCont& oc, NBNodeCont& nc, NB
                     edevice.closeTag();
                 }
                 lane.writeParams(edevice);
+                NWWriter_SUMO::writeStopOffsets(edevice, lane.stopOffsets);
                 edevice.closeTag();
             }
         }
@@ -322,12 +324,26 @@ NWWriter_XML::writeEdgesAndConnections(const OptionsCont& oc, NBNodeCont& nc, NB
             if (c->customTLIndex != -1) {
                 cdevice.writeAttr(SUMO_ATTR_TLLINKINDEX, c->customTLIndex);
             }
+            if (c->customTLIndex2 != -1) {
+                cdevice.writeAttr(SUMO_ATTR_TLLINKINDEX2, c->customTLIndex2);
+            }
             if (c->customShape.size() != 0) {
                 cdevice.writeAttr(SUMO_ATTR_SHAPE, c->customShape);
             }
             cdevice.closeTag();
         }
     }
+    // write custom walkingarea shapes to the connections file
+    for (std::map<std::string, NBNode*>::const_iterator it_node = nc.begin(); it_node != nc.end(); ++it_node) {
+        for (const auto& wacs : it_node->second->getWalkingAreaCustomShapes()) {
+            cdevice.openTag(SUMO_TAG_WALKINGAREA);
+            cdevice.writeAttr(SUMO_ATTR_NODE, it_node->first);
+            cdevice.writeAttr(SUMO_ATTR_EDGES, joinNamedToString(wacs.edges, " "));
+            cdevice.writeAttr(SUMO_ATTR_SHAPE, wacs.shape);
+            cdevice.closeTag();
+        }
+    }
+
     edevice.close();
     cdevice.close();
 }
