@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    ODDistrictCont.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <utils/common/MsgHandler.h>
@@ -55,7 +49,7 @@ ODDistrictCont::~ODDistrictCont() {}
 std::string
 ODDistrictCont::getRandomSourceFromDistrict(const std::string& name) const {
     ODDistrict* district = get(name);
-    if (district == 0) {
+    if (district == nullptr) {
         throw InvalidArgument("There is no district '" + name + "'.");
     }
     return district->getRandomSource();
@@ -65,7 +59,7 @@ ODDistrictCont::getRandomSourceFromDistrict(const std::string& name) const {
 std::string
 ODDistrictCont::getRandomSinkFromDistrict(const std::string& name) const {
     ODDistrict* district = get(name);
-    if (district == 0) {
+    if (district == nullptr) {
         throw InvalidArgument("There is no district '" + name + "'.");
     }
     return district->getRandomSink();
