@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIOSGView.cpp
 /// @author  Daniel Krajzewicz
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #ifdef HAVE_OSG
 
@@ -80,7 +74,7 @@
 #include <microsim/traffic_lights/MSSimpleTrafficLightLogic.h>
 #include <utils/common/RGBColor.h>
 #include <utils/common/MsgHandler.h>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include <utils/geom/PositionVector.h>
 #include <gui/GUISUMOViewParent.h>
 #include <utils/gui/globjects/GLIncludes.h>
@@ -317,9 +311,9 @@ GUIOSGView::onPaint(FXObject*, FXSelector, void*) {
                 GUINet* net = (GUINet*) MSNet::getInstance();
                 try {
                     MSTLLogicControl::TLSLogicVariants& vars = net->getTLSControl().get(d.filename.substr(3, linkStringIdx - 3));
-                    const int linkIdx = TplConvert::_2int(d.filename.substr(linkStringIdx + 1).c_str());
+                    const int linkIdx = StringUtils::toInt(d.filename.substr(linkStringIdx + 1));
                     if (linkIdx < 0 || linkIdx >= static_cast<int>(vars.getActive()->getLinks().size())) {
-                        throw NumberFormatException();
+                        throw NumberFormatException("");
                     }
                     const MSLink* const l = vars.getActive()->getLinksAt(linkIdx)[0];
                     osg::Switch* switchNode = new osg::Switch();
@@ -342,14 +336,21 @@ GUIOSGView::onPaint(FXObject*, FXSelector, void*) {
     }
     myDecalsLock.unlock();
     MSVehicleControl::constVehIt it = MSNet::getInstance()->getVehicleControl().loadedVehBegin();
+    // reset active flag
+    for (auto& item : myVehicles) {
+        item.second.active = false;
+    }
     for (; it != MSNet::getInstance()->getVehicleControl().loadedVehEnd(); it++) {
         GUIVehicle* veh = static_cast<GUIVehicle*>(it->second);
         if (!veh->isOnRoad()) {
             continue;
         }
-        if (myVehicles.find(veh) == myVehicles.end()) {
+        auto itVeh = myVehicles.find(veh);
+        if (itVeh == myVehicles.end()) {
             myVehicles[veh] = GUIOSGBuilder::buildMovable(veh->getVehicleType());
             myRoot->addChild(myVehicles[veh].pos);
+        } else {
+            itVeh->second.active = true;
         }
         osg::PositionAttitudeTransform* n = myVehicles[veh].pos;
         n->setPosition(osg::Vec3d(veh->getPosition().x(), veh->getPosition().y(), veh->getPosition().z()));
@@ -374,6 +375,12 @@ GUIOSGView::onPaint(FXObject*, FXSelector, void*) {
         myVehicles[veh].lights->setValue(1, veh->signalSet(MSVehicle::VEH_SIGNAL_BLINKER_LEFT | MSVehicle::VEH_SIGNAL_BLINKER_EMERGENCY));
         myVehicles[veh].lights->setValue(2, veh->signalSet(MSVehicle::VEH_SIGNAL_BRAKELIGHT));
     }
+    // remove inactive
+    for (auto& item : myVehicles) {
+        if (!item.second.active) {
+            removeVeh(item.first);
+        }
+    }
 
     const SUMOTime now = MSNet::getInstance()->getCurrentTimeStep();
     if (now != myLastUpdate || (myVisualizationChanger != 0 && myVisualizationChanger->shown())) {
@@ -393,12 +400,23 @@ GUIOSGView::onPaint(FXObject*, FXSelector, void*) {
         myCameraManipulator->setByInverseMatrix(m);
     }
 
+    // reset active flag
+    for (auto& item : myPersons) {
+        item.second.active = false;
+    }
     for (std::map<std::string, MSTransportable*>::const_iterator it = MSNet::getInstance()->getPersonControl().loadedBegin(); it != MSNet::getInstance()->getPersonControl().loadedEnd(); ++it) {
         MSTransportable* person = (*it).second;
         // XXX if not departed: continue
-        if (myPersons.find(person) == myPersons.end()) {
+        if (person->hasArrived()) {
+            //std::cout << SIMTIME << " person " << person->getID() << " is loaded but arrived\n";
+            continue;
+        }
+        auto itPers = myPersons.find(person);
+        if (itPers == myPersons.end()) {
             myPersons[person] = GUIOSGBuilder::buildMovable(person->getVehicleType());
             myRoot->addChild(myPersons[person].pos);
+        } else {
+            itPers->second.active = true;
         }
         osg::PositionAttitudeTransform* n = myPersons[person].pos;
         const Position pos = person->getPosition();
@@ -406,6 +424,12 @@ GUIOSGView::onPaint(FXObject*, FXSelector, void*) {
         const double dir = person->getAngle() + M_PI / 2.;
         n->setAttitude(osg::Quat(dir, osg::Vec3d(0, 0, 1)));
     }
+    // remove inactive
+    for (auto& item : myPersons) {
+        if (!item.second.active) {
+            removeTransportable(item.first);
+        }
+    }
     if (myAdapter->makeCurrent()) {
         myViewer->frame();
         makeNonCurrent();
@@ -416,7 +440,7 @@ GUIOSGView::onPaint(FXObject*, FXSelector, void*) {
 
 
 void
-GUIOSGView::remove(GUIVehicle* veh) {
+GUIOSGView::removeVeh(MSVehicle* veh) {
     if (myTracked == veh) {
         stopTrack();
     }
@@ -428,19 +452,29 @@ GUIOSGView::remove(GUIVehicle* veh) {
 }
 
 
+void
+GUIOSGView::removeTransportable(MSTransportable* t) {
+    std::map<MSTransportable*, OSGMovable>::iterator i = myPersons.find(t);
+    if (i != myPersons.end()) {
+        myRoot->removeChild(i->second.pos);
+        myPersons.erase(i);
+    }
+}
+
+
 void
 GUIOSGView::showViewportEditor() {
     getViewportEditor(); // make sure it exists;
     osg::Vec3d lookFromOSG, lookAtOSG, up;
     myViewer->getCameraManipulator()->getInverseMatrix().getLookAt(lookFromOSG, lookAtOSG, up);
     Position from(lookFromOSG[0], lookFromOSG[1], lookFromOSG[2]), at(lookAtOSG[0], lookAtOSG[1], lookAtOSG[2]);
-    myViewportChooser->setOldValues(from, at);
+    myViewportChooser->setOldValues(from, at, 0);
     myViewportChooser->show();
 }
 
 
 void
-GUIOSGView::setViewportFromTo(const Position& lookFrom, const Position& lookAt) {
+GUIOSGView::setViewportFromToRot(const Position& lookFrom, const Position& lookAt, double /*rotation*/) {
     osg::Vec3d lookFromOSG, lookAtOSG, up;
     myViewer->getCameraManipulator()->getHomePosition(lookFromOSG, lookAtOSG, up);
     lookFromOSG[0] = lookFrom.x();
@@ -459,8 +493,8 @@ void
 GUIOSGView::copyViewportTo(GUISUMOAbstractView* view) {
     osg::Vec3d lookFrom, lookAt, up;
     myCameraManipulator->getHomePosition(lookFrom, lookAt, up);
-    view->setViewportFromTo(Position(lookFrom[0], lookFrom[1], lookFrom[2]),
-                            Position(lookAt[0], lookAt[1], lookAt[2]));
+    view->setViewportFromToRot(Position(lookFrom[0], lookFrom[1], lookFrom[2]),
+                               Position(lookAt[0], lookAt[1], lookAt[2]), 0);
 }
 
 
