@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIOSGView.h
 /// @author  Daniel Krajzewicz
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #ifdef HAVE_OSG
 
@@ -123,6 +117,7 @@ public:
         osg::ref_ptr<osg::PositionAttitudeTransform> pos;
         osg::ref_ptr<osg::ShapeDrawable> geom;
         osg::ref_ptr<osg::Switch> lights;
+        bool active;
     };
 
 
@@ -150,7 +145,7 @@ public:
     void showViewportEditor();
 
     /// applies the given viewport settings
-    void setViewportFromTo(const Position& lookFrom, const Position& lookAt);
+    void setViewportFromToRot(const Position& lookFrom, const Position& lookAt, double rotation);
 
     ///@brief copy the viewport to the given view
     void copyViewportTo(GUISUMOAbstractView* view);
@@ -179,7 +174,8 @@ public:
     /// @brief get the current simulation time
     SUMOTime getCurrentTimeStep() const;
 
-    void remove(GUIVehicle* veh);
+    void removeVeh(MSVehicle* veh);
+    void removeTransportable(MSTransportable* t);
 
     // callback
     long onConfigure(FXObject*, FXSelector, void*);
