@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    PCLoaderArcView.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <utils/common/MsgHandler.h>
@@ -170,7 +164,7 @@ PCLoaderArcView::load(const std::string& file, OptionsCont& oc, PCPolyContainer&
                     }
                     shape.push_back_noDoublePos(pos);
                 }
-                SUMOPolygon* poly = new SUMOPolygon(id, type, color, shape, false, fill, layer);
+                SUMOPolygon* poly = new SUMOPolygon(id, type, color, shape, false, fill, 1, layer);
                 if (toFill.add(poly)) {
                     parCont.push_back(poly);
                 }
@@ -187,7 +181,7 @@ PCLoaderArcView::load(const std::string& file, OptionsCont& oc, PCPolyContainer&
                     }
                     shape.push_back_noDoublePos(pos);
                 }
-                SUMOPolygon* poly = new SUMOPolygon(id, type, color, shape, false, fill, layer);
+                SUMOPolygon* poly = new SUMOPolygon(id, type, color, shape, false, fill, 1, layer);
                 if (toFill.add(poly)) {
                     parCont.push_back(poly);
                 }
@@ -223,7 +217,7 @@ PCLoaderArcView::load(const std::string& file, OptionsCont& oc, PCPolyContainer&
                         }
                         shape.push_back_noDoublePos(pos);
                     }
-                    SUMOPolygon* poly = new SUMOPolygon(tid, type, color, shape, false, fill, layer);
+                    SUMOPolygon* poly = new SUMOPolygon(tid, type, color, shape, false, fill, 1, layer);
                     if (toFill.add(poly)) {
                         parCont.push_back(poly);
                     }
@@ -244,7 +238,7 @@ PCLoaderArcView::load(const std::string& file, OptionsCont& oc, PCPolyContainer&
                         }
                         shape.push_back_noDoublePos(pos);
                     }
-                    SUMOPolygon* poly = new SUMOPolygon(tid, type, color, shape, false, fill, layer);
+                    SUMOPolygon* poly = new SUMOPolygon(tid, type, color, shape, false, fill, 1, layer);
                     if (toFill.add(poly)) {
                         parCont.push_back(poly);
                     }
@@ -252,7 +246,7 @@ PCLoaderArcView::load(const std::string& file, OptionsCont& oc, PCPolyContainer&
             }
             break;
             default:
-                WRITE_WARNING("Unsupported shape type occured (id='" + id + "').");
+                WRITE_WARNING("Unsupported shape type occurred (id='" + id + "').");
                 break;
         }
         if (oc.getBool("shapefile.add-param")) {
@@ -279,6 +273,9 @@ PCLoaderArcView::load(const std::string& file, OptionsCont& oc, PCPolyContainer&
 #endif
     PROGRESS_DONE_MESSAGE();
 #else
+    UNUSED_PARAMETER(file);
+    UNUSED_PARAMETER(oc);
+    UNUSED_PARAMETER(toFill);
     WRITE_ERROR("SUMO was compiled without GDAL support.");
 #endif
 }
