@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    PCLoaderOSM.cpp
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <map>
@@ -38,11 +32,8 @@
 #include <utils/common/MsgHandler.h>
 #include <utils/common/ToString.h>
 #include <utils/common/StringUtils.h>
-#include <utils/options/OptionsCont.h>
-#include <utils/options/Option.h>
 #include <utils/common/StdDefs.h>
-#include <polyconvert/PCPolyContainer.h>
-#include "PCLoaderOSM.h"
+#include <utils/common/SysUtils.h>
 #include <utils/common/RGBColor.h>
 #include <utils/geom/GeomHelper.h>
 #include <utils/geom/Position.h>
@@ -50,6 +41,10 @@
 #include <utils/xml/XMLSubSys.h>
 #include <utils/geom/GeomConvHelper.h>
 #include <utils/common/FileHelpers.h>
+#include <utils/options/OptionsCont.h>
+#include <utils/options/Option.h>
+#include <polyconvert/PCPolyContainer.h>
+#include "PCLoaderOSM.h"
 
 // static members
 // ---------------------------------------------------------------------------
@@ -108,6 +103,7 @@ PCLoaderOSM::loadIfSet(OptionsCont& oc, PCPolyContainer& toFill,
             WRITE_ERROR("Could not open osm-file '" + *file + "'.");
             return;
         }
+        const long before = SysUtils::getCurrentMillis();
         PROGRESS_BEGIN_MESSAGE("Parsing nodes from osm-file '" + *file + "'");
         if (!XMLSubSys::runParser(nodesHandler, *file)) {
             for (std::map<long long int, PCOSMNode*>::const_iterator i = nodes.begin(); i != nodes.end(); ++i) {
@@ -115,7 +111,7 @@ PCLoaderOSM::loadIfSet(OptionsCont& oc, PCPolyContainer& toFill,
             }
             throw ProcessError();
         }
-        PROGRESS_DONE_MESSAGE();
+        PROGRESS_TIME_MESSAGE(before);
     }
     // load relations to see which additional ways may be relevant
     Relations relations;
@@ -123,9 +119,10 @@ PCLoaderOSM::loadIfSet(OptionsCont& oc, PCPolyContainer& toFill,
     RelationsHandler relationsHandler(additionalWays, relations, withAttributes, *m);
     for (std::vector<std::string>::const_iterator file = files.begin(); file != files.end(); ++file) {
         // edges
+        const long before = SysUtils::getCurrentMillis();
         PROGRESS_BEGIN_MESSAGE("Parsing relations from osm-file '" + *file + "'");
         XMLSubSys::runParser(relationsHandler, *file);
-        PROGRESS_DONE_MESSAGE();
+        PROGRESS_TIME_MESSAGE(before);
     }
 
     // load ways
@@ -133,13 +130,119 @@ PCLoaderOSM::loadIfSet(OptionsCont& oc, PCPolyContainer& toFill,
     EdgesHandler edgesHandler(nodes, edges, additionalWays, withAttributes, *m);
     for (std::vector<std::string>::const_iterator file = files.begin(); file != files.end(); ++file) {
         // edges
+        const long before = SysUtils::getCurrentMillis();
         PROGRESS_BEGIN_MESSAGE("Parsing edges from osm-file '" + *file + "'");
         XMLSubSys::runParser(edgesHandler, *file);
-        PROGRESS_DONE_MESSAGE();
+        PROGRESS_TIME_MESSAGE(before);
     }
 
     // build all
     const bool useName = oc.getBool("osm.use-name");
+    const double mergeRelationsThreshold = OptionsCont::getOptions().getFloat("osm.merge-relations");
+    // create polygons from relations
+    if (mergeRelationsThreshold >= 0) {
+        for (PCOSMRelation* rel : relations) {
+            if (!rel->keep || rel->myWays.empty()) {
+                continue;
+            }
+            // filter unknown and empty ways
+            int numNodes = 0;
+            for (auto it = rel->myWays.begin(); it != rel->myWays.end();) {
+                if (edges.count(*it) == 0 || edges[*it]->myCurrentNodes.empty()) {
+                    it = rel->myWays.erase(it);
+                } else {
+                    numNodes += (int)edges[*it]->myCurrentNodes.size();
+                    it++;
+                }
+            }
+            if (numNodes == 0) {
+                WRITE_WARNING("Could not import polygon from relation '" + toString(rel->id) + "' (missing ways)");
+                continue;
+            }
+            PCOSMEdge* e = new PCOSMEdge();
+            e->id = rel->id;
+            e->name = rel->name;
+            e->myAttributes = rel->myAttributes;
+            e->myIsClosed = false;
+            e->standalone = true;
+
+            std::set<long long int> remaining(rel->myWays.begin(), rel->myWays.end());
+            PCOSMEdge* minEdge = edges[rel->myWays.front()];
+            e->myCurrentNodes.insert(e->myCurrentNodes.end(), minEdge->myCurrentNodes.begin(), minEdge->myCurrentNodes.end());
+            Position prev(convertNodePosition(nodes[minEdge->myCurrentNodes.back()]));
+            minEdge->standalone = false;
+            remaining.erase(minEdge->id);
+            bool ok = true;
+            while (!remaining.empty()) {
+                // assemble in an order that greedily reduces jump size
+                double minDist = std::numeric_limits<double>::max();
+                bool minFront = false;
+                for (long long int wayID : remaining) {
+                    PCOSMEdge* part = edges[wayID];
+                    Position frontPos(convertNodePosition(nodes.find(part->myCurrentNodes.front())->second));
+                    const double frontDist = prev.distanceTo2D(frontPos);
+                    Position backPos(convertNodePosition(nodes.find(part->myCurrentNodes.back())->second));
+                    const double backDist = prev.distanceTo2D(backPos);
+                    if (frontDist < minDist) {
+                        minDist = frontDist;
+                        minEdge = part;
+                        minFront = true;
+                    }
+                    if (backDist < minDist) {
+                        minDist = backDist;
+                        minEdge = part;
+                        minFront = false;
+                    }
+                }
+                if (minDist > mergeRelationsThreshold) {
+                    double length = 0.;
+                    for (long long int wayID : remaining) {
+                        PCOSMEdge* part = edges[wayID];
+                        Position last(Position::INVALID);
+                        for (long long int nodeID : part->myCurrentNodes) {
+                            Position nodePos(convertNodePosition(nodes[nodeID]));
+                            if (last != Position::INVALID) {
+                                length += last.distanceTo2D(nodePos);
+                            }
+                            last = nodePos;
+                        }
+                        if (part->myIsClosed) {
+                            length += last.distanceTo2D(convertNodePosition(nodes[part->myCurrentNodes.front()]));
+                        }
+                    }
+                    if (length > mergeRelationsThreshold) {
+                        WRITE_WARNING("Could not import polygon from relation '" + toString(rel->id) +
+                                      "' (name:" + e->name + " reason: found gap of " + toString(minDist) +
+                                      "m to way '" + toString(minEdge->id) +
+                                      "')\n Total length of remaining ways: " + toString(length) + "m.");
+                        ok = false;
+                    }
+                    break;
+                }
+                if (minFront) {
+                    e->myCurrentNodes.insert(e->myCurrentNodes.end(), minEdge->myCurrentNodes.begin(), minEdge->myCurrentNodes.end());
+                    prev = convertNodePosition(nodes[minEdge->myCurrentNodes.back()]);
+                } else {
+                    e->myCurrentNodes.insert(e->myCurrentNodes.end(), minEdge->myCurrentNodes.rbegin(), minEdge->myCurrentNodes.rend());
+                    prev = convertNodePosition(nodes[minEdge->myCurrentNodes.front()]);
+                }
+                minEdge->standalone = false;
+                remaining.erase(minEdge->id);
+            }
+            if (ok) {
+                edges[e->id] = e;
+                WRITE_MESSAGE("Assembled polygon from relation '" + toString(rel->id) + "' (name:" + e->name + ")");
+            } else {
+                delete e;
+                // export ways by themselves
+                for (long long int wayID : rel->myWays) {
+                    PCOSMEdge* part = edges[wayID];
+                    part->standalone = true;
+                }
+            }
+        }
+    }
+
     // instatiate polygons
     for (EdgeMap::iterator i = edges.begin(); i != edges.end(); ++i) {
         PCOSMEdge* e = (*i).second;
@@ -147,6 +250,10 @@ PCLoaderOSM::loadIfSet(OptionsCont& oc, PCPolyContainer& toFill,
             // cannot be relevant as a polygon
             continue;
         }
+        if (!e->standalone && mergeRelationsThreshold >= 0) {
+            // part of a relation
+            continue;
+        }
         if (e->myCurrentNodes.size() == 0) {
             WRITE_ERROR("Polygon '" + toString(e->id) + "' has no shape.");
             continue;
@@ -204,16 +311,16 @@ PCLoaderOSM::loadIfSet(OptionsCont& oc, PCPolyContainer& toFill,
             const std::string& value = it->second;
             const std::string fullType = key + "." + value;
             if (tm.has(key + "." + value)) {
-                index = addPOI(n, pos, tm.get(fullType), fullType, index, toFill, ignorePruning, withAttributes);
+                index = addPOI(n, pos, tm.get(fullType), fullType, index, useName, toFill, ignorePruning, withAttributes);
             } else if (tm.has(key)) {
-                index = addPOI(n, pos, tm.get(key), fullType, index, toFill, ignorePruning, withAttributes);
+                index = addPOI(n, pos, tm.get(key), fullType, index, useName, toFill, ignorePruning, withAttributes);
             } else if (MyKeysToInclude.count(key) > 0) {
                 unKnownPOIType = fullType;
             }
         }
         const PCTypeMap::TypeDef& def = tm.getDefault();
         if (index == 0 && !def.discard && unKnownPOIType != "") {
-            addPOI(n, pos, def, unKnownPOIType, index,  toFill, ignorePruning, withAttributes);
+            addPOI(n, pos, def, unKnownPOIType, index, useName, toFill, ignorePruning, withAttributes);
         }
     }
     // delete nodes
@@ -231,6 +338,14 @@ PCLoaderOSM::loadIfSet(OptionsCont& oc, PCPolyContainer& toFill,
 }
 
 
+Position
+PCLoaderOSM::convertNodePosition(PCOSMNode* n) {
+    Position pos(n->lon, n->lat);
+    GeoConvHelper::getProcessing().x2cartesian(pos);
+    return pos;
+}
+
+
 int
 PCLoaderOSM::addPolygon(const PCOSMEdge* edge, const PositionVector& vec, const PCTypeMap::TypeDef& def, const std::string& fullType, int index, bool useName, PCPolyContainer& toFill, bool ignorePruning, bool withAttributes) {
     if (def.discard) {
@@ -242,7 +357,7 @@ PCLoaderOSM::addPolygon(const PCOSMEdge* edge, const PositionVector& vec, const
         SUMOPolygon* poly = new SUMOPolygon(
             StringUtils::escapeXML(id),
             StringUtils::escapeXML(OptionsCont::getOptions().getBool("osm.keep-full-type") ? fullType : def.id),
-            def.color, vec, false, def.allowFill && closedShape, (double)def.layer);
+            def.color, vec, false, def.allowFill && closedShape, 1, def.layer);
         if (withAttributes) {
             poly->updateParameter(edge->myAttributes);
         }
@@ -254,14 +369,15 @@ PCLoaderOSM::addPolygon(const PCOSMEdge* edge, const PositionVector& vec, const
     }
 }
 
+
 int
 PCLoaderOSM::addPOI(const PCOSMNode* node, const Position& pos, const PCTypeMap::TypeDef& def, const std::string& fullType,
-                    int index, PCPolyContainer& toFill, bool ignorePruning, bool withAttributes) {
+                    int index, bool useName, PCPolyContainer& toFill, bool ignorePruning, bool withAttributes) {
     if (def.discard) {
         return index;
     } else {
         const std::string idSuffix = (index == 0 ? "" : "#" + toString(index));
-        const std::string id = def.prefix + toString(node->id) + idSuffix;
+        const std::string id = def.prefix + (useName && node->name != "" ? node->name : toString(node->id)) + idSuffix;
         PointOfInterest* poi = new PointOfInterest(
             StringUtils::escapeXML(id),
             StringUtils::escapeXML(OptionsCont::getOptions().getBool("osm.keep-full-type") ? fullType : def.id),
@@ -295,7 +411,7 @@ PCLoaderOSM::NodesHandler::myStartElement(int element, const SUMOSAXAttributes&
     myParentElements.push_back(element);
     if (element == SUMO_TAG_NODE) {
         bool ok = true;
-        long long int id = attrs.get<long long int>(SUMO_ATTR_ID, 0, ok);
+        long long int id = attrs.get<long long int>(SUMO_ATTR_ID, nullptr, ok);
         if (!ok) {
             return;
         }
@@ -321,8 +437,10 @@ PCLoaderOSM::NodesHandler::myStartElement(int element, const SUMOSAXAttributes&
         bool ok = true;
         std::string key = attrs.getOpt<std::string>(SUMO_ATTR_K, toString(myLastNodeID).c_str(), ok, "", false);
         std::string value = attrs.getOpt<std::string>(SUMO_ATTR_V, toString(myLastNodeID).c_str(), ok, "", false);
-        if (key == "") {
-            myErrorHandler.inform("Empty key in a a tag while parsing node '" + toString(myLastNodeID) + "' occured.");
+        if (key == "name") {
+            myToFill[myLastNodeID]->name = value;
+        } else if (key == "") {
+            myErrorHandler.inform("Empty key in a a tag while parsing node '" + toString(myLastNodeID) + "' occurred.");
             ok = false;
         }
         if (!ok) {
@@ -354,7 +472,7 @@ PCLoaderOSM::RelationsHandler::RelationsHandler(RelationsMap& additionalWays,
     myRelations(relations),
     myWithAttributes(withAttributes),
     myErrorHandler(errorHandler),
-    myCurrentRelation(0) {
+    myCurrentRelation(nullptr) {
 }
 
 
@@ -367,26 +485,28 @@ PCLoaderOSM::RelationsHandler::myStartElement(int element, const SUMOSAXAttribut
     myParentElements.push_back(element);
     // parse "relation" elements
     if (element == SUMO_TAG_RELATION) {
-        bool ok = true;
         myCurrentWays.clear();
-        std::string action = attrs.hasAttribute("action") ? attrs.getStringSecure("action", "") : "";
-        if (action == "delete" || !ok) {
-            myCurrentRelation = 0;
+        const std::string action = attrs.hasAttribute("action") ? attrs.getStringSecure("action", "") : "";
+        if (action == "delete") {
+            myCurrentRelation = nullptr;
+        } else {
+            myCurrentRelation = new PCOSMRelation();
+            myCurrentRelation->keep = false;
+            bool ok = true;
+            myCurrentRelation->id = attrs.get<long long int>(SUMO_ATTR_ID, nullptr, ok);
+            myRelations.push_back(myCurrentRelation);
         }
-        myCurrentRelation = new PCOSMRelation();
-        myCurrentRelation->id = attrs.get<long long int>(SUMO_ATTR_ID, 0, ok);
-        myRelations.push_back(myCurrentRelation);
         return;
-    } else if (myCurrentRelation == 0) {
+    } else if (myCurrentRelation == nullptr) {
         return;
     }
     // parse member elements
     if (element == SUMO_TAG_MEMBER) {
         bool ok = true;
         std::string role = attrs.hasAttribute("role") ? attrs.getStringSecure("role", "") : "";
-        long long int ref = attrs.get<long long int>(SUMO_ATTR_REF, 0, ok);
+        long long int ref = attrs.get<long long int>(SUMO_ATTR_REF, nullptr, ok);
         if (role == "outer" || role == "inner") {
-            std::string memberType = attrs.get<std::string>(SUMO_ATTR_TYPE, 0, ok);
+            std::string memberType = attrs.get<std::string>(SUMO_ATTR_TYPE, nullptr, ok);
             if (memberType == "way") {
                 myCurrentWays.push_back(ref);
             }
@@ -395,12 +515,12 @@ PCLoaderOSM::RelationsHandler::myStartElement(int element, const SUMOSAXAttribut
     }
     // parse values
     if (element == SUMO_TAG_TAG && myParentElements.size() > 2 && myParentElements[myParentElements.size() - 2] == SUMO_TAG_RELATION
-            && myCurrentRelation != 0) {
+            && myCurrentRelation != nullptr) {
         bool ok = true;
         std::string key = attrs.getOpt<std::string>(SUMO_ATTR_K, toString(myCurrentRelation).c_str(), ok, "", false);
         std::string value = attrs.getOpt<std::string>(SUMO_ATTR_V, toString(myCurrentRelation).c_str(), ok, "", false);
         if (key == "") {
-            myErrorHandler.inform("Empty key in a a tag while parsing way '" + toString(myCurrentRelation) + "' occured.");
+            myErrorHandler.inform("Empty key in a a tag while parsing way '" + toString(myCurrentRelation) + "' occurred.");
             ok = false;
         }
         if (!ok) {
@@ -409,6 +529,7 @@ PCLoaderOSM::RelationsHandler::myStartElement(int element, const SUMOSAXAttribut
         if (key == "name") {
             myCurrentRelation->name = value;
         } else if (MyKeysToInclude.count(key) > 0) {
+            myCurrentRelation->keep = true;
             for (std::vector<long long int>::iterator it = myCurrentWays.begin(); it != myCurrentWays.end(); ++it) {
                 myAdditionalWays[*it] = myCurrentRelation;
             }
@@ -422,7 +543,8 @@ void
 PCLoaderOSM::RelationsHandler::myEndElement(int element) {
     myParentElements.pop_back();
     if (element == SUMO_TAG_RELATION) {
-        myCurrentRelation = 0;
+        myCurrentRelation->myWays = myCurrentWays;
+        myCurrentRelation = nullptr;
         myCurrentWays.clear();
     }
 }
@@ -454,19 +576,22 @@ PCLoaderOSM::EdgesHandler::myStartElement(int element, const SUMOSAXAttributes&
     // parse "way" elements
     if (element == SUMO_TAG_WAY) {
         bool ok = true;
-        long long int id = attrs.get<long long int>(SUMO_ATTR_ID, 0, ok);
-        if (!ok) {
+        const long long int id = attrs.get<long long int>(SUMO_ATTR_ID, nullptr, ok);
+        const std::string action = attrs.hasAttribute("action") ? attrs.getStringSecure("action", "") : "";
+        if (action == "delete" || !ok) {
+            myCurrentEdge = nullptr;
             return;
         }
         myCurrentEdge = new PCOSMEdge();
         myCurrentEdge->id = id;
         myCurrentEdge->myIsClosed = false;
+        myCurrentEdge->standalone = false;
         myKeep = (myAdditionalWays.find(id) != myAdditionalWays.end());
     }
     // parse "nd" (node) elements
-    if (element == SUMO_TAG_ND) {
+    if (element == SUMO_TAG_ND && myCurrentEdge != nullptr) {
         bool ok = true;
-        long long int ref = attrs.get<long long int>(SUMO_ATTR_REF, 0, ok);
+        const long long int ref = attrs.get<long long int>(SUMO_ATTR_REF, nullptr, ok);
         if (ok) {
             if (myOSMNodes.find(ref) == myOSMNodes.end()) {
                 WRITE_WARNING("The referenced geometry information (ref='" + toString(ref) + "') is not known");
@@ -477,12 +602,12 @@ PCLoaderOSM::EdgesHandler::myStartElement(int element, const SUMOSAXAttributes&
     }
     // parse values
     if (element == SUMO_TAG_TAG && myParentElements.size() > 2 && myParentElements[myParentElements.size() - 2] == SUMO_TAG_WAY
-            && myCurrentEdge != 0) {
+            && myCurrentEdge != nullptr) {
         bool ok = true;
         std::string key = attrs.getOpt<std::string>(SUMO_ATTR_K, toString(myCurrentEdge->id).c_str(), ok, "", false);
         std::string value = attrs.getOpt<std::string>(SUMO_ATTR_V, toString(myCurrentEdge->id).c_str(), ok, "", false);
         if (key == "") {
-            myErrorHandler.inform("Empty key in a a tag while parsing way '" + toString(myCurrentEdge->id) + "' occured.");
+            myErrorHandler.inform("Empty key in a a tag while parsing way '" + toString(myCurrentEdge->id) + "' occurred.");
             ok = false;
         }
         if (!ok) {
@@ -492,6 +617,7 @@ PCLoaderOSM::EdgesHandler::myStartElement(int element, const SUMOSAXAttributes&
             myCurrentEdge->name = value;
         } else if (MyKeysToInclude.count(key) > 0) {
             myKeep = true;
+            myCurrentEdge->standalone = true;
         }
         myCurrentEdge->myAttributes[key] = value;
     }
@@ -501,7 +627,7 @@ PCLoaderOSM::EdgesHandler::myStartElement(int element, const SUMOSAXAttributes&
 void
 PCLoaderOSM::EdgesHandler::myEndElement(int element) {
     myParentElements.pop_back();
-    if (element == SUMO_TAG_WAY) {
+    if (element == SUMO_TAG_WAY && myCurrentEdge != nullptr) {
         if (myKeep) {
             RelationsMap::const_iterator it = myAdditionalWays.find(myCurrentEdge->id);
             if (it != myAdditionalWays.end()) {
@@ -511,7 +637,7 @@ PCLoaderOSM::EdgesHandler::myEndElement(int element) {
         } else {
             delete myCurrentEdge;
         }
-        myCurrentEdge = 0;
+        myCurrentEdge = nullptr;
     }
 }
 
