@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    PCLoaderXML.cpp
 /// @author  Daniel Krajzewicz
@@ -24,28 +22,25 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <map>
 #include <fstream>
 #include <utils/options/OptionsCont.h>
 #include <utils/options/Option.h>
-#include <utils/common/StdDefs.h>
-#include <polyconvert/PCPolyContainer.h>
+#include <utils/common/MsgHandler.h>
+#include <utils/common/FileHelpers.h>
 #include <utils/common/RGBColor.h>
+#include <utils/common/StdDefs.h>
+#include <utils/common/SysUtils.h>
+#include <polyconvert/PCPolyContainer.h>
 #include <utils/geom/GeomHelper.h>
 #include <utils/geom/Boundary.h>
 #include <utils/geom/Position.h>
 #include <utils/geom/GeoConvHelper.h>
 #include <utils/xml/XMLSubSys.h>
 #include <utils/geom/GeomConvHelper.h>
-#include <utils/common/MsgHandler.h>
-#include <utils/common/FileHelpers.h>
 #include <utils/xml/SUMOXMLDefinitions.h>
 #include "PCLoaderXML.h"
 
@@ -69,11 +64,12 @@ PCLoaderXML::loadIfSet(OptionsCont& oc, PCPolyContainer& toFill,
         if (!FileHelpers::isReadable(*file)) {
             throw ProcessError("Could not open xml-file '" + *file + "'.");
         }
+        const long before = SysUtils::getCurrentMillis();
         PROGRESS_BEGIN_MESSAGE("Parsing XML from '" + *file + "'");
         if (!XMLSubSys::runParser(handler, *file)) {
             throw ProcessError();
         }
-        PROGRESS_DONE_MESSAGE();
+        PROGRESS_TIME_MESSAGE(before);
     }
 }
 
@@ -99,7 +95,7 @@ PCLoaderXML::myStartElement(int element,
     }
     bool ok = true;
     // get the id, report an error if not given or empty...
-    std::string id = attrs.get<std::string>(SUMO_ATTR_ID, 0, ok);
+    std::string id = attrs.get<std::string>(SUMO_ATTR_ID, nullptr, ok);
     std::string type = attrs.getOpt<std::string>(SUMO_ATTR_TYPE, id.c_str(), ok, myOptions.getString("type"));
     if (!ok) {
         return;
