@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    ROEdge.cpp
 /// @author  Daniel Krajzewicz
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/common/MsgHandler.h>
 #include <utils/common/ToString.h>
@@ -75,9 +69,12 @@ ROEdge::ROEdge(const std::string& id, RONode* from, RONode* to, int index, const
         myEdges.push_back(0);
     }
     myEdges[index] = this;
-    if (from == 0 && to == 0) {
+    if (from == nullptr && to == nullptr) {
         // TAZ edge, no lanes
         myCombinedPermissions = SVCAll;
+    } else {
+        myBoundary.add(from->getPosition());
+        myBoundary.add(to->getPosition());
     }
 }
 
@@ -103,22 +100,22 @@ ROEdge::addLane(ROLane* lane) {
 
 
 void
-ROEdge::addSuccessor(ROEdge* s, std::string) {
-    if (s->isInternal() && !isInternal()) {
-        if (s->myApproachingEdges.size() == 0) {
-            s->myApproachingEdges.push_back(this);
-        }
-        return;
-    }
+ROEdge::addSuccessor(ROEdge* s, ROEdge* via, std::string) {
     if (find(myFollowingEdges.begin(), myFollowingEdges.end(), s) == myFollowingEdges.end()) {
         myFollowingEdges.push_back(s);
+        myFollowingViaEdges.push_back(std::make_pair(s, via));
         if (isTazConnector()) {
-            myTazBoundary.add(s->getFromJunction()->getPosition());
+            myBoundary.add(s->getFromJunction()->getPosition());
         }
         if (!isInternal()) {
             s->myApproachingEdges.push_back(this);
             if (s->isTazConnector()) {
-                s->myTazBoundary.add(getToJunction()->getPosition());
+                s->myBoundary.add(getToJunction()->getPosition());
+            }
+            if (via != nullptr) {
+                if (via->myApproachingEdges.size() == 0) {
+                    via->myApproachingEdges.push_back(this);
+                }
             }
         }
     }
@@ -150,15 +147,18 @@ ROEdge::getEffort(const ROVehicle* const veh, double time) const {
 
 
 double
-ROEdge::getDistanceTo(const ROEdge* other) const {
+ROEdge::getDistanceTo(const ROEdge* other, const bool doBoundaryEstimate) const {
+    if (doBoundaryEstimate) {
+        return myBoundary.distanceTo2D(other->myBoundary);
+    }
     if (isTazConnector()) {
         if (other->isTazConnector()) {
-            return myTazBoundary.distanceTo2D(other->myTazBoundary);
+            return myBoundary.distanceTo2D(other->myBoundary);
         }
-        return myTazBoundary.distanceTo2D(other->getFromJunction()->getPosition());
+        return myBoundary.distanceTo2D(other->getFromJunction()->getPosition());
     }
     if (other->isTazConnector()) {
-        return other->myTazBoundary.distanceTo2D(getToJunction()->getPosition());
+        return other->myBoundary.distanceTo2D(getToJunction()->getPosition());
     }
     return getToJunction()->getPosition().distanceTo2D(other->getFromJunction()->getPosition());
 }
@@ -190,7 +190,8 @@ ROEdge::getTravelTime(const ROVehicle* const veh, double time) const {
             }
         }
     }
-    return myLength / MIN2(veh->getType()->maxSpeed, veh->getType()->speedFactor.getParameter()[0] * mySpeed);
+    const double speed = veh != nullptr ? MIN2(veh->getType()->maxSpeed, veh->getType()->speedFactor.getParameter()[0] * mySpeed) : mySpeed;
+    return myLength / speed;
 }
 
 
@@ -321,6 +322,14 @@ ROEdge::getAllEdges() {
 }
 
 
+const Position
+ROEdge::getStopPosition(const SUMOVehicleParameter::Stop& stop) {
+    const double middle = (stop.endPos + stop.startPos) / 2.;
+    const ROEdge* const edge = RONet::getInstance()->getEdge(SUMOXMLDefinitions::getEdgeIDFromLane(stop.lane));
+    return (edge->getFromJunction()->getPosition() + edge->getToJunction()->getPosition()) * (middle / edge->getLength());
+}
+
+
 const ROEdgeVector&
 ROEdge::getSuccessors(SUMOVehicleClass vClass) const {
     if (vClass == SVC_IGNORING || !RONet::getInstance()->hasPermissions() || isTazConnector()) {
@@ -333,41 +342,73 @@ ROEdge::getSuccessors(SUMOVehicleClass vClass) const {
     if (i != myClassesSuccessorMap.end()) {
         // can use cached value
         return i->second;
-    } else {
-        // this vClass is requested for the first time. rebuild all successors
-        std::set<ROEdge*> followers;
-        for (std::vector<ROLane*>::const_iterator it = myLanes.begin(); it != myLanes.end(); ++it) {
-            ROLane* lane = *it;
-            if ((lane->getPermissions() & vClass) != 0) {
-                const std::vector<const ROLane*>& outgoing = lane->getOutgoingLanes();
-                for (std::vector<const ROLane*>::const_iterator it2 = outgoing.begin(); it2 != outgoing.end(); ++it2) {
-                    const ROLane* next = *it2;
-                    if ((next->getPermissions() & vClass) != 0) {
-                        followers.insert(&next->getEdge());
-                    }
+    }
+    // this vClass is requested for the first time. rebuild all successors
+    std::set<ROEdge*> followers;
+    for (const ROLane* const lane : myLanes) {
+        if ((lane->getPermissions() & vClass) != 0) {
+            for (const auto& next : lane->getOutgoingViaLanes()) {
+                if ((next.first->getPermissions() & vClass) != 0) {
+                    followers.insert(&next.first->getEdge());
                 }
             }
         }
-        // also add district edges (they are not connected at the lane level
-        for (ROEdgeVector::const_iterator it = myFollowingEdges.begin(); it != myFollowingEdges.end(); ++it) {
-            if ((*it)->isTazConnector()) {
-                followers.insert(*it);
+    }
+    // also add district edges (they are not connected at the lane level
+    for (ROEdgeVector::const_iterator it = myFollowingEdges.begin(); it != myFollowingEdges.end(); ++it) {
+        if ((*it)->isTazConnector()) {
+            followers.insert(*it);
+        }
+    }
+    myClassesSuccessorMap[vClass].insert(myClassesSuccessorMap[vClass].begin(),
+                                         followers.begin(), followers.end());
+    return myClassesSuccessorMap[vClass];
+}
+
+
+const ROConstEdgePairVector&
+ROEdge::getViaSuccessors(SUMOVehicleClass vClass) const {
+    if (vClass == SVC_IGNORING || !RONet::getInstance()->hasPermissions() || isTazConnector()) {
+        return myFollowingViaEdges;
+    }
+#ifdef HAVE_FOX
+    FXMutexLock locker(myLock);
+#endif
+    std::map<SUMOVehicleClass, ROConstEdgePairVector>::const_iterator i = myClassesViaSuccessorMap.find(vClass);
+    if (i != myClassesViaSuccessorMap.end()) {
+        // can use cached value
+        return i->second;
+    }
+    // this vClass is requested for the first time. rebuild all successors
+    std::set<std::pair<const ROEdge*, const ROEdge*> > followers;
+    for (const ROLane* const lane : myLanes) {
+        if ((lane->getPermissions() & vClass) != 0) {
+            for (const auto& next : lane->getOutgoingViaLanes()) {
+                if ((next.first->getPermissions() & vClass) != 0) {
+                    followers.insert(std::make_pair(&next.first->getEdge(), next.second));
+                }
             }
         }
-        myClassesSuccessorMap[vClass].insert(myClassesSuccessorMap[vClass].begin(),
-                                             followers.begin(), followers.end());
-        return myClassesSuccessorMap[vClass];
     }
-
+    // also add district edges (they are not connected at the lane level
+    for (const ROEdge* e : myFollowingEdges) {
+        if (e->isTazConnector()) {
+            followers.insert(std::make_pair(e, e));
+        }
+    }
+    myClassesViaSuccessorMap[vClass].insert(myClassesViaSuccessorMap[vClass].begin(),
+                                            followers.begin(), followers.end());
+    return myClassesViaSuccessorMap[vClass];
 }
 
 
 bool
 ROEdge::isConnectedTo(const ROEdge* const e, const ROVehicle* const vehicle) const {
-    const SUMOVehicleClass vClass = (vehicle == 0 ? SVC_IGNORING : vehicle->getVClass());
+    const SUMOVehicleClass vClass = (vehicle == nullptr ? SVC_IGNORING : vehicle->getVClass());
     const ROEdgeVector& followers = getSuccessors(vClass);
     return std::find(followers.begin(), followers.end(), e) != followers.end();
 }
 
+
 /****************************************************************************/
 
