@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    ROEdge.h
 /// @author  Daniel Krajzewicz
@@ -28,11 +26,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <map>
@@ -60,6 +54,7 @@ class ROEdge;
 
 typedef std::vector<ROEdge*> ROEdgeVector;
 typedef std::vector<const ROEdge*> ConstROEdgeVector;
+typedef std::vector<std::pair<const ROEdge*, const ROEdge*> > ROConstEdgePairVector;
 
 
 // ===========================================================================
@@ -110,7 +105,7 @@ public:
      * @param[in] s The edge to add
      * @todo What about vehicle-type aware connections?
      */
-    virtual void addSuccessor(ROEdge* s, std::string dir = "");
+    virtual void addSuccessor(ROEdge* s, ROEdge* via = nullptr, std::string dir = "");
 
 
     /** @brief Sets the function of the edge
@@ -316,18 +311,17 @@ public:
     int getNumSuccessors() const;
 
 
-    /** @brief Returns the following edges
-     */
-    const ROEdgeVector& getSuccessors() const {
-        return myFollowingEdges;
-    }
-
-
     /** @brief Returns the following edges, restricted by vClass
-     * @param[in] vClass The vClass for which to restrict the successors
-     * @return The eligible following edges
-     */
-    const ROEdgeVector& getSuccessors(SUMOVehicleClass vClass) const;
+    * @param[in] vClass The vClass for which to restrict the successors
+    * @return The eligible following edges
+    */
+    const ROEdgeVector& getSuccessors(SUMOVehicleClass vClass = SVC_IGNORING) const;
+
+    /** @brief Returns the following edges including vias, restricted by vClass
+    * @param[in] vClass The vClass for which to restrict the successors
+    * @return The eligible following edges
+    */
+    const ROConstEdgePairVector& getViaSuccessors(SUMOVehicleClass vClass = SVC_IGNORING) const;
 
 
     /** @brief Returns the number of edges connected to this edge
@@ -440,7 +434,7 @@ public:
 
 
     /// @brief optimistic distance heuristic for use in routing
-    double getDistanceTo(const ROEdge* other) const;
+    double getDistanceTo(const ROEdge* other, const bool doBoundaryEstimate=false) const;
 
 
     /** @brief Returns all ROEdges */
@@ -455,6 +449,9 @@ public:
         myInterpolate = interpolate;
     }
 
+    /// @brief return the coordinates of the center of the given stop
+    static const Position getStopPosition(const SUMOVehicleParameter::Stop& stop);
+
     /// @brief get edge priority (road class)
     int getPriority() const {
         return myPriority;
@@ -527,6 +524,8 @@ protected:
     /// @brief List of edges that may be approached from this edge
     ROEdgeVector myFollowingEdges;
 
+    ROConstEdgePairVector myFollowingViaEdges;
+
     /// @brief List of edges that approached this edge
     ROEdgeVector myApproachingEdges;
 
@@ -542,8 +541,8 @@ protected:
     /// @brief The list of allowed vehicle classes combined across lanes
     SVCPermissions myCombinedPermissions;
 
-    /// @brief The bounding rectangle of incoming or outgoing edges for taz connectors
-    Boundary myTazBoundary;
+    /// @brief The bounding rectangle of end nodes incoming or outgoing edges for taz connectors or of my own start and end node for normal edges
+    Boundary myBoundary;
 
     static ROEdgeVector myEdges;
 
@@ -551,6 +550,9 @@ protected:
     /// @brief The successors available for a given vClass
     mutable std::map<SUMOVehicleClass, ROEdgeVector> myClassesSuccessorMap;
 
+    /// @brief The successors with vias available for a given vClass
+    mutable std::map<SUMOVehicleClass, ROConstEdgePairVector> myClassesViaSuccessorMap;
+
 #ifdef HAVE_FOX
     /// The mutex used to avoid concurrent updates of myClassesSuccessorMap
     mutable FXMutex myLock;
