@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    ROHelper.cpp
 /// @author  Daniel Krajzewicz
@@ -21,16 +19,13 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <functional>
 #include <vector>
 #include "ROEdge.h"
 #include "ROVehicle.h"
+#include "ROHelper.h"
 
 
 // ===========================================================================
@@ -40,14 +35,18 @@
 
 namespace ROHelper {
 void
-recheckForLoops(ConstROEdgeVector& edges) {
-    // XXX check for stops, departLane, departPos, departSpeed, ....
+recheckForLoops(ConstROEdgeVector& edges, const ConstROEdgeVector& mandatory) {
+    // for simplicities sake, prevent removal of any mandatory edges
+    // in theory these edges could occur multiple times so it might be possible
+    // to delete some of them anyway.
+    // XXX check for departLane, departPos, departSpeed, ....
 
     // removal of edge loops within the route (edge occurs twice)
     std::map<const ROEdge*, int> lastOccurence; // index of the last occurence of this edge
     for (int ii = 0; ii < (int)edges.size(); ++ii) {
         std::map<const ROEdge*, int>::iterator it_pre = lastOccurence.find(edges[ii]);
-        if (it_pre != lastOccurence.end()) {
+        if (it_pre != lastOccurence.end() &&
+                noMandatory(mandatory, edges.begin() + it_pre->second, edges.begin() + ii)) {
             edges.erase(edges.begin() + it_pre->second, edges.begin() + ii);
             ii = it_pre->second;
         } else {
@@ -64,21 +63,18 @@ recheckForLoops(ConstROEdgeVector& edges) {
             lastStart = i;
         }
     }
-    if (lastStart > 0) {
+    if (lastStart > 0 && noMandatory(mandatory, edges.begin(), edges.begin() + lastStart - 1)) {
         edges.erase(edges.begin(), edges.begin() + lastStart - 1);
     }
     // remove loops at the route's end
     //  (vehicle makes a turnaround to get into the right direction at an already passed node)
     const RONode* end = edges.back()->getToJunction();
-    int firstEnd = (int)edges.size() - 1;
-    for (int i = 0; i < firstEnd; i++) {
-        if (edges[i]->getToJunction() == end) {
-            firstEnd = i;
+    for (int i = 0; i < (int)edges.size() - 1; i++) {
+        if (edges[i]->getToJunction() == end && noMandatory(mandatory, edges.begin() + i + 2, edges.end())) {
+            edges.erase(edges.begin() + i + 2, edges.end());
+            break;
         }
     }
-    if (firstEnd < (int)edges.size() - 1) {
-        edges.erase(edges.begin() + firstEnd + 2, edges.end());
-    }
 
     // removal of node loops (node occurs twice) is not done because these may occur legitimately
     /*
@@ -104,6 +100,20 @@ recheckForLoops(ConstROEdgeVector& edges) {
     */
 }
 
+bool
+noMandatory(const ConstROEdgeVector& mandatory,
+            ConstROEdgeVector::const_iterator start,
+            ConstROEdgeVector::const_iterator end) {
+    for (const ROEdge* m : mandatory) {
+        for (auto it = start; it != end; it++) {
+            if (*it == m) {
+                return false;
+            }
+        }
+    }
+    return true;
+}
+
 
 }
 
