@@ -1,23 +1,20 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    ROLane.h
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @date    Sept 2002
-/// @version $Id: ROLane.h 20482 2016-04-18 20:49:42Z behrisch $
+/// @version $Id$
 ///
 // A single lane the router may use
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2016 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 #ifndef ROLane_h
 #define ROLane_h
 
@@ -25,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <utils/common/Named.h>
@@ -63,7 +56,7 @@ public:
      * @param[in] maxSpeed The maximum speed allowed on the lane
      * @param[in] permissions Vehicle classes that may pass this lane
      */
-    ROLane(const std::string& id, ROEdge* edge, SUMOReal length, SUMOReal maxSpeed, SVCPermissions permissions) :
+    ROLane(const std::string& id, ROEdge* edge, double length, double maxSpeed, SVCPermissions permissions) :
         Named(id), myEdge(edge), myLength(length), myMaxSpeed(maxSpeed), myPermissions(permissions) {
     }
 
@@ -75,7 +68,7 @@ public:
     /** @brief Returns the length of the lane
      * @return The length of this lane
      */
-    SUMOReal getLength() const {
+    double getLength() const {
         return myLength;
     }
 
@@ -83,7 +76,7 @@ public:
     /** @brief Returns the maximum speed allowed on this lane
      * @return The maximum speed allowed on this lane
      */
-    SUMOReal getSpeed() const {
+    double getSpeed() const {
         return myMaxSpeed;
     }
 
@@ -102,13 +95,13 @@ public:
         return *myEdge;
     }
 
-    /// @brief get the list of outgoing lanes
-    const std::vector<const ROLane*>& getOutgoingLanes() const {
+    /// @brief get the map of outgoing lanes to via edges
+    const std::vector<std::pair<const ROLane*, const ROEdge*> >& getOutgoingViaLanes() const {
         return myOutgoingLanes;
     }
 
-    void addOutgoingLane(ROLane* lane) {
-        myOutgoingLanes.push_back(lane);
+    void addOutgoingLane(ROLane* lane, ROEdge* via = nullptr) {
+        myOutgoingLanes.push_back(std::make_pair(lane, via));
     }
 
     /// @brief get the state of the link from the logical predecessor to this lane (ignored for routing)
@@ -125,15 +118,15 @@ private:
     ROEdge* myEdge;
 
     /// @brief The length of the lane
-    SUMOReal myLength;
+    double myLength;
 
     /// @brief The maximum speed allowed on the lane
-    SUMOReal myMaxSpeed;
+    double myMaxSpeed;
 
     /// @brief The encoding of allowed vehicle classes
     SVCPermissions myPermissions;
 
-    std::vector<const ROLane*> myOutgoingLanes;
+    std::vector<std::pair<const ROLane*, const ROEdge*> > myOutgoingLanes;
 
 
 private:
