@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    RONet.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <algorithm>
 #include <utils/vehicle/RouteCostCalculator.h>
@@ -51,7 +45,7 @@
 // ===========================================================================
 // static member definitions
 // ===========================================================================
-RONet* RONet::myInstance = 0;
+RONet* RONet::myInstance = nullptr;
 
 
 // ===========================================================================
@@ -59,7 +53,7 @@ RONet* RONet::myInstance = 0;
 // ===========================================================================
 RONet*
 RONet::getInstance(void) {
-    if (myInstance != 0) {
+    if (myInstance != nullptr) {
         return myInstance;
     }
     throw ProcessError("A network was not yet constructed.");
@@ -67,8 +61,10 @@ RONet::getInstance(void) {
 
 
 RONet::RONet()
-    : myVehicleTypes(), myDefaultVTypeMayBeDeleted(true), myDefaultPedTypeMayBeDeleted(true),
-      myRoutesOutput(0), myRouteAlternativesOutput(0), myTypesOutput(0),
+    : myVehicleTypes(), myDefaultVTypeMayBeDeleted(true),
+      myDefaultPedTypeMayBeDeleted(true), myDefaultBikeTypeMayBeDeleted(true),
+      myHaveActiveFlows(true),
+      myRoutesOutput(nullptr), myRouteAlternativesOutput(nullptr), myTypesOutput(nullptr),
       myReadRouteNo(0), myDiscardedRouteNo(0), myWrittenRouteNo(0),
       myHavePermissions(false),
       myNumInternalEdges(0),
@@ -76,7 +72,7 @@ RONet::RONet()
                      && OptionsCont::getOptions().getBool("ignore-errors") ? MsgHandler::getWarningInstance() : MsgHandler::getErrorInstance()),
       myKeepVTypeDist(OptionsCont::getOptions().exists("keep-vtype-distributions")
                       && OptionsCont::getOptions().getBool("keep-vtype-distributions")) {
-    if (myInstance != 0) {
+    if (myInstance != nullptr) {
         throw ProcessError("A network was already constructed.");
     }
     SUMOVTypeParameter* type = new SUMOVTypeParameter(DEFAULT_VTYPE_ID, SVC_PASSENGER);
@@ -86,6 +82,10 @@ RONet::RONet()
     defPedType->onlyReferenced = true;
     defPedType->parametersSet |= VTYPEPARS_VEHICLECLASS_SET;
     myVehicleTypes.add(defPedType->id, defPedType);
+    SUMOVTypeParameter* defBikeType = new SUMOVTypeParameter(DEFAULT_BIKETYPE_ID, SVC_BICYCLE);
+    defBikeType->onlyReferenced = true;
+    defBikeType->parametersSet |= VTYPEPARS_VEHICLECLASS_SET;
+    myVehicleTypes.add(defBikeType->id, defBikeType);
     myInstance = this;
 }
 
@@ -95,7 +95,7 @@ RONet::~RONet() {
         for (RORoutable* const r : routables->second) {
             const ROVehicle* const veh = dynamic_cast<const ROVehicle*>(r);
             // delete routes and the vehicle
-            if (veh != 0 && veh->getRouteDefinition()->getID()[0] == '!') {
+            if (veh != nullptr && veh->getRouteDefinition()->getID()[0] == '!') {
                 if (!myRoutes.remove(veh->getRouteDefinition()->getID())) {
                     delete veh->getRouteDefinition();
                 }
@@ -106,7 +106,7 @@ RONet::~RONet() {
     for (const RORoutable* const r : myPTVehicles) {
         const ROVehicle* const veh = dynamic_cast<const ROVehicle*>(r);
         // delete routes and the vehicle
-        if (veh != 0 && veh->getRouteDefinition()->getID()[0] == '!') {
+        if (veh != nullptr && veh->getRouteDefinition()->getID()[0] == '!') {
             if (!myRoutes.remove(veh->getRouteDefinition()->getID())) {
                 delete veh->getRouteDefinition();
             }
@@ -127,7 +127,7 @@ const std::map<SUMOVehicleClass, double>*
 RONet::getRestrictions(const std::string& id) const {
     std::map<std::string, std::map<SUMOVehicleClass, double> >::const_iterator i = myRestrictions.find(id);
     if (i == myRestrictions.end()) {
-        return 0;
+        return nullptr;
     }
     return &i->second;
 }
@@ -171,7 +171,7 @@ RONet::addDistrictEdge(const std::string tazID, const std::string edgeID, const
         return false;
     }
     ROEdge* edge = getEdge(edgeID);
-    if (edge == 0) {
+    if (edge == nullptr) {
         WRITE_ERROR("The edge '" + edgeID + "' for TAZ '" + tazID + "' is unknown.");
         return false;
     }
@@ -252,15 +252,15 @@ RONet::writeIntermodal(const OptionsCont& options, ROIntermodalRouter& router) c
 void
 RONet::cleanup() {
     // end writing
-    if (myRoutesOutput != 0) {
+    if (myRoutesOutput != nullptr) {
         myRoutesOutput->close();
     }
     // only if opened
-    if (myRouteAlternativesOutput != 0) {
+    if (myRouteAlternativesOutput != nullptr) {
         myRouteAlternativesOutput->close();
     }
     // only if opened
-    if (myTypesOutput != 0) {
+    if (myTypesOutput != nullptr) {
         myTypesOutput->close();
     }
     RouteCostCalculator<RORoute, ROEdge, ROVehicle>::cleanup();
@@ -283,7 +283,10 @@ RONet::getVehicleTypeSecure(const std::string& id) {
     if (id == DEFAULT_PEDTYPE_ID) {
         myDefaultPedTypeMayBeDeleted = false;
     }
-    if (type != 0) {
+    if (id == DEFAULT_BIKETYPE_ID) {
+        myDefaultBikeTypeMayBeDeleted = false;
+    }
+    if (type != nullptr) {
         return type;
     }
     VTypeDistDictType::iterator it2 = myVTypeDistDict.find(id);
@@ -401,15 +404,17 @@ RONet::addContainer(const SUMOTime depart, const std::string desc) {
 
 
 void
-RONet::checkFlows(SUMOTime time, MsgHandler* errorHandler, const bool keepPT) {
-    std::vector<std::string> toRemove;
+RONet::checkFlows(SUMOTime time, MsgHandler* errorHandler) {
+    myHaveActiveFlows = false;
     for (const auto& i : myFlows) {
         SUMOVehicleParameter* pars = i.second;
         if (pars->repetitionProbability > 0) {
+            if (pars->repetitionEnd > pars->depart) {
+                myHaveActiveFlows = true;
+            }
             const SUMOTime origDepart = pars->depart;
             while (pars->depart < time) {
                 if (pars->repetitionEnd <= pars->depart) {
-                    toRemove.push_back(i.first);
                     break;
                 }
                 // only call rand if all other conditions are met
@@ -439,6 +444,7 @@ RONet::checkFlows(SUMOTime time, MsgHandler* errorHandler, const bool keepPT) {
             }
         } else {
             while (pars->repetitionsDone < pars->repetitionNumber) {
+                myHaveActiveFlows = true;
                 SUMOTime depart = static_cast<SUMOTime>(pars->depart + pars->repetitionsDone * pars->repetitionOffset);
                 if (myDepartures.find(pars->id) != myDepartures.end()) {
                     depart = myDepartures[pars->id].back();
@@ -460,7 +466,7 @@ RONet::checkFlows(SUMOTime time, MsgHandler* errorHandler, const bool keepPT) {
                 pars->repetitionsDone++;
                 // try to build the vehicle
                 SUMOVTypeParameter* type = getVehicleTypeSecure(pars->vtypeid);
-                if (type == 0) {
+                if (type == nullptr) {
                     type = getVehicleTypeSecure(DEFAULT_VTYPE_ID);
                 } else {
                     // fix the type id in case we used a distribution
@@ -472,14 +478,8 @@ RONet::checkFlows(SUMOTime time, MsgHandler* errorHandler, const bool keepPT) {
                 addVehicle(newPars->id, veh);
                 delete newPars;
             }
-            if (pars->repetitionsDone == pars->repetitionNumber && (!keepPT || pars->line == "")) {
-                toRemove.push_back(i.first);
-            }
         }
     }
-    for (std::vector<std::string>::const_iterator i = toRemove.begin(); i != toRemove.end(); ++i) {
-        myFlows.remove(*i);
-    }
 }
 
 
@@ -534,7 +534,9 @@ RONet::saveAndRemoveRoutesUntil(OptionsCont& options, const RORouterProvider& pr
                                 SUMOTime time) {
     MsgHandler* mh = (options.getBool("ignore-errors") ?
                       MsgHandler::getWarningInstance() : MsgHandler::getErrorInstance());
-    checkFlows(time, mh, !provider.getIntermodalRouter().hasNet());
+    if (myHaveActiveFlows) {
+        checkFlows(time, mh);
+    }
     SUMOTime lastTime = -1;
     const bool removeLoops = options.getBool("remove-loops");
     const int maxNumThreads = options.getInt("routing-threads");
@@ -613,7 +615,7 @@ RONet::saveAndRemoveRoutesUntil(OptionsCont& options, const RORouterProvider& pr
                 // delete routes and the vehicle
                 if (!r->isPublicTransport() || r->isPartOfFlow()) {
                     const ROVehicle* const veh = dynamic_cast<const ROVehicle*>(r);
-                    if (veh != 0 && veh->getRouteDefinition()->getID()[0] == '!') {
+                    if (veh != nullptr && veh->getRouteDefinition()->getID()[0] == '!') {
                         if (!myRoutes.remove(veh->getRouteDefinition()->getID())) {
                             delete veh->getRouteDefinition();
                         }
@@ -625,7 +627,7 @@ RONet::saveAndRemoveRoutesUntil(OptionsCont& options, const RORouterProvider& pr
         }
         if (containerTime == minTime) {
             myRoutesOutput->writePreformattedTag(container->second);
-            if (myRouteAlternativesOutput != 0) {
+            if (myRouteAlternativesOutput != nullptr) {
                 myRouteAlternativesOutput->writePreformattedTag(container->second);
             }
             myContainers.erase(container);
@@ -637,7 +639,7 @@ RONet::saveAndRemoveRoutesUntil(OptionsCont& options, const RORouterProvider& pr
 
 bool
 RONet::furtherStored() {
-    return myRoutables.size() > 0 || myFlows.size() > 0 || myContainers.size() > 0;
+    return myRoutables.size() > 0 || (myFlows.size() > 0 && myHaveActiveFlows) || myContainers.size() > 0;
 }
 
 
@@ -657,29 +659,30 @@ void
 RONet::adaptIntermodalRouter(ROIntermodalRouter& router) {
     // add access to all parking areas
     for (const auto& i : myInstance->myStoppingPlaces[SUMO_TAG_PARKING_AREA]) {
-        router.addAccess(i.first, myInstance->getEdgeForLaneID(i.second->lane), (i.second->startPos + i.second->endPos) / 2., SUMO_TAG_PARKING_AREA);
+        router.getNetwork()->addAccess(i.first, myInstance->getEdgeForLaneID(i.second->lane), (i.second->startPos + i.second->endPos) / 2., 0., SUMO_TAG_PARKING_AREA);
     }
     // add access to all public transport stops
     for (const auto& stop : myInstance->myStoppingPlaces[SUMO_TAG_BUS_STOP]) {
-        router.addAccess(stop.first, myInstance->getEdgeForLaneID(stop.second->lane), (stop.second->startPos + stop.second->endPos) / 2., SUMO_TAG_BUS_STOP);
-        for (std::multimap<std::string, double>::const_iterator a = stop.second->accessPos.begin(); a != stop.second->accessPos.end(); ++a) {
-            router.addAccess(stop.first, myInstance->getEdgeForLaneID(a->first), a->second, SUMO_TAG_BUS_STOP);
+        router.getNetwork()->addAccess(stop.first, myInstance->getEdgeForLaneID(stop.second->lane), (stop.second->startPos + stop.second->endPos) / 2., 0., SUMO_TAG_BUS_STOP);
+        for (const auto& a : stop.second->accessPos) {
+            router.getNetwork()->addAccess(stop.first, myInstance->getEdgeForLaneID(std::get<0>(a)), std::get<1>(a), std::get<2>(a), SUMO_TAG_BUS_STOP);
         }
     }
     // fill the public transport router with pre-parsed public transport lines
     for (const auto& i : myInstance->myFlows) {
         if (i.second->line != "") {
-            RORouteDef* route = myInstance->getRouteDef(i.second->routeid);
-            const std::vector<SUMOVehicleParameter::Stop>* addStops = 0;
-            if (route != 0 && route->getFirstRoute() != 0) {
+            const RORouteDef* const route = myInstance->getRouteDef(i.second->routeid);
+            const std::vector<SUMOVehicleParameter::Stop>* addStops = nullptr;
+            if (route != nullptr && route->getFirstRoute() != nullptr) {
                 addStops = &route->getFirstRoute()->getStops();
             }
-            router.addSchedule(*i.second, addStops);
+            router.getNetwork()->addSchedule(*i.second, addStops);
         }
     }
     for (const RORoutable* const veh : myInstance->myPTVehicles) {
         // add single vehicles with line attribute which are not part of a flow
-        router.addSchedule(veh->getParameter());
+        // no need to add route stops here, they have been added to the vehicle before
+        router.getNetwork()->addSchedule(veh->getParameter());
     }
 }
 
@@ -695,6 +698,17 @@ RONet::setPermissionsFound() {
     myHavePermissions = true;
 }
 
+const std::string
+RONet::getStoppingPlaceName(const std::string& id) const {
+    for (const auto& mapItem : myStoppingPlaces) {
+        SUMOVehicleParameter::Stop* stop = mapItem.second.get(id);
+        if (stop != nullptr) {
+            // see RONetHandler::parseStoppingPlace
+            return stop->busstop;
+        }
+    }
+    return "";
+}
 
 #ifdef HAVE_FOX
 // ---------------------------------------------------------------------------
