@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    RONetHandler.cpp
 /// @author  Daniel Krajzewicz
@@ -25,18 +23,14 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
-#include <utils/options/OptionsCont.h>
 #include <utils/common/MsgHandler.h>
 #include <utils/common/StringTokenizer.h>
 #include <utils/common/UtilExceptions.h>
 #include <utils/common/ToString.h>
+#include <utils/common/StringUtils.h>
 #include <utils/xml/SUMORouteHandler.h>
 #include <utils/xml/SUMOSAXHandler.h>
 #include <utils/xml/SUMOXMLDefinitions.h>
@@ -51,12 +45,10 @@
 // ===========================================================================
 // method definitions
 // ===========================================================================
-RONetHandler::RONetHandler(RONet& net,
-                           ROAbstractEdgeBuilder& eb)
+RONetHandler::RONetHandler(RONet& net, ROAbstractEdgeBuilder& eb, const bool ignoreInternal)
     : SUMOSAXHandler("sumo-network"),
-      myNet(net), myCurrentName(),
-      myCurrentEdge(0), myCurrentStoppingPlace(0),
-      myEdgeBuilder(eb) {}
+      myNet(net), myEdgeBuilder(eb), myIgnoreInternal(ignoreInternal),
+      myCurrentName(), myCurrentEdge(nullptr), myCurrentStoppingPlace(nullptr) {}
 
 
 RONetHandler::~RONetHandler() {}
@@ -101,7 +93,7 @@ RONetHandler::myStartElement(int element,
             break;
         case SUMO_TAG_TYPE: {
             bool ok = true;
-            myCurrentTypeID = attrs.get<std::string>(SUMO_ATTR_ID, 0, ok);
+            myCurrentTypeID = attrs.get<std::string>(SUMO_ATTR_ID, nullptr, ok);
             break;
         }
         case SUMO_TAG_RESTRICTION: {
@@ -138,7 +130,7 @@ void
 RONetHandler::parseEdge(const SUMOSAXAttributes& attrs) {
     // get the id, report an error if not given or empty...
     bool ok = true;
-    myCurrentName = attrs.get<std::string>(SUMO_ATTR_ID, 0, ok);
+    myCurrentName = attrs.get<std::string>(SUMO_ATTR_ID, nullptr, ok);
     if (!ok) {
         throw ProcessError();
     }
@@ -151,7 +143,7 @@ RONetHandler::parseEdge(const SUMOSAXAttributes& attrs) {
     std::string from;
     std::string to;
     int priority;
-    myCurrentEdge = 0;
+    myCurrentEdge = nullptr;
     if (func == EDGEFUNC_INTERNAL || func == EDGEFUNC_CROSSING || func == EDGEFUNC_WALKINGAREA) {
         assert(myCurrentName[0] == ':');
         const std::string junctionID = myCurrentName.substr(1, myCurrentName.rfind('_') - 1);
@@ -167,13 +159,13 @@ RONetHandler::parseEdge(const SUMOSAXAttributes& attrs) {
         }
     }
     RONode* fromNode = myNet.getNode(from);
-    if (fromNode == 0) {
+    if (fromNode == nullptr) {
         myUnseenNodeIDs.insert(from);
         fromNode = new RONode(from);
         myNet.addNode(fromNode);
     }
     RONode* toNode = myNet.getNode(to);
-    if (toNode == 0) {
+    if (toNode == nullptr) {
         myUnseenNodeIDs.insert(to);
         toNode = new RONode(to);
         myNet.addNode(toNode);
@@ -188,20 +180,20 @@ RONetHandler::parseEdge(const SUMOSAXAttributes& attrs) {
         fromNode->addOutgoing(myCurrentEdge);
         toNode->addIncoming(myCurrentEdge);
     } else {
-        myCurrentEdge = 0;
+        myCurrentEdge = nullptr;
     }
 }
 
 
 void
 RONetHandler::parseLane(const SUMOSAXAttributes& attrs) {
-    if (myCurrentEdge == 0) {
-        // was an internal edge to skip or an error occured
+    if (myCurrentEdge == nullptr) {
+        // was an internal edge to skip or an error occurred
         return;
     }
     bool ok = true;
     // get the id, report an error if not given or empty...
-    std::string id = attrs.get<std::string>(SUMO_ATTR_ID, 0, ok);
+    std::string id = attrs.get<std::string>(SUMO_ATTR_ID, nullptr, ok);
     if (!ok) {
         return;
     }
@@ -232,7 +224,7 @@ void
 RONetHandler::parseJunction(const SUMOSAXAttributes& attrs) {
     bool ok = true;
     // get the id, report an error if not given or empty...
-    std::string id = attrs.get<std::string>(SUMO_ATTR_ID, 0, ok);
+    std::string id = attrs.get<std::string>(SUMO_ATTR_ID, nullptr, ok);
     if (attrs.getNodeType(ok) == NODETYPE_INTERNAL) {
         return;
     }
@@ -245,7 +237,7 @@ RONetHandler::parseJunction(const SUMOSAXAttributes& attrs) {
         return;
     }
     RONode* n = myNet.getNode(id);
-    if (n == 0) {
+    if (n == nullptr) {
         WRITE_WARNING("Skipping isolated junction '" + id + "'.");
     } else {
         n->setPosition(Position(x, y, z));
@@ -256,18 +248,18 @@ RONetHandler::parseJunction(const SUMOSAXAttributes& attrs) {
 void
 RONetHandler::parseConnection(const SUMOSAXAttributes& attrs) {
     bool ok = true;
-    std::string fromID = attrs.get<std::string>(SUMO_ATTR_FROM, 0, ok);
-    std::string toID = attrs.get<std::string>(SUMO_ATTR_TO, 0, ok);
-    int fromLane = attrs.get<int>(SUMO_ATTR_FROM_LANE, 0, ok);
-    int toLane = attrs.get<int>(SUMO_ATTR_TO_LANE, 0, ok);
-    std::string dir = attrs.get<std::string>(SUMO_ATTR_DIR, 0, ok);
-    std::string viaID = attrs.getOpt<std::string>(SUMO_ATTR_VIA, 0, ok, "");
+    std::string fromID = attrs.get<std::string>(SUMO_ATTR_FROM, nullptr, ok);
+    std::string toID = attrs.get<std::string>(SUMO_ATTR_TO, nullptr, ok);
+    const int fromLane = attrs.get<int>(SUMO_ATTR_FROM_LANE, nullptr, ok);
+    const int toLane = attrs.get<int>(SUMO_ATTR_TO_LANE, nullptr, ok);
+    std::string dir = attrs.get<std::string>(SUMO_ATTR_DIR, nullptr, ok);
+    std::string viaID = attrs.getOpt<std::string>(SUMO_ATTR_VIA, nullptr, ok, "");
     ROEdge* from = myNet.getEdge(fromID);
     ROEdge* to = myNet.getEdge(toID);
-    if (from == 0) {
+    if (from == nullptr) {
         throw ProcessError("unknown from-edge '" + fromID + "' in connection");
     }
-    if (to == 0) {
+    if (to == nullptr) {
         throw ProcessError("unknown to-edge '" + toID + "' in connection");
     }
     if ((int)from->getLanes().size() <= fromLane) {
@@ -276,15 +268,17 @@ RONetHandler::parseConnection(const SUMOSAXAttributes& attrs) {
     if ((int)to->getLanes().size() <= toLane) {
         throw ProcessError("invalid toLane '" + toString(toLane) + "' in connection to '" + toID + "'.");
     }
-    from->getLanes()[fromLane]->addOutgoingLane(to->getLanes()[toLane]);
-    from->addSuccessor(to, dir);
-    if (viaID != "") {
-        ROEdge* via = myNet.getEdge(viaID.substr(0, viaID.rfind('_')));
-        if (via == 0) {
+    if (myIgnoreInternal || viaID == "") {
+        from->getLanes()[fromLane]->addOutgoingLane(to->getLanes()[toLane]);
+        from->addSuccessor(to, nullptr, dir);
+    }  else {
+        ROEdge* const via = myNet.getEdge(viaID.substr(0, viaID.rfind('_')));
+        if (via == nullptr) {
             throw ProcessError("unknown via-edge '" + viaID + "' in connection");
         }
-        from->addSuccessor(via, dir);
-        return;
+        from->getLanes()[fromLane]->addOutgoingLane(to->getLanes()[toLane], via);
+        from->addSuccessor(to, via, dir);
+        via->addSuccessor(to, nullptr, dir);
     }
 }
 
@@ -301,7 +295,7 @@ RONetHandler::parseStoppingPlace(const SUMOSAXAttributes& attrs, const SumoXMLTa
         throw ProcessError();
     }
     const ROEdge* edge = myNet.getEdgeForLaneID(myCurrentStoppingPlace->lane);
-    if (edge == 0) {
+    if (edge == nullptr) {
         throw InvalidArgument("Unknown lane '" + myCurrentStoppingPlace->lane + "' for " + toString(element) + " '" + id + "'.");
     }
     // get the positions
@@ -311,6 +305,8 @@ RONetHandler::parseStoppingPlace(const SUMOSAXAttributes& attrs, const SumoXMLTa
     if (!ok || !SUMORouteHandler::checkStopPos(myCurrentStoppingPlace->startPos, myCurrentStoppingPlace->endPos, edge->getLength(), POSITION_EPS, friendlyPos)) {
         throw InvalidArgument("Invalid position for " + toString(element) + " '" + id + "'.");
     }
+    // this is a hack: the busstop attribute is meant to hold the id within the simulation context but this is not used within the router context
+    myCurrentStoppingPlace->busstop = attrs.getOpt<std::string>(SUMO_ATTR_NAME, id.c_str(), ok, "");
     myNet.addStoppingPlace(id, element, myCurrentStoppingPlace);
 }
 
@@ -320,10 +316,11 @@ RONetHandler::parseAccess(const SUMOSAXAttributes& attrs) {
     bool ok = true;
     const std::string lane = attrs.get<std::string>(SUMO_ATTR_LANE, "access", ok);
     const ROEdge* edge = myNet.getEdgeForLaneID(lane);
-    if (edge == 0) {
+    if (edge == nullptr) {
         throw InvalidArgument("Unknown lane '" + lane + "' for access.");
     }
     double pos = attrs.getOpt<double>(SUMO_ATTR_POSITION, "access", ok, 0.);
+    const double length = attrs.getOpt<double>(SUMO_ATTR_LENGTH, "access", ok, -1);
     const bool friendlyPos = attrs.getOpt<bool>(SUMO_ATTR_FRIENDLY_POS, "access", ok, false);
     if (!ok || !SUMORouteHandler::checkStopPos(pos, pos, edge->getLength(), 0., friendlyPos)) {
         throw InvalidArgument("Invalid position " + toString(pos) + " for access on lane '" + lane + "'.");
@@ -331,19 +328,19 @@ RONetHandler::parseAccess(const SUMOSAXAttributes& attrs) {
     if (!ok) {
         throw ProcessError();
     }
-    myCurrentStoppingPlace->accessPos.insert(std::make_pair(lane, pos));
+    myCurrentStoppingPlace->accessPos.push_back(std::make_tuple(lane, pos, length));
 }
 
 
 void
 RONetHandler::parseDistrict(const SUMOSAXAttributes& attrs) {
-    myCurrentEdge = 0;
+    myCurrentEdge = nullptr;
     bool ok = true;
-    myCurrentName = attrs.get<std::string>(SUMO_ATTR_ID, 0, ok);
+    myCurrentName = attrs.get<std::string>(SUMO_ATTR_ID, nullptr, ok);
     if (!ok) {
         return;
     }
-    myNet.addDistrict(myCurrentName, myEdgeBuilder.buildEdge(myCurrentName + "-source", 0, 0, 0), myEdgeBuilder.buildEdge(myCurrentName + "-sink", 0, 0, 0));
+    myNet.addDistrict(myCurrentName, myEdgeBuilder.buildEdge(myCurrentName + "-source", nullptr, nullptr, 0), myEdgeBuilder.buildEdge(myCurrentName + "-sink", nullptr, nullptr, 0));
     if (attrs.hasAttribute(SUMO_ATTR_EDGES)) {
         std::vector<std::string> desc = attrs.getStringVector(SUMO_ATTR_EDGES);
         for (std::vector<std::string>::const_iterator i = desc.begin(); i != desc.end(); ++i) {
@@ -362,6 +359,4 @@ RONetHandler::parseDistrictEdge(const SUMOSAXAttributes& attrs, bool isSource) {
 }
 
 
-
 /****************************************************************************/
-
