@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    RONetHandler.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <utils/xml/SUMOSAXHandler.h>
@@ -63,7 +57,7 @@ public:
      * @param[in] net The network instance to fill
      * @param[in] eb The abstract edge builder to use
      */
-    RONetHandler(RONet& net, ROAbstractEdgeBuilder& eb);
+    RONetHandler(RONet& net, ROAbstractEdgeBuilder& eb, const bool ignoreInternal);
 
 
     /// @brief Destructor
@@ -186,6 +180,12 @@ protected:
     /// @brief The net to store the information into
     RONet& myNet;
 
+    /// @brief The object used to build of edges of the desired type
+    ROAbstractEdgeBuilder& myEdgeBuilder;
+
+    /// @brief whether to ignore junction internal edges
+    const bool myIgnoreInternal;
+
     /// @brief The name of the edge/node that is currently processed
     std::string myCurrentName;
 
@@ -198,9 +198,6 @@ protected:
     /// @brief The currently built stopping place
     SUMOVehicleParameter::Stop* myCurrentStoppingPlace;
 
-    /// @brief The object used to build of edges of the desired type
-    ROAbstractEdgeBuilder& myEdgeBuilder;
-
     /// @brief temporary data for checking node initialisation after network parsing is finished
     std::set<std::string> myUnseenNodeIDs;
 
