@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    ROPerson.h
 /// @author  Robert Hilbrich
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <iostream>
@@ -71,7 +65,7 @@ public:
                  const std::string& vTypes, const double departPos, const double arrivalPos, const std::string& busStop,
                  double walkFactor);
 
-    void addRide(const ROEdge* const from, const ROEdge* const to, const std::string& lines, const std::string& destStop);
+    void addRide(const ROEdge* const from, const ROEdge* const to, const std::string& lines, double arrivalPos, const std::string& destStop);
 
     void addWalk(const ConstROEdgeVector& edges, const double duration, const double speed,
                  const double departPos, const double arrivalPos, const std::string& busStop);
@@ -93,6 +87,7 @@ public:
         }
         virtual const ROEdge* getOrigin() const = 0;
         virtual const ROEdge* getDestination() const = 0;
+        virtual double getDestinationPos() const = 0;
         virtual void saveVehicles(OutputDevice& /* os */, OutputDevice* const /* typeos */, bool /* asAlternatives */, OptionsCont& /* options */) const {}
         virtual void saveAsXML(OutputDevice& os, const bool extended) const = 0;
         virtual bool isStop() const {
@@ -117,6 +112,9 @@ public:
         const ROEdge* getDestination() const {
             return edge;
         }
+        double getDestinationPos() const {
+            return stopDesc.endPos;
+        }
         void saveAsXML(OutputDevice& os, const bool /* extended */) const {
             stopDesc.write(os);
         }
@@ -148,6 +146,7 @@ public:
 
         virtual const ROEdge* getOrigin() const = 0;
         virtual const ROEdge* getDestination() const = 0;
+        virtual double getDestinationPos() const = 0;
         virtual void saveAsXML(OutputDevice& os, const bool extended) const = 0;
     protected:
         double cost;
@@ -160,8 +159,16 @@ public:
     class Ride : public TripItem {
     public:
         Ride(const ROEdge* const _from, const ROEdge* const _to,
-             const std::string& _lines, const double _cost, const std::string& _destStop = "")
-            : TripItem(_cost), from(_from), to(_to), lines(_lines), destStop(_destStop) {}
+             const std::string& _lines, const double _cost, const double arrivalPos,
+             const std::string& _destStop = "", const std::string& _intended = "", const SUMOTime _depart = -1) :
+            TripItem(_cost),
+            from(_from), to(_to),
+            lines(_lines),
+            destStop(_destStop),
+            intended(_intended),
+            depart(_depart),
+            arr(arrivalPos) {
+        }
 
         const ROEdge* getOrigin() const {
             return from;
@@ -169,6 +176,9 @@ public:
         const ROEdge* getDestination() const {
             return to;
         }
+        double getDestinationPos() const {
+            return arr;
+        }
         void saveAsXML(OutputDevice& os, const bool extended) const;
 
     private:
@@ -176,6 +186,9 @@ public:
         const ROEdge* const to;
         const std::string lines;
         const std::string destStop;
+        const std::string intended;
+        const SUMOTime depart;
+        const double arr;
 
     private:
         /// @brief Invalidated assignment operator
@@ -203,6 +216,9 @@ public:
         const ROEdge* getDestination() const {
             return edges.back();
         }
+        double getDestinationPos() const {
+            return arr;
+        }
         void saveAsXML(OutputDevice& os, const bool extended) const;
 
     private:
@@ -223,10 +239,10 @@ public:
     class PersonTrip : public PlanItem {
     public:
         PersonTrip()
-            : from(0), to(0), modes(SVC_PEDESTRIAN), dep(0), arr(0), busStop(""), walkFactor(1.0) {}
+            : from(0), to(0), modes(SVC_PEDESTRIAN), dep(0), arr(0), stopDest(""), walkFactor(1.0) {}
         PersonTrip(const ROEdge* const from, const ROEdge* const to, const SVCPermissions modeSet,
-                   const double departPos, const double arrivalPos, const std::string& busStop, double _walkFactor)
-            : from(from), to(to), modes(modeSet), dep(departPos), arr(arrivalPos), busStop(busStop), walkFactor(_walkFactor) {}
+                   const double departPos, const double arrivalPos, const std::string& _stopDest, double _walkFactor)
+            : from(from), to(to), modes(modeSet), dep(departPos), arr(arrivalPos), stopDest(_stopDest), walkFactor(_walkFactor) {}
         /// @brief Destructor
         virtual ~PersonTrip() {
             for (std::vector<TripItem*>::const_iterator it = myTripItems.begin(); it != myTripItems.end(); ++it) {
@@ -251,7 +267,14 @@ public:
             return from != 0 ? from : myTripItems.front()->getOrigin();
         }
         const ROEdge* getDestination() const {
-            return to != 0 ? to : myTripItems.back()->getDestination();
+            return to;
+        }
+        double getDestinationPos() const {
+            if (myTripItems.empty()) {
+                return getArrivalPos(true);
+            } else {
+                return myTripItems.back()->getDestinationPos();
+            }
         }
         double getDepartPos(bool replaceDefault = true) const {
             return dep == std::numeric_limits<double>::infinity() && replaceDefault ? 0 : dep;
@@ -262,8 +285,8 @@ public:
         SVCPermissions getModes() const {
             return modes;
         }
-        bool hasBusStopDest() const {
-            return busStop != "";
+        const std::string& getStopDest() const {
+            return stopDest;
         }
         virtual bool needsRouting() const {
             return myTripItems.empty();
@@ -283,7 +306,7 @@ public:
         const ROEdge* to;
         const SVCPermissions modes;
         const double dep, arr;
-        const std::string busStop;
+        const std::string stopDest;
         /// @brief the fully specified trips
         std::vector<TripItem*> myTripItems;
         /// @brief the vehicles which may be used for routing
