@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    RORoute.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <iostream>
@@ -52,12 +46,12 @@ RORoute::RORoute(const std::string& id, double costs, double prop,
 
 RORoute::RORoute(const std::string& id, const ConstROEdgeVector& route)
     : Named(StringUtils::convertUmlaute(id)), myCosts(0.0),
-      myProbability(0.0), myRoute(route), myColor(0), myStops() {}
+      myProbability(0.0), myRoute(route), myColor(nullptr), myStops() {}
 
 RORoute::RORoute(const RORoute& src)
     : Named(src.myID), myCosts(src.myCosts),
-      myProbability(src.myProbability), myRoute(src.myRoute), myColor(0) {
-    if (src.myColor != 0) {
+      myProbability(src.myProbability), myRoute(src.myRoute), myColor(nullptr) {
+    if (src.myColor != nullptr) {
         myColor = new RGBColor(*src.myColor);
     }
 }
@@ -81,8 +75,8 @@ RORoute::setProbability(double prob) {
 
 
 void
-RORoute::recheckForLoops() {
-    ROHelper::recheckForLoops(myRoute);
+RORoute::recheckForLoops(const ConstROEdgeVector& mandatory) {
+    ROHelper::recheckForLoops(myRoute, mandatory);
 }
 
 void
@@ -102,30 +96,24 @@ RORoute::writeXMLDefinition(OutputDevice& dev, const ROVehicle* const veh,
         dev.writeAttr(SUMO_ATTR_PROB, myProbability);
         dev.setPrecision();
     }
-    if (myColor != 0) {
+    if (myColor != nullptr) {
         dev.writeAttr(SUMO_ATTR_COLOR, *myColor);
     }
-    if (!myRoute.empty()) {
-        const int frontOffset = myRoute.front()->isTazConnector() ? 1 : 0;
-        const int backOffset = myRoute.back()->isTazConnector() ? 1 : 0;
-        if (frontOffset + backOffset > 0) {
-            ConstROEdgeVector temp(myRoute.begin() + frontOffset, myRoute.end() - backOffset);
-            dev.writeAttr(SUMO_ATTR_EDGES, temp);
-        } else {
-            dev.writeAttr(SUMO_ATTR_EDGES, myRoute);
+    ConstROEdgeVector tempRoute;
+    for (const ROEdge* roe : myRoute) {
+        if (!roe->isInternal() && !roe->isTazConnector()) {
+            tempRoute.push_back(roe);
         }
-    } else {
-        dev.writeAttr(SUMO_ATTR_EDGES, myRoute);
     }
+    dev.writeAttr(SUMO_ATTR_EDGES, tempRoute);
     if (withExitTimes) {
-        std::string exitTimes;
+        std::vector<double> exitTimes;
         double time = STEPS2TIME(veh->getDepartureTime());
-        for (ConstROEdgeVector::const_iterator i = myRoute.begin(); i != myRoute.end(); ++i) {
-            if (i != myRoute.begin()) {
-                exitTimes += " ";
+        for (const ROEdge* roe : myRoute) {
+            time += roe->getTravelTime(veh, time);
+            if (!roe->isInternal() && !roe->isTazConnector()) {
+                exitTimes.push_back(time);
             }
-            time += (*i)->getTravelTime(veh, time);
-            exitTimes += toString(time);
         }
         dev.writeAttr("exitTimes", exitTimes);
     }
