@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    RORouteDef.cpp
 /// @author  Daniel Krajzewicz
@@ -23,16 +21,12 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <iterator>
 #include <algorithm>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include <utils/common/ToString.h>
 #include <utils/common/Named.h>
 #include <utils/common/StringUtils.h>
@@ -58,7 +52,7 @@ bool RORouteDef::myUsingJTRR(false);
 RORouteDef::RORouteDef(const std::string& id, const int lastUsed,
                        const bool tryRepair, const bool mayBeDisconnected) :
     Named(StringUtils::convertUmlaute(id)),
-    myPrecomputed(0), myLastUsed(lastUsed), myTryRepair(tryRepair), myMayBeDisconnected(mayBeDisconnected) {
+    myPrecomputed(nullptr), myLastUsed(lastUsed), myTryRepair(tryRepair), myMayBeDisconnected(mayBeDisconnected) {
 }
 
 
@@ -89,7 +83,7 @@ RORouteDef::addAlternativeDef(const RORouteDef* alt) {
 RORoute*
 RORouteDef::buildCurrentRoute(SUMOAbstractRouter<ROEdge, ROVehicle>& router,
                               SUMOTime begin, const ROVehicle& veh) const {
-    if (myPrecomputed == 0) {
+    if (myPrecomputed == nullptr) {
         preComputeCurrentRoute(router, begin, veh);
     }
     return myPrecomputed;
@@ -127,7 +121,7 @@ RORouteDef::preComputeCurrentRoute(SUMOAbstractRouter<ROEdge, ROVehicle>& router
                     WRITE_WARNING("Repaired route of vehicle '" + veh.getID() + "'.");
                 }
                 myNewRoute = true;
-                RGBColor* col = myAlternatives[0]->getColor() != 0 ? new RGBColor(*myAlternatives[0]->getColor()) : 0;
+                RGBColor* col = myAlternatives[0]->getColor() != nullptr ? new RGBColor(*myAlternatives[0]->getColor()) : nullptr;
                 myPrecomputed = new RORoute(myID, 0, myAlternatives[0]->getProbability(), newEdges, col, myAlternatives[0]->getStops());
             } else {
                 myPrecomputed = myAlternatives[0];
@@ -156,7 +150,7 @@ RORouteDef::preComputeCurrentRoute(SUMOAbstractRouter<ROEdge, ROVehicle>& router
         if (cheapest >= 0) {
             myPrecomputed = myAlternatives[cheapest];
         } else {
-            RGBColor* col = myAlternatives[0]->getColor() != 0 ? new RGBColor(*myAlternatives[0]->getColor()) : 0;
+            RGBColor* col = myAlternatives[0]->getColor() != nullptr ? new RGBColor(*myAlternatives[0]->getColor()) : nullptr;
             myPrecomputed = new RORoute(myID, 0, 1, edges, col, myAlternatives[0]->getStops());
             myNewRoute = true;
         }
@@ -170,22 +164,20 @@ RORouteDef::repairCurrentRoute(SUMOAbstractRouter<ROEdge, ROVehicle>& router,
                                ConstROEdgeVector oldEdges, ConstROEdgeVector& newEdges) const {
     MsgHandler* mh = (OptionsCont::getOptions().getBool("ignore-errors") ?
                       MsgHandler::getWarningInstance() : MsgHandler::getErrorInstance());
-    ConstROEdgeVector mandatory;
     const int initialSize = (int)oldEdges.size();
     if (initialSize == 1) {
         if (myUsingJTRR) {
             /// only ROJTRRouter is supposed to handle this type of input
-            router.compute(oldEdges.front(), 0, &veh, begin, newEdges);
+            router.compute(oldEdges.front(), nullptr, &veh, begin, newEdges);
         } else {
             newEdges = oldEdges;
         }
     } else {
-        // prepare mandatory edges
         if (oldEdges.front()->prohibits(&veh)) {
             // option repair.from is in effect
             const std::string& frontID = oldEdges.front()->getID();
             for (ConstROEdgeVector::iterator i = oldEdges.begin(); i != oldEdges.end();) {
-                if ((*i)->prohibits(&veh)) {
+                if ((*i)->prohibits(&veh) || (*i)->isInternal()) {
                     i = oldEdges.erase(i);
                 } else {
                     WRITE_MESSAGE("Changing invalid starting edge '" + frontID
@@ -198,40 +190,21 @@ RORouteDef::repairCurrentRoute(SUMOAbstractRouter<ROEdge, ROVehicle>& router,
             mh->inform("Could not find new starting edge for vehicle '" + veh.getID() + "'.");
             return false;
         }
-        mandatory.push_back(oldEdges.front());
-        ConstROEdgeVector stops = veh.getStopEdges();
-        for (ConstROEdgeVector::const_iterator i = stops.begin(); i != stops.end(); ++i) {
-            if ((*i)->isInternal()) {
-                // the edges before and after the internal edge are mandatory
-                const ROEdge* before = (*i)->getNormalBefore();
-                const ROEdge* after = (*i)->getNormalAfter();
-                if (after != mandatory.back()) {
-                    mandatory.push_back(before);
-                    mandatory.push_back(after);
-                }
-            } else {
-                if (*i != mandatory.back()) {
-                    mandatory.push_back(*i);
-                }
-            }
-        }
         if (oldEdges.back()->prohibits(&veh)) {
             // option repair.to is in effect
             const std::string& backID = oldEdges.back()->getID();
             // oldEdges cannot get empty here, otherwise we would have left the stage when checking "from"
-            while (oldEdges.back()->prohibits(&veh)) {
+            while (oldEdges.back()->prohibits(&veh) || oldEdges.back()->isInternal()) {
                 oldEdges.pop_back();
             }
             WRITE_MESSAGE("Changing invalid destination edge '" + backID
                           + "' to edge '" + oldEdges.back()->getID() + "' for vehicle '" + veh.getID() + "'.");
         }
-        if (mandatory.size() < 2 || oldEdges.back() != mandatory.back()) {
-            mandatory.push_back(oldEdges.back());
-        }
+        ConstROEdgeVector mandatory = veh.getMandatoryEdges(oldEdges.front(), oldEdges.back());
         assert(mandatory.size() >= 2);
         // removed prohibited
         for (ConstROEdgeVector::iterator i = oldEdges.begin(); i != oldEdges.end();) {
-            if ((*i)->prohibits(&veh)) {
+            if ((*i)->prohibits(&veh) || (*i)->isInternal()) {
                 // no need to check the mandatories here, this was done before
                 i = oldEdges.erase(i);
             } else {
@@ -398,7 +371,7 @@ RORouteDef*
 RORouteDef::copyOrigDest(const std::string& id) const {
     RORouteDef* result = new RORouteDef(id, 0, true, true);
     RORoute* route = myAlternatives[0];
-    RGBColor* col = route->getColor() != 0 ? new RGBColor(*route->getColor()) : 0;
+    RGBColor* col = route->getColor() != nullptr ? new RGBColor(*route->getColor()) : nullptr;
     ConstROEdgeVector edges;
     edges.push_back(route->getFirst());
     edges.push_back(route->getLast());
@@ -412,7 +385,7 @@ RORouteDef::copy(const std::string& id, const SUMOTime stopOffset) const {
     RORouteDef* result = new RORouteDef(id, 0, myTryRepair, myMayBeDisconnected);
     for (std::vector<RORoute*>::const_iterator i = myAlternatives.begin(); i != myAlternatives.end(); i++) {
         RORoute* route = *i;
-        RGBColor* col = route->getColor() != 0 ? new RGBColor(*route->getColor()) : 0;
+        RGBColor* col = route->getColor() != nullptr ? new RGBColor(*route->getColor()) : nullptr;
         RORoute* newRoute = new RORoute(id, 0, 1, route->getEdgeVector(), col, route->getStops());
         newRoute->addStopOffset(stopOffset);
         result->addLoadedAlternative(newRoute);
