@@ -1,24 +1,21 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    ROVehicle.h
 /// @author  Daniel Krajzewicz
 /// @author  Michael Behrisch
 /// @author  Jakob Erdmann
 /// @date    Sept 2002
-/// @version $Id: ROVehicle.h 20482 2016-04-18 20:49:42Z behrisch $
+/// @version $Id$
 ///
 // A vehicle as used by router
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2002-2016 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 #ifndef ROVehicle_h
 #define ROVehicle_h
 
@@ -26,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <iostream>
@@ -85,15 +78,6 @@ public:
     }
 
 
-    /** @brief Returns the definition of the vehicle parameter
-     *
-     * @return The vehicle's parameter
-     */
-    inline const SUMOVehicleParameter& getParameter() const {
-        return myParameter;
-    }
-
-
     /** @brief Returns the first edge the vehicle takes
      *
      * @return The vehicle's departure edge
@@ -109,7 +93,7 @@ public:
      * @return The vehicle's depart time
      */
     inline SUMOTime getDepartureTime() const {
-        return MAX2(SUMOTime(0), myParameter.depart);
+        return MAX2(SUMOTime(0), getParameter().depart);
     }
 
 
@@ -117,12 +101,16 @@ public:
         return myStopEdges;
     }
 
+
+    /// @brief compute mandatory edges
+    ConstROEdgeVector getMandatoryEdges(const ROEdge* requiredStart, const ROEdge* requiredEnd) const;
+
     /** @brief Returns an upper bound for the speed factor of this vehicle
      *
      * @return the maximum speed factor
      */
-    inline SUMOReal getChosenSpeedFactor() const {
-        return SUMOReal(2. * getType()->speedDev + 1.) * getType()->speedFactor;
+    inline double getChosenSpeedFactor() const {
+        return getType()->speedFactor.getMax();
     }
 
 
