@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    sumo_main.cpp
 /// @author  Daniel Krajzewicz
@@ -25,45 +23,78 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #ifdef HAVE_VERSION_H
 #include <version.h>
 #endif
 
 #include <ctime>
+#include <csignal>
 #include <string>
 #include <iostream>
 #include <netload/NLBuilder.h>
 #include <utils/options/OptionsCont.h>
 #include <utils/options/OptionsIO.h>
+#include <utils/iodevices/OutputDevice.h>
 #include <utils/common/MsgHandler.h>
 #include <utils/common/SystemFrame.h>
 #include <utils/common/UtilExceptions.h>
 #include <utils/common/ToString.h>
+#include <utils/common/StdDefs.h>
 #include <utils/xml/XMLSubSys.h>
-
-#ifndef NO_TRACI
 #include <traci-server/TraCIServer.h>
-#endif
 
 
 // ===========================================================================
 // functions
 // ===========================================================================
+void
+signalHandler(int signum) {
+    if (MSNet::hasInstance()) {
+        switch (signum) {
+            case SIGINT:
+            case SIGTERM:
+                if (MSNet::getInstance()->isInterrupted()) {
+                    std::cout << "Another interrupt signal received, hard exit." << std::endl;
+                    exit(signum);
+                }
+                std::cout << "Interrupt signal received, trying to exit gracefully." << std::endl;
+                MSNet::getInstance()->interrupt();
+                break;
+#ifndef _MSC_VER
+            case SIGUSR1:
+                std::cout << "Step #" << SIMSTEP << std::endl;
+                std::cout << MSNet::getInstance()->generateStatistics(string2time(OptionsCont::getOptions().getString("begin"))) << std::endl;
+                break;
+            case SIGUSR2:
+                //TODO reload sim
+                break;
+#endif
+            default:
+                break;
+        }
+    }
+}
+
+
 /* -------------------------------------------------------------------------
  * main
  * ----------------------------------------------------------------------- */
 int
 main(int argc, char** argv) {
+    signal(SIGINT, signalHandler);
+    signal(SIGTERM, signalHandler);
+#ifndef _MSC_VER
+    signal(SIGUSR1, signalHandler);
+    signal(SIGUSR2, signalHandler);
+#endif
+
     OptionsCont& oc = OptionsCont::getOptions();
     // give some application descriptions
-    oc.setApplicationDescription("A microscopic road traffic simulation.");
-    oc.setApplicationName("sumo", "SUMO Version " VERSION_STRING);
+    oc.setApplicationDescription("A microscopic, multi-modal traffic simulation.");
+    oc.setApplicationName("sumo", "Eclipse SUMO Version " VERSION_STRING);
+    gSimulation = true;
     int ret = 0;
     try {
         // initialise subsystems
@@ -98,9 +129,7 @@ main(int argc, char** argv) {
         ret = 1;
 #endif
     }
-#ifndef NO_TRACI
     TraCIServer::close();
-#endif
     SystemFrame::close();
     return ret;
 }
