@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    TraCIServer.h
 /// @author  Axel Wegener
@@ -31,13 +29,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
-
-#ifndef NO_TRACI
 
 #include <map>
 #include <string>
@@ -55,8 +47,9 @@
 #include <utils/options/OptionsCont.h>
 #include <microsim/MSNet.h>
 #include <microsim/traffic_lights/MSTrafficLightLogic.h>
+#include <traci-server/TraCIConstants.h>
+#include <libsumo/Subscription.h>
 #include <libsumo/TraCIDefs.h>
-#include "TraCIConstants.h"
 #include "TraCIServerAPI_Lane.h"
 
 
@@ -66,12 +59,11 @@
 /** @class TraCIServer
  * @brief TraCI server used to control sumo by a remote TraCI client
  */
-class TraCIServer : public MSNet::VehicleStateListener {
+class TraCIServer : public MSNet::VehicleStateListener, public libsumo::VariableWrapper {
 public:
     /// @brief Definition of a method to be called for serving an associated commandID
     typedef bool(*CmdExecutor)(TraCIServer& server, tcpip::Storage& inputStorage, tcpip::Storage& outputStorage);
 
-
     SUMOTime getTargetTime() const {
         return myTargetTime;
     }
@@ -119,7 +111,7 @@ public:
     static void runEmbedded(std::string pyFile);
 #endif
 
-    void vehicleStateChanged(const SUMOVehicle* const vehicle, MSNet::VehicleState to);
+    void vehicleStateChanged(const SUMOVehicle* const vehicle, MSNet::VehicleState to, const std::string& info = "");
 
     /// @name Writing Status Messages
     /// @{
@@ -165,7 +157,7 @@ public:
 
     void writeResponseWithLength(tcpip::Storage& outputStorage, tcpip::Storage& tempMsg);
 
-    void collectObjectsInRange(int domain, const PositionVector& shape, double range, std::set<std::string>& into);
+    void writePositionVector(tcpip::Storage& outputStorage, const libsumo::TraCIPositionVector& shape);
 
 
     /// @name Helpers for reading and checking values
@@ -225,15 +217,6 @@ public:
     bool readTypeCheckingPosition2D(tcpip::Storage& inputStorage, libsumo::TraCIPosition& into);
 
 
-    /** @brief Reads the value type and a 2D bounding box, verifying the type
-     *
-     * @param[in, changed] inputStorage The storage to read from
-     * @param[out] into Holder of the read value
-     * @return Whether a 2D bounding box was given (by data type)
-     */
-    bool readTypeCheckingBoundary(tcpip::Storage& inputStorage, Boundary& into);
-
-
     /** @brief Reads the value type and a byte, verifying the type
      *
      * @param[in, changed] inputStorage The storage to read from
@@ -270,6 +253,18 @@ public:
         return myLoadArgs;
     }
 
+    /// @name VariableWrapper interface
+    /// @{
+    void initWrapper(const int domainID, const int variable, const std::string& objID);
+    bool wrapDouble(const std::string& objID, const int variable, const double value);
+    bool wrapInt(const std::string& objID, const int variable, const int value);
+    bool wrapString(const std::string& objID, const int variable, const std::string& value);
+    bool wrapStringList(const std::string& objID, const int variable, const std::vector<std::string>& value);
+    bool wrapPosition(const std::string& objID, const int variable, const libsumo::TraCIPosition& value);
+    bool wrapColor(const std::string& objID, const int variable, const libsumo::TraCIColor& value);
+    tcpip::Storage& getWrapperStorage();
+    /// @}
+
 
 private:
     /** @brief Constructor
@@ -371,9 +366,12 @@ private:
     /// @brief The storage to read from
     tcpip::Storage myInputStorage;
 
-    /// @brief The storage to writeto
+    /// @brief The storage to write to
     tcpip::Storage myOutputStorage;
 
+    /// @brief A temporary storage to let the wrapper write to
+    tcpip::Storage myWrapperStorage;
+
     /// @brief The last timestep's subscription results
     tcpip::Storage mySubscriptionCache;
 
@@ -388,50 +386,11 @@ private:
 
     std::vector<std::string> myLoadArgs;
 
-    /** @class Subscription
-     * @brief Representation of a subscription
-     */
-    class Subscription {
-    public:
-        /** @brief Constructor
-         * @param[in] commandIdArg The command id of the subscription
-         * @param[in] idArg The id of the object that is subscribed
-         * @param[in] variablesArg The subscribed variables
-         * @param[in] beginTimeArg The begin time of the subscription
-         * @param[in] endTimeArg The end time of the subscription
-         * @param[in] contextVarsArg Whether the subscription is a context subscription (variable subscription otherwise)
-         * @param[in] contextDomainArg The domain ID of the context
-         * @param[in] rangeArg The range of the context
-         */
-        Subscription(int commandIdArg, const std::string& idArg,
-                     const std::vector<int>& variablesArg, const std::vector<std::vector<unsigned char> >& paramsArg,
-                     SUMOTime beginTimeArg, SUMOTime endTimeArg, bool contextVarsArg, int contextDomainArg, double rangeArg)
-            : commandId(commandIdArg), id(idArg), variables(variablesArg), parameters(paramsArg), beginTime(beginTimeArg), endTime(endTimeArg),
-              contextVars(contextVarsArg), contextDomain(contextDomainArg), range(rangeArg) {}
-
-        /// @brief commandIdArg The command id of the subscription
-        int commandId;
-        /// @brief The id of the object that is subscribed
-        std::string id;
-        /// @brief The subscribed variables
-        std::vector<int> variables;
-        /// @brief The parameters for the subscribed variables
-        std::vector<std::vector<unsigned char> > parameters;
-        /// @brief The begin time of the subscription
-        SUMOTime beginTime;
-        /// @brief The end time of the subscription
-        SUMOTime endTime;
-        /// @brief Whether the subscription is a context subscription (variable subscription otherwise)
-        bool contextVars;
-        /// @brief The domain ID of the context
-        int contextDomain;
-        /// @brief The range of the context
-        double range;
-
-    };
-
     /// @brief The list of known, still valid subscriptions
-    std::vector<Subscription> mySubscriptions;
+    std::vector<libsumo::Subscription> mySubscriptions;
+
+    /// @brief The last modified context subscription (the one to add a filter to, see @addSubscriptionFilter(), currently only for vehicle to vehicle context)
+    libsumo::Subscription* myLastContextSubscription;
 
     /// @brief Changes in the states of simulated vehicles
     /// @note
@@ -444,14 +403,32 @@ private:
 
 private:
     bool addObjectVariableSubscription(const int commandId, const bool hasContext);
-    void initialiseSubscription(const Subscription& s);
+    void initialiseSubscription(libsumo::Subscription& s);
     void removeSubscription(int commandId, const std::string& identity, int domain);
-    bool processSingleSubscription(const TraCIServer::Subscription& s, tcpip::Storage& writeInto,
+    bool processSingleSubscription(const libsumo::Subscription& s, tcpip::Storage& writeInto,
                                    std::string& errors);
 
 
+    bool addSubscriptionFilter();
+    void removeFilters();
+    void addSubscriptionFilterLanes(std::vector<int> lanes);
+    void addSubscriptionFilterNoOpposite();
+    void addSubscriptionFilterDownstreamDistance(double dist);
+    void addSubscriptionFilterUpstreamDistance(double dist);
+    void addSubscriptionFilterLeadFollow();
+    // TODO: for libsumo, implement convenience definitions present in python client:
+    //    void addSubscriptionFilterCF();
+    //    void addSubscriptionFilterLC(int direction);
+    void addSubscriptionFilterTurn();
+    void addSubscriptionFilterVClass(SVCPermissions vClasses);
+    void addSubscriptionFilterVType(std::set<std::string> vTypes);
+    bool isVehicleToVehicleContextSubscription(const libsumo::Subscription& s);
+
     bool findObjectShape(int domain, const std::string& id, PositionVector& shape);
 
+    /// @brief check whether a found objID refers to the central object of a context subscription
+    bool centralObject(const libsumo::Subscription& s, const std::string& objID);
+
 
 private:
     /// @brief Invalidated assignment operator
@@ -460,6 +437,4 @@ private:
 };
 
 
-#endif
-
 #endif
