@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    TraCIServerAPI_Edge.h
 /// @author  Daniel Krajzewicz
@@ -23,13 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
-
-#ifndef NO_TRACI
 
 #include "TraCIServer.h"
 #include <foreign/tcpip/storage.h>
@@ -64,14 +56,6 @@ public:
                            tcpip::Storage& outputStorage);
 
 
-    /** @brief Returns the named edge's shape
-     * @param[in] id The id of the searched edge
-     * @param[out] shape The shape, if the edge is known
-     * @return Whether the edge is known
-     */
-    static bool getShape(const std::string& id, PositionVector& shape);
-
-
 private:
     /// @brief invalidated copy constructor
     TraCIServerAPI_Edge(const TraCIServerAPI_Edge& s);
@@ -83,8 +67,6 @@ private:
 };
 
 
-#endif
-
 #endif
 
 /****************************************************************************/
