@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2009-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2009-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    TraCIServerAPI_Lane.h
 /// @author  Daniel Krajzewicz
@@ -25,13 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
-
-#ifndef NO_TRACI
 
 #include <foreign/tcpip/storage.h>
 
@@ -71,15 +63,6 @@ public:
                            tcpip::Storage& outputStorage);
 
 
-    /** @brief Returns the named lane's shape
-     *
-     * @param[in] id The id of the searched lane
-     * @param[out] shape The shape, if the lane is known
-     * @return Whether the lane is known
-     */
-    static bool getShape(const std::string& id, PositionVector& shape);
-
-
 private:
     /// @brief invalidated copy constructor
     TraCIServerAPI_Lane(const TraCIServerAPI_Lane& s);
@@ -91,8 +74,6 @@ private:
 };
 
 
-#endif
-
 #endif
 
 /****************************************************************************/
