@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    TraCIServerAPI_Polygon.h
 /// @author  Daniel Krajzewicz
@@ -24,13 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
-
-#ifndef NO_TRACI
 
 #include "TraCIServer.h"
 #include <foreign/tcpip/storage.h>
@@ -65,23 +57,6 @@ public:
                            tcpip::Storage& outputStorage);
 
 
-    /** @brief Returns the named polygons's shape
-     *
-     * @param[in] id The id of the searched polygon
-     * @param[out] shape The shape, if the polygon is known
-     * @return Whether the polygon is known
-     */
-    static bool getShape(const std::string& id, PositionVector& shape);
-
-
-private:
-    /** @brief Returns the named polygon
-     * @param[in] id The id of the searched polygon
-     * @return The named polygon, or 0 if it is not known
-     */
-    static SUMOPolygon* getPolygon(const std::string& id);
-
-
 private:
     /// @brief invalidated copy constructor
     TraCIServerAPI_Polygon(const TraCIServerAPI_Polygon& s);
@@ -93,8 +68,6 @@ private:
 };
 
 
-#endif
-
 #endif
 
 /****************************************************************************/
