@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    TraCIServerAPI_Simulation.h
 /// @author  Daniel Krajzewicz
@@ -24,13 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
-
-#ifndef NO_TRACI
 
 #include <string>
 #include <map>
@@ -67,14 +59,6 @@ public:
                            tcpip::Storage& outputStorage);
 
 
-    /**
-     * Converts a cartesian position to the closest road map position
-     *
-     * @param pos cartesian position that is to be converted
-     * @return the closest road map position to the cartesian position
-     */
-    static std::pair<MSLane*, double> convertCartesianToRoadMap(Position pos);
-
     /**
      * Converts a road map position to a cartesian position
      *
@@ -105,8 +89,6 @@ private:
 };
 
 
-#endif
-
 #endif
 
 /****************************************************************************/
