@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    TraCIServerAPI_Vehicle.h
 /// @author  Daniel Krajzewicz
@@ -24,13 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
-
-#ifndef NO_TRACI
 
 #include <microsim/MSEdgeWeightsStorage.h>
 #include "TraCIServer.h"
@@ -66,14 +58,6 @@ public:
                            tcpip::Storage& outputStorage);
 
 
-    /** @brief Returns the named vehicle's position
-     * @param[in] id The id of the searched vehicle
-     * @param[out] p The position, if the vehicle is on the network
-     * @return Whether the vehicle is known (and on road)
-     */
-    static bool getPosition(const std::string& id, Position& p);
-
-
 private:
     /// @brief invalidated copy constructor
     TraCIServerAPI_Vehicle(const TraCIServerAPI_Vehicle& s);
@@ -85,8 +69,6 @@ private:
 };
 
 
-#endif
-
 #endif
 
 /****************************************************************************/
