@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MsgHandler.cpp
 /// @author  Daniel Krajzewicz
@@ -22,40 +20,43 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <cassert>
 #include <vector>
 #include <algorithm>
 #include <iostream>
-#include "MsgHandler.h"
 #include <utils/options/OptionsCont.h>
 #include <utils/iodevices/OutputDevice.h>
 #include <utils/common/UtilExceptions.h>
+
+#include "MsgHandler.h"
 #include "AbstractMutex.h"
 
 
 // ===========================================================================
 // static member variables
 // ===========================================================================
-MsgHandler* MsgHandler::myErrorInstance = 0;
-MsgHandler* MsgHandler::myWarningInstance = 0;
-MsgHandler* MsgHandler::myMessageInstance = 0;
+
+MsgHandler* MsgHandler::myDebugInstance = nullptr;
+MsgHandler* MsgHandler::myGLDebugInstance = nullptr;
+MsgHandler* MsgHandler::myErrorInstance = nullptr;
+MsgHandler* MsgHandler::myWarningInstance = nullptr;
+MsgHandler* MsgHandler::myMessageInstance = nullptr;
 bool MsgHandler::myAmProcessingProcess = false;
-AbstractMutex* MsgHandler::myLock = 0;
+AbstractMutex* MsgHandler::myLock = nullptr;
+bool MsgHandler::myWriteDebugMessages(false);
+bool MsgHandler::myWriteDebugGLMessages(false);
 
 
 // ===========================================================================
 // method definitions
 // ===========================================================================
+
 MsgHandler*
 MsgHandler::getMessageInstance() {
-    if (myMessageInstance == 0) {
+    if (myMessageInstance == nullptr) {
         myMessageInstance = new MsgHandler(MT_MESSAGE);
     }
     return myMessageInstance;
@@ -64,7 +65,7 @@ MsgHandler::getMessageInstance() {
 
 MsgHandler*
 MsgHandler::getWarningInstance() {
-    if (myWarningInstance == 0) {
+    if (myWarningInstance == nullptr) {
         myWarningInstance = new MsgHandler(MT_WARNING);
     }
     return myWarningInstance;
@@ -73,16 +74,44 @@ MsgHandler::getWarningInstance() {
 
 MsgHandler*
 MsgHandler::getErrorInstance() {
-    if (myErrorInstance == 0) {
+    if (myErrorInstance == nullptr) {
         myErrorInstance = new MsgHandler(MT_ERROR);
     }
     return myErrorInstance;
 }
 
 
+MsgHandler*
+MsgHandler::getDebugInstance() {
+    if (myDebugInstance == nullptr) {
+        myDebugInstance = new MsgHandler(MT_DEBUG);
+    }
+    return myDebugInstance;
+}
+
+
+MsgHandler*
+MsgHandler::getGLDebugInstance() {
+    if (myGLDebugInstance == nullptr) {
+        myGLDebugInstance = new MsgHandler(MT_GLDEBUG);
+    }
+    return myGLDebugInstance;
+}
+
+
+void
+MsgHandler::enableDebugMessages(bool enable) {
+    myWriteDebugMessages = enable;
+}
+
+void
+MsgHandler::enableDebugGLMessages(bool enable) {
+    myWriteDebugGLMessages = enable;
+}
+
 void
 MsgHandler::inform(std::string msg, bool addType) {
-    if (myLock != 0) {
+    if (myLock != nullptr) {
         myLock->lock();
     }
     // beautify progress output
@@ -92,12 +121,12 @@ MsgHandler::inform(std::string msg, bool addType) {
     }
     msg = build(msg, addType);
     // inform all receivers
-    for (RetrieverVector::iterator i = myRetrievers.begin(); i != myRetrievers.end(); i++) {
-        (*i)->inform(msg);
+    for (auto i : myRetrievers) {
+        i->inform(msg);
     }
-    // set the information that something occured
+    // set the information that something occurred
     myWasInformed = true;
-    if (myLock != 0) {
+    if (myLock != nullptr) {
         myLock->unlock();
     }
 }
@@ -105,18 +134,18 @@ MsgHandler::inform(std::string msg, bool addType) {
 
 void
 MsgHandler::beginProcessMsg(std::string msg, bool addType) {
-    if (myLock != 0) {
+    if (myLock != nullptr) {
         myLock->lock();
     }
     msg = build(msg, addType);
     // inform all other receivers
-    for (RetrieverVector::iterator i = myRetrievers.begin(); i != myRetrievers.end(); i++) {
-        (*i)->inform(msg, ' ');
+    for (auto i : myRetrievers) {
+        i->inform(msg, ' ');
         myAmProcessingProcess = true;
     }
-    // set the information that something occured
+    // set the information that something occurred
     myWasInformed = true;
-    if (myLock != 0) {
+    if (myLock != nullptr) {
         myLock->unlock();
     }
 }
@@ -124,17 +153,17 @@ MsgHandler::beginProcessMsg(std::string msg, bool addType) {
 
 void
 MsgHandler::endProcessMsg(std::string msg) {
-    if (myLock != 0) {
+    if (myLock != nullptr) {
         myLock->lock();
     }
     // inform all other receivers
-    for (RetrieverVector::iterator i = myRetrievers.begin(); i != myRetrievers.end(); i++) {
-        (*i)->inform(msg);
+    for (auto i : myRetrievers) {
+        i->inform(msg);
     }
-    // set the information that something occured
+    // set the information that something occurred
     myWasInformed = true;
     myAmProcessingProcess = false;
-    if (myLock != 0) {
+    if (myLock != nullptr) {
         myLock->unlock();
     }
 }
@@ -142,11 +171,11 @@ MsgHandler::endProcessMsg(std::string msg) {
 
 void
 MsgHandler::clear() {
-    if (myLock != 0) {
+    if (myLock != nullptr) {
         myLock->lock();
     }
     myWasInformed = false;
-    if (myLock != 0) {
+    if (myLock != nullptr) {
         myLock->unlock();
     }
 }
@@ -154,13 +183,13 @@ MsgHandler::clear() {
 
 void
 MsgHandler::addRetriever(OutputDevice* retriever) {
-    if (myLock != 0) {
+    if (myLock != nullptr) {
         myLock->lock();
     }
     if (!isRetriever(retriever)) {
         myRetrievers.push_back(retriever);
     }
-    if (myLock != 0) {
+    if (myLock != nullptr) {
         myLock->unlock();
     }
 }
@@ -168,15 +197,14 @@ MsgHandler::addRetriever(OutputDevice* retriever) {
 
 void
 MsgHandler::removeRetriever(OutputDevice* retriever) {
-    if (myLock != 0) {
+    if (myLock != nullptr) {
         myLock->lock();
     }
-    RetrieverVector::iterator i =
-        find(myRetrievers.begin(), myRetrievers.end(), retriever);
+    RetrieverVector::iterator i = find(myRetrievers.begin(), myRetrievers.end(), retriever);
     if (i != myRetrievers.end()) {
         myRetrievers.erase(i);
     }
-    if (myLock != 0) {
+    if (myLock != nullptr) {
         myLock->unlock();
     }
 }
@@ -188,6 +216,25 @@ MsgHandler::isRetriever(OutputDevice* retriever) const {
 }
 
 
+void
+MsgHandler::removeRetrieverFromAllInstances(OutputDevice* out) {
+    if (myDebugInstance != nullptr) {
+        myDebugInstance->removeRetriever(out);
+    }
+    if (myGLDebugInstance != nullptr) {
+        myGLDebugInstance->removeRetriever(out);
+    }
+    if (myErrorInstance != nullptr) {
+        myErrorInstance->removeRetriever(out);
+    }
+    if (myWarningInstance != nullptr) {
+        myWarningInstance->removeRetriever(out);
+    }
+    if (myMessageInstance != nullptr) {
+        myMessageInstance->removeRetriever(out);
+    }
+}
+
 void
 MsgHandler::initOutputOptions() {
     // initialize console properly
@@ -199,33 +246,21 @@ MsgHandler::initOutputOptions() {
     }
     // build the logger if possible
     if (oc.isSet("log", false)) {
-        try {
-            OutputDevice* logFile = &OutputDevice::getDevice(oc.getString("log"));
-            getErrorInstance()->addRetriever(logFile);
-            if (!oc.getBool("no-warnings")) {
-                getWarningInstance()->addRetriever(logFile);
-            }
-            getMessageInstance()->addRetriever(logFile);
-        } catch (IOError&) {
-            throw ProcessError("Could not build logging file '" + oc.getString("log") + "'");
+        OutputDevice* logFile = &OutputDevice::getDevice(oc.getString("log"));
+        getErrorInstance()->addRetriever(logFile);
+        if (!oc.getBool("no-warnings")) {
+            getWarningInstance()->addRetriever(logFile);
         }
+        getMessageInstance()->addRetriever(logFile);
     }
     if (oc.isSet("message-log", false)) {
-        try {
-            OutputDevice* logFile = &OutputDevice::getDevice(oc.getString("message-log"));
-            getMessageInstance()->addRetriever(logFile);
-        } catch (IOError&) {
-            throw ProcessError("Could not build logging file '" + oc.getString("message-log") + "'");
-        }
+        OutputDevice* logFile = &OutputDevice::getDevice(oc.getString("message-log"));
+        getMessageInstance()->addRetriever(logFile);
     }
     if (oc.isSet("error-log", false)) {
-        try {
-            OutputDevice* logFile = &OutputDevice::getDevice(oc.getString("error-log"));
-            getErrorInstance()->addRetriever(logFile);
-            getWarningInstance()->addRetriever(logFile);
-        } catch (IOError&) {
-            throw ProcessError("Could not build logging file '" + oc.getString("error-log") + "'");
-        }
+        OutputDevice* logFile = &OutputDevice::getDevice(oc.getString("error-log"));
+        getErrorInstance()->addRetriever(logFile);
+        getWarningInstance()->addRetriever(logFile);
     }
     if (!oc.getBool("verbose")) {
         getMessageInstance()->removeRetriever(&OutputDevice::getDevice("stdout"));
@@ -235,23 +270,27 @@ MsgHandler::initOutputOptions() {
 
 void
 MsgHandler::cleanupOnEnd() {
-    if (myLock != 0) {
+    if (myLock != nullptr) {
         myLock->lock();
     }
     delete myMessageInstance;
-    myMessageInstance = 0;
+    myMessageInstance = nullptr;
     delete myWarningInstance;
-    myWarningInstance = 0;
+    myWarningInstance = nullptr;
     delete myErrorInstance;
-    myErrorInstance = 0;
-    if (myLock != 0) {
+    myErrorInstance = nullptr;
+    delete myDebugInstance;
+    myDebugInstance = nullptr;
+    delete myGLDebugInstance;
+    myGLDebugInstance = nullptr;
+    if (myLock != nullptr) {
         myLock->unlock();
     }
 }
 
 
-MsgHandler::MsgHandler(MsgType type)
-    : myType(type), myWasInformed(false) {
+MsgHandler::MsgHandler(MsgType type) :
+    myType(type), myWasInformed(false) {
     if (type == MT_MESSAGE) {
         addRetriever(&OutputDevice::getDevice("stdout"));
     } else {
@@ -276,7 +315,5 @@ MsgHandler::assignLock(AbstractMutex* lock) {
     myLock = lock;
 }
 
-
-
 /****************************************************************************/
 
