@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    RGBColor.h
 /// @author  Daniel Krajzewicz
@@ -25,13 +23,10 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
+#include <random>
 #include <utils/common/UtilExceptions.h>
 
 
@@ -108,6 +103,10 @@ public:
     /// @brief obtain inverted of current RGBColor
     RGBColor invertedColor() const;
 
+    static std::mt19937* getColorRNG() {
+        return &myRNG;
+    }
+
     /** @brief Parses a color information
      *
      * It is assumed that the color is stored as "<RED>,<GREEN>,<BLUE>"
@@ -160,6 +159,13 @@ public:
      */
     static RGBColor fromHSV(double h, double s, double v);
 
+    /** @brief Return color with random hue
+     * @param[in] s Saturation (0-1)
+     * @param[in] v Value (0-1)
+     * @return The color as RGB
+     */
+    static RGBColor randomHue(double s = 1, double v = 1);
+
     /** @brief Writes the color to the given stream
     * @param[out] os The stream to write to
     * @param[in] col The color to write
@@ -185,6 +191,7 @@ public:
     static const RGBColor WHITE;
     static const RGBColor BLACK;
     static const RGBColor GREY;
+    static const RGBColor INVISIBLE;
     /// @}
 
     /// @brief The default color (for vehicle types and vehicles)
@@ -196,6 +203,9 @@ public:
 private:
     /// @brief The color amounts
     unsigned char myRed, myGreen, myBlue, myAlpha;
+
+    /// @brief A random number generator to generate random colors independent of other randomness
+    static std::mt19937 myRNG;
 };
 
 
