@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    SUMOVehicleClass.h
 /// @author  Daniel Krajzewicz
@@ -27,11 +25,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <set>
@@ -45,7 +39,7 @@
 // class declarations
 // ===========================================================================
 class OutputDevice;
-
+class SUMOSAXAttributes;
 
 // ===========================================================================
 // enum definitions
@@ -108,7 +102,9 @@ enum SUMOVehicleShape {
     /// @brief render as a fire brigade
     SVS_FIREBRIGADE,
     /// @brief render as a police car
-    SVS_POLICE
+    SVS_POLICE,
+    /// @brief render as a rickshaw
+    SVS_RICKSHAW
 };
 
 
@@ -199,8 +195,10 @@ enum SUMOVehicleClass {
     SVC_CUSTOM2 = 1 << 24,
     //@}
 
+    /// @brief classes which drive on tracks
+    SVC_RAIL_CLASSES = SVC_RAIL_ELECTRIC | SVC_RAIL | SVC_RAIL_URBAN | SVC_TRAM,
     /// @brief classes which (normally) do not drive on normal roads
-    SVC_NON_ROAD = SVC_TRAM | SVC_RAIL | SVC_RAIL_URBAN | SVC_RAIL_ELECTRIC | SVC_SHIP
+    SVC_NON_ROAD = SVC_RAIL_CLASSES | SVC_SHIP
 };
 
 extern const int SUMOVehicleClass_MAX;
@@ -291,6 +289,9 @@ extern void writePermissions(OutputDevice& into, SVCPermissions permissions);
 /// @brief writes allowed disallowed attributes if needed;
 extern void writePreferences(OutputDevice& into, SVCPermissions preferred);
 
+/// @brief Extract stopOffsets from attributes of stopOffset element
+extern std::map<SVCPermissions, double> parseStopOffsets(const SUMOSAXAttributes& attrs, bool& ok);
+
 // ---------------------------------------------------------------------------
 // vehicle shape class
 // ---------------------------------------------------------------------------
@@ -327,11 +328,24 @@ extern bool isWaterway(SVCPermissions permissions);
  */
 extern bool isForbidden(SVCPermissions permissions);
 
+/** @brief Returns whether an edge with the given permission is a sidewalk
+ * @param[in] permissions The permissions of the edge
+ * @return Whether the edge is a sidewalk
+ */
+extern bool isSidewalk(SVCPermissions permissions);
+
+/** @brief Returns whether an edge with the given permission forbids vehicles
+ * @param[in] permissions The permissions of the edge
+ * @return Whether the edge is forbidden for vehicles
+ */
+extern bool noVehicles(SVCPermissions permissions);
+
 // ---------------------------------------------------------------------------
 // default vehicle type parameter
 // ---------------------------------------------------------------------------
 extern const std::string DEFAULT_VTYPE_ID;
 extern const std::string DEFAULT_PEDTYPE_ID;
+extern const std::string DEFAULT_BIKETYPE_ID;
 
 extern const double DEFAULT_VEH_PROB; // !!! does this belong here?
 
