@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    ToString.h
 /// @author  Christian Roessel
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <sstream>
 #include <string>
@@ -54,7 +48,7 @@
 template <class T>
 inline std::string toString(const T& t, std::streamsize accuracy = gPrecision) {
     std::ostringstream oss;
-    oss.setf(std::ios::fixed , std::ios::floatfield);
+    oss.setf(std::ios::fixed, std::ios::floatfield);
     oss << std::setprecision(accuracy);
     oss << t;
     return oss.str();
@@ -75,6 +69,7 @@ inline std::string toString(const Named* obj, std::streamsize accuracy) {
     return Named::getIDSecure(obj);
 }
 
+
 template <>
 inline std::string toString<SumoXMLTag>(const SumoXMLTag& tag, std::streamsize accuracy) {
     UNUSED_PARAMETER(accuracy);
@@ -116,6 +111,12 @@ inline std::string toString<LaneSpreadFunction>(const LaneSpreadFunction& lsf, s
     return SUMOXMLDefinitions::LaneSpreadFunctions.getString(lsf);
 }
 
+template <>
+inline std::string toString<RightOfWay>(const RightOfWay& row, std::streamsize accuracy) {
+    UNUSED_PARAMETER(accuracy);
+    return SUMOXMLDefinitions::RightOfWayValues.getString(row);
+}
+
 
 template <>
 inline std::string toString<LinkState>(const LinkState& linkState, std::streamsize accuracy) {
@@ -256,6 +257,26 @@ inline std::string joinToStringSorting(const std::vector<T>& v, const T_BETWEEN&
 }
 
 
+template <typename T, typename T_BETWEEN>
+inline std::string joinNamedToStringSorting(const std::set<T*>& ns, const T_BETWEEN& between) {
+    std::vector<std::string> ids;
+    for (T* n : ns) {
+        ids.push_back(Named::getIDSecure(n));
+    }
+    return joinToStringSorting(ids, between);
+}
+
+
+template <typename T, typename C, typename T_BETWEEN>
+inline std::string joinNamedToString(const std::set<T*, C>& ns, const T_BETWEEN& between) {
+    std::vector<std::string> ids;
+    for (T* n : ns) {
+        ids.push_back(Named::getIDSecure(n));
+    }
+    return joinToString(ids, between);
+}
+
+
 template <typename V>
 inline std::string toString(const std::set<V*>& v, std::streamsize accuracy = gPrecision) {
     UNUSED_PARAMETER(accuracy);
