@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    Distribution_Parameterized.cpp
 /// @author  Daniel Krajzewicz
@@ -22,17 +20,13 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <cassert>
 #include <utils/common/RandHelper.h>
 #include <utils/common/StringTokenizer.h>
 #include <utils/common/ToString.h>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include "Distribution_Parameterized.h"
 
 
@@ -66,10 +60,10 @@ Distribution_Parameterized::parse(const std::string& description) {
     if (distName == "norm" || distName == "normc") {
         std::vector<std::string> params = StringTokenizer(description.substr(distName.size() + 1, description.size() - distName.size() - 2), ',').getVector();
         myParameter.resize(params.size());
-        std::transform(params.begin(), params.end(), myParameter.begin(), TplConvert::_str2double);
+        std::transform(params.begin(), params.end(), myParameter.begin(), StringUtils::toDouble);
         setID(distName);
     } else {
-        myParameter[0] = TplConvert::_str2double(description);
+        myParameter[0] = StringUtils::toDouble(description);
     }
     assert(!myParameter.empty());
     if (myParameter.size() == 1) {
@@ -110,5 +104,20 @@ Distribution_Parameterized::toStr(std::streamsize accuracy) const {
 }
 
 
+bool
+Distribution_Parameterized::isValid(std::string& error) {
+    if (myParameter.size() > 2) {
+        if (myParameter[0] > getMax()) {
+            error = "distribution mean " + toString(myParameter[0]) + " is larger than upper boundary " + toString(getMax());
+            return false;
+        }
+        if (myParameter[0] < myParameter[2]) {
+            error = "distribution mean " + toString(myParameter[0]) + " is smaller than lower boundary " + toString(myParameter[2]);
+            return false;
+        }
+    }
+    return true;
+}
+
 /****************************************************************************/
 
