@@ -1,4 +1,12 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2004-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    FXSingleEventThread.cpp
 /// @author  unknown_author
 /// @author  Daniel Krajzewicz
@@ -6,30 +14,15 @@
 /// @author  Laura Bieker
 /// @author  Jakob Erdmann
 /// @date    2004-03-19
-/// @version $Id: FXSingleEventThread.cpp 20433 2016-04-13 08:00:14Z behrisch $
+/// @version $Id$
 ///
 //
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2004-2016 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 
 /* =========================================================================
  * included modules
  * ======================================================================= */
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/common/StdDefs.h>
 #include "MFXInterThreadEventClient.h"
@@ -43,10 +36,6 @@
 #include <process.h>
 #endif
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif
-
 #ifndef WIN32
 # define PIPE_READ 0
 # define PIPE_WRITE 1
@@ -73,7 +62,7 @@ FXSingleEventThread::FXSingleEventThread(FXApp* a, MFXInterThreadEventClient* cl
     UNUSED_PARAMETER(res); // only used for assertion
     myApp->addInput(event[PIPE_READ], INPUT_READ, this, ID_THREAD_EVENT);
 #else
-    event = CreateEvent(NULL, FALSE, FALSE, NULL);
+    event = CreateEvent(nullptr, FALSE, FALSE, nullptr);
     FXASSERT(event != NULL);
     myApp->addInput(event, INPUT_READ, this, ID_THREAD_EVENT);
 #endif
@@ -97,7 +86,8 @@ void
 FXSingleEventThread::signal() {
 #ifndef WIN32
     FXuint seltype = SEL_THREAD;
-    ::write(event[PIPE_WRITE], &seltype, sizeof(seltype));
+    FXint res = ::write(event[PIPE_WRITE], &seltype, sizeof(seltype));
+    UNUSED_PARAMETER(res); // to make the compiler happy
 #else
     ::SetEvent(event);
 #endif
@@ -108,7 +98,8 @@ void
 FXSingleEventThread::signal(FXuint seltype) {
     UNUSED_PARAMETER(seltype);
 #ifndef WIN32
-    ::write(event[PIPE_WRITE], &seltype, sizeof(seltype));
+    FXint res = ::write(event[PIPE_WRITE], &seltype, sizeof(seltype));
+    UNUSED_PARAMETER(res); // to make the compiler happy
 #else
     ::SetEvent(event);
 #endif
@@ -119,19 +110,20 @@ long
 FXSingleEventThread::onThreadSignal(FXObject*, FXSelector, void*) {
 #ifndef WIN32
     FXuint seltype = SEL_THREAD;
-    ::read(event[PIPE_READ], &seltype, sizeof(seltype));
+    FXint res = ::read(event[PIPE_READ], &seltype, sizeof(seltype));
+    UNUSED_PARAMETER(res); // to make the compiler happy
 #else
     //FIXME need win32 support
 #endif
     FXSelector sel = FXSEL(SEL_THREAD, 0);
-    handle(this, sel, 0);
+    handle(this, sel, nullptr);
     return 0;
 }
 
 
 long
 FXSingleEventThread::onThreadEvent(FXObject*, FXSelector , void*) {
-    myClient->eventOccured();
+    myClient->eventOccurred();
     /*
     FXuint seltype1 = FXSELTYPE(SEL_THREAD);
     if(myTarget && myTarget->handle(this,FXSEL(seltype1,mySelector),NULL)) {
