@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2004-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2004-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    FXThreadEvent.cpp
 /// @author  Mathew Robertson
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <fxver.h>
 #define NOMINMAX
@@ -82,7 +76,7 @@ FXThreadEvent::FXThreadEvent(FXObject* tgt, FXSelector sel) : FXBaseObject(tgt,
     UNUSED_PARAMETER(res); // only used for assertion
     getApp()->addInput(event[PIPE_READ], INPUT_READ, this, ID_THREAD_EVENT);
 #else
-    event = CreateEvent(NULL, FALSE, FALSE, NULL);
+    event = CreateEvent(nullptr, FALSE, FALSE, nullptr);
     FXASSERT(event != NULL);
     getApp()->addInput(event, INPUT_READ, this, ID_THREAD_EVENT);
 #endif
@@ -136,7 +130,7 @@ long FXThreadEvent::onThreadSignal(FXObject*, FXSelector, void*) {
 #else
     //FIXME need win32 support
 #endif
-    handle(this, FXSEL(seltype, 0), NULL);
+    handle(this, FXSEL(seltype, 0), nullptr);
     return 0;
 }
 
@@ -144,7 +138,7 @@ long FXThreadEvent::onThreadSignal(FXObject*, FXSelector, void*) {
 // which is now in the main thread (ie no longer in the worker thread)
 long FXThreadEvent::onThreadEvent(FXObject*, FXSelector sel, void*) {
     FXuint seltype = FXSELTYPE(sel);
-    return target && target->handle(this, FXSEL(seltype, message), NULL);
+    return target && target->handle(this, FXSEL(seltype, message), nullptr);
 }
 
 }
