@@ -1,47 +1,43 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2005-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    MFXImageHelper.cpp
 /// @author  Daniel Krajzewicz
 /// @date    2005-05-04
-/// @version $Id: MFXImageHelper.cpp 18095 2015-03-17 09:39:00Z behrisch $
+/// @version $Id$
 ///
 // missing_desc
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2005-2015 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 
 
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <fx.h>
 #include <FXPNGImage.h>
 #include <FXJPGImage.h>
+#ifdef _MSC_VER
+#pragma warning(push)
+#pragma warning(disable: 4244) // do not warn about integer conversions
+#endif
 #include <FXTIFImage.h>
+#ifdef _MSC_VER
+#pragma warning(pop)
+#endif
 #include <utils/common/ToString.h>
 #include "MFXImageHelper.h"
 
 #include <cassert>
 
-#ifdef CHECK_MEMORY_LEAKS
-#include <foreign/nvwa/debug_new.h>
-#endif // CHECK_MEMORY_LEAKS
-
 void
 MFXImageHelper::checkSupported(FXString ext) {
     if (comparecase(ext, "png") == 0) {
@@ -64,35 +60,35 @@ FXImage*
 MFXImageHelper::loadImage(FXApp* a, const std::string& file) {
     FXString ext = FXPath::extension(file.c_str());
     checkSupported(ext);
-    FXImage* img = NULL;
+    FXImage* img = nullptr;
     if (comparecase(ext, "gif") == 0) {
-        img = new FXGIFImage(a, NULL, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
+        img = new FXGIFImage(a, nullptr, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
     } else if (comparecase(ext, "bmp") == 0) {
-        img = new FXBMPImage(a, NULL, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
+        img = new FXBMPImage(a, nullptr, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
     } else if (comparecase(ext, "xpm") == 0) {
-        img = new FXXPMImage(a, NULL, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
+        img = new FXXPMImage(a, nullptr, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
     } else if (comparecase(ext, "pcx") == 0) {
-        img = new FXPCXImage(a, NULL, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
+        img = new FXPCXImage(a, nullptr, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
     } else if (comparecase(ext, "ico") == 0 || comparecase(ext, "cur") == 0) {
-        img = new FXICOImage(a, NULL, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
+        img = new FXICOImage(a, nullptr, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
     } else if (comparecase(ext, "tga") == 0) {
-        img = new FXTGAImage(a, NULL, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
+        img = new FXTGAImage(a, nullptr, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
     } else if (comparecase(ext, "rgb") == 0) {
-        img = new FXRGBImage(a, NULL, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
+        img = new FXRGBImage(a, nullptr, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
     } else if (comparecase(ext, "xbm") == 0) {
-        img = new FXXBMImage(a, NULL, NULL, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
+        img = new FXXBMImage(a, nullptr, nullptr, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
     } else if (comparecase(ext, "png") == 0) {
-        img = new FXPNGImage(a, NULL, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
+        img = new FXPNGImage(a, nullptr, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
     } else if (comparecase(ext, "jpg") == 0 || comparecase(ext, "jpeg") == 0) {
-        img = new FXJPGImage(a, NULL, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
+        img = new FXJPGImage(a, nullptr, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
     } else if (comparecase(ext, "tif") == 0 || comparecase(ext, "tiff") == 0) {
-        img = new FXTIFImage(a, NULL, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
+        img = new FXTIFImage(a, nullptr, IMAGE_KEEP | IMAGE_SHMI | IMAGE_SHMP);
     } else {
         throw InvalidArgument("Unknown file extension '" + toString(ext.text()) + "' for image '" + file + "'!");
     }
 
     FXFileStream stream;
-    if (img != NULL && stream.open(file.c_str(), FXStreamLoad)) {
+    if (img != nullptr && stream.open(file.c_str(), FXStreamLoad)) {
         a->beginWaitCursor();
         img->loadPixels(stream);
         stream.close();
