@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2007-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2007-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    MFXMutex.cpp
 /// @author  Mathew Robertson
@@ -23,11 +21,7 @@
 /* =========================================================================
  * included modules
  * ======================================================================= */
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <fxver.h>
 #define NOMINMAX
@@ -57,7 +51,7 @@ MFXMutex::MFXMutex() : lock_(0) {
     (void)status; // only used for assertion
     pthread_mutexattr_destroy(&attr);
 #else
-    mutexHandle = CreateMutex(NULL, FALSE, NULL);
+    mutexHandle = CreateMutex(nullptr, FALSE, nullptr);
     FXASSERT(mutexHandle != NULL);
 #endif
 }
