@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    Boundary.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 #include <utility>
 
 #include "GeomHelper.h"
@@ -219,6 +213,12 @@ Boundary::crosses(const Position& p1, const Position& p2) const {
 }
 
 
+bool
+Boundary::isInitialised() const {
+    return myWasInitialised;
+}
+
+
 double
 Boundary::distanceTo2D(const Position& p) const {
     const double leftDist = myXmin - p.x();
@@ -337,6 +337,25 @@ operator<<(std::ostream& os, const Boundary& b) {
 }
 
 
+bool
+Boundary::operator==(const Boundary& b) const {
+    return (
+               myXmin == b.myXmin &&
+               myXmax == b.myXmax &&
+               myYmin == b.myYmin &&
+               myYmax == b.myYmax &&
+               myZmin == b.myZmin &&
+               myZmax == b.myZmax &&
+               myWasInitialised == b.myWasInitialised);
+}
+
+
+bool
+Boundary::operator!=(const Boundary& b) const {
+    return !(*this == b);
+}
+
+
 void
 Boundary::set(double xmin, double ymin, double xmax, double ymax) {
     myXmin = xmin;
