@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    Boundary.h
 /// @author  Daniel Krajzewicz
@@ -25,14 +23,11 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include <utility>
+
 #include "AbstractPoly.h"
 #include "Position.h"
 
@@ -44,73 +39,79 @@
  * @class Boundary
  * @brief A class that stores a 2D geometrical boundary
  */
-class Boundary
-    : public AbstractPoly {
+class Boundary : public AbstractPoly {
 public:
-    /// Constructor - the boundary is unset
+    /// @brief Constructor - the boundary is unset
     Boundary();
 
-    /// Constructor - the boundary will be build using the given values
+    /// @brief Constructor - the boundary will be build using the given values
     Boundary(double x1, double y1, double x2, double y2);
 
+    /// @brief Constructor - the boundary will be build using the given values including Z
     Boundary(double x1, double y1, double z1, double x2, double y2, double z2);
 
-    /// Destructor
+    /// @brief Destructor
     ~Boundary();
 
-    /// Resets the boundary
+    /// @brief Resets the boundary
     void reset();
 
-    /// Makes the boundary include the given coordinate
+    /// @brief Makes the boundary include the given coordinate
     void add(double x, double y, double z = 0);
 
-    /// Makes the boundary include the given coordinate
+    /// @brief Makes the boundary include the given coordinate
     void add(const Position& p);
 
-    /// Makes the boundary include the given boundary
+    /// @brief Makes the boundary include the given boundary
     void add(const Boundary& p);
 
-    /// Returns the center of the boundary
+    /// @brief Returns the center of the boundary
     Position getCenter() const;
 
-    /// Returns minimum x-coordinate
+    /// @brief Returns minimum x-coordinate
     double xmin() const;
 
-    /// Returns maximum x-coordinate
+    /// @brief Returns maximum x-coordinate
     double xmax() const;
 
-    /// Returns minimum y-coordinate
+    /// @brief Returns minimum y-coordinate
     double ymin() const;
 
-    /// Returns maximum y-coordinate
+    /// @brief Returns maximum y-coordinate
     double ymax() const;
 
-    /// Returns minimum z-coordinate
+    /// @brief Returns minimum z-coordinate
     double zmin() const;
 
-    /// Returns maximum z-coordinate
+    /// @brief Returns maximum z-coordinate
     double zmax() const;
 
-    /// Returns the width of the boudary (x-axis)
+    /// @brief Returns the width of the boudary (x-axis)
     double getWidth() const;
 
-    /// Returns the height of the boundary (y-axis)
+    /// @brief Returns the height of the boundary (y-axis)
     double getHeight() const;
 
-    /// Returns the elevation range of the boundary (z-axis)
+    /// @brief Returns the elevation range of the boundary (z-axis)
     double getZRange() const;
 
-    /// Returns whether the boundary contains the given coordinate
+    /// @name inherited from AbstractPoly
+    /// @{
+    /// @brief Returns whether the boundary contains the given coordinate
     bool around(const Position& p, double offset = 0) const;
 
-    /// Returns whether the boundary overlaps with the given polygon
+    /// @brief Returns whether the boundary overlaps with the given polygon
     bool overlapsWith(const AbstractPoly& poly, double offset = 0) const;
 
-    /// Returns whether the boundary is partially within the given polygon
+    /// @brief Returns whether the boundary is partially within the given polygon
     bool partialWithin(const AbstractPoly& poly, double offset = 0) const;
 
-    /// Returns whether the boundary crosses the given line
+    /// @brief Returns whether the boundary crosses the given line
     bool crosses(const Position& p1, const Position& p2) const;
+    /// @}
+
+    /// @brief check if Boundary is Initialised
+    bool isInitialised() const;
 
     /// @brief returns the euclidean distance in the x-y-plane
     double distanceTo2D(const Position& p) const;
@@ -118,37 +119,41 @@ public:
     /// @brief returns the euclidean distance in the x-y-plane
     double distanceTo2D(const Boundary& b) const;
 
-
-    /** @brief extends the boundary by the given amount
-     *
-     * The method returns a reference to the instance for further use */
+    /**@brief extends the boundary by the given amount
+     * @return a reference to the instance for further use
+     */
     Boundary& grow(double by);
 
-    /// Increases the width of the boundary (x-axis)
+    /// @brief Increases the width of the boundary (x-axis)
     void growWidth(double by);
 
-    /// Increases the height of the boundary (y-axis)
+    /// @brief Increases the height of the boundary (y-axis)
     void growHeight(double by);
 
-    /// flips ymin and ymax
+    /// @brief flips ymin and ymax
     void flipY();
 
-    /// Sets the boundary to the given values
+    /// @brief Sets the boundary to the given values
     void set(double xmin, double ymin, double xmax, double ymax);
 
-    /// Moves the boundary by the given amount
+    /// @brief Moves the boundary by the given amount
     void moveby(double x, double y, double z = 0);
 
-    /// Output operator
+    /// @brief Output operator
     friend std::ostream& operator<<(std::ostream& os, const Boundary& b);
 
+    /// @brief Comparison operator equal
+    bool operator==(const Boundary& b) const;
+
+    /// @brief Comparison operator not equal
+    bool operator!=(const Boundary& b) const;
+
 private:
-    /// The boundaries
+    /// @brief The boundaries
     double myXmin, myXmax, myYmin, myYmax, myZmin, myZmax;
 
-    /// Information whether the boundary was initialised
+    /// @brief Information whether the boundary was initialised
     bool myWasInitialised;
-
 };
 
 
