@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GeoConvHelper.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <map>
 #include <cmath>
@@ -55,17 +49,20 @@ int GeoConvHelper::myNumLoaded = 0;
 // ===========================================================================
 
 GeoConvHelper::GeoConvHelper(const std::string& proj, const Position& offset,
-                             const Boundary& orig, const Boundary& conv, double scale, bool inverse):
+                             const Boundary& orig, const Boundary& conv, double scale, double rot, bool inverse, bool flatten):
     myProjString(proj),
 #ifdef HAVE_PROJ
-    myProjection(0),
-    myInverseProjection(0),
-    myGeoProjection(0),
+    myProjection(nullptr),
+    myInverseProjection(nullptr),
+    myGeoProjection(nullptr),
 #endif
     myOffset(offset),
     myGeoScale(scale),
+    mySin(sin(DEG2RAD(-rot))), // rotate clockwise
+    myCos(cos(DEG2RAD(-rot))),
     myProjectionMethod(NONE),
     myUseInverseProjection(inverse),
+    myFlatten(flatten),
     myOrigBoundary(orig),
     myConvBoundary(conv) {
     if (proj == "!") {
@@ -82,7 +79,7 @@ GeoConvHelper::GeoConvHelper(const std::string& proj, const Position& offset,
     } else {
         myProjectionMethod = PROJ;
         myProjection = pj_init_plus(proj.c_str());
-        if (myProjection == 0) {
+        if (myProjection == nullptr) {
             // !!! check pj_errno
             throw ProcessError("Could not build projection!");
         }
@@ -93,18 +90,33 @@ GeoConvHelper::GeoConvHelper(const std::string& proj, const Position& offset,
 
 GeoConvHelper::~GeoConvHelper() {
 #ifdef HAVE_PROJ
-    if (myProjection != 0) {
+    if (myProjection != nullptr) {
         pj_free(myProjection);
     }
-    if (myInverseProjection != 0) {
+    if (myInverseProjection != nullptr) {
         pj_free(myInverseProjection);
     }
-    if (myGeoProjection != 0) {
+    if (myGeoProjection != nullptr) {
         pj_free(myInverseProjection);
     }
 #endif
 }
 
+bool
+GeoConvHelper::operator==(const GeoConvHelper& o) const {
+    return (
+               myProjString == o.myProjString &&
+               myOffset == o.myOffset &&
+               myProjectionMethod == o.myProjectionMethod &&
+               myOrigBoundary == o.myOrigBoundary &&
+               myConvBoundary == o.myConvBoundary &&
+               myGeoScale == o.myGeoScale &&
+               myCos == o.myCos &&
+               mySin == o.mySin &&
+               myUseInverseProjection == o.myUseInverseProjection &&
+               myFlatten == o.myFlatten
+           );
+}
 
 GeoConvHelper&
 GeoConvHelper::operator=(const GeoConvHelper& orig) {
@@ -114,27 +126,30 @@ GeoConvHelper::operator=(const GeoConvHelper& orig) {
     myOrigBoundary = orig.myOrigBoundary;
     myConvBoundary = orig.myConvBoundary;
     myGeoScale = orig.myGeoScale;
+    myCos = orig.myCos;
+    mySin = orig.mySin;
     myUseInverseProjection = orig.myUseInverseProjection;
+    myFlatten = orig.myFlatten;
 #ifdef HAVE_PROJ
-    if (myProjection != 0) {
+    if (myProjection != nullptr) {
         pj_free(myProjection);
-        myProjection = 0;
+        myProjection = nullptr;
     }
-    if (myInverseProjection != 0) {
+    if (myInverseProjection != nullptr) {
         pj_free(myInverseProjection);
-        myInverseProjection = 0;
+        myInverseProjection = nullptr;
     }
-    if (myGeoProjection != 0) {
+    if (myGeoProjection != nullptr) {
         pj_free(myGeoProjection);
-        myGeoProjection = 0;
+        myGeoProjection = nullptr;
     }
-    if (orig.myProjection != 0) {
+    if (orig.myProjection != nullptr) {
         myProjection = pj_init_plus(orig.myProjString.c_str());
     }
-    if (orig.myInverseProjection != 0) {
+    if (orig.myInverseProjection != nullptr) {
         myInverseProjection = pj_init_plus(pj_get_def(orig.myInverseProjection, 0));
     }
-    if (orig.myGeoProjection != 0) {
+    if (orig.myGeoProjection != nullptr) {
         myGeoProjection = pj_init_plus(pj_get_def(orig.myGeoProjection, 0));
     }
 #endif
@@ -146,8 +161,10 @@ bool
 GeoConvHelper::init(OptionsCont& oc) {
     std::string proj = "!"; // the default
     double scale = oc.getFloat("proj.scale");
+    double rot = oc.getFloat("proj.rotate");
     Position offset = Position(oc.getFloat("offset.x"), oc.getFloat("offset.y"));
     bool inverse = oc.exists("proj.inverse") && oc.getBool("proj.inverse");
+    bool flatten = oc.exists("flatten") && oc.getBool("flatten");
 
     if (oc.getBool("simple-projection")) {
         proj = "-";
@@ -174,7 +191,7 @@ GeoConvHelper::init(OptionsCont& oc) {
         proj = oc.getString("proj");
     }
 #endif
-    myProcessing = GeoConvHelper(proj, offset, Boundary(), Boundary(), scale, inverse);
+    myProcessing = GeoConvHelper(proj, offset, Boundary(), Boundary(), scale, rot, inverse, flatten);
     myFinal = myProcessing;
     return true;
 }
@@ -199,6 +216,9 @@ GeoConvHelper::addProjectionOptions(OptionsCont& oc) {
     oc.doRegister("proj.scale", new Option_Float(1.0));
     oc.addDescription("proj.scale", "Projection", "Scaling factor for input coordinates");
 
+    oc.doRegister("proj.rotate", new Option_Float(0.0));
+    oc.addDescription("proj.rotate", "Projection", "Rotation (clockwise degrees) for input coordinates");
+
 #ifdef HAVE_PROJ
     oc.doRegister("proj.utm", new Option_Bool(false));
     oc.addDescription("proj.utm", "Projection", "Determine the UTM zone (for a universal transversal mercator projection based on the WGS84 ellipsoid)");
@@ -262,7 +282,7 @@ GeoConvHelper::x2cartesian(Position& from, bool includeInBoundary) {
     }
     // init projection parameter on first use
 #ifdef HAVE_PROJ
-    if (myProjection == 0) {
+    if (myProjection == nullptr) {
         double x = from.x() * myGeoScale;
         switch (myProjectionMethod) {
             case DHDN_UTM: {
@@ -279,6 +299,7 @@ GeoConvHelper::x2cartesian(Position& from, bool includeInBoundary) {
                 //!!! check pj_errno
                 x = ((x - 500000.) / 1000000.) * 3; // continues with UTM
             }
+            FALLTHROUGH;
             case UTM: {
                 int zone = (int)(x + 180) / 6 + 1;
                 myProjString = "+proj=utm +zone=" + toString(zone) +
@@ -304,10 +325,10 @@ GeoConvHelper::x2cartesian(Position& from, bool includeInBoundary) {
                 break;
         }
     }
-    if (myInverseProjection != 0) {
+    if (myInverseProjection != nullptr) {
         double x = from.x();
         double y = from.y();
-        if (pj_transform(myInverseProjection, myGeoProjection, 1, 1, &x, &y, NULL)) {
+        if (pj_transform(myInverseProjection, myGeoProjection, 1, 1, &x, &y, nullptr)) {
             WRITE_WARNING("Could not transform (" + toString(x) + "," + toString(y) + ")");
         }
         from.set(double(x * RAD_TO_DEG), double(y * RAD_TO_DEG));
@@ -326,8 +347,10 @@ GeoConvHelper::x2cartesian(Position& from, bool includeInBoundary) {
 
 bool
 GeoConvHelper::x2cartesian_const(Position& from) const {
-    double x = from.x() * myGeoScale;
-    double y = from.y() * myGeoScale;
+    double x2 = from.x() * myGeoScale;
+    double y2 = from.y() * myGeoScale;
+    double x = x2 * myCos - y2 * mySin;
+    double y = x2 * mySin + y2 * myCos;
     if (myProjectionMethod == NONE) {
         from.add(myOffset);
     } else if (myUseInverseProjection) {
@@ -342,7 +365,7 @@ GeoConvHelper::x2cartesian_const(Position& from) const {
             return false;
         }
 #ifdef HAVE_PROJ
-        if (myProjection != 0) {
+        if (myProjection != nullptr) {
             projUV p;
             p.u = x * DEG_TO_RAD;
             p.v = y * DEG_TO_RAD;
@@ -364,6 +387,9 @@ GeoConvHelper::x2cartesian_const(Position& from) const {
     }
     from.set(x, y);
     from.add(myOffset);
+    if (myFlatten) {
+        from.setz(0);
+    }
     return true;
 }
 
