@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GeoConvHelper.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <map>
 #include <string>
@@ -66,7 +60,7 @@ public:
 
     /// @brief Constructor
     GeoConvHelper(const std::string& proj, const Position& offset,
-                  const Boundary& orig, const Boundary& conv, double scale = 1.0, bool inverse = false);
+                  const Boundary& orig, const Boundary& conv, double scale = 1.0, double rot = 0.0, bool inverse = false, bool flatten=false);
 
     /// @brief Destructor
     ~GeoConvHelper();
@@ -96,6 +90,10 @@ public:
         return myLoaded;
     }
 
+    static int getNumLoaded() {
+        return myNumLoaded;
+    }
+
     /**@brief compute the location attributes which will be used for output
      * based on the loaded location data, the given options and the transformations applied during processing
      */
@@ -149,12 +147,18 @@ public:
     /// @brief Returns the network base
     const Position getOffsetBase() const;
 
-    /// @brief Returns the network offset
+    /// @brief Returns the original projection definition
     const std::string& getProjString() const;
 
     /// @brief @brief writes the location element
     static void writeLocation(OutputDevice& into);
 
+    bool operator==(const GeoConvHelper& o) const;
+
+    bool operator!=(const GeoConvHelper& o) const {
+        return !(*this == o);
+    }
+
 private:
     /// @brief projection method
     enum ProjectionMethod {
@@ -186,12 +190,19 @@ private:
     /// @brief The scaling to apply to geo-coordinates
     double myGeoScale;
 
+    /// @brief The rotation to apply to geo-coordinates
+    double mySin;
+    double myCos;
+
     /// @brief Information whether no projection shall be done
     ProjectionMethod myProjectionMethod;
 
     /// @brief Information whether inverse projection shall be used
     bool myUseInverseProjection;
 
+    /// @brief whether to discard z-data
+    bool myFlatten;
+
     /// @brief The boundary before conversion (x2cartesian)
     Boundary myOrigBoundary;
 
