@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GeomConvHelper.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <utils/geom/PositionVector.h>
@@ -45,7 +39,7 @@
  */
 class GeomConvHelper {
 public:
-    /** @brief Builds a PositionVector from a string representation, reporting occured errors
+    /** @brief Builds a PositionVector from a string representation, reporting occurred errors
      *
      * It is assumed, the vector is stored as "x,y[ x,y]*" where x and y are doubles.
      * @param[in] shpdef The shape definition to parse
@@ -60,7 +54,7 @@ public:
             const char* objectid, bool& ok, bool allowEmpty, bool report = true);
 
 
-    /** @brief Builds a boundary from its string representation, reporting occured errors
+    /** @brief Builds a boundary from its string representation, reporting occurred errors
      *
      * It is assumed that the boundary is stored as a quadruple of double, divided by ','.
      * @param[in] def The boundary definition to parse
@@ -78,8 +72,8 @@ private:
     /** @brief Writes an error message into the MessageHandler
      * @param[in] report Whether errors shall be written to msg handler's error instance
      * @param[in] what Name of the parsed object ("Shape", or "Boundary")
-     * @param[in] objecttype The name of the parsed object type the error occured at
-     * @param[in] objectid The name of the parsed object type the error occured at
+     * @param[in] objecttype The name of the parsed object type the error occurred at
+     * @param[in] objectid The name of the parsed object type the error occurred at
      * @param[out] desc Error description
      */
     static void emitError(bool report, const std::string& what, const std::string& objecttype,
