@@ -1,35 +1,28 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    PositionVector.cpp
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @author  Walter Bamberger
 /// @date    Sept 2002
-/// @version $Id: PositionVector.cpp 23529 2017-03-18 10:22:36Z behrisch $
+/// @version $Id$
 ///
 // A list of positions
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 
 
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <queue>
 #include <cmath>
@@ -45,9 +38,13 @@
 #include "Position.h"
 #include "PositionVector.h"
 #include "GeomHelper.h"
-#include "Helper_ConvexHull.h"
 #include "Boundary.h"
 
+// ===========================================================================
+// static members
+// ===========================================================================
+const PositionVector PositionVector::EMPTY;
+
 // ===========================================================================
 // method definitions
 // ===========================================================================
@@ -76,6 +73,9 @@ PositionVector::~PositionVector() {}
 
 bool
 PositionVector::around(const Position& p, double offset) const {
+    if (size() < 2) {
+        return false;
+    }
     if (offset != 0) {
         PositionVector tmp(*this);
         tmp.scaleAbsolute(offset);
@@ -104,8 +104,20 @@ PositionVector::around(const Position& p, double offset) const {
 
 bool
 PositionVector::overlapsWith(const AbstractPoly& poly, double offset) const {
-    for (const_iterator i = begin(); i != end() - 1; i++) {
-        if (poly.around(*i, offset)) {
+    if (
+        // check whether one of my points lies within the given poly
+        partialWithin(poly, offset) ||
+        // check whether the polygon lies within me
+        poly.partialWithin(*this, offset)) {
+        return true;
+    }
+    if (size() >= 2) {
+        for (const_iterator i = begin(); i != end() - 1; i++) {
+            if (poly.crosses(*i, *(i + 1))) {
+                return true;
+            }
+        }
+        if (size() > 2 && poly.crosses(back(), front())) {
             return true;
         }
     }
@@ -116,6 +128,9 @@ PositionVector::overlapsWith(const AbstractPoly& poly, double offset) const {
 double
 PositionVector::getOverlapWith(const PositionVector& poly, double zThreshold) const {
     double result = 0;
+    if ((size() == 0) || (poly.size() == 0)) {
+        return result;
+    }
     // this points within poly
     for (const_iterator i = begin(); i != end() - 1; i++) {
         if (poly.around(*i)) {
@@ -191,27 +206,47 @@ PositionVector::intersectionPosition2D(const PositionVector& v1) const {
 
 const Position&
 PositionVector::operator[](int index) const {
-    if (index >= 0) {
+    /* bracket operators works as in Python. Examples:
+        - A = {'a', 'b', 'c', 'd'} (size 4)
+        - A [2] returns 'c' because 0 < 2 < 4
+        - A [100] thrown an exception because 100 > 4
+        - A [-1] returns 'd' because 4 - 1 = 3
+        - A [-100] thrown an exception because (4-100) < 0
+    */
+    if (index >= 0 && index < (int)size()) {
         return at(index);
-    } else {
+    } else if (index < 0 && -index <= (int)size()) {
         return at((int)size() + index);
+    } else {
+        throw ProcessError("Index out of range in bracket operator of PositionVector");
     }
 }
 
 
 Position&
 PositionVector::operator[](int index) {
-    if (index >= 0) {
+    /* bracket operators works as in Python. Examples:
+        - A = {'a', 'b', 'c', 'd'} (size 4)
+        - A [2] returns 'c' because 0 < 2 < 4
+        - A [100] thrown an exception because 100 > 4
+        - A [-1] returns 'd' because 4 - 1 = 3
+        - A [-100] thrown an exception because (4-100) < 0
+    */
+    if (index >= 0 && index < (int)size()) {
         return at(index);
-    } else {
+    } else if (index < 0 && -index <= (int)size()) {
         return at((int)size() + index);
+    } else {
+        throw ProcessError("Index out of range in bracket operator of PositionVector");
     }
 }
 
 
 Position
 PositionVector::positionAtOffset(double pos, double lateralOffset) const {
-    assert(size() != 0);
+    if (size() == 0) {
+        return Position::INVALID;
+    }
     const_iterator i = begin();
     double seenLength = 0;
     do {
@@ -231,6 +266,9 @@ PositionVector::positionAtOffset(double pos, double lateralOffset) const {
 
 Position
 PositionVector::positionAtOffset2D(double pos, double lateralOffset) const {
+    if (size() == 0) {
+        return Position::INVALID;
+    }
     const_iterator i = begin();
     double seenLength = 0;
     do {
@@ -246,6 +284,9 @@ PositionVector::positionAtOffset2D(double pos, double lateralOffset) const {
 
 double
 PositionVector::rotationAtOffset(double pos) const {
+    if (size() == 0) {
+        return INVALID_DOUBLE;
+    }
     if (pos < 0) {
         pos += length();
     }
@@ -274,6 +315,9 @@ PositionVector::rotationDegreeAtOffset(double pos) const {
 
 double
 PositionVector::slopeDegreeAtOffset(double pos) const {
+    if (size() == 0) {
+        return INVALID_DOUBLE;
+    }
     const_iterator i = begin();
     double seenLength = 0;
     do {
@@ -294,10 +338,13 @@ PositionVector::slopeDegreeAtOffset(double pos) const {
 Position
 PositionVector::positionAtOffset(const Position& p1, const Position& p2, double pos, double lateralOffset) {
     const double dist = p1.distanceTo(p2);
-    if (pos < 0 || dist < pos) {
+    if (pos < 0. || dist < pos) {
         return Position::INVALID;
     }
     if (lateralOffset != 0) {
+        if (dist == 0.) {
+            return Position::INVALID;
+        }
         const Position offset = sideOffset(p1, p2, -lateralOffset); // move in the same direction as Position::move2side
         if (pos == 0.) {
             return p1 + offset;
@@ -357,6 +404,9 @@ PositionVector::getPolygonCenter() const {
 
 Position
 PositionVector::getCentroid() const {
+    if (size() == 0) {
+        return Position::INVALID;
+    }
     PositionVector tmp = *this;
     if (!isClosed()) { // make sure its closed
         tmp.push_back(tmp[0]);
@@ -416,13 +466,17 @@ Position
 PositionVector::getLineCenter() const {
     if (size() == 1) {
         return (*this)[0];
+    } else {
+        return positionAtOffset(double((length() / 2.)));
     }
-    return positionAtOffset(double((length() / 2.)));
 }
 
 
 double
 PositionVector::length() const {
+    if (size() == 0) {
+        return 0;
+    }
     double len = 0;
     for (const_iterator i = begin(); i != end() - 1; i++) {
         len += (*i).distanceTo(*(i + 1));
@@ -433,6 +487,9 @@ PositionVector::length() const {
 
 double
 PositionVector::length2D() const {
+    if (size() == 0) {
+        return 0;
+    }
     double len = 0;
     for (const_iterator i = begin(); i != end() - 1; i++) {
         len += (*i).distanceTo2D(*(i + 1));
@@ -465,6 +522,9 @@ PositionVector::area() const {
 
 bool
 PositionVector::partialWithin(const AbstractPoly& poly, double offset) const {
+    if (size() < 2) {
+        return false;
+    }
     for (const_iterator i = begin(); i != end() - 1; i++) {
         if (poly.around(*i, offset)) {
             return true;
@@ -481,29 +541,35 @@ PositionVector::crosses(const Position& p1, const Position& p2) const {
 
 
 std::pair<PositionVector, PositionVector>
-PositionVector::splitAt(double where) const {
+PositionVector::splitAt(double where, bool use2D) const {
+    const double len = use2D ? length2D() : length();
     if (size() < 2) {
         throw InvalidArgument("Vector to short for splitting");
     }
-    if (where <= POSITION_EPS || where >= length() - POSITION_EPS) {
-        WRITE_WARNING("Splitting vector close to end (pos: " + toString(where) + ", length: " + toString(length()) + ")");
+    if (where < 0 || where > len) {
+        throw InvalidArgument("Invalid split position " + toString(where) + " for vector of length " + toString(len));
+    }
+    if (where <= POSITION_EPS || where >= len - POSITION_EPS) {
+        WRITE_WARNING("Splitting vector close to end (pos: " + toString(where) + ", length: " + toString(len) + ")");
     }
     PositionVector first, second;
     first.push_back((*this)[0]);
     double seen = 0;
     const_iterator it = begin() + 1;
-    double next = first.back().distanceTo(*it);
+    double next = use2D ? first.back().distanceTo2D(*it) : first.back().distanceTo(*it);
     // see how many points we can add to first
     while (where >= seen + next + POSITION_EPS) {
         seen += next;
         first.push_back(*it);
         it++;
-        next = first.back().distanceTo(*it);
+        next = use2D ? first.back().distanceTo2D(*it) : first.back().distanceTo(*it);
     }
     if (fabs(where - (seen + next)) > POSITION_EPS || it == end() - 1) {
         // we need to insert a new point because 'where' is not close to an
         // existing point or it is to close to the endpoint
-        const Position p = positionAtOffset(first.back(), *it, where - seen);
+        const Position p = (use2D
+                            ? positionAtOffset2D(first.back(), *it, where - seen)
+                            : positionAtOffset(first.back(), *it, where - seen));
         first.push_back(p);
         second.push_back(p);
     } else {
@@ -516,7 +582,7 @@ PositionVector::splitAt(double where) const {
     assert(first.size() >= 2);
     assert(second.size() >= 2);
     assert(first.back() == second.front());
-    assert(fabs(first.length() + second.length() - length()) < 2 * POSITION_EPS);
+    assert(fabs((use2D ? first.length2D() + second.length2D() : first.length() + second.length()) - len) < 2 * POSITION_EPS);
     return std::pair<PositionVector, PositionVector>(first, second);
 }
 
@@ -541,7 +607,7 @@ PositionVector::sortAsPolyCWByAngle() {
 
 void
 PositionVector::add(double xoff, double yoff, double zoff) {
-    for (int i = 0; i < static_cast<int>(size()); i++) {
+    for (int i = 0; i < (int)size(); i++) {
         (*this)[i].add(xoff, yoff, zoff);
     }
 }
@@ -555,7 +621,7 @@ PositionVector::add(const Position& offset) {
 
 void
 PositionVector::mirrorX() {
-    for (int i = 0; i < static_cast<int>(size()); i++) {
+    for (int i = 0; i < (int)size(); i++) {
         (*this)[i].mul(1, -1);
     }
 }
@@ -580,8 +646,7 @@ PositionVector::increasing_x_y_sorter::increasing_x_y_sorter() {}
 
 
 int
-PositionVector::increasing_x_y_sorter::operator()(const Position& p1,
-        const Position& p2) const {
+PositionVector::increasing_x_y_sorter::operator()(const Position& p1, const Position& p2) const {
     if (p1.x() != p2.x()) {
         return p1.x() < p2.x();
     }
@@ -595,17 +660,9 @@ PositionVector::isLeft(const Position& P0, const Position& P1,  const Position&
 }
 
 
-PositionVector
-PositionVector::convexHull() const {
-    PositionVector ret = *this;
-    ret.sortAsPolyCWByAngle();
-    return simpleHull_2D(ret);
-}
-
-
 void
 PositionVector::append(const PositionVector& v, double sameThreshold) {
-    if (size() > 0 && v.size() > 0 && back().distanceTo(v[0]) < sameThreshold) {
+    if ((size() > 0) && (v.size() > 0) && (back().distanceTo(v[0]) < sameThreshold)) {
         copy(v.begin() + 1, v.end(), back_inserter(*this));
     } else {
         copy(v.begin(), v.end(), back_inserter(*this));
@@ -655,6 +712,9 @@ PositionVector::getSubpart(double beginOffset, double endOffset) const {
 
 PositionVector
 PositionVector::getSubpart2D(double beginOffset, double endOffset) const {
+    if (size() == 0) {
+        return PositionVector();
+    }
     PositionVector ret;
     Position begPos = front();
     if (beginOffset > POSITION_EPS) {
@@ -695,6 +755,9 @@ PositionVector::getSubpart2D(double beginOffset, double endOffset) const {
 
 PositionVector
 PositionVector::getSubpartByIndex(int beginIndex, int count) const {
+    if (size() == 0) {
+        return PositionVector();
+    }
     if (beginIndex < 0) {
         beginIndex += (int)size();
     }
@@ -711,12 +774,18 @@ PositionVector::getSubpartByIndex(int beginIndex, int count) const {
 
 double
 PositionVector::beginEndAngle() const {
+    if (size() == 0) {
+        return INVALID_DOUBLE;
+    }
     return front().angleTo2D(back());
 }
 
 
 double
 PositionVector::nearest_offset_to_point2D(const Position& p, bool perpendicular) const {
+    if (size() == 0) {
+        return INVALID_DOUBLE;
+    }
     double minDist = std::numeric_limits<double>::max();
     double nearestPos = GeomHelper::INVALID_OFFSET;
     double seen = 0;
@@ -750,6 +819,9 @@ PositionVector::nearest_offset_to_point2D(const Position& p, bool perpendicular)
 
 Position
 PositionVector::transformToVectorCoordinates(const Position& p, bool extend) const {
+    if (size() == 0) {
+        return Position::INVALID;
+    }
     // @toDo this duplicates most of the code in nearest_offset_to_point2D. It should be refactored
     if (extend) {
         PositionVector extended = *this;
@@ -797,7 +869,9 @@ PositionVector::transformToVectorCoordinates(const Position& p, bool extend) con
 
 int
 PositionVector::indexOfClosest(const Position& p) const {
-    assert(size() > 0);
+    if (size() == 0) {
+        return -1;
+    }
     double minDist = std::numeric_limits<double>::max();
     double dist;
     int closest = 0;
@@ -814,6 +888,9 @@ PositionVector::indexOfClosest(const Position& p) const {
 
 int
 PositionVector::insertAtClosest(const Position& p) {
+    if (size() == 0) {
+        return -1;
+    }
     double minDist = std::numeric_limits<double>::max();
     int insertionIndex = 1;
     for (int i = 0; i < (int)size() - 1; i++) {
@@ -852,6 +929,9 @@ PositionVector::removeClosest(const Position& p) {
 std::vector<double>
 PositionVector::intersectsAtLengths2D(const PositionVector& other) const {
     std::vector<double> ret;
+    if (other.size() == 0) {
+        return ret;
+    }
     for (const_iterator i = other.begin(); i != other.end() - 1; i++) {
         std::vector<double> atSegment = intersectsAtLengths2D(*i, *(i + 1));
         copy(atSegment.begin(), atSegment.end(), back_inserter(ret));
@@ -863,6 +943,9 @@ PositionVector::intersectsAtLengths2D(const PositionVector& other) const {
 std::vector<double>
 PositionVector::intersectsAtLengths2D(const Position& lp1, const Position& lp2) const {
     std::vector<double> ret;
+    if (size() == 0) {
+        return ret;
+    }
     double pos = 0;
     for (const_iterator i = begin(); i != end() - 1; i++) {
         const Position& p1 = *i;
@@ -879,20 +962,21 @@ PositionVector::intersectsAtLengths2D(const Position& lp1, const Position& lp2)
 
 void
 PositionVector::extrapolate(const double val, const bool onlyFirst, const bool onlyLast) {
-    assert(size() > 1);
-    Position& p1 = (*this)[0];
-    Position& p2 = (*this)[1];
-    const Position offset = (p2 - p1) * (val / p1.distanceTo(p2));
-    if (!onlyLast) {
-        p1.sub(offset);
-    }
-    if (!onlyFirst) {
-        if (size() == 2) {
-            p2.add(offset);
-        } else {
-            const Position& e1 = (*this)[-2];
-            Position& e2 = (*this)[-1];
-            e2.sub((e1 - e2) * (val / e1.distanceTo(e2)));
+    if (size() > 0) {
+        Position& p1 = (*this)[0];
+        Position& p2 = (*this)[1];
+        const Position offset = (p2 - p1) * (val / p1.distanceTo(p2));
+        if (!onlyLast) {
+            p1.sub(offset);
+        }
+        if (!onlyFirst) {
+            if (size() == 2) {
+                p2.add(offset);
+            } else {
+                const Position& e1 = (*this)[-2];
+                Position& e2 = (*this)[-1];
+                e2.sub((e1 - e2) * (val / e1.distanceTo(e2)));
+            }
         }
     }
 }
@@ -900,18 +984,21 @@ PositionVector::extrapolate(const double val, const bool onlyFirst, const bool o
 
 void
 PositionVector::extrapolate2D(const double val, const bool onlyFirst) {
-    assert(size() > 1);
-    Position& p1 = (*this)[0];
-    Position& p2 = (*this)[1];
-    const Position offset = (p2 - p1) * (val / p1.distanceTo2D(p2));
-    p1.sub(offset);
-    if (!onlyFirst) {
-        if (size() == 2) {
-            p2.add(offset);
-        } else {
-            const Position& e1 = (*this)[-2];
-            Position& e2 = (*this)[-1];
-            e2.sub((e1 - e2) * (val / e1.distanceTo2D(e2)));
+    if (size() > 0) {
+        Position& p1 = (*this)[0];
+        Position& p2 = (*this)[1];
+        if (p1.distanceTo2D(p2) > 0) {
+            const Position offset = (p2 - p1) * (val / p1.distanceTo2D(p2));
+            p1.sub(offset);
+            if (!onlyFirst) {
+                if (size() == 2) {
+                    p2.add(offset);
+                } else {
+                    const Position& e1 = (*this)[-2];
+                    Position& e2 = (*this)[-1];
+                    e2.sub((e1 - e2) * (val / e1.distanceTo2D(e2)));
+                }
+            }
         }
     }
 }
@@ -939,6 +1026,7 @@ PositionVector::move2side(double amount) {
     if (size() < 2) {
         return;
     }
+    removeDoublePoints(POSITION_EPS, true);
     if (length2D() == 0) {
         return;
     }
@@ -947,11 +1035,15 @@ PositionVector::move2side(double amount) {
         if (i == 0) {
             const Position& from = (*this)[i];
             const Position& to = (*this)[i + 1];
-            shape.push_back(from - sideOffset(from, to, amount));
+            if (from != to) {
+                shape.push_back(from - sideOffset(from, to, amount));
+            }
         } else if (i == static_cast<int>(size()) - 1) {
             const Position& from = (*this)[i - 1];
             const Position& to = (*this)[i];
-            shape.push_back(to - sideOffset(from, to, amount));
+            if (from != to) {
+                shape.push_back(to - sideOffset(from, to, amount));
+            }
         } else {
             const Position& from = (*this)[i - 1];
             const Position& me = (*this)[i];
@@ -987,19 +1079,81 @@ PositionVector::move2side(double amount) {
 }
 
 
+void 
+PositionVector::move2side(std::vector<double> amount) {
+    if (size() < 2) {
+        return;
+    }
+    if (length2D() == 0) {
+        return;
+    }
+    if (size() != amount.size()) {
+        throw InvalidArgument("Numer of offsets (" + toString(amount.size()) 
+                + ") does not match number of points (" + toString(size()) + ")");
+    }
+    PositionVector shape;
+    for (int i = 0; i < static_cast<int>(size()); i++) {
+        if (i == 0) {
+            const Position& from = (*this)[i];
+            const Position& to = (*this)[i + 1];
+            if (from != to) {
+                shape.push_back(from - sideOffset(from, to, amount[i]));
+            }
+        } else if (i == static_cast<int>(size()) - 1) {
+            const Position& from = (*this)[i - 1];
+            const Position& to = (*this)[i];
+            if (from != to) {
+                shape.push_back(to - sideOffset(from, to, amount[i]));
+            }
+        } else {
+            const Position& from = (*this)[i - 1];
+            const Position& me = (*this)[i];
+            const Position& to = (*this)[i + 1];
+            PositionVector fromMe(from, me);
+            fromMe.extrapolate2D(me.distanceTo2D(to));
+            const double extrapolateDev = fromMe[1].distanceTo2D(to);
+            if (fabs(extrapolateDev) < POSITION_EPS) {
+                // parallel case, just shift the middle point
+                shape.push_back(me - sideOffset(from, to, amount[i]));
+            } else if (fabs(extrapolateDev - 2 * me.distanceTo2D(to)) < POSITION_EPS) {
+                // counterparallel case, just shift the middle point
+                PositionVector fromMe(from, me);
+                fromMe.extrapolate2D(amount[i]);
+                shape.push_back(fromMe[1]);
+            } else {
+                Position offsets = sideOffset(from, me, amount[i]);
+                Position offsets2 = sideOffset(me, to, amount[i]);
+                PositionVector l1(from - offsets, me - offsets);
+                PositionVector l2(me - offsets2, to - offsets2);
+                Position meNew  = l1.intersectionPosition2D(l2[0], l2[1], 100);
+                if (meNew == Position::INVALID) {
+                    throw InvalidArgument("no line intersection");
+                }
+                meNew = meNew + Position(0, 0, me.z());
+                shape.push_back(meNew);
+            }
+            // copy original z value
+            shape.back().set(shape.back().x(), shape.back().y(), me.z());
+        }
+    }
+    *this = shape;
+}
+
 double
 PositionVector::angleAt2D(int pos) const {
-    assert((int)size() > pos + 1);
-    return (*this)[pos].angleTo2D((*this)[pos + 1]);
+    if ((pos + 1) < (int)size()) {
+        return (*this)[pos].angleTo2D((*this)[pos + 1]);
+    } else {
+        return INVALID_DOUBLE;
+    }
 }
 
 
 void
 PositionVector::closePolygon() {
-    if (size() == 0 || (*this)[0] == back()) {
-        return;
+    if ((size() != 0) && ((*this)[0] != back())) {
+        push_back((*this)[0]);
     }
-    push_back((*this)[0]);
 }
 
 
@@ -1055,9 +1209,36 @@ PositionVector::push_front_noDoublePos(const Position& p) {
 }
 
 
+void
+PositionVector::insert_noDoublePos(const std::vector<Position>::iterator& at, const Position& p) {
+    if (at == begin()) {
+        push_front_noDoublePos(p);
+    } else if (at == end()) {
+        push_back_noDoublePos(p);
+    } else {
+        if (!p.almostSame(*at) && !p.almostSame(*(at - 1))) {
+            insert(at, p);
+        }
+    }
+}
+
+
 bool
 PositionVector::isClosed() const {
-    return size() >= 2 && (*this)[0] == back();
+    return (size() >= 2) && ((*this)[0] == back());
+}
+
+
+bool 
+PositionVector::isNAN() const {
+    // iterate over all positions and check if is NAN
+    for (auto i = begin(); i != end(); i++) {
+        if (i->isNAN()) {
+            return true;
+        }
+    }
+    // all ok, then return false
+    return false;
 }
 
 
@@ -1079,22 +1260,46 @@ PositionVector::removeDoublePoints(double minDist, bool assertLength) {
 
 bool
 PositionVector::operator==(const PositionVector& v2) const {
-    if (size() == v2.size()) {
-        for (int i = 0; i < (int)size(); i++) {
-            if ((*this)[i] != v2[i]) {
-                return false;
-            }
-        }
-        return true;
-    } else {
-        return false;
-    }
+    return static_cast<vp>(*this) == static_cast<vp>(v2);
 }
 
 
+bool
+PositionVector::operator!=(const PositionVector& v2) const {
+    return static_cast<vp>(*this) != static_cast<vp>(v2);
+}
+
+PositionVector
+PositionVector::operator-(const PositionVector& v2) const {
+    if (length() != v2.length()) {
+        WRITE_ERROR("Trying to substract PositionVectors of different lengths.");
+    }
+    PositionVector pv;
+    auto i1 = begin();
+    auto i2 = v2.begin();
+    while (i1 != end()) {
+        pv.add(*i1 - *i2);
+    }
+    return pv;
+}
+
+PositionVector
+PositionVector::operator+(const PositionVector& v2) const {
+    if (length() != v2.length()) {
+        WRITE_ERROR("Trying to substract PositionVectors of different lengths.");
+    }
+    PositionVector pv;
+    auto i1 = begin();
+    auto i2 = v2.begin();
+    while (i1 != end()) {
+        pv.add(*i1 + *i2);
+    }
+    return pv;
+}
+
 bool
 PositionVector::hasElevation() const {
-    if (size() > 2) {
+    if (size() < 2) {
         return false;
     }
     for (const_iterator i = begin(); i != end() - 1; i++) {
@@ -1145,7 +1350,7 @@ PositionVector::intersects(const Position& p11, const Position& p12, const Posit
             }
         }
         if (a != -1e12) {
-            if (x != 0) {
+            if (x != nullptr) {
                 if (p11.x() != p12.x()) {
                     *mu = (a - p11.x()) / (p12.x() - p11.x());
                     *x = a;
@@ -1181,7 +1386,7 @@ PositionVector::intersects(const Position& p11, const Position& p12, const Posit
             return false;
         }
     }
-    if (x != 0) {
+    if (x != nullptr) {
         *x = p11.x() + mua * (p12.x() - p11.x());
         *y = p11.y() + mua * (p12.y() - p11.y());
         *mu = mua;
@@ -1272,14 +1477,17 @@ PositionVector::getOrthogonal(const Position& p, double extend, bool before, dou
 PositionVector
 PositionVector::smoothedZFront(double dist) const {
     PositionVector result = *this;
+    if (size() == 0) {
+        return result;
+    }
     const double z0 = (*this)[0].z();
     // the z-delta of the first segment
     const double dz = (*this)[1].z() - z0;
     // if the shape only has 2 points it is as smooth as possible already
     if (size() > 2 && dz != 0) {
-        dist = MIN2(dist, length());
+        dist = MIN2(dist, length2D());
         // check wether we need to insert a new point at dist
-        Position pDist = positionAtOffset(dist);
+        Position pDist = positionAtOffset2D(dist);
         int iLast = indexOfClosest(pDist);
         // prevent close spacing to reduce impact of rounding errors in z-axis
         if (pDist.distanceTo2D((*this)[iLast]) > POSITION_EPS * 20) {
@@ -1298,6 +1506,41 @@ PositionVector::smoothedZFront(double dist) const {
 }
 
 
+PositionVector
+PositionVector::interpolateZ(double zStart, double zEnd) const {
+    PositionVector result = *this;
+    if (size() == 0) {
+        return result;
+    }
+    result[0].setz(zStart);
+    result[-1].setz(zEnd);
+    const double dz = zEnd - zStart;
+    const double length = length2D();
+    double seen = 0;
+    for (int i = 1; i < (int)size() - 1; ++i) {
+        seen += result[i].distanceTo2D(result[i - 1]);
+        result[i].setz(zStart + dz * seen / length);
+    }
+    return result;
+}
+
+PositionVector
+PositionVector::resample(double maxLength) const {
+    PositionVector result;
+    if (maxLength == 0) {
+        return result;
+    }
+    const double length = length2D();
+    if (length < POSITION_EPS) {
+        return result;
+    }
+    maxLength = length / ceil(length / maxLength);
+    for (double pos = 0; pos <= length; pos += maxLength) {
+        result.push_back(positionAtOffset2D(pos));
+    }
+    return result;
+}
+
 double
 PositionVector::offsetAtIndex2D(int index) const {
     if (index < 0 || index >= (int)size()) {
@@ -1312,12 +1555,18 @@ PositionVector::offsetAtIndex2D(int index) const {
 
 
 double
-PositionVector::getMaxGrade() const {
+PositionVector::getMaxGrade(double& maxJump) const {
     double result = 0;
     for (int i = 1; i < (int)size(); ++i) {
         const Position& p1 = (*this)[i - 1];
         const Position& p2 = (*this)[i];
-        result = MAX2(result, (double)fabs((p1.z() - p2.z()) / p1.distanceTo2D(p2)));
+        const double distZ = fabs(p1.z() - p2.z());
+        const double dist2D = p1.distanceTo2D(p2);
+        if (dist2D == 0) {
+            maxJump = MAX2(maxJump, distZ);
+        } else {
+            result = MAX2(result, distZ / dist2D);
+        }
     }
     return result;
 }
