@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIDesigns.h
 /// @author  Pablo Alvarez Lopez
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <fx.h>
 
@@ -45,8 +39,12 @@
 /// @brief text field extended over Frame with thick frame and limited to Doubles/doubles
 #define GUIDesignTextFieldReal              (FRAME_THICK | LAYOUT_FILL_X | LAYOUT_FIX_HEIGHT | TEXTFIELD_REAL), 0, 0, 0, 23, 2, 2, 2, 2
 
+/// @brief text field with thick frame and size of 100x23
+#define GUIDesignTextFielWidth100           (FRAME_THICK | LAYOUT_FIX_WIDTH | LAYOUT_FIX_HEIGHT), 0, 0, 100, 23, 2, 2, 2, 2
+
 /// @brief Num of column of text field
 #define GUIDesignTextFieldNCol              1
+
 /// @}
 
 
@@ -67,8 +65,9 @@
 /// @brief button only with icon     (46x23)
 #define GUIDesignButtonIconRectangular      (FRAME_THICK | FRAME_RAISED | LAYOUT_FIX_WIDTH | LAYOUT_FIX_HEIGHT), 0, 0, 46, 23, 2, 2, 2, 2
 
-/// @brief button used in breakpoint editor
-#define GUIDesignButtonBreakpoint           (ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED), 0, 0, 0, 0, 4, 4, 3, 3
+/// @brief button rectangular with thick and raise frame with a size of 100x23
+#define GUIDesignButtonRectangular100x23    (FRAME_THICK | FRAME_RAISED | ICON_BEFORE_TEXT | JUSTIFY_CENTER_X | JUSTIFY_CENTER_Y | LAYOUT_FIX_WIDTH | LAYOUT_FIX_HEIGHT), 0, 0, 100, 23, 2, 2, 2, 2
+
 /// @}
 
 
@@ -114,6 +113,9 @@
 
 /// @brief checkButton without thick extended over the frame used for attributes
 #define GUIDesignCheckButtonAttribute       (CHECKBUTTON_NORMAL | JUSTIFY_CENTER_Y | LAYOUT_FIX_HEIGHT | JUSTIFY_LEFT), 0, 0, 0, 23, 2, 2, 2, 2
+
+/// @brief checkButton with thick extended over the frame used for attributes
+#define GUIDesignCheckButtonAttributeLabel  (CHECKBUTTON_NORMAL | JUSTIFY_CENTER_Y | LAYOUT_FIX_WIDTH | LAYOUT_FIX_HEIGHT | JUSTIFY_LEFT | FRAME_THICK), 0, 0, 100, 23, 2, 2, 2, 2
 /// @}
 
 
@@ -145,7 +147,7 @@
 /// @brief label extended over frame without thick and with text justify to right and height of 23
 #define GUIDesignLabelRight                 (JUSTIFY_RIGHT | LAYOUT_FILL_X | ICON_BEFORE_TEXT | LAYOUT_FIX_HEIGHT), 0, 0, 0, 23, 2, 2, 2, 2
 
-/// @brief label extended over frame without thickand  with text justify to center and height of 23
+/// @brief label extended over frame without thick and with text justify to center and height of 23
 #define GUIDesignLabelCenter                (JUSTIFY_NORMAL | LAYOUT_FILL_X | ICON_BEFORE_TEXT | LAYOUT_FIX_HEIGHT), 0, 0, 0, 23, 2, 2, 2, 2
 
 /// @brief label extended over frame with thick and with text justify to left and height of 23
@@ -163,8 +165,8 @@
 /// @brief label extended over the matrix column with thick frame and height of 23
 #define GUIDesignLabelAttribute             (FRAME_THICK | LAYOUT_FIX_WIDTH | LAYOUT_FIX_HEIGHT | ICON_BEFORE_TEXT), 0, 0, 100, 23, 2, 2, 2, 2
 
-/// @brief label extended over over frame without thickand with text justify to center and withouht vertical spaces
-#define GUIDesignLabelAboutInfo             (JUSTIFY_NORMAL | LAYOUT_FILL_X | ICON_BEFORE_TEXT), 0, 0, 0, 0, 2, 2, 0, 0
+/// @brief label extended over frame without thick and with text justify to center and without vertical spaces
+#define GUIDesignLabelAboutInfo             (JUSTIFY_LEFT | LAYOUT_FILL_X | ICON_BEFORE_TEXT), 0, 0, 0, 0, 2, 2, 0, 0
 
 /// @brief label ticked filled only with an icon of 32x32
 #define GUIDesignLabelIcon32x32Thicked      (FRAME_THICK | ICON_BEFORE_TEXT | LAYOUT_FIX_HEIGHT | LAYOUT_FIX_WIDTH), 0, 0, 24, 23, 2, 2, 2, 2
@@ -172,14 +174,18 @@
 /// @brief label ticked filled used for VClasses. It uses icons of 64x32 pixels
 #define GUIDesignLabelIcon64x32Thicked      (FRAME_THICK | ICON_BEFORE_TEXT | LAYOUT_FIX_WIDTH | LAYOUT_FIX_HEIGHT), 0, 0, 94, 46, 2, 2, 2, 2
 
-/// @brief design for label with icon of 64x64 px
-#define GUIDesignLabelIcon64x64noSpacing    (LAYOUT_CENTER_Y | LAYOUT_CENTER_X | LAYOUT_FIX_WIDTH | LAYOUT_FIX_HEIGHT ), 0, 0, 64, 64, 0, 0, 0, 0
+/// @brief design for label with icon
+#define GUIDesignLabelIcon                  (LAYOUT_CENTER_Y | LAYOUT_CENTER_X ), 0, 0, 0, 0, 2, 2, 0, 0
 
 /// @brief label ticked filled extended over frame used for VClasses. can be used by icons of 64x32 pixels
 #define GUIDesignLabelIconExtendedx46Ticked (FRAME_THICK | ICON_BEFORE_TEXT | LAYOUT_FILL_X | LAYOUT_FIX_HEIGHT), 0, 0, 0, 46, 2, 2, 2, 2
 
 /// @brief label extended over frame without thick and with text justify to left, used to show information in frames
 #define GUIDesignLabelFrameInformation      (JUSTIFY_LEFT | LAYOUT_FILL_X | ICON_BEFORE_TEXT), 0, 0, 0, 0, 2, 2, 2, 2
+
+/// @brief label with thick, text justify to left and size of 100x23
+#define GUIDesignLabelThick100              (FRAME_THICK | ICON_BEFORE_TEXT | LAYOUT_FIX_WIDTH | LAYOUT_FIX_HEIGHT), 0, 0, 100, 23, 2, 2, 2, 2
+
 /// @}
 
 
@@ -203,10 +209,10 @@
 /// @name FXPackers
 /// @{
 /// @brief Horizontal frame extended over frame parent
-#define GUIDesignHorizontalFrame            (LAYOUT_FILL_X)
+#define GUIDesignHorizontalFrame            (LAYOUT_FILL_X), 0, 0, 0, 0, 4, 4, 4, 4, 4, 4
 
 /// @brief Vertical frame extended over frame parent
-#define GUIDesignVerticalFrame              (LAYOUT_FILL_Y)
+#define GUIDesignVerticalFrame              (LAYOUT_FILL_Y), 0, 0, 0, 0, 4, 4, 4, 4, 4, 4
 
 /// @brief Horizontal frame used for pack icons
 #define GUIDesignHorizontalFrameIcons       (LAYOUT_FILL_X | FRAME_THICK), 0, 0, 0, 0, 0, 0, 0, 0, 2, 2
@@ -220,11 +226,20 @@
 /// @brief Group box design extended over frame
 #define GUIDesignGroupBoxFrame              (LAYOUT_FILL_X | FRAME_GROOVE | GROUPBOX_TITLE_CENTER)
 
+/// @brief Group box design extended over frame (X and Y)
+#define GUIDesignGroupBoxFrameFill          (LAYOUT_FILL_X | LAYOUT_FILL_Y | FRAME_GROOVE | GROUPBOX_TITLE_CENTER)
+
+/// @brief Group box design for elements of width 100
+#define GUIDesignGroupBoxFrame100           (LAYOUT_FIX_WIDTH | FRAME_GROOVE | GROUPBOX_TITLE_CENTER), 0, 0, 112, 0, 4, 4, 4, 4, 4, 4
+
 /// @brief FXMatrix used to pack values in Viewsettings
 #define GUIDesignMatrixViewSettings         (LAYOUT_FILL_X | LAYOUT_BOTTOM | LAYOUT_LEFT | MATRIX_BY_COLUMNS), 0, 0, 0, 0, 10, 10, 10, 10, 5, 5
 
 /// @brief Matrix design extended over Frame and used for represent attributes and their values (Deprecated)
 #define GUIDesignMatrixAttributes           (LAYOUT_FILL_X | MATRIX_BY_COLUMNS | PACK_UNIFORM_WIDTH)
+
+/// @brief Matrix for pack GLTypes (used in GNESelectorFrame)
+#define GUIDesignMatrixLockGLTypes          (LAYOUT_FILL_X | LAYOUT_BOTTOM | LAYOUT_LEFT | MATRIX_BY_COLUMNS), 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
 /// @}
 
 
@@ -391,11 +406,29 @@
 
 /// @name design for dialog boxs
 /// @{
-/// @brief design for standard dialog box     (for example, about dialog)
+/// @brief design for standard dialog box with close button (for example, about dialog)
 #define GUIDesignDialogBox                      (DECOR_CLOSE | DECOR_TITLE)
 
+/// @brief design for standard dialog box that can be stretched (But not shrinked)
+#define GUIDesignDialogBoxStretchable           (DECOR_CLOSE | DECOR_TITLE | DECOR_STRETCHABLE)
+
+/// @brief design for standard dialog box that can be schinked (But not stretched)
+#define GUIDesignDialogBoxShrinkable            (DECOR_CLOSE | DECOR_TITLE | DECOR_SHRINKABLE)
+
+/// @brief design for standard dialog box (for example, about dialog)
+#define GUIDesignDialogBoxResizable             (DECOR_CLOSE | DECOR_TITLE | DECOR_RESIZE)
+
 /// @brief design for dialog box with specift width and height     (for example, additional dialogs)
 #define GUIDesignDialogBoxExplicit              (DECOR_CLOSE | DECOR_TITLE | LAYOUT_EXPLICIT)
+
+/// @brief design for dialog box with specift width and height that can be stretched (But not shrinked)
+#define GUIDesignDialogBoxExplicitStretchable   (DECOR_CLOSE | DECOR_TITLE | LAYOUT_EXPLICIT | DECOR_STRETCHABLE)
+
+/// @brief design for dialog box with specift width and height that can be schinked (But not stretched)
+#define GUIDesignDialogBoxExplicitShrinkable    (DECOR_CLOSE | DECOR_TITLE | LAYOUT_EXPLICIT | DECOR_SHRINKABLE)
+
+/// @brief design for dialog box with specift width and height and resizable
+#define GUIDesignDialogBoxExplicitResizable     (DECOR_CLOSE | DECOR_TITLE | LAYOUT_EXPLICIT | DECOR_RESIZE)
 /// @}
 
 
@@ -404,6 +437,9 @@
 /// @brief design for table extended over frame
 #define GUIDesignTable                          (LAYOUT_FILL_X | LAYOUT_FILL_Y)
 
+/// @brief design for table extended over frame that cannot be edited
+#define GUIDesignTableNotEditable               (LAYOUT_FILL_X | LAYOUT_FILL_Y | TABLE_READONLY)
+
 /// @brief design for table extended over frame but with limited Height
 #define GUIDesignTableLimitedHeight             (LAYOUT_FILL_X | LAYOUT_FIX_HEIGHT)
 
@@ -414,12 +450,51 @@
 #define GUIDesignTableIconCellWidth             23
 /// @}
 
+
+/// @name design for Chooser (locator) and breakpoint dialogs
+/// @{
+/// @brief design for Chooser dialog specifying size
+#define GUIDesignChooserDialog                  (DECOR_ALL), 20, 20, 300, 300
+
+/// @brief design for Chooser buttons
+#define GUIDesignChooserButtons                 (ICON_BEFORE_TEXT | LAYOUT_FIX_WIDTH | LAYOUT_FIX_HEIGHT | FRAME_THICK | FRAME_RAISED), 0, 0, 150, 23, 2, 2, 2, 2
+
+/// @brief design for Chooser TextField
+#define GUIDesignChooserTextField               (LAYOUT_FILL_X | LAYOUT_FIX_HEIGHT | FRAME_THICK | FRAME_SUNKEN), 0, 0, 0, 23, 2, 2, 2, 2
+
+/// @brief design for Chooser List
+#define GUIDesignChooserListSingle              (LIST_SINGLESELECT | LAYOUT_FILL_X | LAYOUT_FILL_Y | FRAME_SUNKEN | FRAME_THICK), 0, 0, 0, 0
+
+/// @brief design for Chooser List
+#define GUIDesignChooserListMultiple            (LIST_MULTIPLESELECT | LAYOUT_FILL_X | LAYOUT_FILL_Y | FRAME_SUNKEN | FRAME_THICK), 0, 0, 0, 0
+
+/// @brief design for Breakpoint table
+#define GUIDesignBreakpointTable                (LAYOUT_FILL_X | LAYOUT_FILL_Y | FRAME_SUNKEN | FRAME_THICK), 0, 0, 0, 0
+
+/// @brief Height of breakpoint Table header
+#define GUIDesignBreakpointTableHeaderHeight    23
+
+/// @brief design for Chooser Layout left
+#define GUIDesignChooserLayoutLeft              (LAYOUT_FILL_X | LAYOUT_FILL_Y | LAYOUT_TOP), 0, 0, 0, 0, 4, 4, 4, 4
+
+/// @brief design for Chooser Layout right
+#define GUIDesignChooserLayoutRight             (LAYOUT_TOP), 0, 0, 0, 0, 4, 4, 4, 4
+
+/// @brief design for Chooser  Layout list
+#define GUIDesignChooserLayoutList              (LAYOUT_FILL_X | LAYOUT_FILL_Y | LAYOUT_TOP | FRAME_THICK | FRAME_SUNKEN), 0, 0, 0, 0, 0, 0, 0, 0
+
+/// @}
+
+
 /// @brief Tree list used in frames to represent childs of elements
 #define GUIDesignTreeListFrame                  (TREELIST_SHOWS_LINES | TREELIST_SHOWS_BOXES | TREELIST_SINGLESELECT | FRAME_SUNKEN | FRAME_THICK | LAYOUT_FILL_X | LAYOUT_FIX_HEIGHT), 0, 0, 0, 200
 
 /// @brief design for FXLists
 #define GUIDesignList                           (FRAME_NORMAL | LAYOUT_FILL_X | LAYOUT_FIX_HEIGHT | LIST_NORMAL)
 
+/// @brief design for FXLists that only allow a single selected elements
+#define GUIDesignListSingleElement              (FRAME_NORMAL | LAYOUT_FILL_X | LAYOUT_FIX_HEIGHT | LIST_SINGLESELECT)
+
 /// @brief design for FXLists
 #define GUIDesignListExtended                   (LIST_NORMAL | FRAME_SUNKEN | FRAME_THICK | LAYOUT_FILL_X | LAYOUT_FILL_Y)
 
