@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIDialog_GLChosenEditor.h
 /// @author  Daniel Krajzewicz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <vector>
@@ -58,28 +52,20 @@ class GUIDialog_GLChosenEditor : public FXMainWindow, public GUISelectedStorage:
     FXDECLARE(GUIDialog_GLChosenEditor)
 
 public:
-    /** @brief Constructor
-     *
-     * Notifies both the parent and the storage about being initialised.
-     *
+    /** @brief Constructor (Notifies both the parent and the storage about being initialised)
      * @param[in] parent The parent window
      * @param[in] str The storage of object selections to use
      */
-    GUIDialog_GLChosenEditor(GUIMainWindow* parent,
-                             GUISelectedStorage* str);
+    GUIDialog_GLChosenEditor(GUIMainWindow* parent, GUISelectedStorage* str);
 
-
-    /** @brief Destructor
-     *
-     * Notifies both the parent and the storage about being destroyed.
-     */
+    /// @brief Destructor (Notifies both the parent and the storage about being destroyed)
     ~GUIDialog_GLChosenEditor();
 
-
-    /** @brief Rebuilds the entire list
-     */
+    /// @brief Rebuilds the entire list
     void rebuildList();
 
+    // @brief called if the global selection changes
+    void selectionUpdated();
 
     /// @name FOX-callbacks
     /// @{
@@ -94,7 +80,6 @@ public:
      */
     long onCmdLoad(FXObject*, FXSelector, void*);
 
-
     /** @brief Called when the user presses the Save-button
      *
      * Opens a file dialog and forces the selection container to save the list
@@ -120,7 +105,6 @@ public:
      */
     long onCmdClear(FXObject*, FXSelector, void*);
 
-
     /** @brief Called when the user presses the Close-button
      *
      * Closes itself.
@@ -128,9 +112,9 @@ public:
     long onCmdClose(FXObject*, FXSelector, void*);
     /// @}
 
-
-    // called if the global selection changes
-    void selectionUpdated();
+protected:
+    /// FOX needs this
+    GUIDialog_GLChosenEditor() {}
 
 private:
     /// @brief The list that holds the ids
@@ -141,11 +125,6 @@ private:
 
     /// @brief The storage
     GUISelectedStorage* myStorage;
-
-protected:
-    /// FOX needs this
-    GUIDialog_GLChosenEditor() { }
-
 };
 
 
