@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2003-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2003-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIMessageWindow.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <cassert>
 #include <utils/common/MsgHandler.h>
@@ -49,18 +43,19 @@ bool GUIMessageWindow::myLocateLinks = true;
 // method definitions
 // ===========================================================================
 GUIMessageWindow::GUIMessageWindow(FXComposite* parent) :
-    FXText(parent, 0, 0, 0, 0, 0, 0, 50),
-    myStyles(new FXHiliteStyle[7]),
-    myErrorRetriever(0),
-    myMessageRetriever(0),
-    myWarningRetriever(0) {
+    FXText(parent, nullptr, 0, 0, 0, 0, 0, 50),
+    myStyles(new FXHiliteStyle[8]),
+    myErrorRetriever(nullptr),
+    myMessageRetriever(nullptr),
+    myWarningRetriever(nullptr) {
     setStyled(true);
     setEditable(false);
-    const FXColor white = FXRGB(0xff, 0xff, 0xff);
-    const FXColor blue  = FXRGB(0x00, 0x00, 0x88);
-    const FXColor green = FXRGB(0x00, 0x88, 0x00);
-    const FXColor red   = FXRGB(0x88, 0x00, 0x00);
-    const FXColor yellow = FXRGB(0xe6, 0x98, 0x00);
+    const FXColor white   = FXRGB(0xff, 0xff, 0xff);
+    const FXColor blue    = FXRGB(0x00, 0x00, 0x88);
+    const FXColor green   = FXRGB(0x00, 0x88, 0x00);
+    const FXColor red     = FXRGB(0x88, 0x00, 0x00);
+    const FXColor yellow  = FXRGB(0xe6, 0x98, 0x00);
+    const FXColor fuchsia = FXRGB(0x88, 0x00, 0x88);
     // set separator style
     myStyles[0].normalForeColor = blue;
     myStyles[0].normalBackColor = white;
@@ -91,6 +86,11 @@ GUIMessageWindow::GUIMessageWindow(FXComposite* parent) :
     myStyles[3].hiliteForeColor = yellow;
     myStyles[6] = myStyles[3];
     myStyles[6].style = STYLE_UNDERLINE;
+    // set GLDebug text style
+    myStyles[7] = myStyles[0];
+    myStyles[7].normalForeColor = fuchsia;
+    myStyles[7].selectBackColor = fuchsia;
+    myStyles[7].hiliteForeColor = fuchsia;
     //
     setHiliteStyles(myStyles);
 }
@@ -127,7 +127,7 @@ GUIMessageWindow::getActiveStringObject(const FXString& text, const FXint pos, c
             return GUIGlObjectStorage::gIDStorage.getObjectBlocking(type + ":" + id);
         }
     }
-    return 0;
+    return nullptr;
 }
 
 
@@ -140,10 +140,10 @@ GUIMessageWindow::setCursorPos(FXint pos, FXbool notify) {
         if (viewIDs.empty()) {
             return;
         }
-        GUIGlChildWindow* const child = dynamic_cast<GUIGlChildWindow*>(main->getViewByID(viewIDs[0]));
+        GUIGlChildWindow* const child = main->getViewByID(viewIDs[0]);
         const FXString text = getText();
         const GUIGlObject* const glObj = getActiveStringObject(text, pos, lineStart(pos), lineEnd(pos));
-        if (glObj != 0) {
+        if (glObj != nullptr) {
             child->setView(glObj->getGlID());
             GUIGlObjectStorage::gIDStorage.unblockObject(glObj->getGlID());
             if (getApp()->getKeyState(KEY_Control_L)) {
@@ -162,15 +162,23 @@ GUIMessageWindow::appendMsg(GUIEventType eType, const std::string& msg) {
     // build the styled message
     FXint style = 1;
     switch (eType) {
-        case EVENT_ERROR_OCCURED:
+        case EVENT_DEBUG_OCCURRED:
+            // color: blue
+            style = 0;
+            break;
+        case EVENT_GLDEBUG_OCCURRED:
+            // color: fuchsia
+            style = 7;
+            break;
+        case EVENT_ERROR_OCCURRED:
             // color: red
             style = 2;
             break;
-        case EVENT_WARNING_OCCURED:
+        case EVENT_WARNING_OCCURRED:
             // color: yellow
             style = 3;
             break;
-        case EVENT_MESSAGE_OCCURED:
+        case EVENT_MESSAGE_OCCURRED:
             // color: green
             style = 1;
             break;
@@ -182,7 +190,7 @@ GUIMessageWindow::appendMsg(GUIEventType eType, const std::string& msg) {
         FXint pos = text.find("'");
         while (pos >= 0) {
             const GUIGlObject* const glObj = getActiveStringObject(text, pos + 1, 0, text.length());
-            if (glObj != 0) {
+            if (glObj != nullptr) {
                 GUIGlObjectStorage::gIDStorage.unblockObject(glObj->getGlID());
                 FXString insText = text.left(pos + 1);
                 FXText::appendStyledText(insText, style + 1);
@@ -234,13 +242,17 @@ GUIMessageWindow::clear() {
 
 void
 GUIMessageWindow::registerMsgHandlers() {
-    if (myMessageRetriever == 0) {
+    if (myMessageRetriever == nullptr) {
         // initialize only if registration is requested
-        myMessageRetriever = new MsgOutputDevice(this, EVENT_MESSAGE_OCCURED);
-        myErrorRetriever = new MsgOutputDevice(this, EVENT_ERROR_OCCURED);
-        myWarningRetriever = new MsgOutputDevice(this, EVENT_WARNING_OCCURED);
+        myMessageRetriever = new MsgOutputDevice(this, EVENT_MESSAGE_OCCURRED);
+        myErrorRetriever = new MsgOutputDevice(this, EVENT_ERROR_OCCURRED);
+        myDebugRetriever = new MsgOutputDevice(this, EVENT_DEBUG_OCCURRED);
+        myGLDebugRetriever = new MsgOutputDevice(this, EVENT_GLDEBUG_OCCURRED);
+        myWarningRetriever = new MsgOutputDevice(this, EVENT_WARNING_OCCURRED);
     }
     MsgHandler::getMessageInstance()->addRetriever(myMessageRetriever);
+    MsgHandler::getDebugInstance()->addRetriever(myDebugRetriever);
+    MsgHandler::getGLDebugInstance()->addRetriever(myGLDebugRetriever);
     MsgHandler::getErrorInstance()->addRetriever(myErrorRetriever);
     MsgHandler::getWarningInstance()->addRetriever(myWarningRetriever);
 }
@@ -249,6 +261,8 @@ GUIMessageWindow::registerMsgHandlers() {
 void
 GUIMessageWindow::unregisterMsgHandlers() {
     MsgHandler::getMessageInstance()->removeRetriever(myMessageRetriever);
+    MsgHandler::getDebugInstance()->removeRetriever(myDebugRetriever);
+    MsgHandler::getGLDebugInstance()->removeRetriever(myGLDebugRetriever);
     MsgHandler::getErrorInstance()->removeRetriever(myErrorRetriever);
     MsgHandler::getWarningInstance()->removeRetriever(myWarningRetriever);
 }
