@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIParameterTableWindow.cpp
 /// @author  Daniel Krajzewicz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <fx.h>
@@ -66,7 +60,7 @@ std::vector<GUIParameterTableWindow*> GUIParameterTableWindow::myContainer;
 // method definitions
 // ===========================================================================
 GUIParameterTableWindow::GUIParameterTableWindow(GUIMainWindow& app, GUIGlObject& o, int noRows) :
-    FXMainWindow(app.getApp(), (o.getFullName() + " Parameter").c_str(), NULL, NULL, DECOR_ALL, 20, 20, 500, (FXint)((noRows + numParams(&o))  * 20 + 60)),
+    FXMainWindow(app.getApp(), (o.getFullName() + " Parameter").c_str(), nullptr, nullptr, DECOR_ALL, 20, 20, 500, (FXint)((noRows + numParams(&o))  * 20 + 60)),
     myObject(&o),
     myApplication(&app),
     myCurrentPos(0) {
@@ -104,7 +98,7 @@ GUIParameterTableWindow::~GUIParameterTableWindow() {
     for (std::vector<GUIParameterTableItemInterface*>::iterator i = myItems.begin(); i != myItems.end(); ++i) {
         delete(*i);
     }
-    if (myObject != 0) {
+    if (myObject != nullptr) {
         myObject->removeParameterTable(this);
     }
     myLock.unlock();
@@ -119,7 +113,7 @@ GUIParameterTableWindow::~GUIParameterTableWindow() {
 void
 GUIParameterTableWindow::removeObject(GUIGlObject* /*i*/) {
     AbstractMutex::ScopedLocker locker(myLock);
-    myObject = 0;
+    myObject = nullptr;
 }
 
 
@@ -156,12 +150,12 @@ GUIParameterTableWindow::onRightButtonPress(FXObject* sender, FXSelector sel, vo
     if (!i->dynamic()) {
         return 1;
     }
-    if (myObject == 0) {
+    if (myObject == nullptr) {
         return 1;
     }
 
     GUIParam_PopupMenuInterface* p = new GUIParam_PopupMenuInterface(*myApplication, *this, *myObject, i->getName(), i->getdoubleSourceCopy());
-    new FXMenuCommand(p, "Open in new Tracker", 0, p, MID_OPENTRACKER);
+    new FXMenuCommand(p, "Open in new Tracker", nullptr, p, MID_OPENTRACKER);
     // set geometry
     p->setX(static_cast<FXEvent*>(eventData)->root_x);
     p->setY(static_cast<FXEvent*>(eventData)->root_y);
@@ -172,27 +166,6 @@ GUIParameterTableWindow::onRightButtonPress(FXObject* sender, FXSelector sel, vo
 }
 
 
-void
-GUIParameterTableWindow::mkItem(const char* name, bool dynamic, ValueSource<unsigned>* src) {
-    GUIParameterTableItemInterface* i = new GUIParameterTableItem<unsigned>(myTable, myCurrentPos++, name, dynamic, src);
-    myItems.push_back(i);
-}
-
-
-void
-GUIParameterTableWindow::mkItem(const char* name, bool dynamic, ValueSource<int>* src) {
-    GUIParameterTableItemInterface* i = new GUIParameterTableItem<int>(myTable, myCurrentPos++, name, dynamic, src);
-    myItems.push_back(i);
-}
-
-
-void
-GUIParameterTableWindow::mkItem(const char* name, bool dynamic, ValueSource<double>* src) {
-    GUIParameterTableItemInterface* i = new GUIParameterTableItem<double>(myTable, myCurrentPos++, name, dynamic, src);
-    myItems.push_back(i);
-}
-
-
 void
 GUIParameterTableWindow::mkItem(const char* name, bool dynamic, std::string value) {
     // T = double is only a dummy type here
@@ -232,7 +205,7 @@ GUIParameterTableWindow::mkItem(const char* name, bool dynamic, long long int va
 void
 GUIParameterTableWindow::updateTable() {
     AbstractMutex::ScopedLocker locker(myLock);
-    if (myObject == 0) {
+    if (myObject == nullptr) {
         return;
     }
     for (std::vector<GUIParameterTableItemInterface*>::iterator i = myItems.begin(); i != myItems.end(); i++) {
@@ -244,16 +217,16 @@ GUIParameterTableWindow::updateTable() {
 void
 GUIParameterTableWindow::closeBuilding(const Parameterised* p) {
     // add generic paramters if available
-    if (p == 0) {
+    if (p == nullptr) {
         p = dynamic_cast<const Parameterised*>(myObject);
     }
-    if (p != 0) {
-        const std::map<std::string, std::string>& map = p->getMap();
+    if (p != nullptr) {
+        const std::map<std::string, std::string>& map = p->getParametersMap();
         for (std::map<std::string, std::string>::const_iterator it = map.begin(); it != map.end(); ++it) {
             mkItem(("param:" + it->first).c_str(), false, it->second);
         }
     }
-    myApplication->addChild(this, true);
+    myApplication->addChild(this);
     create();
     show();
 }
@@ -262,7 +235,7 @@ GUIParameterTableWindow::closeBuilding(const Parameterised* p) {
 int
 GUIParameterTableWindow::numParams(const GUIGlObject* obj) {
     const Parameterised* p = dynamic_cast<const Parameterised*>(obj);
-    return p != 0 ? (int)p->getMap().size() : 0;
+    return p != nullptr ? (int)p->getParametersMap().size() : 0;
 }
 
 
