@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIParameterTableWindow.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <string>
@@ -39,6 +33,7 @@
 #include <utils/foxtools/MFXMutex.h>
 #include <utils/common/ValueSource.h>
 #include <utils/common/SUMOTime.h>
+#include "GUIParameterTableItem.h"
 
 
 // ===========================================================================
@@ -105,31 +100,17 @@ public:
     /// @name Row adding functions
     /// @{
 
-    /** @brief Adds a row which obtains its value from an unsigned-ValueSource
+    /** @brief Adds a row which obtains its value from a ValueSource
      *
      * @param[in] name The name of the row entry
      * @param[in] dynamic Information whether the entry is dynamic
      * @param[in] src The value source to use
      */
-    void mkItem(const char* name, bool dynamic, ValueSource<unsigned>* src);
-
-    /** @brief Adds a row which obtains its value from an integer-ValueSource
-     *
-     * @param[in] name The name of the row entry
-     * @param[in] dynamic Information whether the entry is dynamic
-     * @param[in] src The value source to use
-     */
-    void mkItem(const char* name, bool dynamic, ValueSource<int>* src);
-
-
-    /** @brief Adds a row which obtains its value from an double-ValueSource
-     *
-     * @param[in] name The name of the row entry
-     * @param[in] dynamic Information whether the entry is dynamic
-     * @param[in] src The value source to use
-     */
-    void mkItem(const char* name, bool dynamic, ValueSource<double>* src);
-
+    template<class T>
+    void mkItem(const char* name, bool dynamic, ValueSource<T>* src) {
+        GUIParameterTableItemInterface* i = new GUIParameterTableItem<T>(myTable, myCurrentPos++, name, dynamic, src);
+        myItems.push_back(i);
+    }
 
     /** @brief Adds a row which shows a string-value
      *
