@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUISelectedStorage.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <algorithm>
 #include <utils/gui/globjects/GUIGlObject.h>
@@ -102,13 +96,19 @@ GUISelectedStorage::isSelected(GUIGlObjectType type, GUIGlID id) {
     switch (type) {
         case GLO_NETWORK:
             return false;
-        case GLO_ADDITIONAL:
-            return isSelected(GLO_TRIGGER, id) || isSelected(GLO_DETECTOR, id) || mySelections[GLO_ADDITIONAL].isSelected(id);
         default:
             return mySelections[type].isSelected(id);
     }
 }
 
+bool 
+GUISelectedStorage::isSelected(const GUIGlObject* o) {
+    if (o == nullptr) {
+        return false;
+    } else {
+        return isSelected(o->getType(), o->getGlID());
+    }
+}
 
 void
 GUISelectedStorage::select(GUIGlID id, bool update) {
@@ -264,7 +264,7 @@ GUISelectedStorage::add2Update(UpdateTarget* updateTarget) {
 
 void
 GUISelectedStorage::remove2Update() {
-    myUpdateTarget = 0;
+    myUpdateTarget = nullptr;
 }
 
 
@@ -273,7 +273,7 @@ GUISelectedStorage::save(const std::string& filename, const std::set<GUIGlID>& i
     OutputDevice& dev = OutputDevice::getDevice(filename);
     for (std::set<GUIGlID>::const_iterator i = ids.begin(); i != ids.end(); ++i) {
         GUIGlObject* object = GUIGlObjectStorage::gIDStorage.getObjectBlocking(*i);
-        if (object != 0) {
+        if (object != nullptr) {
             std::string name = object->getFullName();
             dev << name << "\n";
             GUIGlObjectStorage::gIDStorage.unblockObject(*i);
