@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUISelectedStorage.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <set>
 #include <string>
@@ -112,6 +106,8 @@ public:
      */
     bool isSelected(GUIGlObjectType type, GUIGlID id);
 
+    bool isSelected(const GUIGlObject* o);
+
     /** @brief Adds the object with the given id
      *
      * The id of the object is added to the sub-container that is
@@ -185,7 +181,7 @@ public:
      *
      * @param[in] filename The name of the file to load the list of selected objects from
      * @param[in] type The type of the objects to load if changed from default
-     * @return error messages if errors occured or the empty string
+     * @return error messages if errors occurred or the empty string
      */
     std::string load(const std::string& filename, GUIGlObjectType type = GLO_MAX);
 
