@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIUserIO.cpp
 /// @author  Daniel Krajzewicz
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "GUIUserIO.h"
 
@@ -48,5 +42,14 @@ GUIUserIO::copyToClipboard(const FXApp& app, const std::string& text) {
     }
 }
 
+std::string
+GUIUserIO::copyFromClipboard(const FXApp& app) {
+    FXString string;
+    if (app.getActiveWindow()->getDNDData(FROM_CLIPBOARD,FXWindow::utf8Type,string)) {
+        return string.text();
+    };
+    return string.text();
+}
+
 /****************************************************************************/
 
