@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIUserIO.h
 /// @author  Daniel Krajzewicz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <fx.h>
@@ -52,14 +46,18 @@
 class GUIUserIO {
 public:
     /** @brief Copies the given text to clipboard
-     *
-     * This method is only implemented for MS Windows.
      *
      * @param[in] app The application to use
      * @param[in] text The text to copy
      */
     static void copyToClipboard(const FXApp& app, const std::string& text);
 
+    /** @brief Copies text from the clipboard
+     *
+     * @param[in] app The application to use
+     */
+    static std::string copyFromClipboard(const FXApp& app);
+
     static std::string clipped;
 
 };
