@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIEvent_Message.h
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "GUIEvent.h"
 #include <string>
@@ -46,21 +40,27 @@ class GUIEvent_Message : public GUIEvent {
 public:
     /// constructor
     GUIEvent_Message(const std::string& msg)
-        : GUIEvent(EVENT_STATUS_OCCURED), myMsg(msg) {
+        : GUIEvent(EVENT_STATUS_OCCURRED), myMsg(msg) {
     }
 
     /// constructor
     GUIEvent_Message(MsgHandler::MsgType type, const std::string& msg)
-        : GUIEvent(EVENT_MESSAGE_OCCURED), myMsg(msg) {
+        : GUIEvent(EVENT_MESSAGE_OCCURRED), myMsg(msg) {
         switch (type) {
             case MsgHandler::MT_MESSAGE:
-                myType = EVENT_MESSAGE_OCCURED;
+                myType = EVENT_MESSAGE_OCCURRED;
                 break;
             case MsgHandler::MT_WARNING:
-                myType = EVENT_WARNING_OCCURED;
+                myType = EVENT_WARNING_OCCURRED;
                 break;
             case MsgHandler::MT_ERROR:
-                myType = EVENT_ERROR_OCCURED;
+                myType = EVENT_ERROR_OCCURRED;
+                break;
+            case MsgHandler::MT_DEBUG:
+                myType = EVENT_DEBUG_OCCURRED;
+                break;
+            case MsgHandler::MT_GLDEBUG:
+                myType = EVENT_GLDEBUG_OCCURRED;
                 break;
             default:
                 throw 1;
