@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIGlObject.cpp
 /// @author  Daniel Krajzewicz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <stack>
@@ -43,6 +37,7 @@
 #include <utils/gui/windows/GUIMainWindow.h>
 #include <utils/gui/div/GUIGlobalSelection.h>
 #include <utils/gui/div/GLHelper.h>
+#include <utils/gui/div/GLObjectValuePassConnector.h>
 #include "GUIGlObject.h"
 #include "GUIGlObjectStorage.h"
 
@@ -51,23 +46,44 @@
 // ===========================================================================
 
 StringBijection<GUIGlObjectType>::Entry GUIGlObject::GUIGlObjectTypeNamesInitializer[] = {
-    {"network",       GLO_NETWORK},
-    {"edge",          GLO_EDGE},
-    {"lane",          GLO_LANE},
-    {"junction",      GLO_JUNCTION},
-    {"crossing",      GLO_CROSSING},
-    {"connection",    GLO_CONNECTION},
-    {"prohibition",   GLO_PROHIBITION},
-    {"tlLogic",       GLO_TLLOGIC},
-    {"detector",      GLO_DETECTOR},
-    {"trigger",       GLO_TRIGGER},
-    {"additional",    GLO_ADDITIONAL},
-    {"polygon",       GLO_POLYGON},
-    {"poi",           GLO_POI},
-    {"vehicle",       GLO_VEHICLE},
-    {"person",        GLO_PERSON},
-    {"container",     GLO_CONTAINER},
-    {"undefined",     GLO_MAX}
+    {"network",             GLO_NETWORK},
+    {"netElement",          GLO_NETELEMENT},
+    {"edge",                GLO_EDGE},
+    {"lane",                GLO_LANE},
+    {"junction",            GLO_JUNCTION},
+    {"crossing",            GLO_CROSSING},
+    {"connection",          GLO_CONNECTION},
+    {"prohibition",         GLO_PROHIBITION},
+    {"tlLogic",             GLO_TLLOGIC},
+    {"additional",          GLO_ADDITIONAL},
+    {"busStop",             GLO_BUS_STOP},
+    {"access",              GLO_ACCESS},
+    {"taz",                 GLO_TAZ},
+    {"containerStop",       GLO_CONTAINER_STOP},
+    {"chargingStation",     GLO_CHARGING_STATION},
+    {"parkingArea",         GLO_PARKING_AREA},
+    {"parkingSpace",        GLO_PARKING_SPACE},
+    {"e1Detector",          GLO_E1DETECTOR},
+    {"e1DetectorME",        GLO_E1DETECTOR_ME},
+    {"e1DetectorInstant",   GLO_E1DETECTOR_INSTANT},
+    {"e2Detector",          GLO_E2DETECTOR},
+    {"e3Detector",          GLO_E3DETECTOR},
+    {"entryDetector",       GLO_DET_ENTRY},
+    {"exitDetector",        GLO_DET_EXIT},
+    {"rerouter",            GLO_REROUTER},
+    {"rerouterEdge",        GLO_REROUTER_EDGE},
+    {"variableSpeedSign",   GLO_VSS},
+    {"calibrator",          GLO_CALIBRATOR},
+    {"routeProbe",          GLO_ROUTEPROBE},
+    {"vaporizer",           GLO_VAPORIZER},
+    {"shape",               GLO_SHAPE},
+    {"polygon",             GLO_POLYGON},
+    {"poi",                 GLO_POI},
+    {"routeElement",        GLO_ROUTEELEMENT},
+    {"vehicle",             GLO_VEHICLE},
+    {"person",              GLO_PERSON},
+    {"container",           GLO_CONTAINER},
+    {"undefined",           GLO_MAX}
 };
 
 
@@ -75,31 +91,24 @@ StringBijection<GUIGlObjectType> GUIGlObject::TypeNames(GUIGlObjectTypeNamesInit
 const GUIGlID GUIGlObject::INVALID_ID = 0;
 
 // ===========================================================================
-// method definitions
+// method definitionsas
 // ===========================================================================
 
 GUIGlObject::GUIGlObject(GUIGlObjectType type, const std::string& microsimID) :
     myGLObjectType(type),
-    myMicrosimID(microsimID),
-    myPrefix(TypeNames.getString(type)) {
-    myFullName = createFullName();
-    myGlID = GUIGlObjectStorage::gIDStorage.registerObject(this, myFullName);
-}
-
-
-GUIGlObject::GUIGlObject(const std::string& prefix, GUIGlObjectType type, const std::string& microsimID) :
-    myGLObjectType(type),
-    myMicrosimID(microsimID),
-    myPrefix(prefix) {
+    myMicrosimID(microsimID) {
+    // make sure that reserved GLO_ADDITIONAL isn't used
+    assert(myGLObjectType != GLO_ADDITIONAL);
     myFullName = createFullName();
     myGlID = GUIGlObjectStorage::gIDStorage.registerObject(this, myFullName);
 }
 
 
 GUIGlObject::~GUIGlObject() {
-    for (std::set<GUIParameterTableWindow*>::iterator i = myParamWindows.begin(); i != myParamWindows.end(); ++i) {
-        (*i)->removeObject(this);
+    for (auto i : myParamWindows) {
+        i->removeObject(this);
     }
+    GLObjectValuePassConnector<double>::removeObject(*this);
     GUIGlObjectStorage::gIDStorage.remove(getGlID());
 }
 
@@ -110,7 +119,7 @@ GUIGlObject::getFullName() const {
 }
 
 
-const std::string&
+std::string
 GUIGlObject::getParentName() const {
     return StringUtils::emptyString;
 }
@@ -126,7 +135,7 @@ GUIParameterTableWindow*
 GUIGlObject::getTypeParameterWindow(GUIMainWindow& app, GUISUMOAbstractView& parent) {
     UNUSED_PARAMETER(&app);
     UNUSED_PARAMETER(&parent);
-    return 0;
+    return nullptr;
 }
 
 
@@ -171,9 +180,8 @@ GUIGlObject::setNode(osg::Node* node) {
 #endif
 
 void
-GUIGlObject::buildPopupHeader(GUIGLObjectPopupMenu* ret, GUIMainWindow& app,
-                              bool addSeparator) {
-    new MFXMenuHeader(ret, app.getBoldFont(), getFullName().c_str(), 0, 0, 0);
+GUIGlObject::buildPopupHeader(GUIGLObjectPopupMenu* ret, GUIMainWindow& app, bool addSeparator) {
+    new MFXMenuHeader(ret, app.getBoldFont(), getFullName().c_str(), nullptr, nullptr, 0);
     if (addSeparator) {
         new FXMenuSeparator(ret);
     }
@@ -191,8 +199,8 @@ GUIGlObject::buildCenterPopupEntry(GUIGLObjectPopupMenu* ret, bool addSeparator)
 
 void
 GUIGlObject::buildNameCopyPopupEntry(GUIGLObjectPopupMenu* ret, bool addSeparator) {
-    new FXMenuCommand(ret, "Copy name to clipboard", 0, ret, MID_COPY_NAME);
-    new FXMenuCommand(ret, "Copy typed name to clipboard", 0, ret, MID_COPY_TYPED_NAME);
+    new FXMenuCommand(ret, "Copy name to clipboard", nullptr, ret, MID_COPY_NAME);
+    new FXMenuCommand(ret, "Copy typed name to clipboard", nullptr, ret, MID_COPY_TYPED_NAME);
     if (addSeparator) {
         new FXMenuSeparator(ret);
     }
@@ -232,9 +240,9 @@ GUIGlObject::buildShowTypeParamsPopupEntry(GUIGLObjectPopupMenu* ret, bool addSe
 
 void
 GUIGlObject::buildPositionCopyEntry(GUIGLObjectPopupMenu* ret, bool addSeparator) {
-    new FXMenuCommand(ret, "Copy cursor position to clipboard", 0, ret, MID_COPY_CURSOR_POSITION);
+    new FXMenuCommand(ret, "Copy cursor position to clipboard", nullptr, ret, MID_COPY_CURSOR_POSITION);
     if (GeoConvHelper::getFinal().usingGeoProjection()) {
-        new FXMenuCommand(ret, "Copy cursor geo-position to clipboard", 0, ret, MID_COPY_CURSOR_GEOPOSITION);
+        new FXMenuCommand(ret, "Copy cursor geo-position to clipboard", nullptr, ret, MID_COPY_CURSOR_GEOPOSITION);
     }
     if (addSeparator) {
         new FXMenuSeparator(ret);
@@ -266,13 +274,6 @@ GUIGlObject::removeParameterTable(GUIParameterTableWindow* t) {
 }
 
 
-void
-GUIGlObject::setPrefix(const std::string& prefix) {
-    myPrefix = prefix;
-    myFullName = createFullName();
-}
-
-
 void
 GUIGlObject::buildShapePopupOptions(GUIMainWindow& app, GUIGLObjectPopupMenu* ret, const std::string& type) {
     assert(ret);
@@ -290,7 +291,7 @@ GUIGlObject::buildShapePopupOptions(GUIMainWindow& app, GUIGLObjectPopupMenu* re
     buildPositionCopyEntry(ret, false);
     // only show type if isn't empty
     if (type != "") {
-        new FXMenuCommand(ret, ("type: " + type + "").c_str(), 0, 0, 0);
+        new FXMenuCommand(ret, ("type: " + type + "").c_str(), nullptr, nullptr, 0);
         new FXMenuSeparator(ret);
     }
 }
@@ -313,7 +314,7 @@ GUIGlObject::buildAdditionalsPopupOptions(GUIMainWindow& app, GUIGLObjectPopupMe
     buildPositionCopyEntry(ret, false);
     // only show type if isn't empty
     if (type != "") {
-        new FXMenuCommand(ret, ("type: " + type + "").c_str(), 0, 0, 0);
+        new FXMenuCommand(ret, ("type: " + type + "").c_str(), nullptr, nullptr, 0);
         new FXMenuSeparator(ret);
     }
 }
@@ -321,14 +322,14 @@ GUIGlObject::buildAdditionalsPopupOptions(GUIMainWindow& app, GUIGLObjectPopupMe
 
 std::string
 GUIGlObject::createFullName() const {
-    return myPrefix + ":" + getMicrosimID();
+    return TypeNames.getString(myGLObjectType) + ":" + getMicrosimID();
 }
 
 
 void
 GUIGlObject::drawName(const Position& pos, const double scale, const GUIVisualizationTextSettings& settings, const double angle) const {
     if (settings.show) {
-        GLHelper::drawText(getMicrosimID(), pos, GLO_MAX, settings.size / scale, settings.color, angle);
+        GLHelper::drawTextSettings(settings, getMicrosimID(), pos, scale, angle);
     }
 }
 
