@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIPolygon.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <utils/foxtools/MFXMutex.h>
@@ -55,13 +49,15 @@ public:
      * @param[in] layer The layer of the polygon
      * @param[in] angle The rotation of the polygon
      * @param[in] imgFile The raster image of the polygon
+     * @param[in] relativePath set image file as relative path
      * @param[in] shape The shape of the polygon
      * @param[in] geo specifiy if shape was loaded as GEO
      * @param[in] fill Whether the polygon shall be filled
+     * @param[in] lineWidth Line width when drawing unfilled polygon
      */
     GUIPolygon(const std::string& id, const std::string& type,
-               const RGBColor& color, const PositionVector& shape, bool geo, bool fill,
-               double layer = 0, double angle = 0, const std::string& imgFile = "");
+               const RGBColor& color, const PositionVector& shape, bool geo, bool fill, double lineWidth,
+               double layer = 0, double angle = 0, const std::string& imgFile = "", bool relativePath = false);
 
     /// @brief Destructor
     ~GUIPolygon();
@@ -111,10 +107,15 @@ public:
     /// @brief set a new shape and update the tesselation
     virtual void setShape(const PositionVector& shape);
 
-    /// @brief set a new shape and update the tesselation
-    void setLineWidth(double lineWidth) {
-        myLineWidth = lineWidth;
-    }
+protected:
+    /// @brief set color
+    void setColor(const GUIVisualizationSettings& s) const;
+
+    /// @brief check if Polygon can be drawn
+    bool checkDraw(const GUIVisualizationSettings& s) const;
+
+    /// @brief draw inner Polygon (before pushName() )
+    void drawInnerPolygon(const GUIVisualizationSettings& s) const;
 
 private:
     /// The mutex used to avoid concurrent updates of the shape
@@ -123,9 +124,6 @@ private:
     /// @brief id of the display list for the cached tesselation
     mutable GLuint myDisplayList;
 
-    /// @brief the previous line width for deciding whether the display list must be refreshed
-    mutable double myLineWidth;
-
     /// @brief store the drawing commands in a display list
     void storeTesselation(double lineWidth) const;
 
