@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIIcons.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 
 // ===========================================================================
@@ -42,17 +36,19 @@
 enum GUIIcon {
     /// @name general Interface icons
     /// @{
-    ICON_APP = 0,
-    ICON_DLR,
     ICON_SUMO,
+    ICON_SUMO_MINI,
+    ICON_SUMO_LOGO,
     ICON_EMPTY,
     ICON_OPEN_CONFIG,
     ICON_OPEN_NET,
     ICON_OPEN_SHAPES,
     ICON_OPEN_ADDITIONALS,
+    ICON_OPEN_TLSPROGRAMS,
     ICON_RELOAD,
     ICON_SAVE,
     ICON_CLOSE,
+    ICON_HELP,
     /// @}
 
     /// @name simulation control icons
@@ -181,10 +177,12 @@ enum GUIIcon {
     ICON_UNDO,
     ICON_REDO,
     ICON_NETEDIT,
+    ICON_NETEDIT_MINI,
     ICON_LOCK,
     ICON_ADD,
     ICON_REMOVE,
-    ICON_NETEDITARROW,
+    ICON_NETEDITARROWLEFT,
+    ICON_NETEDITARROWRIGHT,
     /// @}
 
     /// @name lane icons
@@ -192,6 +190,7 @@ enum GUIIcon {
     ICON_LANEPEDESTRIAN,
     ICON_LANEBUS,
     ICON_LANEBIKE,
+    ICON_LANEGREENVERGE,
     /// @}
 
     /// @name netedit modes icons
@@ -200,12 +199,14 @@ enum GUIIcon {
     ICON_MODECONNECTION,
     ICON_MODECREATEEDGE,
     ICON_MODECROSSING,
+    ICON_MODETAZ,
     ICON_MODEDELETE,
     ICON_MODEINSPECT,
     ICON_MODEMOVE,
     ICON_MODESELECT,
     ICON_MODETLS,
     ICON_MODEPOLYGON,
+    ICON_MODEPROHIBITION,
     /// @}
 
     /// @name netedit processing icons
@@ -229,6 +230,7 @@ enum GUIIcon {
     /// @name netedit additional icons
     /// @{
     ICON_BUSSTOP,
+    ICON_ACCESS,
     ICON_CONTAINERSTOP,
     ICON_CHARGINGSTATION,
     ICON_E1,
@@ -236,11 +238,30 @@ enum GUIIcon {
     ICON_E3,
     ICON_E3ENTRY,
     ICON_E3EXIT,
+    ICON_E1INSTANT,
     ICON_REROUTER,
     ICON_ROUTEPROBE,
     ICON_VAPORIZER,
     ICON_VARIABLESPEEDSIGN,
     ICON_CALIBRATOR,
+    ICON_PARKINGAREA,
+    ICON_PARKINGSPACE,
+    ICON_REROUTERINTERVAL,
+    ICON_VSSSTEP,
+    ICON_CLOSINGREROUTE,
+    ICON_CLOSINGLANEREROUTE,
+    ICON_DESTPROBREROUTE,
+    ICON_PARKINGZONEREROUTE,
+    ICON_ROUTEPROBREROUTE,
+    ICON_TAZ,
+    ICON_TAZEDGE,
+    /// @}
+
+    /// @name netedit routeElements icons
+    /// @{
+    ICON_FLOW,
+    ICON_ROUTE,
+    ICON_VTYPE,
     /// @}
 
     /// @name vehicle Class icons
