@@ -1,24 +1,21 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    GUISettingsHandler.h
 /// @author  Michael Behrisch
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @date    Fri, 24. Apr 2009
-/// @version $Id: GUISettingsHandler.h 14425 2013-08-16 20:11:47Z behrisch $
+/// @version $Id$
 ///
 // The handler for parsing gui settings from xml.
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
-// Copyright (C) 2001-2013 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 #ifndef GUISettingsHandler_h
 #define GUISettingsHandler_h
 
@@ -26,13 +23,10 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/xml/SUMOSAXHandler.h>
+#include <utils/distribution/RandomDistributor.h>
 
 
 // ===========================================================================
@@ -53,7 +47,7 @@ public:
     /** @brief Constructor
      * @param[in] file the file to parse
      */
-    GUISettingsHandler(const std::string& content, bool isFile = true);
+    GUISettingsHandler(const std::string& content, bool isFile = true, bool netedit = false);
 
 
     /// @brief Destructor
@@ -84,15 +78,7 @@ public:
     /** @brief Sets the viewport which has been parsed
      * @param[in] parent the view for which the viewport has to be set
      */
-    void setViewport(GUISUMOAbstractView* view) const;
-
-
-    /** @brief Sets the viewport which has been parsed
-     * @param[out] zoom Variable to store the loaded zoom into
-     * @param[out] xoff Variable to store the loaded x-offset into
-     * @param[out] yoff Variable to store the loaded y-offset into
-     */
-    void setViewport(Position& lookFrom, Position& lookAt) const;
+    void applyViewport(GUISUMOAbstractView* view) const;
 
 
     /** @brief Makes a snapshot if it has been parsed
@@ -117,7 +103,7 @@ public:
     /** @brief Returns the parsed delay
      * @return the parsed delay
      */
-    SUMOReal getDelay() const;
+    double getDelay() const;
 
 
     /** @brief Returns the parsed breakpoints
@@ -139,6 +125,10 @@ public:
         return myViewType;
     }
 
+    RandomDistributor<std::string> getEventDistribution(const std::string& id);
+    double getJamSoundTime() {
+        return myJamSoundTime;
+    }
 
 private:
     /// @brief The settings to fill
@@ -148,7 +138,7 @@ private:
     std::string myViewType;
 
     /// @brief The delay loaded
-    SUMOReal myDelay;
+    double myDelay;
 
     /// @brief The viewport loaded, zoom is stored in z coordinate
     Position myLookFrom;
@@ -156,8 +146,11 @@ private:
     /// @brief The point to look at, only needed for osg view
     Position myLookAt;
 
+    /// @brief View rotation
+    double myRotation;
+
     /// @brief mappig of time steps to filenames for potential snapshots
-    std::map<SUMOTime, std::string> mySnapshots;
+    std::map<SUMOTime, std::vector<std::string> > mySnapshots;
 
     /// @brief The decals list to fill
     std::vector<GUISUMOAbstractView::Decal> myDecals;
@@ -168,16 +161,28 @@ private:
     /// @brief The current color scheme
     GUIColorScheme* myCurrentScheme;
 
+    /// @brief The current scaling scheme
+    GUIScaleScheme* myCurrentScaleScheme;
+
     /// @brief The parsed breakpoints
     std::vector<SUMOTime> myBreakpoints;
 
+    /// @brief The parsed event distributions
+    std::map<std::string, RandomDistributor<std::string> > myEventDistributions;
+    double myJamSoundTime;
+
 private:
 
-    /// @brief parse combined settings of bool, size and color
+    /// @brief parse attributes for textSettings
     GUIVisualizationTextSettings parseTextSettings(
         const std::string& prefix, const SUMOSAXAttributes& attrs,
         GUIVisualizationTextSettings defaults);
 
+    /// @brief parse attributes for sizeSettings
+    GUIVisualizationSizeSettings parseSizeSettings(
+        const std::string& prefix, const SUMOSAXAttributes& attrs,
+        GUIVisualizationSizeSettings defaults);
+
 };
 
 #endif
