@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIVisualizationSettings.cpp
 /// @author  Daniel Krajzewicz
@@ -23,14 +21,11 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <map>
 #include <vector>
+#include <utils/gui/div/GUIGlobalSelection.h>
 #include "GUIVisualizationSettings.h"
 #include "GUIPropertyScheme.h"
 
@@ -58,39 +53,60 @@ const RGBColor SUMO_color_ALLWAY_STOP(0, 0, 192);
 const RGBColor SUMO_color_ZIPPER(192, 128, 64);
 const RGBColor SUMO_color_DEADEND(0, 0, 0);
 
-/* -------------------------------------------------------------------------
- * color constants for other objects
- * ----------------------------------------------------------------------- */
+// -------------------------------------------------------------------------
+// color constants for other objects
+// -------------------------------------------------------------------------
+
+const RGBColor GUIVisualizationSettings::SUMO_color_busStop(76, 170, 50);
+const RGBColor GUIVisualizationSettings::SUMO_color_busStop_sign(255, 235, 0);
+const RGBColor GUIVisualizationSettings::SUMO_color_containerStop(83, 89, 172);
+const RGBColor GUIVisualizationSettings::SUMO_color_containerStop_sign(177, 184, 186, 171);
+const RGBColor GUIVisualizationSettings::SUMO_color_chargingStation(114, 210, 252);
+const RGBColor GUIVisualizationSettings::SUMO_color_chargingStation_sign(255, 235, 0);
+const RGBColor GUIVisualizationSettings::SUMO_color_chargingStation_charge(255, 180, 0);
+const RGBColor GUIVisualizationSettings::SUMO_color_E1(255, 255, 0);
+const RGBColor GUIVisualizationSettings::SUMO_color_E1Instant(255, 0, 255);
+const RGBColor GUIVisualizationSettings::SUMO_color_E2(0, 204, 204);
 const RGBColor GUIVisualizationSettings::SUMO_color_E3Entry(0, 92, 64);
 const RGBColor GUIVisualizationSettings::SUMO_color_E3Exit(92, 0, 0);
 
+const std::string GUIVisualizationSettings::SCHEME_NAME_EDGE_PARAM_NUMERICAL("by param (numerical, streetwise)");
+const std::string GUIVisualizationSettings::SCHEME_NAME_LANE_PARAM_NUMERICAL("by param (numerical, lanewise)");
+
 // ===========================================================================
 // member method definitions
 // ===========================================================================
 GUIVisualizationSettings::GUIVisualizationSettings(bool _netedit) :
     name(""),
     netedit(_netedit),
+    angle(0),
     dither(false),
     backgroundColor(RGBColor::WHITE),
     showGrid(false), gridXSize(100), gridYSize(100),
-    laneShowBorders(false), showLinkDecals(true),
+    laneShowBorders(false), showBikeMarkings(true), showLinkDecals(true),
     showLinkRules(true), showRails(true),
     edgeName(false, 50, RGBColor(255, 128, 0, 255)),
     internalEdgeName(false, 40, RGBColor(128, 64, 0, 255)),
     cwaEdgeName(false, 50, RGBColor::MAGENTA),
     streetName(false, 55, RGBColor::YELLOW),
+    edgeValue(false, 100, RGBColor::CYAN),
     hideConnectors(false),
     laneWidthExaggeration(1),
     laneMinSize(0),
     showLaneDirection(false),
     showSublanes(true),
+    spreadSuperposed(false),
+    edgeParam("EDGE_KEY"),
+    laneParam("LANE_KEY"),
     vehicleQuality(0), showBlinker(true),
     drawLaneChangePreference(false), drawMinGap(false),
     showBTRange(false), vehicleSize(1),
     vehicleName(false, 50, RGBColor(204, 153, 0, 255)),
+    vehicleValue(false, 80, RGBColor::CYAN),
     personQuality(0),
     personSize(1),
     personName(false, 50, RGBColor(0, 153, 204, 255)),
+    personValue(false, 80, RGBColor::CYAN),
     containerQuality(0),
     containerSize(1),
     containerName(false, 50, RGBColor(0, 153, 204, 255)),
@@ -112,7 +128,12 @@ GUIVisualizationSettings::GUIVisualizationSettings(bool _netedit) :
     polyType(false, 50, RGBColor(255, 0, 128, 255)),
     showSizeLegend(true),
     gaming(false),
-    selectionScale(1),
+    selectionColor(0, 0, 204, 255),
+    selectedEdgeColor(0, 0, 204, 255),
+    selectedLaneColor(0, 0, 128, 255),
+    selectedConnectionColor(0, 0, 100, 255),
+    selectedAdditionalColor(0, 0, 150, 255),
+    selectionScale(1.),
     drawForSelecting(false) {
 
     if (netedit) {
@@ -131,9 +152,10 @@ GUIVisualizationSettings::initSumoGuiDefaults() {
     scheme.addColor(RGBColor(192, 66, 44), 2, "bike lane");
     scheme.addColor(RGBColor(0, 0, 0, 0), 3, "green verge");
     scheme.addColor(RGBColor(150, 200, 200), 4, "waterway");
-    scheme.addColor(RGBColor(92, 92, 92), 5, "no passenger"); // paths, service roads etc
-    scheme.addColor(RGBColor::RED, 6, "closed"); // road closing
-    scheme.addColor(RGBColor::GREEN, 7, "connector"); // macro-connector
+    scheme.addColor(RGBColor::BLACK, 5, "railway");
+    scheme.addColor(RGBColor(92, 92, 92), 6, "no passenger"); // paths, service roads etc
+    scheme.addColor(RGBColor::RED, 7, "closed"); // road closing
+    scheme.addColor(RGBColor::GREEN, 8, "connector"); // macro-connector
     laneColorer.addScheme(scheme);
     scheme = GUIColorScheme("by selection (lane-/streetwise)", RGBColor(128, 128, 128, 255), "unselected", true);
     scheme.addColor(RGBColor(0, 80, 180, 255), 1, "selected");
@@ -288,6 +310,14 @@ GUIVisualizationSettings::initSumoGuiDefaults() {
     scheme.addColor(RGBColor::YELLOW, (double)10);
     scheme.addColor(RGBColor::RED, (double)100);
     laneColorer.addScheme(scheme);
+    scheme = GUIColorScheme("by TAZ (streetwise)", RGBColor(204, 204, 204), "no TAZ", true);
+    laneColorer.addScheme(scheme);
+    scheme = GUIColorScheme(SCHEME_NAME_EDGE_PARAM_NUMERICAL, RGBColor(204, 204, 204));
+    scheme.setAllowsNegativeValues(true);
+    laneColorer.addScheme(scheme);
+    scheme = GUIColorScheme(SCHEME_NAME_LANE_PARAM_NUMERICAL, RGBColor(204, 204, 204));
+    scheme.setAllowsNegativeValues(true);
+    laneColorer.addScheme(scheme);
 
 
     /// add vehicle coloring schemes
@@ -306,9 +336,9 @@ GUIVisualizationSettings::initSumoGuiDefaults() {
     scheme.addColor(RGBColor::BLUE, (double)(120 / 3.6));
     scheme.addColor(RGBColor::MAGENTA, (double)(150 / 3.6));
     vehicleColorer.addScheme(scheme);
-    scheme = GUIColorScheme("by action step", RGBColor::GREY);
-    scheme.addColor(RGBColor(0, 255, 0, 255), 1.);
-    scheme.addColor(RGBColor(80, 160, 80, 255), 2.);
+    scheme = GUIColorScheme("by action step", RGBColor::GREY, "no action", true);
+    scheme.addColor(RGBColor(0, 255, 0, 255), 1., "action in next step");
+    scheme.addColor(RGBColor(80, 160, 80, 255), 2., "had action step");
     vehicleColorer.addScheme(scheme);
     scheme = GUIColorScheme("by waiting time", RGBColor::BLUE);
     scheme.addColor(RGBColor::CYAN, (double)30);
@@ -368,6 +398,7 @@ GUIVisualizationSettings::initSumoGuiDefaults() {
     scheme.addColor(RGBColor(0, 102, 204, 255), 1, "selected");
     vehicleColorer.addScheme(scheme);
     scheme = GUIColorScheme("by offset from best lane", RGBColor(179, 179, 179, 255), "0");
+    scheme.addColor(RGBColor(255, 0, 255, 255), -100, "opposite lane");
     scheme.addColor(RGBColor(255,   0, 0, 255), -3, "-3");
     scheme.addColor(RGBColor(255, 255, 0, 255), -1, "-1");
     scheme.addColor(RGBColor(0, 255, 255, 255),  1,  "1");
@@ -407,19 +438,21 @@ GUIVisualizationSettings::initSumoGuiDefaults() {
     vehicleColorer.addScheme(GUIColorScheme("random", RGBColor::YELLOW, "", true));
 
     /// add person coloring schemes
-    personColorer.addScheme(GUIColorScheme("given person/type color", RGBColor::YELLOW, "", true));
-    personColorer.addScheme(GUIColorScheme("uniform", RGBColor::YELLOW, "", true));
-    personColorer.addScheme(GUIColorScheme("given/assigned person color", RGBColor::YELLOW, "", true));
-    personColorer.addScheme(GUIColorScheme("given/assigned type color", RGBColor::YELLOW, "", true));
+    personColorer.addScheme(GUIColorScheme("given person/type color", RGBColor::BLUE, "", true));
+    personColorer.addScheme(GUIColorScheme("uniform", RGBColor::BLUE, "", true));
+    personColorer.addScheme(GUIColorScheme("given/assigned person color", RGBColor::BLUE, "", true));
+    personColorer.addScheme(GUIColorScheme("given/assigned type color", RGBColor::BLUE, "", true));
     scheme = GUIColorScheme("by speed", RGBColor::RED);
     scheme.addColor(RGBColor::YELLOW, (double)(2.5 / 3.6));
     scheme.addColor(RGBColor::GREEN, (double)(5 / 3.6));
     scheme.addColor(RGBColor::BLUE, (double)(10 / 3.6));
     personColorer.addScheme(scheme);
-    scheme = GUIColorScheme("by mode", RGBColor::YELLOW); // walking
-    scheme.addColor(RGBColor::BLUE, (double)(1)); // riding
-    scheme.addColor(RGBColor::RED, (double)(2)); // stopped
-    scheme.addColor(RGBColor::GREEN, (double)(3)); // waiting for ride
+    scheme = GUIColorScheme("by mode", RGBColor::GREY, "waiting for insertion", true);
+    scheme.addColor(RGBColor::RED, (double)(1), "stopped");
+    scheme.addColor(RGBColor::GREEN, (double)(2), "walking");
+    scheme.addColor(RGBColor::BLUE, (double)(3), "riding");
+    scheme.addColor(RGBColor::CYAN, (double)(4), "accessing trainStop");
+    scheme.addColor(RGBColor::YELLOW, (double)(5), "waiting for ride");
     personColorer.addScheme(scheme);
     scheme = GUIColorScheme("by waiting time", RGBColor::BLUE);
     scheme.addColor(RGBColor::CYAN, (double)30);
@@ -443,10 +476,12 @@ GUIVisualizationSettings::initSumoGuiDefaults() {
     scheme.addColor(RGBColor::GREEN, (double)(5 / 3.6));
     scheme.addColor(RGBColor::BLUE, (double)(10 / 3.6));
     containerColorer.addScheme(scheme);
-    scheme = GUIColorScheme("by mode", RGBColor::YELLOW); // walking
-    scheme.addColor(RGBColor::BLUE, (double)(1)); // riding
-    scheme.addColor(RGBColor::RED, (double)(2)); // stopped
-    scheme.addColor(RGBColor::GREEN, (double)(3)); // waiting for ride
+    scheme = GUIColorScheme("by mode", RGBColor::GREY, "waiting for insertion", true);
+    scheme.addColor(RGBColor::RED, (double)(1), "stopped");
+    scheme.addColor(RGBColor::GREEN, (double)(2), "tranship"); // walking
+    scheme.addColor(RGBColor::BLUE, (double)(3), "transport");
+    scheme.addColor(RGBColor::CYAN, (double)(4), "accessing trainStop");
+    scheme.addColor(RGBColor::YELLOW, (double)(5), "waiting for transport");
     containerColorer.addScheme(scheme);
     scheme = GUIColorScheme("by waiting time", RGBColor::BLUE);
     scheme.addColor(RGBColor::CYAN, (double)30);
@@ -489,6 +524,19 @@ GUIVisualizationSettings::initSumoGuiDefaults() {
     scheme.setAllowsNegativeValues(true);
     junctionColorer.addScheme(scheme);
 
+    /// add POI coloring schemes
+    poiColorer.addScheme(GUIColorScheme("given POI color", RGBColor::RED, "", true));
+    scheme = GUIColorScheme("by selection", RGBColor(179, 179, 179, 255), "unselected", true);
+    scheme.addColor(RGBColor(0, 102, 204, 255), 1, "selected");
+    poiColorer.addScheme(scheme);
+    poiColorer.addScheme(GUIColorScheme("uniform", RGBColor::RED, "", true));
+
+    /// add polygon coloring schemes
+    polyColorer.addScheme(GUIColorScheme("given polygon color", RGBColor::ORANGE, "", true));
+    scheme = GUIColorScheme("by selection", RGBColor(179, 179, 179, 255), "unselected", true);
+    scheme.addColor(RGBColor(0, 102, 204, 255), 1, "selected");
+    polyColorer.addScheme(scheme);
+    polyColorer.addScheme(GUIColorScheme("uniform", RGBColor::ORANGE, "", true));
 
     /// add lane scaling schemes
     {
@@ -577,7 +625,7 @@ GUIVisualizationSettings::initSumoGuiDefaults() {
 
 
     /// add edge coloring schemes
-    edgeColorer.addScheme(GUIColorScheme("uniform (streetwise)", RGBColor::BLACK, "", true));
+    edgeColorer.addScheme(GUIColorScheme("uniform", RGBColor(0, 0, 0, 0), "", true));
     scheme = GUIColorScheme("by selection (streetwise)", RGBColor(128, 128, 128, 255), "unselected", true);
     scheme.addColor(RGBColor(0, 80, 180, 255), 1, "selected");
     edgeColorer.addScheme(scheme);
@@ -651,6 +699,8 @@ GUIVisualizationSettings::initSumoGuiDefaults() {
     scheme.addColor(RGBColor::YELLOW, (double)10);
     scheme.addColor(RGBColor::RED, (double)100);
     edgeColorer.addScheme(scheme);
+    scheme = GUIColorScheme("by TAZ (streetwise)", RGBColor(204, 204, 204), "no TAZ", true);
+    edgeColorer.addScheme(scheme);
 
 
     /// add edge scaling schemes
@@ -692,7 +742,8 @@ GUIVisualizationSettings::initNeteditDefaults() {
     scheme.addColor(RGBColor(192, 66, 44), 2, "bike lane");
     scheme.addColor(RGBColor(200, 255, 200), 3, "green verge");
     scheme.addColor(RGBColor(150, 200, 200), 4, "waterway");
-    scheme.addColor(RGBColor(92, 92, 92), 5, "no passenger"); // paths, service roads etc
+    scheme.addColor(RGBColor::BLACK, 5, "railway");
+    scheme.addColor(RGBColor(92, 92, 92), 6, "no passenger"); // paths, service roads etc
     laneColorer.addScheme(scheme);
     scheme = GUIColorScheme("by selection (lane-/streetwise)", RGBColor(128, 128, 128, 255), "unselected", true);
     scheme.addColor(RGBColor(0, 80, 180, 255), 1, "selected");
@@ -765,10 +816,17 @@ GUIVisualizationSettings::initNeteditDefaults() {
     scheme.addColor(RGBColor::BLUE, (double) - .3);
     scheme.setAllowsNegativeValues(true);
     laneColorer.addScheme(scheme);
+    scheme = GUIColorScheme(SCHEME_NAME_EDGE_PARAM_NUMERICAL, RGBColor(204, 204, 204));
+    scheme.setAllowsNegativeValues(true);
+    laneColorer.addScheme(scheme);
+    scheme = GUIColorScheme(SCHEME_NAME_LANE_PARAM_NUMERICAL, RGBColor(204, 204, 204));
+    scheme.setAllowsNegativeValues(true);
+    laneColorer.addScheme(scheme);
 
     scheme = GUIColorScheme("uniform", RGBColor(102, 0, 0), "", true);
     scheme.addColor(RGBColor(204, 0, 0), 1, "shape not computed");
     scheme.addColor(RGBColor(153, 0, 0), 2, "geometry points");
+    scheme.addColor(RGBColor::GREEN, 3, "custom shape");
     junctionColorer.addScheme(scheme);
     scheme = GUIColorScheme("by selection", RGBColor(128, 128, 128, 255), "unselected", true);
     scheme.addColor(RGBColor(0, 80, 180, 255), 1, "selected");
@@ -796,6 +854,20 @@ GUIVisualizationSettings::initNeteditDefaults() {
     scheme.setAllowsNegativeValues(true);
     junctionColorer.addScheme(scheme);
 
+    /// add POI coloring schemes
+    poiColorer.addScheme(GUIColorScheme("given POI color", RGBColor::RED, "", true));
+    scheme = GUIColorScheme("by selection", RGBColor(179, 179, 179, 255), "unselected", true);
+    scheme.addColor(RGBColor(0, 102, 204, 255), 1, "selected");
+    poiColorer.addScheme(scheme);
+    poiColorer.addScheme(GUIColorScheme("uniform", RGBColor::RED, "", true));
+
+    /// add polygon coloring schemes
+    polyColorer.addScheme(GUIColorScheme("given polygon color", RGBColor::ORANGE, "", true));
+    scheme = GUIColorScheme("by selection", RGBColor(179, 179, 179, 255), "unselected", true);
+    scheme.addColor(RGBColor(0, 102, 204, 255), 1, "selected");
+    polyColorer.addScheme(scheme);
+    polyColorer.addScheme(GUIColorScheme("uniform", RGBColor::ORANGE, "", true));
+
     /// add edge scaling schemes
     {
         GUIScaleScheme scheme = GUIScaleScheme("default", 1, "uniform", true);
@@ -862,6 +934,7 @@ GUIVisualizationSettings::save(OutputDevice& dev) const {
     dev.writeAttr("laneEdgeMode", getLaneEdgeMode());
     dev.writeAttr("scaleMode", getLaneEdgeScaleMode());
     dev.writeAttr("laneShowBorders", laneShowBorders);
+    dev.writeAttr("showBikeMarkings", showBikeMarkings);
     dev.writeAttr("showLinkDecals", showLinkDecals);
     dev.writeAttr("showLinkRules", showLinkRules);
     dev.writeAttr("showRails", showRails);
@@ -870,6 +943,9 @@ GUIVisualizationSettings::save(OutputDevice& dev) const {
     dev.writeAttr("minSize", laneMinSize);
     dev.writeAttr("showDirection", showLaneDirection);
     dev.writeAttr("showSublanes", showSublanes);
+    dev.writeAttr("spreadSuperposed", spreadSuperposed);
+    dev.writeAttr("edgeParam", edgeParam);
+    dev.writeAttr("laneParam", laneParam);
     dev.lf();
     dev << "               ";
     edgeName.print(dev, "edgeName");
@@ -882,6 +958,9 @@ GUIVisualizationSettings::save(OutputDevice& dev) const {
     dev.lf();
     dev << "               ";
     streetName.print(dev, "streetName");
+    dev.lf();
+    dev << "               ";
+    edgeValue.print(dev, "edgeValue");
     laneColorer.save(dev);
     laneScaler.save(dev);
     edgeColorer.save(dev);
@@ -893,9 +972,13 @@ GUIVisualizationSettings::save(OutputDevice& dev) const {
     dev.writeAttr("vehicleQuality", vehicleQuality);
     vehicleSize.print(dev, "vehicle");
     dev.writeAttr("showBlinker", showBlinker);
+    dev.writeAttr("drawMinGap", drawMinGap);
     dev.lf();
     dev << "                 ";
     vehicleName.print(dev, "vehicleName");
+    dev.lf();
+    dev << "                 ";
+    vehicleValue.print(dev, "vehicleValue");
     vehicleColorer.save(dev);
     dev.closeTag();
     // persons
@@ -906,17 +989,20 @@ GUIVisualizationSettings::save(OutputDevice& dev) const {
     dev.lf();
     dev << "                ";
     personName.print(dev, "personName");
+    dev.lf();
+    dev << "                 ";
+    personValue.print(dev, "personValue");
     personColorer.save(dev);
     dev.closeTag();
-    // persons
+    // containers
     dev.openTag(SUMO_TAG_VIEWSETTINGS_CONTAINERS);
     dev.writeAttr("containerMode", containerColorer.getActive());
     dev.writeAttr("containerQuality", containerQuality);
-    personSize.print(dev, "container");
+    containerSize.print(dev, "container");
     dev.lf();
     dev << "                ";
-    personName.print(dev, "containerName");
-    personColorer.save(dev);
+    containerName.print(dev, "containerName");
+    containerColorer.save(dev);
     dev.closeTag();
     // junctions
     dev.openTag(SUMO_TAG_VIEWSETTINGS_JUNCTIONS);
@@ -953,12 +1039,14 @@ GUIVisualizationSettings::save(OutputDevice& dev) const {
     poiSize.print(dev, "poi");
     poiName.print(dev, "poiName");
     poiType.print(dev, "poiType");
+    poiColorer.save(dev);
     dev.closeTag();
     // polys
     dev.openTag(SUMO_TAG_VIEWSETTINGS_POLYS);
     polySize.print(dev, "poly");
     polyName.print(dev, "polyName");
     polyType.print(dev, "polyType");
+    polyColorer.save(dev);
     dev.closeTag();
     // legend
     dev.openTag(SUMO_TAG_VIEWSETTINGS_LEGEND);
@@ -977,6 +1065,21 @@ GUIVisualizationSettings::operator==(const GUIVisualizationSettings& v2) {
     if (backgroundColor != v2.backgroundColor) {
         return false;
     }
+    if (selectionColor != v2.selectionColor) {
+        return false;
+    }
+    if (selectedEdgeColor != v2.selectedEdgeColor) {
+        return false;
+    }
+    if (selectedLaneColor != v2.selectedLaneColor) {
+        return false;
+    }
+    if (selectedConnectionColor != v2.selectedConnectionColor) {
+        return false;
+    }
+    if (selectedAdditionalColor != v2.selectedAdditionalColor) {
+        return false;
+    }
     if (showGrid != v2.showGrid) {
         return false;
     }
@@ -1002,6 +1105,9 @@ GUIVisualizationSettings::operator==(const GUIVisualizationSettings& v2) {
     if (laneShowBorders != v2.laneShowBorders) {
         return false;
     }
+    if (showBikeMarkings != v2.showBikeMarkings) {
+        return false;
+    }
     if (showLinkDecals != v2.showLinkDecals) {
         return false;
     }
@@ -1023,6 +1129,9 @@ GUIVisualizationSettings::operator==(const GUIVisualizationSettings& v2) {
     if (streetName != v2.streetName) {
         return false;
     }
+    if (edgeValue != v2.edgeValue) {
+        return false;
+    }
     if (hideConnectors != v2.hideConnectors) {
         return false;
     }
@@ -1038,6 +1147,15 @@ GUIVisualizationSettings::operator==(const GUIVisualizationSettings& v2) {
     if (showSublanes != v2.showSublanes) {
         return false;
     }
+    if (spreadSuperposed != v2.spreadSuperposed) {
+        return false;
+    }
+    if (edgeParam != v2.edgeParam) {
+        return false;
+    }
+    if (laneParam != v2.laneParam) {
+        return false;
+    }
     if (!(vehicleColorer == v2.vehicleColorer)) {
         return false;
     }
@@ -1062,6 +1180,9 @@ GUIVisualizationSettings::operator==(const GUIVisualizationSettings& v2) {
     if (vehicleName != v2.vehicleName) {
         return false;
     }
+    if (vehicleValue != v2.vehicleValue) {
+        return false;
+    }
     if (!(personColorer == v2.personColorer)) {
         return false;
     }
@@ -1074,6 +1195,9 @@ GUIVisualizationSettings::operator==(const GUIVisualizationSettings& v2) {
     if (personName != v2.personName) {
         return false;
     }
+    if (personValue != v2.personValue) {
+        return false;
+    }
     if (!(containerColorer == v2.containerColorer)) {
         return false;
     }
@@ -1089,6 +1213,12 @@ GUIVisualizationSettings::operator==(const GUIVisualizationSettings& v2) {
     if (!(junctionColorer == v2.junctionColorer)) {
         return false;
     }
+    if (!(poiColorer == v2.poiColorer)) {
+        return false;
+    }
+    if (!(polyColorer == v2.polyColorer)) {
+        return false;
+    }
     if (drawLinkTLIndex != v2.drawLinkTLIndex) {
         return false;
     }
@@ -1157,9 +1287,11 @@ GUIVisualizationSettings::operator==(const GUIVisualizationSettings& v2) {
 
 
 double
-GUIVisualizationSizeSettings::getExaggeration(const GUIVisualizationSettings& s, double factor) const {
+GUIVisualizationSizeSettings::getExaggeration(const GUIVisualizationSettings& s, const GUIGlObject* o, double factor) const {
     /// @note should look normal-sized at zoom 1000
-    return (constantSize && !s.drawForSelecting) ? MAX2((double)exaggeration, exaggeration * factor / s.scale) : exaggeration;
+    return (constantSize && !s.drawForSelecting && (!constantSizeSelected || o == nullptr || gSelected.isSelected(o))) 
+        ? MAX2((double)exaggeration, exaggeration * factor / s.scale) 
+        : (!constantSizeSelected || o == nullptr || gSelected.isSelected(o) ? exaggeration : 1);
 }
 
 
@@ -1201,6 +1333,21 @@ GUIVisualizationSettings::getLinkColor(const LinkState& ls) {
     }
 }
 
+double
+GUIVisualizationSettings::getTextAngle(double objectAngle) const {
+    double viewAngle = objectAngle - angle;
+    while (viewAngle < 0) {
+        viewAngle += 360;
+    }
+    // fmod round towards zero which is not want we want for negative numbers
+    viewAngle = fmod(viewAngle, 360);
+    if (viewAngle > 90 && viewAngle < 270) {
+        // avoid reading text on it's head
+        objectAngle -= 180;
+    }
+    return objectAngle;
+}
+
 /****************************************************************************/
 
 
