@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIAppEnum.h
 /// @author  Daniel Krajzewicz
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <fx.h>
 
@@ -76,6 +70,8 @@ enum {
     MID_OPEN_SHAPES,
     /// @brief Load additional file with additional elements
     MID_OPEN_ADDITIONALS,
+    /// @brief Load additional file with additional elements
+    MID_OPEN_TLSPROGRAMS,
     /// @brief Reload the previously loaded simulation
     MID_RELOAD,
     /// @brief Loads a file previously loaded
@@ -96,6 +92,8 @@ enum {
     MID_STOP,
     /// @brief Perform a single simulation step
     MID_STEP,
+    /// @brief Save state to file
+    MID_SIMSAVE,
     /// @}
 
 
@@ -130,6 +128,8 @@ enum {
     MID_EDIT_BREAKPOINTS,
     /// @brief Open in netedit
     MID_NETEDIT,
+    /// @brief Open in SUMO GUI
+    MID_SUMOGUI,
     /// @}
 
 
@@ -198,6 +198,8 @@ enum {
     MID_TIME_TOOGLE,
     /// @brief toogle delay between alternative value
     MID_DELAY_TOOGLE,
+    /// @brief scale traffic
+    MID_DEMAND_SCALE,
     /// @}
 
 
@@ -240,6 +242,8 @@ enum {
     MID_SHOWPARS,
     /// @brief Show object type parameter - popup entry
     MID_SHOWTYPEPARS,
+    /// @brief Show transportable plan
+    MID_SHOWPLAN,
     /// @brief Show TLS phases - popup entry
     MID_SWITCH_OFF,
     MID_SWITCH,
@@ -415,6 +419,8 @@ enum {
     MID_GNE_HOTKEY_DEL,
     /// @brief hot key <ENTER> accept current operation
     MID_GNE_HOTKEY_ENTER,
+    /// @brief hot key <Ctrl + G> for toogle grid
+    MID_GNE_HOTKEY_TOOGLE_GRID,
     /// @}
 
 
@@ -441,6 +447,10 @@ enum {
     MID_GNE_TOOLBARFILE_SAVEADDITIONALS,
     /// @brief save additionals as
     MID_GNE_TOOLBARFILE_SAVEADDITIONALS_AS,
+    /// @brief save TLS Programs
+    MID_GNE_TOOLBARFILE_SAVETLSPROGRAMS,
+    /// @brief save TLS Programs as
+    MID_GNE_TOOLBARFILE_SAVETLSPROGRAMS_AS,
     /// @}
 
 
@@ -483,8 +493,12 @@ enum {
     MID_GNE_SETMODE_ADDITIONAL,
     /// @brief mode for editing crossing
     MID_GNE_SETMODE_CROSSING,
+    /// @brief mode for editing TAZ
+    MID_GNE_SETMODE_TAZ,
     /// @brief mode for creating polygons
     MID_GNE_SETMODE_POLYGON,
+    /// @brief mode for editing connection prohibitions
+    MID_GNE_SETMODE_PROHIBITION,
     /// @}
 
 
@@ -514,21 +528,25 @@ enum {
 
     /// @name GNEFrame messages
     /// @{
-
-    /// @brief set GEO Attribute
-    MID_GNEFRAME_GEOATTRIBUTE,
-    /// @brief enable or disable use GEO
-    MID_GNEFRAME_USEGEO,
-
-
     // MID_GNE_WIZARD,
+    /// @brief attribute added
+    MID_GNE_ADD_ATTRIBUTE,
+    /// @brief attribute removed
+    MID_GNE_REMOVE_ATTRIBUTE,
     /// @brief attribute edited
     MID_GNE_SET_ATTRIBUTE,
-    /// @brief attribute block shape
-    MID_GNE_SET_BLOCKING_SHAPE,
-    /// @brief attribute close shape
-    MID_GNE_SET_CLOSING_SHAPE,
-
+    /// @brief create something
+    MID_GNE_CREATE,
+    /// @brief used to select a type of element in a combo box
+    MID_GNE_SET_TYPE,
+    /// @brief text attribute edited
+    MID_GNE_SET_ATTRIBUTE_TEXT,
+    /// @brief bool attribute edited
+    MID_GNE_SET_ATTRIBUTE_BOOL,
+    /// @brief attribute edited trought dialog
+    MID_GNE_SET_ATTRIBUTE_DIALOG,
+    /// @brief select items
+    MID_GNE_SELECT,
     /// @}
 
 
@@ -543,6 +561,12 @@ enum {
     MID_GNE_SELECTORFRAME_PROCESSSTRING,
     /// @brief changes the visual scaling of selected items
     MID_GNE_SELECTORFRAME_SELECTSCALE,
+    /// @brief start drawing polygon
+    MID_GNE_STARTDRAWING,
+    /// @brief stop drawing polygon
+    MID_GNE_STOPDRAWING,
+    /// @brief abort drawing polygon
+    MID_GNE_ABORTDRAWING,
     /// @}
 
 
@@ -575,8 +599,10 @@ enum {
     MID_GNE_INSPECTORFRAME_COPYTEMPLATE,
     /// @brief go back to the previous element
     MID_GNE_INSPECTORFRAME_GOBACK,
-    /// @brief open edit attribute dialog
-    MID_GNE_INSPECTORFRAME_ATTRIBUTEEDITOR,
+    /// @brief inspect next element
+    MID_GNE_INSPECTORFRAME_NEXT,
+    /// @brief inspect previous element
+    MID_GNE_INSPECTORFRAME_PREVIOUS,
     /// @}
 
 
@@ -611,6 +637,14 @@ enum {
     MID_GNE_TLSFRAME_PHASE_DELETE,
     /// @brief cleanup unused states
     MID_GNE_TLSFRAME_CLEANUP,
+    /// @brief mark unused states
+    MID_GNE_TLSFRAME_MARKUNUSED,
+    /// @brief mark unused states
+    MID_GNE_TLSFRAME_ADDUNUSED,
+    /// @brief Load Program
+    MID_GNE_TLSFRAME_LOAD_PROGRAM,
+    /// @brief cleanup unused states
+    MID_GNE_TLSFRAME_SAVE_PROGRAM,
     /// @}
 
 
@@ -619,75 +653,52 @@ enum {
 
     /// @brief Create crossing
     MID_GNE_CROSSINGFRAME_CREATECROSSING,
-    /// @brief use selected edges only
-    MID_GNE_CROSSINGFRAME_USEONLYSELECTEDEDGES,
     /// @}
 
-
     /// @name GNEAdditionalFrame messages
     /// @{
 
-    /// @brief select type of additional
-    MID_GNE_ADDITIONALFRAME_SELECTADDITIONALTYPE,
-    /// @brief change reference point
-    MID_GNE_ADDITIONALFRAME_REFERENCEPOINT,
-    /// @brief change parameter of type text
-    MID_GNE_ADDITIONALFRAME_CHANGEPARAMETER_TEXT,
-    /// @brief change parameter of tpye bool
-    MID_GNE_ADDITIONALFRAME_CHANGEPARAMETER_BOOL,
-    /// @brief attribute block movement
-    MID_GNE_ADDITIONALFRAME_BLOCKMOVEMENT,
-    /// @brief attribute Parent
-    MID_GNE_ADDITIONALFRAME_CHANGEPARENT,
     /// @brief add row
     MID_GNE_ADDITIONALFRAME_ADDROW,
     /// @brief remove row
     MID_GNE_ADDITIONALFRAME_REMOVEROW,
-    /// @brief select additional parent
-    MID_GNE_ADDITIONALFRAME_SELECTADDITIONALPARENT,
-    /// @brief search edge
-    MID_GNE_ADDITIONALFRAME_SEARCHEDGE,
-    /// @brief show only selected edge in a list
-    MID_GNE_ADDITIONALFRAME_SHOWONLYSELECTEDEDGES,
-    /// @brief select edge
-    MID_GNE_ADDITIONALFRAME_SELECTEDGE,
-    /// @brief clear selection of edges
-    MID_GNE_ADDITIONALFRAME_CLEAREDGESELECTION,
-    /// @brief invert selection of edges
-    MID_GNE_ADDITIONALFRAME_INVERTEDGESELECTION,
-    /// @brief search lane
-    MID_GNE_ADDITIONALFRAME_SEARCHLANE,
-    /// @brief use selected lanes
-    MID_GNE_ADDITIONALFRAME_USESELECTEDLANES,
-    /// @brief select lane
-    MID_GNE_ADDITIONALFRAME_SELECTLANE,
-    /// @brief clear selection of lanes
-    MID_GNE_ADDITIONALFRAME_CLEARLANESELECTION,
-    /// @brief invert selection of lanes
-    MID_GNE_ADDITIONALFRAME_INVERTLANESELECTION,
+    /// @brief search element
+    MID_GNE_ADDITIONALFRAME_SEARCH,
+    /// @brief use selected elements
+    MID_GNE_ADDITIONALFRAME_USESELECTED,
+    /// @brief select element
+    MID_GNE_ADDITIONALFRAME_SELECT,
+    /// @brief clear selection of elements
+    MID_GNE_ADDITIONALFRAME_CLEARSELECTION,
+    /// @brief invert selection of eleents
+    MID_GNE_ADDITIONALFRAME_INVERTSELECTION,
+    /// @brief start selection of consecutive egdes/lanes
+    MID_GNE_ADDITIONALFRAME_STARTSELECTION,
+    /// @brief stop selection of consecutive egdes/lanes
+    MID_GNE_ADDITIONALFRAME_STOPSELECTION,
+    /// @brief abort selection of consecutive egdes/lanes
+    MID_GNE_ADDITIONALFRAME_ABORTSELECTION,
     /// @}
 
 
-    /// @name GNEPolygonFrame messages
+    /// @name GNEProhibitionFrame messages
     /// @{
 
-    /// @brief start drawing polygon
-    MID_GNE_POLYGONFRAME_STARTDRAWING,
-    /// @brief stop drawing polygon
-    MID_GNE_POLYGONFRAME_STOPDRAWING,
+    /// @brief select prohibiting connection
+    MID_GNE_PROHIBITIONFRAME_SELECTPROHIBITING,
+    /// @brief select connections to be prohibited
+    MID_GNE_PROHIBITIONFRAME_SELECTPROHIBITED,
     /// @brief abort drawing polygon
-    MID_GNE_POLYGONFRAME_ABORTDRAWING,
-    /// @brief enable or disable closing polygon after drawing
-    MID_GNE_POLYGONFRAME_CLOSE,
+    MID_GNE_PROHIBITIONFRAME_ABORTDRAWING,
     /// @}
 
 
     /// @name GNEEdge messages
     /// @{
 
-    /// @brief set non-default geometry endpoint
-    MID_GNE_EDGE_SET_ENDPOINT,
-    /// @brief restore geometry endpoint to node position
+    /// @brief change default geometry endpoints
+    MID_GNE_EDGE_EDIT_ENDPOINT,
+    /// @brief reset default geometry endpoints
     MID_GNE_EDGE_RESET_ENDPOINT,
     /// @brief remove inner geometry
     MID_GNE_EDGE_STRAIGHTEN,
@@ -717,8 +728,12 @@ enum {
     MID_GNE_JUNCTION_RESET_CONNECTIONS,
     /// @brief turn junction into geometry node
     MID_GNE_JUNCTION_REPLACE,
+    /// @brief turn junction into multiple junctions
+    MID_GNE_JUNCTION_SPLIT,
     /// @brief edit junction shape
     MID_GNE_JUNCTION_EDIT_SHAPE,
+    /// @brief reset junction shape
+    MID_GNE_JUNCTION_RESET_SHAPE,
     /// @}
 
 
@@ -766,24 +781,32 @@ enum {
 
     /// @brief duplicate a lane
     MID_GNE_LANE_DUPLICATE,
+    /// @brief remove greenVerge
+    MID_GNE_LANE_RESET_CUSTOMSHAPE,
     /// @brief transform lane to sidewalk
     MID_GNE_LANE_TRANSFORM_SIDEWALK,
     /// @brief transform lane to bikelane
     MID_GNE_LANE_TRANSFORM_BIKE,
     /// @brief transform lane to busLane
     MID_GNE_LANE_TRANSFORM_BUS,
+    /// @brief transform lane to greenVerge
+    MID_GNE_LANE_TRANSFORM_GREENVERGE,
     /// @brief add sidewalk
     MID_GNE_LANE_ADD_SIDEWALK,
     /// @brief add bikelane
     MID_GNE_LANE_ADD_BIKE,
     /// @brief add busLane
     MID_GNE_LANE_ADD_BUS,
+    /// @brief add greenVerge
+    MID_GNE_LANE_ADD_GREENVERGE,
     /// @brief remove sidewalk
     MID_GNE_LANE_REMOVE_SIDEWALK,
     /// @brief remove bikelane
     MID_GNE_LANE_REMOVE_BIKE,
     /// @brief remove busLane
     MID_GNE_LANE_REMOVE_BUS,
+    /// @brief remove greenVerge
+    MID_GNE_LANE_REMOVE_GREENVERGE,
     /// @}
 
 
@@ -802,8 +825,10 @@ enum {
     /// @{
     /// @brief add row
     MID_GNE_VARIABLESPEEDSIGN_ADDROW,
-    /// @brief remove row
-    MID_GNE_VARIABLESPEEDSIGN_TABLE_STEPS,
+    /// @brief Click over Table
+    MID_GNE_VARIABLESPEEDSIGN_TABLE,
+    /// @brief sort table values
+    MID_GNE_VARIABLESPEEDSIGN_SORT,
     /// @}
 
 
@@ -812,7 +837,7 @@ enum {
 
     /// @brief select table interval
     MID_GNE_REROUTEDIALOG_TABLE_INTERVAL,
-    /// @brief change table clisng lane reroute reroute
+    /// @brief change table closing lane reroute reroute
     MID_GNE_REROUTEDIALOG_TABLE_CLOSINGLANEREROUTE,
     /// @brief change table route closing reroute
     MID_GNE_REROUTEDIALOG_TABLE_CLOSINGREROUTE,
@@ -820,8 +845,12 @@ enum {
     MID_GNE_REROUTEDIALOG_TABLE_DESTPROBREROUTE,
     /// @brief change table route probability reroute
     MID_GNE_REROUTEDIALOG_TABLE_ROUTEPROBREROUTE,
+    /// @brief change table parkingAreaReroute
+    MID_GNE_REROUTEDIALOG_TABLE_PARKINGAREAREROUTE,
     /// @brief add interval
     MID_GNE_REROUTEDIALOG_ADD_INTERVAL,
+    /// @brief sort rerouter intervals
+    MID_GNE_REROUTEDIALOG_SORT_INTERVAL,
     /// @brief add closing lane reroute
     MID_GNE_REROUTEDIALOG_ADD_CLOSINGLANEREROUTE,
     /// @brief add closing reroute
@@ -830,6 +859,8 @@ enum {
     MID_GNE_REROUTEDIALOG_ADD_DESTPROBREROUTE,
     /// @brief add route probability route
     MID_GNE_REROUTEDIALOG_ADD_ROUTEPROBREROUTE,
+    /// @brief add parkingAreaReroute
+    MID_GNE_REROUTEDIALOG_ADD_PARKINGAREAREROUTE,
     /// @brief edit interval
     MID_GNE_REROUTEDIALOG_EDIT_INTERVAL,
     /// @}
@@ -851,8 +882,6 @@ enum {
     MID_GNE_CALIBRATORDIALOG_ADD_VEHICLETYPE,
     /// @brief set new variable
     MID_GNE_CALIBRATORDIALOG_SET_VARIABLE,
-    /// @brief set flow type
-    MID_GNE_CALIBRATORDIALOG_SET_FLOWTYPE,
     /// @}
 
     /// @name allowDisallow Dialog messages
@@ -876,6 +905,19 @@ enum {
     MID_GNE_FIXSTOPPINGPLACES_CHANGE,
     /// @}
 
+    /// @name Generic Parameters Dialog messages
+    /// @{
+
+    /// @brief Generic parameters dialog load
+    MID_GNE_GENERICPARAMETERS_LOAD,
+    /// @brief Generic parameters dialog save
+    MID_GNE_GENERICPARAMETERS_SAVE,
+    /// @brief Generic parameters dialog clear
+    MID_GNE_GENERICPARAMETERS_CLEAR,
+    /// @brief Generic parameters dialog sort
+    MID_GNE_GENERICPARAMETERS_SORT,
+    /// @}
+
 
     /// @brief last element of enum (not used)
     MID_LAST
