@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIDanielPerspectiveChanger.cpp
 /// @author  Daniel Krajzewicz
@@ -23,15 +21,12 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <fxkeys.h>
 #include <utils/geom/Boundary.h>
 #include <utils/geom/Position.h>
+#include <utils/geom/GeomHelper.h>
 #include <utils/gui/settings/GUICompleteSchemeStorage.h>
 #include "GUIPerspectiveChanger.h"
 #include "GUIDanielPerspectiveChanger.h"
@@ -158,7 +153,7 @@ GUIDanielPerspectiveChanger::onLeftBtnPress(void* data) {
 
 bool
 GUIDanielPerspectiveChanger::onLeftBtnRelease(void* data) {
-    myMouseButtonState &= !MOUSEBTN_LEFT;
+    myMouseButtonState &= ~MOUSEBTN_LEFT;
     FXEvent* e = (FXEvent*) data;
     myMouseXPosition = e->win_x;
     myMouseYPosition = e->win_y;
@@ -180,8 +175,8 @@ GUIDanielPerspectiveChanger::onRightBtnPress(void* data) {
 
 bool
 GUIDanielPerspectiveChanger::onRightBtnRelease(void* data) {
-    myMouseButtonState &= !MOUSEBTN_RIGHT;
-    if (data != 0) {
+    myMouseButtonState &= ~MOUSEBTN_RIGHT;
+    if (data != nullptr) {
         FXEvent* e = (FXEvent*) data;
         myMouseXPosition = e->win_x;
         myMouseYPosition = e->win_y;
@@ -228,7 +223,13 @@ GUIDanielPerspectiveChanger::onMouseMove(void* data) {
     switch (myMouseButtonState) {
         case MOUSEBTN_LEFT:
             if (pastDelay) {
-                move(xdiff, ydiff);
+                if (myRotation != 0) {
+                    Position diffRot = Position(xdiff, ydiff).rotateAround2D(
+                                           DEG2RAD(myRotation), Position(0, 0));
+                    move((int)diffRot.x(), (int)diffRot.y());
+                } else {
+                    move(xdiff, ydiff);
+                }
                 if (moved) {
                     myMoveOnClick = true;
                 }
@@ -272,6 +273,11 @@ GUIDanielPerspectiveChanger::setViewportFrom(double xPos, double yPos, double zP
 }
 
 
+void
+GUIDanielPerspectiveChanger::setRotation(double rotation) {
+    myRotation = rotation;
+}
+
 void
 GUIDanielPerspectiveChanger::changeCanvasSizeLeft(int change) {
     myViewPort = Boundary(
@@ -294,9 +300,7 @@ GUIDanielPerspectiveChanger::onKeyPress(void* data) {
     double moveY = 0;
     double moveFactor = 1;
     bool pageVertical = true;
-    bool ctrl = false;
     if (e->state & CONTROLMASK) {
-        ctrl = true;
         zoomDiff /= 2;
         moveFactor /= 10;
     } else if (e->state & SHIFTMASK) {
@@ -352,13 +356,6 @@ GUIDanielPerspectiveChanger::onKeyPress(void* data) {
             myCallback.recenterView();
             myCallback.update();
             return 1;
-        case FX::KEY_v:
-            // from an architecture standpoint this isn't the best place to put
-            // this. But its simple
-            if (ctrl) {
-                myCallback.showViewschemeEditor();
-                return 1;
-            }
         default:
             return 0;
     }
