@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIDanielPerspectiveChanger.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/geom/Position.h>
 #include "GUIPerspectiveChanger.h"
@@ -102,6 +96,9 @@ public:
     /// @brief Alternative method for setting the viewport
     void setViewportFrom(double xPos, double yPos, double zPos);
 
+    /// @brief Sets the rotation
+    void setRotation(double rotation);
+
     /* @brief Adapts the viewport so that a change in canvass size keeps most of the
      * view intact (by showing more / less instead of zooming)
      * The canvass is clipped/enlarged on the left side of the screen
