@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIDialog_GLObjChooser.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <vector>
@@ -63,50 +57,29 @@ FXIMPLEMENT(GUIDialog_GLObjChooser, FXMainWindow, GUIDialog_GLObjChooserMap, ARR
 // ===========================================================================
 // method definitions
 // ===========================================================================
-GUIDialog_GLObjChooser::GUIDialog_GLObjChooser(
-    GUIGlChildWindow* parent,
-    FXIcon* icon,
-    const FXString& title,
-    const std::vector<GUIGlID>& ids,
-    GUIGlObjectStorage& glStorage):
-    FXMainWindow(parent->getApp(), title, icon, NULL, DECOR_ALL, 20, 20, 300, 300),
+GUIDialog_GLObjChooser::GUIDialog_GLObjChooser(GUIGlChildWindow* parent, FXIcon* icon, const FXString& title, const std::vector<GUIGlID>& ids, GUIGlObjectStorage& /*glStorage*/) :
+    FXMainWindow(parent->getApp(), title, icon, nullptr, GUIDesignChooserDialog),
     myParent(parent) {
-    FXHorizontalFrame* hbox = new FXHorizontalFrame(this, LAYOUT_FILL_X | LAYOUT_FILL_Y, 0, 0, 0, 0, 0, 0, 0, 0);
+    FXHorizontalFrame* hbox = new FXHorizontalFrame(this, GUIDesignAuxiliarFrame);
     // build the list
-    FXVerticalFrame* layout1 = new FXVerticalFrame(hbox, LAYOUT_FILL_X | LAYOUT_FILL_Y | LAYOUT_TOP, 0, 0, 0, 0, 4, 4, 4, 4);
-    myTextEntry = new FXTextField(layout1, 0, this, MID_CHOOSER_TEXT, LAYOUT_FILL_X | FRAME_THICK | FRAME_SUNKEN);
-    FXVerticalFrame* style1 = new FXVerticalFrame(layout1, LAYOUT_FILL_X | LAYOUT_FILL_Y | LAYOUT_TOP | FRAME_THICK | FRAME_SUNKEN, 0, 0, 0, 0, 0, 0, 0, 0);
-    myList = new FXList(style1, this, MID_CHOOSER_LIST, LAYOUT_FILL_X | LAYOUT_FILL_Y | LIST_SINGLESELECT | FRAME_SUNKEN | FRAME_THICK);
-    for (std::vector<GUIGlID>::const_iterator i = ids.begin(); i != ids.end(); ++i) {
-        GUIGlObject* o = glStorage.getObjectBlocking(*i);
-        if (o == 0) {
-            continue;
-        }
-        const std::string& name = o->getMicrosimID();
-        bool selected = myParent->isSelected(o);
-        FXIcon* icon = selected ? GUIIconSubSys::getIcon(ICON_FLAG) : 0;
-        myIDs.insert(o->getGlID());
-        myList->appendItem(name.c_str(), icon, (void*) & (*myIDs.find(o->getGlID())));
-        glStorage.unblockObject(*i);
-    }
+    FXVerticalFrame* layoutLeft = new FXVerticalFrame(hbox, GUIDesignChooserLayoutLeft);
+    myTextEntry = new FXTextField(layoutLeft, 0, this, MID_CHOOSER_TEXT, GUIDesignChooserTextField);
+    FXVerticalFrame* layoutList = new FXVerticalFrame(layoutLeft, GUIDesignChooserLayoutList);
+    myList = new FXList(layoutList, this, MID_CHOOSER_LIST, GUIDesignChooserListSingle);
+    refreshList(ids);
     // build the buttons
-    FXVerticalFrame* layout = new FXVerticalFrame(hbox, LAYOUT_TOP, 0, 0, 0, 0, 4, 4, 4, 4);
-    myCenterButton = new FXButton(layout, "Center\t\t", GUIIconSubSys::getIcon(ICON_RECENTERVIEW),
-                                  this, MID_CHOOSER_CENTER, ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                                  0, 0, 0, 0, 4, 4, 4, 4);
-    new FXHorizontalSeparator(layout, GUIDesignHorizontalSeparator);
-    new FXButton(layout, "&Hide Unselected\t\t", GUIIconSubSys::getIcon(ICON_FLAG),
-                 this, MID_CHOOSER_FILTER, ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 4, 4);
-    new FXButton(layout, "&Select/deselect\tSelect/deselect current object\t", GUIIconSubSys::getIcon(ICON_FLAG),
-                 this, MID_CHOOSEN_INVERT, ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 4, 4);
-    new FXHorizontalSeparator(layout, GUIDesignHorizontalSeparator);
-    new FXButton(layout, "&Close\t\t", GUIIconSubSys::getIcon(ICON_NO),
-                 this, MID_CANCEL, ICON_BEFORE_TEXT | LAYOUT_FILL_X | FRAME_THICK | FRAME_RAISED,
-                 0, 0, 0, 0, 4, 4, 4, 4);
+    FXVerticalFrame* layoutRight = new FXVerticalFrame(hbox, GUIDesignChooserLayoutRight);
+    myCenterButton = new FXButton(layoutRight, "Center\t\t", GUIIconSubSys::getIcon(ICON_RECENTERVIEW), this, MID_CHOOSER_CENTER, GUIDesignChooserButtons);
+    new FXHorizontalSeparator(layoutRight, GUIDesignHorizontalSeparator);
+    new FXButton(layoutRight, "&Hide Unselected\t\t", GUIIconSubSys::getIcon(ICON_FLAG), this, MID_CHOOSER_FILTER, GUIDesignChooserButtons);
+    new FXButton(layoutRight, "&Select/deselect\tSelect/deselect current object\t", GUIIconSubSys::getIcon(ICON_FLAG), this, MID_CHOOSEN_INVERT, GUIDesignChooserButtons);
+    new FXHorizontalSeparator(layoutRight, GUIDesignHorizontalSeparator);
+    new FXButton(layoutRight, "&Close\t\t", GUIIconSubSys::getIcon(ICON_NO), this, MID_CANCEL, GUIDesignChooserButtons);
 
     myParent->getParent()->addChild(this);
+    // create and show dialog
+    create();
+    show();
 }
 
 
@@ -174,7 +147,7 @@ GUIDialog_GLObjChooser::onListKeyPress(FXObject*, FXSelector, void* ptr) {
     FXEvent* event = (FXEvent*)ptr;
     switch (event->code) {
         case KEY_Return:
-            onCmdText(0, 0, 0);
+            onCmdText(nullptr, 0, nullptr);
             break;
         default:
             break;
@@ -187,33 +160,49 @@ long
 GUIDialog_GLObjChooser::onCmdFilter(FXObject*, FXSelector, void*) {
     FXIcon* flag = GUIIconSubSys::getIcon(ICON_FLAG);
     std::vector<GUIGlID> selectedGlIDs;
-    std::vector<FXString> selectedMicrosimIDs;
     const int numItems = myList->getNumItems();
     for (int i = 0; i < numItems; i++) {
         const GUIGlID glID = *static_cast<GUIGlID*>(myList->getItemData(i));
         if (myList->getItemIcon(i) == flag) {
             selectedGlIDs.push_back(glID);
-            selectedMicrosimIDs.push_back(myList->getItemText(i));
         }
     }
-    myList->clearItems();
-    const int numSelected = (const int)selectedGlIDs.size();
-    for (int i = 0; i < numSelected; i++) {
-        myList->appendItem(selectedMicrosimIDs[i], flag, (void*) & (*myIDs.find(selectedGlIDs[i])));
-    }
-    myList->update();
+    refreshList(selectedGlIDs);
     return 1;
 }
 
+std::string
+GUIDialog_GLObjChooser::getObjectName(GUIGlObject* o) const {
+    return o->getMicrosimID();
+}
+
+void
+GUIDialog_GLObjChooser::refreshList(const std::vector<GUIGlID>& ids) {
+    myList->clearItems();
+    for (auto i : ids) {
+        GUIGlObject* o = GUIGlObjectStorage::gIDStorage.getObjectBlocking(i);
+        if (o == nullptr) {
+            continue;
+        }
+        const std::string& name = getObjectName(o);
+        bool selected = myParent->isSelected(o);
+        FXIcon* icon = selected ? GUIIconSubSys::getIcon(ICON_FLAG) : nullptr;
+        myIDs.insert(o->getGlID());
+        myList->appendItem(name.c_str(), icon, (void*) & (*myIDs.find(o->getGlID())));
+        GUIGlObjectStorage::gIDStorage.unblockObject(i);
+    }
+    myList->update();
+}
+
+
 long
 GUIDialog_GLObjChooser::onCmdToggleSelection(FXObject*, FXSelector, void*) {
     FXIcon* flag = GUIIconSubSys::getIcon(ICON_FLAG);
     int i = myList->getCurrentItem();
     if (i >= 0) {
-        GUIGlID* glID = static_cast<GUIGlID*>(myList->getItemData(i));
-        gSelected.toggleSelection(*glID);
+        toggleSelection(i);
         if (myList->getItemIcon(i) == flag) {
-            myList->setItemIcon(i, 0);
+            myList->setItemIcon(i, nullptr);
         } else {
             myList->setItemIcon(i, flag);
         }
@@ -224,5 +213,14 @@ GUIDialog_GLObjChooser::onCmdToggleSelection(FXObject*, FXSelector, void*) {
 }
 
 
+void
+GUIDialog_GLObjChooser::toggleSelection(int listIndex) {
+    GUIGlID* glID = static_cast<GUIGlID*>(myList->getItemData(listIndex));
+    gSelected.toggleSelection(*glID);
+}
+
+
+
+
 /****************************************************************************/
 
