@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUIDialog_ViewSettings.h
 /// @author  Daniel Krajzewicz
@@ -25,15 +23,10 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <fx.h>
 #include <utils/gui/windows/GUISUMOAbstractView.h>
-#include <utils/foxtools/FXRealSpinDial.h>
 #include <utils/foxtools/MFXAddEditTypedTable.h>
 
 
@@ -67,8 +60,10 @@ public:
         void update(const GUIVisualizationTextSettings& settings);
 
         FXCheckButton* myCheck;
-        FXRealSpinDial* mySizeDial;
+        FXRealSpinner* mySizeDial;
         FXColorWell* myColorWell;
+        FXColorWell* myBGColorWell;
+        FXCheckButton* myConstSizeCheck;
     };
 
     class SizePanel {
@@ -79,9 +74,10 @@ public:
         GUIVisualizationSizeSettings getSettings();
         void update(const GUIVisualizationSizeSettings& settings);
 
-        FXRealSpinDial* myMinSizeDial;
-        FXRealSpinDial* myExaggerateDial;
+        FXRealSpinner* myMinSizeDial;
+        FXRealSpinner* myExaggerateDial;
         FXCheckButton* myCheck;
+        FXCheckButton* myCheckSelected;
     };
 
     /** @brief Constructor
@@ -172,15 +168,15 @@ public:
 private:
     bool updateColorRanges(FXObject* sender, std::vector<FXColorWell*>::const_iterator colIt,
                            std::vector<FXColorWell*>::const_iterator colEnd,
-                           std::vector<FXRealSpinDial*>::const_iterator threshIt,
-                           std::vector<FXRealSpinDial*>::const_iterator threshEnd,
+                           std::vector<FXRealSpinner*>::const_iterator threshIt,
+                           std::vector<FXRealSpinner*>::const_iterator threshEnd,
                            std::vector<FXButton*>::const_iterator buttonIt,
                            GUIColorScheme& scheme);
 
-    bool updateScaleRanges(FXObject* sender, std::vector<FXRealSpinDial*>::const_iterator colIt,
-                           std::vector<FXRealSpinDial*>::const_iterator colEnd,
-                           std::vector<FXRealSpinDial*>::const_iterator threshIt,
-                           std::vector<FXRealSpinDial*>::const_iterator threshEnd,
+    bool updateScaleRanges(FXObject* sender, std::vector<FXRealSpinner*>::const_iterator colIt,
+                           std::vector<FXRealSpinner*>::const_iterator colEnd,
+                           std::vector<FXRealSpinner*>::const_iterator threshIt,
+                           std::vector<FXRealSpinner*>::const_iterator threshEnd,
                            std::vector<FXButton*>::const_iterator buttonIt,
                            GUIScaleScheme& scheme);
 
@@ -188,7 +184,7 @@ private:
      */
     FXMatrix* rebuildColorMatrix(FXVerticalFrame* frame,
                                  std::vector<FXColorWell*>& colors,
-                                 std::vector<FXRealSpinDial*>& thresholds,
+                                 std::vector<FXRealSpinner*>& thresholds,
                                  std::vector<FXButton*>& buttons,
                                  FXCheckButton* interpolation,
                                  GUIColorScheme& scheme);
@@ -196,8 +192,8 @@ private:
     /** @brief Rebuilds manipulators for the current scaling scheme
      */
     FXMatrix* rebuildScaleMatrix(FXVerticalFrame* frame,
-                                 std::vector<FXRealSpinDial*>& scales,
-                                 std::vector<FXRealSpinDial*>& thresholds,
+                                 std::vector<FXRealSpinner*>& scales,
+                                 std::vector<FXRealSpinner*>& thresholds,
                                  std::vector<FXButton*>& buttons,
                                  FXCheckButton* interpolation,
                                  GUIScaleScheme& scheme);
@@ -233,6 +229,9 @@ private:
     /// @brief save window position and size to the registry
     void saveWindowSize();
 
+    /// @brief load window position and size from the registry
+    void loadWindowSize();
+
 private:
     /// @brief The parent view (which settings are changed)
     GUISUMOAbstractView* myParent;
@@ -253,39 +252,47 @@ private:
     /// @{
     FXComboBox* mySchemeName;
     FXCheckButton* myShowGrid;
-    FXRealSpinDial* myGridXSizeDialer, *myGridYSizeDialer;
+    FXRealSpinner* myGridXSizeDialer, *myGridYSizeDialer;
 
     FXColorWell* myBackgroundColor;
     FXVerticalFrame* myDecalsFrame;
     MFXAddEditTypedTable* myDecalsTable;
 
+    /// selection colors
+    FXColorWell* mySelectionColor;
+    FXColorWell* mySelectedEdgeColor;
+    FXColorWell* mySelectedLaneColor;
+    FXColorWell* mySelectedConnectionColor;
+    FXColorWell* mySelectedAdditionalColor;
+
     /// ... lane colorer
     FXComboBox* myLaneEdgeColorMode;
     FXVerticalFrame* myLaneColorSettingFrame;
     std::vector<FXColorWell*> myLaneColors;
-    std::vector<FXRealSpinDial*> myLaneThresholds;
+    std::vector<FXRealSpinner*> myLaneThresholds;
     std::vector<FXButton*> myLaneButtons;
     FXCheckButton* myLaneColorInterpolation;
     FXButton* myLaneColorRainbow;
     FXButton* myJunctionColorRainbow;
+    FXTextField* myParamKey;
 
     /// ... lane scaler
     FXComboBox* myLaneEdgeScaleMode;
     FXVerticalFrame* myLaneScaleSettingFrame;
-    std::vector<FXRealSpinDial*> myLaneScales;
-    std::vector<FXRealSpinDial*> myLaneScaleThresholds;
+    std::vector<FXRealSpinner*> myLaneScales;
+    std::vector<FXRealSpinner*> myLaneScaleThresholds;
     std::vector<FXButton*> myLaneScaleButtons;
     FXCheckButton* myLaneScaleInterpolation;
 
-    FXCheckButton* myShowLaneBorders, *myShowLaneDecals, *myShowLinkRules, *myShowRails,
-                   *myHideMacroConnectors, *myShowLaneDirection, *myShowSublanes;
-    FXRealSpinDial* myLaneWidthUpscaleDialer;
-    FXRealSpinDial* myLaneMinWidthDialer;
+    FXCheckButton* myShowLaneBorders, *myShowBikeMarkings, *myShowLaneDecals, *myShowLinkRules, *myShowRails,
+                   *myHideMacroConnectors, *myShowLaneDirection, *myShowSublanes, *mySpreadSuperposed;
+    FXRealSpinner* myLaneWidthUpscaleDialer;
+    FXRealSpinner* myLaneMinWidthDialer;
 
     FXComboBox* myVehicleColorMode, *myVehicleShapeDetail;
     FXVerticalFrame* myVehicleColorSettingFrame;
     std::vector<FXColorWell*> myVehicleColors;
-    std::vector<FXRealSpinDial*> myVehicleThresholds;
+    std::vector<FXRealSpinner*> myVehicleThresholds;
     std::vector<FXButton*> myVehicleButtons;
     FXCheckButton* myVehicleColorInterpolation;
     FXCheckButton* myShowBlinker, *myShowMinGap, *myShowBTRange; /* *myShowLaneChangePreference,*/
@@ -293,42 +300,58 @@ private:
     FXComboBox* myPersonColorMode, *myPersonShapeDetail;
     FXVerticalFrame* myPersonColorSettingFrame;
     std::vector<FXColorWell*> myPersonColors;
-    std::vector<FXRealSpinDial*> myPersonThresholds;
+    std::vector<FXRealSpinner*> myPersonThresholds;
     std::vector<FXButton*> myPersonButtons;
     FXCheckButton* myPersonColorInterpolation;
 
     FXComboBox* myContainerColorMode, *myContainerShapeDetail;
     FXVerticalFrame* myContainerColorSettingFrame;
     std::vector<FXColorWell*> myContainerColors;
-    std::vector<FXRealSpinDial*> myContainerThresholds;
+    std::vector<FXRealSpinner*> myContainerThresholds;
     std::vector<FXButton*> myContainerButtons;
     FXCheckButton* myContainerColorInterpolation;
-    FXRealSpinDial* myContainerMinSizeDialer, *myContainerUpscaleDialer;
+    FXRealSpinner* myContainerMinSizeDialer, *myContainerUpscaleDialer;
 
     FXComboBox* myJunctionColorMode;
     FXVerticalFrame* myJunctionColorSettingFrame;
     std::vector<FXColorWell*> myJunctionColors;
-    std::vector<FXRealSpinDial*> myJunctionThresholds;
+    std::vector<FXRealSpinner*> myJunctionThresholds;
     std::vector<FXButton*> myJunctionButtons;
     FXCheckButton* myJunctionColorInterpolation;
 
+    FXComboBox* myPOIColorMode, *myPOIShapeDetail;
+    FXVerticalFrame* myPOIColorSettingFrame;
+    std::vector<FXColorWell*> myPOIColors;
+    std::vector<FXRealSpinner*> myPOIThresholds;
+    std::vector<FXButton*> myPOIButtons;
+    FXCheckButton* myPOIColorInterpolation;
+
+    FXComboBox* myPolyColorMode, *myPolyShapeDetail;
+    FXVerticalFrame* myPolyColorSettingFrame;
+    std::vector<FXColorWell*> myPolyColors;
+    std::vector<FXRealSpinner*> myPolyThresholds;
+    std::vector<FXButton*> myPolyButtons;
+    FXCheckButton* myPolyColorInterpolation;
+
     FXCheckButton* myShowLane2Lane;
     FXCheckButton* myDrawJunctionShape;
     FXCheckButton* myDrawCrossingsAndWalkingAreas;
     FXCheckButton* myDither;
     FXCheckButton* myShowSizeLegend;
 
-    NamePanel* myEdgeNamePanel, *myInternalEdgeNamePanel, *myCwaEdgeNamePanel, *myStreetNamePanel,
+    NamePanel* myEdgeNamePanel, *myInternalEdgeNamePanel, *myCwaEdgeNamePanel, *myStreetNamePanel, *myEdgeValuePanel,
                *myJunctionIndexPanel, *myTLIndexPanel,
                *myJunctionNamePanel, *myInternalJunctionNamePanel,
-               *myVehicleNamePanel, *myPersonNamePanel, *myContainerNamePanel,
+               *myVehicleNamePanel, *myVehicleValuePanel,
+               *myPersonNamePanel, *myPersonValuePanel,
+               *myContainerNamePanel,
                *myAddNamePanel, *myAddFullNamePanel, *myPOINamePanel, *myPolyNamePanel, *myPOITypePanel, *myPolyTypePanel;
 
     SizePanel* myVehicleSizePanel, *myPersonSizePanel, *myContainerSizePanel, *myPOISizePanel, *myPolySizePanel, *myAddSizePanel, *myJunctionSizePanel;
 
 
     // load/save-menu
-    FXCheckButton* mySaveViewPort, *mySaveDelay, *mySaveDecals;
+    FXCheckButton* mySaveViewPort, *mySaveDelay, *mySaveDecals, *mySaveBreakpoints;
     /// @}
 
 
