@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    GUISUMOAbstractView.cpp
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include <utility>
@@ -37,7 +31,9 @@
 #include <cassert>
 #include <limits>
 #include <fxkeys.h>
-#include <foreign/gl2ps/gl2ps.h>
+#ifdef HAVE_GL2PS
+#include <gl2ps.h>
+#endif
 #include <utils/foxtools/FXSingleEventThread.h>
 #include <utils/foxtools/MFXCheckableButton.h>
 #include <utils/foxtools/MFXImageHelper.h>
@@ -57,6 +53,7 @@
 #include <utils/gui/globjects/GUIPolygon.h>
 #include <utils/gui/windows/GUIDialog_ViewSettings.h>
 #include <utils/geom/GeoConvHelper.h>
+#include <utils/geom/GeomHelper.h>
 #include <utils/gui/settings/GUICompleteSchemeStorage.h>
 #include <utils/gui/globjects/GLIncludes.h>
 #include <utils/gui/settings/GUIVisualizationSettings.h>
@@ -85,6 +82,12 @@
 // ===========================================================================
 //#define DEBUG_SNAPSHOT
 
+// ===========================================================================
+// static members
+// ===========================================================================
+
+const double GUISUMOAbstractView::SENSITIVITY = 0.1; // meters
+
 
 // ===========================================================================
 // member method definitions
@@ -122,19 +125,17 @@ GUISUMOAbstractView::GUISUMOAbstractView(FXComposite* p, GUIMainWindow& app, GUI
     myApp(&app),
     myParent(parent),
     myGrid(&((SUMORTree&)grid)),
-    myChanger(0),
+    myChanger(nullptr),
     myMouseHotspotX(app.getDefaultCursor()->getHotX()),
     myMouseHotspotY(app.getDefaultCursor()->getHotY()),
-    myPopup(0),
+    myPopup(nullptr),
     myPopupPosition(Position(0, 0)),
     myUseToolTips(false),
     myAmInitialised(false),
-    myViewportChooser(0),
+    myViewportChooser(nullptr),
     myWindowCursorPositionX(getWidth() / 2),
     myWindowCursorPositionY(getHeight() / 2),
-    myVisualizationChanger(0),
-    myApplicationSnapshots(0),
-    myApplicationSnapshotsLock(0) {
+    myVisualizationChanger(nullptr) {
     setTarget(this);
     enable();
     flags |= FLAG_ENABLED;
@@ -192,10 +193,16 @@ Position
 GUISUMOAbstractView::snapToActiveGrid(const Position& pos) const {
     Position result = pos;
     if (myVisualizationSettings->showGrid) {
-        const double xRest = std::fmod(pos.x(), myVisualizationSettings->gridXSize) + (pos.x() < 0 ? myVisualizationSettings->gridXSize : 0);
-        const double yRest = std::fmod(pos.y(), myVisualizationSettings->gridYSize) + (pos.y() < 0 ? myVisualizationSettings->gridYSize : 0);
-        result.setx(pos.x() - xRest + (xRest < myVisualizationSettings->gridXSize * 0.5 ? 0 : myVisualizationSettings->gridXSize));
-        result.sety(pos.y() - yRest + (yRest < myVisualizationSettings->gridYSize * 0.5 ? 0 : myVisualizationSettings->gridYSize));
+        if (pos.z() == 0) {
+            const double xRest = std::fmod(pos.x(), myVisualizationSettings->gridXSize) + (pos.x() < 0 ? myVisualizationSettings->gridXSize : 0);
+            const double yRest = std::fmod(pos.y(), myVisualizationSettings->gridYSize) + (pos.y() < 0 ? myVisualizationSettings->gridYSize : 0);
+            result.setx(pos.x() - xRest + (xRest < myVisualizationSettings->gridXSize * 0.5 ? 0 : myVisualizationSettings->gridXSize));
+            result.sety(pos.y() - yRest + (yRest < myVisualizationSettings->gridYSize * 0.5 ? 0 : myVisualizationSettings->gridYSize));
+        } else {
+            // snapZToActiveGrid uses grid Y Size
+            const double zRest = std::fmod(pos.z(), myVisualizationSettings->gridYSize) + (pos.z() < 0 ? myVisualizationSettings->gridYSize : 0);
+            result.setz(pos.z() - zRest + (zRest < myVisualizationSettings->gridYSize * 0.5 ? 0 : myVisualizationSettings->gridYSize));
+        }
     }
     return result;
 }
@@ -207,7 +214,12 @@ GUISUMOAbstractView::screenPos2NetPos(int x, int y) const {
     double xNet = bound.xmin() + bound.getWidth() * x / getWidth();
     // cursor origin is in the top-left corner
     double yNet = bound.ymin() + bound.getHeight() * (getHeight() - y) / getHeight();
-    return Position(xNet, yNet);
+    // rotate around the viewport center
+    if (myChanger->getRotation() != 0) {
+        return Position(xNet, yNet).rotateAround2D(-DEG2RAD(myChanger->getRotation()), bound.getCenter());
+    } else {
+        return Position(xNet, yNet);
+    }
 }
 
 
@@ -287,8 +299,8 @@ GUISUMOAbstractView::paintGL() {
     glEnable(GL_BLEND);
     glDisable(GL_LINE_SMOOTH);
 
-    applyGLTransform();
-    doPaintGL(GL_RENDER, myChanger->getViewport());
+    Boundary bound = applyGLTransform();
+    doPaintGL(GL_RENDER, bound);
     if (myVisualizationSettings->showSizeLegend) {
         displayLegend();
     }
@@ -307,9 +319,21 @@ GUISUMOAbstractView::getObjectUnderCursor() {
 }
 
 
+std::vector<GUIGlID> 
+GUISUMOAbstractView::getObjectstUnderCursor() {
+
+    return getObjectsAtPosition(getPositionInformation(), SENSITIVITY);
+}
+
+
+std::vector<GUIGlObject*>
+GUISUMOAbstractView::getGUIGlObjectsUnderCursor() {
+    return getGUIGlObjectsAtPosition(getPositionInformation(), SENSITIVITY);
+}
+
+
 GUIGlID
 GUISUMOAbstractView::getObjectAtPosition(Position pos) {
-    const double SENSITIVITY = 0.1; // meters
     Boundary selection;
     selection.add(pos);
     selection.grow(SENSITIVITY);
@@ -317,24 +341,28 @@ GUISUMOAbstractView::getObjectAtPosition(Position pos) {
     // Interpret results
     int idMax = 0;
     double maxLayer = -std::numeric_limits<double>::max();
-    for (std::vector<GUIGlID>::const_iterator it = ids.begin(); it != ids.end(); it++) {
-        GUIGlID id = *it;
-        GUIGlObject* o = GUIGlObjectStorage::gIDStorage.getObjectBlocking(id);
-        if (o == 0) {
+    // iterate over obtained GUIGlIDs
+    for (const auto &i : ids) {
+        // obtain GUIGlObject
+        GUIGlObject* o = GUIGlObjectStorage::gIDStorage.getObjectBlocking(i);
+        // check that GUIGlObject exist
+        if (o == nullptr) {
             continue;
         }
+        // check that GUIGlObject isn't the network
         if (o->getGlID() == 0) {
             continue;
         }
         //std::cout << "point selection hit " << o->getMicrosimID() << "\n";
         GUIGlObjectType type = o->getType();
-        if (type != 0) {
+        // avoid network
+        if (type != GLO_NETWORK) {
             double layer = (double)type;
             // determine an "abstract" layer for shapes
             //  this "layer" resembles the layer of the shape
             //  taking into account the stac of other objects
             if (type == GLO_POI || type == GLO_POLYGON) {
-                layer = dynamic_cast<Shape*>(o)->getLayer();
+                layer = dynamic_cast<Shape*>(o)->getShapeLayer();
             }
             if (type == GLO_LANE && GUIVisualizationSettings::UseMesoSim) {
                 // do not select lanes in meso mode
@@ -342,11 +370,12 @@ GUISUMOAbstractView::getObjectAtPosition(Position pos) {
             }
             // check whether the current object is above a previous one
             if (layer > maxLayer) {
-                idMax = id;
+                idMax = i;
                 maxLayer = layer;
             }
         }
-        GUIGlObjectStorage::gIDStorage.unblockObject(id);
+        // unblock object
+        GUIGlObjectStorage::gIDStorage.unblockObject(i);
     }
     return idMax;
 }
@@ -354,34 +383,71 @@ GUISUMOAbstractView::getObjectAtPosition(Position pos) {
 
 std::vector<GUIGlID>
 GUISUMOAbstractView::getObjectsAtPosition(Position pos, double radius) {
+    // declare result vector
+    std::vector<GUIGlID> result;
+    // calculate boundary
     Boundary selection;
     selection.add(pos);
     selection.grow(radius);
+    // obtain GUIGlID of objects in boundary
     const std::vector<GUIGlID> ids = getObjectsInBoundary(selection);
-    std::vector<GUIGlID> result;
-    // Interpret results
-    for (std::vector<GUIGlID>::const_iterator it = ids.begin(); it != ids.end(); it++) {
-        GUIGlID id = *it;
-        GUIGlObject* o = GUIGlObjectStorage::gIDStorage.getObjectBlocking(id);
-        if (o == 0) {
+    // iterate over obtained GUIGlIDs
+    for (const auto &i : ids) {
+        // obtain GUIGlObject
+        GUIGlObject* o = GUIGlObjectStorage::gIDStorage.getObjectBlocking(i);
+        // check that GUIGlObject exist
+        if (o == nullptr) {
             continue;
         }
+        // check that GUIGlObject isn't the network
         if (o->getGlID() == 0) {
             continue;
         }
         //std::cout << "point selection hit " << o->getMicrosimID() << "\n";
         GUIGlObjectType type = o->getType();
-        if (type != 0) {
-            result.push_back(id);
+        // avoid network
+        if (type != GLO_NETWORK) {
+            result.push_back(i);
         }
-        GUIGlObjectStorage::gIDStorage.unblockObject(id);
+        // unblock object
+        GUIGlObjectStorage::gIDStorage.unblockObject(i);
+    }
+    return result;
+}
+
+
+std::vector<GUIGlObject*>
+GUISUMOAbstractView::getGUIGlObjectsAtPosition(Position pos, double radius) {
+    // declare result vector
+    std::vector<GUIGlObject*> result;
+    // calculate boundary
+    Boundary selection;
+    selection.add(pos);
+    selection.grow(radius);
+    // obtain GUIGlID of objects in boundary
+    const std::vector<GUIGlID> ids = getObjectsInBoundary(selection);
+    // iterate over obtained GUIGlIDs
+    for (const auto &i : ids) {
+        // obtain GUIGlObject
+        GUIGlObject* o = GUIGlObjectStorage::gIDStorage.getObjectBlocking(i);
+        // check that GUIGlObject exist
+        if (o == nullptr) {
+            continue;
+        }
+        // check that GUIGlObject isn't the network
+        if (o->getGlID() == 0) {
+            continue;
+        }
+        result.push_back(o);
+        // unblock object
+        GUIGlObjectStorage::gIDStorage.unblockObject(i);
     }
     return result;
 }
 
 
 std::vector<GUIGlID>
-GUISUMOAbstractView::getObjectsInBoundary(const Boundary& bound) {
+GUISUMOAbstractView::getObjectsInBoundary(Boundary bound) {
     const int NB_HITS_MAX = 1024 * 1024;
     // Prepare the selection mode
     static GUIGlID hits[NB_HITS_MAX];
@@ -391,7 +457,7 @@ GUISUMOAbstractView::getObjectsInBoundary(const Boundary& bound) {
 
     Boundary oldViewPort = myChanger->getViewport(false); // backup the actual viewPort
     myChanger->setViewport(bound);
-    applyGLTransform(false);
+    bound = applyGLTransform(false);
 
     // paint in select mode
     myVisualizationSettings->drawForSelecting = true;
@@ -423,10 +489,16 @@ void
 GUISUMOAbstractView::showToolTipFor(const GUIGlID id) {
     if (id != 0) {
         GUIGlObject* object = GUIGlObjectStorage::gIDStorage.getObjectBlocking(id);
-        if (object != 0) {
+        if (object != nullptr) {
             Position pos = getPositionInformation();
             pos.add(0, p2m(15));
-            GLHelper::drawTextBox(object->getFullName(), pos, GLO_MAX - 1, p2m(20), RGBColor::BLACK, RGBColor(255, 179, 0, 255));
+            std::string label = object->getFullName();
+            if (myVisualizationSettings->edgeValue.show && 
+                    (object->getType() == GLO_EDGE || object->getType() == GLO_LANE)) {
+                const int activeScheme = myVisualizationSettings->getLaneEdgeMode();
+                label += " (" + toString(object->getColorValue(*myVisualizationSettings, activeScheme)) + ")";
+            }
+            GLHelper::drawTextBox(label, pos, GLO_MAX - 1, p2m(20), RGBColor::BLACK, RGBColor(255, 179, 0, 255));
             GUIGlObjectStorage::gIDStorage.unblockObject(id);
         }
     }
@@ -438,7 +510,7 @@ GUISUMOAbstractView::paintGLGrid() {
     // obtain minimum grid
     double minimumSizeGrid = (myVisualizationSettings->gridXSize < myVisualizationSettings->gridYSize) ? myVisualizationSettings->gridXSize : myVisualizationSettings->gridYSize;
     // Check if the distance is enought to draw grid
-    if (myVisualizationSettings->scale * myVisualizationSettings->addSize.getExaggeration(*myVisualizationSettings) >= (25 / minimumSizeGrid)) {
+    if (myVisualizationSettings->scale * myVisualizationSettings->addSize.getExaggeration(*myVisualizationSettings, nullptr) >= (25 / minimumSizeGrid)) {
         glEnable(GL_DEPTH_TEST);
         glLineWidth(1);
         // get multiplication values (2 is the marging)
@@ -500,10 +572,13 @@ GUISUMOAbstractView::displayLegend() {
     glLoadIdentity();
 
     // draw the scale bar
+    const double z = -1;
     glDisable(GL_TEXTURE_2D);
     glDisable(GL_ALPHA_TEST);
     glDisable(GL_BLEND);
     glEnable(GL_DEPTH_TEST);
+    glPushMatrix();
+    glTranslated(0, 0, z);
 
     double len = (double) pixelSize / (double)(getWidth() - 1) * (double) 2.0;
     glColor3d(0, 0, 0);
@@ -521,14 +596,15 @@ GUISUMOAbstractView::displayLegend() {
     glVertex2d(-.98 + len, -1. + o);
     glVertex2d(-.98 + len, -1. + o2);
     glEnd();
+    glPopMatrix();
 
     const double fontHeight = 0.1 * 300. / getHeight();
     const double fontWidth = 0.1 * 300. / getWidth();
     // draw 0
-    GLHelper::drawText("0", Position(-.99, -0.99 + o2 + oo), 0.1, fontHeight, RGBColor::BLACK, 0, FONS_ALIGN_LEFT, fontWidth);
+    GLHelper::drawText("0", Position(-.99, -0.99 + o2 + oo), z, fontHeight, RGBColor::BLACK, 0, FONS_ALIGN_LEFT, fontWidth);
 
     // draw current scale
-    GLHelper::drawText((text.substr(0, noDigits) + "m").c_str(), Position(-.99 + len, -0.99 + o2 + oo), 0.1, fontHeight, RGBColor::BLACK, 0, FONS_ALIGN_LEFT, fontWidth);
+    GLHelper::drawText((text.substr(0, noDigits) + "m").c_str(), Position(-.99 + len, -0.99 + o2 + oo), z, fontHeight, RGBColor::BLACK, 0, FONS_ALIGN_LEFT, fontWidth);
 
     // restore matrices
     glMatrixMode(GL_PROJECTION);
@@ -559,7 +635,7 @@ GUISUMOAbstractView::recenterView() {
 void
 GUISUMOAbstractView::centerTo(GUIGlID id, bool applyZoom, double zoomDist) {
     GUIGlObject* o = GUIGlObjectStorage::gIDStorage.getObjectBlocking(id);
-    if (o != 0 && dynamic_cast<GUIGlObject*>(o) != 0) {
+    if (o != nullptr && dynamic_cast<GUIGlObject*>(o) != nullptr) {
         if (applyZoom && zoomDist < 0) {
             myChanger->setViewport(o->getCenteringBoundary());
             update(); // only update when centering onto an object once
@@ -639,10 +715,10 @@ GUISUMOAbstractView::getPopupPosition() const {
 
 void
 GUISUMOAbstractView::destroyPopup() {
-    if (myPopup != NULL) {
+    if (myPopup != nullptr) {
         delete myPopup;
         myPopupPosition.set(0, 0);
-        myPopup = NULL;
+        myPopup = nullptr;
     }
 }
 
@@ -733,6 +809,12 @@ long
 GUISUMOAbstractView::onMouseWheel(FXObject*, FXSelector , void* data) {
     if (!myApp->isGaming()) {
         myChanger->onMouseWheel(data);
+        // upddate viewport
+        if (myViewportChooser != nullptr) {
+            myViewportChooser->setValues(myChanger->getZoom(),
+                                         myChanger->getXPos(), myChanger->getYPos(),
+                                         myChanger->getRotation());
+        }
         updatePositionInformation();
     }
     return 1;
@@ -745,12 +827,14 @@ GUISUMOAbstractView::onMouseMove(FXObject*, FXSelector , void* data) {
     if (myPopup && (myPopup->shown() == false)) {
         destroyPopup();
     }
-    if (myPopup == NULL) {
-        if (myViewportChooser == 0 || !myViewportChooser->haveGrabbed()) {
+    if (myPopup == nullptr) {
+        if (myViewportChooser == nullptr || !myViewportChooser->haveGrabbed()) {
             myChanger->onMouseMove(data);
         }
-        if (myViewportChooser != 0) {
-            myViewportChooser->setValues(myChanger->getZoom(), myChanger->getXPos(), myChanger->getYPos());
+        if (myViewportChooser != nullptr) {
+            myViewportChooser->setValues(myChanger->getZoom(),
+                                         myChanger->getXPos(), myChanger->getYPos(),
+                                         myChanger->getRotation());
         }
         updatePositionInformation();
     }
@@ -773,13 +857,13 @@ GUISUMOAbstractView::openObjectDialog() {
     if (makeCurrent()) {
         // initialise the select mode
         int id = getObjectUnderCursor();
-        GUIGlObject* o = 0;
+        GUIGlObject* o = nullptr;
         if (id != 0) {
             o = GUIGlObjectStorage::gIDStorage.getObjectBlocking(id);
         } else {
             o = GUIGlObjectStorage::gIDStorage.getNetObject();
         }
-        if (o != 0) {
+        if (o != nullptr) {
             myPopup = o->getPopUpMenu(*myApp, *this);
             int x, y;
             FXuint b;
@@ -789,7 +873,7 @@ GUISUMOAbstractView::openObjectDialog() {
             myPopup->create();
             myPopup->show();
             myPopupPosition = getPositionInformation();
-            myChanger->onRightBtnRelease(0);
+            myChanger->onRightBtnRelease(nullptr);
             GUIGlObjectStorage::gIDStorage.unblockObject(id);
             setFocus();
         }
@@ -800,7 +884,7 @@ GUISUMOAbstractView::openObjectDialog() {
 
 long
 GUISUMOAbstractView::onKeyPress(FXObject* o, FXSelector sel, void* data) {
-    if (myPopup != NULL) {
+    if (myPopup != nullptr) {
         return myPopup->onKeyPress(o, sel, data);
     } else {
         FXGLCanvas::onKeyPress(o, sel, data);
@@ -811,7 +895,7 @@ GUISUMOAbstractView::onKeyPress(FXObject* o, FXSelector sel, void* data) {
 
 long
 GUISUMOAbstractView::onKeyRelease(FXObject* o, FXSelector sel, void* data) {
-    if (myPopup != NULL) {
+    if (myPopup != nullptr) {
         return myPopup->onKeyRelease(o, sel, data);
     } else {
         FXGLCanvas::onKeyRelease(o, sel, data);
@@ -822,22 +906,21 @@ GUISUMOAbstractView::onKeyRelease(FXObject* o, FXSelector sel, void* data) {
 
 // ------------ Dealing with snapshots
 void
-GUISUMOAbstractView::addSnapshot(SUMOTime time, const std::string& file) {
+GUISUMOAbstractView::addSnapshot(SUMOTime time, const std::string& file, const int width, const int height) {
 #ifdef DEBUG_SNAPSHOT
-    std::cout << "add snappshot time=" << time << " file=" << file << "\n";
+    std::cout << "add snapshot time=" << time << " file=" << file << "\n";
 #endif
-    mySnapshotsLock.lock();
-    mySnapshots[time].push_back(file);
-    mySnapshotsLock.unlock();
-    if (myApplicationSnapshots != 0) {
-        myApplicationSnapshotsLock->lock();
-        myApplicationSnapshots->insert(time);
-        myApplicationSnapshotsLock->unlock();
-    }
+    FXMutexLock lock(mySnapshotsMutex);
+    mySnapshots[time].push_back(std::make_tuple(file, width, height));
 }
 
+
 std::string
-GUISUMOAbstractView::makeSnapshot(const std::string& destFile) {
+GUISUMOAbstractView::makeSnapshot(const std::string& destFile, const int width, const int height) {
+    if (width >= 0) {
+        resize(width, height);
+        repaint();
+    }
     std::string errorMessage;
     FXString ext = FXPath::extension(destFile.c_str());
     const bool useGL2PS = ext == "ps" || ext == "eps" || ext == "pdf" || ext == "svg" || ext == "tex" || ext == "pgf";
@@ -867,6 +950,7 @@ GUISUMOAbstractView::makeSnapshot(const std::string& destFile) {
     applyGLTransform();
 
     if (useGL2PS) {
+#ifdef HAVE_GL2PS
         GLint format = GL2PS_PS;
         if (ext == "ps") {
             format = GL2PS_PS;
@@ -901,7 +985,6 @@ GUISUMOAbstractView::makeSnapshot(const std::string& destFile) {
             glDisable(GL_ALPHA_TEST);
             glDisable(GL_BLEND);
             glEnable(GL_DEPTH_TEST);
-            // compute lane width
             // draw decals (if not in grabbing mode)
             if (!myUseToolTips) {
                 drawDecals();
@@ -926,6 +1009,9 @@ GUISUMOAbstractView::makeSnapshot(const std::string& destFile) {
             glFinish();
         }
         fclose(fp);
+#else
+        return "Could not save '" + destFile + "', gl2ps was not enabled at compile time.";
+#endif
     } else {
         doPaintGL(GL_RENDER, myChanger->getViewport());
         if (myVisualizationSettings->showSizeLegend) {
@@ -989,42 +1075,46 @@ GUISUMOAbstractView::saveFrame(const std::string& destFile, FXColor* buf) {
 
 void
 GUISUMOAbstractView::checkSnapshots() {
-    SUMOTime time = getCurrentTimeStep() - DELTA_T;
+    const SUMOTime time = getCurrentTimeStep() - DELTA_T;
 #ifdef DEBUG_SNAPSHOT
-    std::cout << "check snappshots time=" << time << " registeredTimes=" << mySnapshots.size() << "\n";
+    std::cout << "check snapshots time=" << time << " registeredTimes=" << mySnapshots.size() << "\n";
 #endif
-    mySnapshotsLock.lock();
-    std::map<SUMOTime, std::vector<std::string> >::iterator snapIt = mySnapshots.find(time);
-    std::vector<std::string> files;
-    if (snapIt != mySnapshots.end()) {
-        files = snapIt->second;
-        mySnapshots.erase(snapIt);
+    FXMutexLock lock(mySnapshotsMutex);
+    const auto snapIt = mySnapshots.find(time);
+    if (snapIt == mySnapshots.end()) {
+        return;
     }
-    mySnapshotsLock.unlock();
+    std::vector<std::tuple<std::string, int, int> > files = snapIt->second;
+    lock.unlock();
     // decouple map access and painting to avoid deadlock
-    for (auto file : files) {
+    for (const auto& entry : files) {
 #ifdef DEBUG_SNAPSHOT
-        std::cout << "make snappshot time=" << time << " file=" << file << "\n";
+        std::cout << "make snapshot time=" << time << " file=" << file << "\n";
 #endif
-        std::string error = makeSnapshot(file);
-        if (error != "") {
+        const std::string& error = makeSnapshot(std::get<0>(entry), std::get<1>(entry), std::get<2>(entry));
+        if (error != "" && error != "video") {
             WRITE_WARNING(error);
         }
     }
     // synchronization with a waiting run thread
-    if (!files.empty()) {
-        assert(myApplicationSnapshots != 0);
-        assert(myApplicationSnapshotsLock != 0);
-        myApplicationSnapshotsLock->lock();
-        myApplicationSnapshots->erase(time);
-        myApplicationSnapshotsLock->unlock();
-    }
+    lock.lock();
+    mySnapshots.erase(time);
+    mySnapshotCondition.signal();
 #ifdef DEBUG_SNAPSHOT
     std::cout << "  files=" << toString(files) << " myApplicationSnapshots=" << joinToString(*myApplicationSnapshots, ",") << "\n";
 #endif
 }
 
 
+void
+GUISUMOAbstractView::waitForSnapshots(const SUMOTime snapshotTime) {
+    FXMutexLock lock(mySnapshotsMutex);
+    if (mySnapshots.count(snapshotTime) > 0) {
+        mySnapshotCondition.wait(mySnapshotsMutex);
+    }
+}
+
+
 SUMOTime
 GUISUMOAbstractView::getCurrentTimeStep() const {
     return 0;
@@ -1033,7 +1123,7 @@ GUISUMOAbstractView::getCurrentTimeStep() const {
 
 void
 GUISUMOAbstractView::showViewschemeEditor() {
-    if (myVisualizationChanger == 0) {
+    if (myVisualizationChanger == nullptr) {
         myVisualizationChanger =
             new GUIDialog_ViewSettings(
             this, myVisualizationSettings,
@@ -1048,11 +1138,21 @@ GUISUMOAbstractView::showViewschemeEditor() {
 
 GUIDialog_EditViewport*
 GUISUMOAbstractView::getViewportEditor() {
-    if (myViewportChooser == 0) {
-        myViewportChooser = new GUIDialog_EditViewport(this, "Edit Viewport", 0, 0);
+    if (myViewportChooser == nullptr) {
+        const FXint minSize = 100;
+        const FXint minTitlebarHeight = 20;
+        int x = MAX2(0, MIN2(getApp()->reg().readIntEntry(
+                                 "VIEWPORT_DIALOG_SETTINGS", "x", 150),
+                             getApp()->getRootWindow()->getWidth() - minSize));
+        int y = MAX2(minTitlebarHeight, MIN2(getApp()->reg().readIntEntry(
+                "VIEWPORT_DIALOG_SETTINGS", "y", 150),
+                                             getApp()->getRootWindow()->getHeight() - minSize));
+        myViewportChooser = new GUIDialog_EditViewport(this, "Edit Viewport", x, y);
         myViewportChooser->create();
     }
-    myViewportChooser->setValues(myChanger->getZoom(), myChanger->getXPos(), myChanger->getYPos());
+    myViewportChooser->setValues(myChanger->getZoom(),
+                                 myChanger->getXPos(), myChanger->getYPos(),
+                                 myChanger->getRotation());
     return myViewportChooser;
 }
 
@@ -1061,14 +1161,15 @@ void
 GUISUMOAbstractView::showViewportEditor() {
     getViewportEditor(); // make sure it exists;
     Position p(myChanger->getXPos(), myChanger->getYPos(), myChanger->getZPos());
-    myViewportChooser->setOldValues(p, Position::INVALID);
+    myViewportChooser->setOldValues(p, Position::INVALID, myChanger->getRotation());
     myViewportChooser->show();
 }
 
 
 void
-GUISUMOAbstractView::setViewportFromTo(const Position& lookFrom, const Position& /* lookAt */) {
+GUISUMOAbstractView::setViewportFromToRot(const Position& lookFrom, const Position& /* lookAt */, double rotation) {
     myChanger->setViewportFrom(lookFrom.x(), lookFrom.y(), lookFrom.z());
+    myChanger->setRotation(rotation);
     update();
 }
 
@@ -1076,8 +1177,9 @@ GUISUMOAbstractView::setViewportFromTo(const Position& lookFrom, const Position&
 void
 GUISUMOAbstractView::copyViewportTo(GUISUMOAbstractView* view) {
     // look straight down
-    view->setViewportFromTo(Position(myChanger->getXPos(), myChanger->getYPos(), myChanger->getZPos()),
-                            Position(myChanger->getXPos(), myChanger->getYPos(), 0));
+    view->setViewportFromToRot(Position(myChanger->getXPos(), myChanger->getYPos(), myChanger->getZPos()),
+                               Position(myChanger->getXPos(), myChanger->getYPos(), 0),
+                               myChanger->getRotation());
 }
 
 
@@ -1101,13 +1203,13 @@ GUISUMOAbstractView::getVisualisationSettings() const {
 
 void
 GUISUMOAbstractView::remove(GUIDialog_EditViewport*) {
-    myViewportChooser = 0;
+    myViewportChooser = nullptr;
 }
 
 
 void
 GUISUMOAbstractView::remove(GUIDialog_ViewSettings*) {
-    myVisualizationChanger = 0;
+    myVisualizationChanger = nullptr;
 }
 
 
@@ -1225,7 +1327,7 @@ GUISUMOAbstractView::checkGDALImage(Decal& d) {
     }
     FXFREE(&result);
 #endif
-    return 0;
+    return nullptr;
 }
 
 
@@ -1241,7 +1343,7 @@ GUISUMOAbstractView::drawDecals() {
         if (!d.initialised) {
             try {
                 FXImage* img = checkGDALImage(d);
-                if (img == 0) {
+                if (img == nullptr) {
                     img = MFXImageHelper::loadImage(getApp(), d.filename);
                 }
                 MFXImageHelper::scalePower2(img, GUITexturesHelper::getMaxTextureSize());
@@ -1315,7 +1417,7 @@ GUISUMOAbstractView::isAdditionalGLVisualisationEnabled(GUIGlObject* const which
 }
 
 
-void
+Boundary
 GUISUMOAbstractView::applyGLTransform(bool fixRatio) {
     Boundary bound = myChanger->getViewport(fixRatio);
     glMatrixMode(GL_PROJECTION);
@@ -1330,6 +1432,22 @@ GUISUMOAbstractView::applyGLTransform(bool fixRatio) {
     double scaleY = (double)getHeight() / bound.getHeight();
     glScaled(scaleX, scaleY, 1);
     glTranslated(-bound.xmin(), -bound.ymin(), 0);
+    // rotate around the center of the screen
+    //double angle = -90;
+    if (myChanger->getRotation() != 0) {
+        glTranslated(bound.getCenter().x(), bound.getCenter().y(), 0);
+        glRotated(myChanger->getRotation(), 0, 0, 1);
+        glTranslated(-bound.getCenter().x(), -bound.getCenter().y(), 0);
+        Boundary rotBound;
+        double rad = -DEG2RAD(myChanger->getRotation());
+        rotBound.add(Position(bound.xmin(), bound.ymin()).rotateAround2D(rad, bound.getCenter()));
+        rotBound.add(Position(bound.xmin(), bound.ymax()).rotateAround2D(rad, bound.getCenter()));
+        rotBound.add(Position(bound.xmax(), bound.ymin()).rotateAround2D(rad, bound.getCenter()));
+        rotBound.add(Position(bound.xmax(), bound.ymax()).rotateAround2D(rad, bound.getCenter()));
+        bound = rotBound;
+        myVisualizationSettings->angle = myChanger->getRotation();
+    }
+    return bound;
 }
 
 
@@ -1361,9 +1479,8 @@ GUISUMOAbstractView::Decal::Decal() :
     skip2D(false),
     screenRelative(false),
     glID(-1),
-    image(0) {
+    image(nullptr) {
 }
 
 
 /****************************************************************************/
-
