@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2004-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2004-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    OutputDevice.h
 /// @author  Daniel Krajzewicz
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <map>
@@ -125,7 +119,7 @@ public:
 
     /**  Closes all registered devices
      */
-    static void closeAll();
+    static void closeAll(bool keepErrorRetrievers = false);
     /// @}
 
 
@@ -143,7 +137,7 @@ public:
     /// @{
 
     /// @brief Constructor
-    OutputDevice(const bool binary = false, const int defaultIndentation = 0);
+    OutputDevice(const bool binary = false, const int defaultIndentation = 0, const std::string& filename = "");
 
 
     /// @brief Destructor
@@ -155,6 +149,8 @@ public:
      */
     virtual bool ok();
 
+    /// @brief get filename or suitable description of this device
+    const std::string& getFilename();
 
     /** @brief Closes the device and removes it from the dictionary
      */
@@ -219,7 +215,7 @@ public:
     OutputDevice& openTag(const SumoXMLTag& xmlElement);
 
 
-    /** @brief Closes the most recently opened tag
+    /** @brief Closes the most recently opened tag and optionally adds a comment
      *
      * The topmost xml-element from the stack is written into the stream
      *  as a closing element. Depending on the formatter used
@@ -229,7 +225,7 @@ public:
      * @return Whether a further element existed in the stack and could be closed
      * @todo it is not verified that the topmost element was closed
      */
-    bool closeTag();
+    bool closeTag(const std::string& comment = "");
 
 
 
@@ -308,6 +304,11 @@ public:
         return *this;
     }
 
+    /// @brief writes padding (ignored for binary output)
+    OutputDevice& writePadding(const std::string& val) {
+        myFormatter->writePadding(getOStream(), val);
+        return *this;
+    }
 
     /** @brief Retrieves a message to this device.
      *
@@ -328,6 +329,10 @@ public:
         return *this;
     }
 
+    void flush() {
+        getOStream().flush();
+    }
+
 protected:
     /// @brief Returns the associated ostream
     virtual std::ostream& getOStream() = 0;
@@ -351,6 +356,9 @@ private:
 
     const bool myAmBinary;
 
+protected:
+    std::string myFilename;
+
 public:
     /// @brief Invalidated copy constructor.
     OutputDevice(const OutputDevice&);
