@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2004-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2004-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    OutputDevice_CERR.cpp
 /// @author  Daniel Krajzewicz
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include "OutputDevice_CERR.h"
@@ -35,7 +29,7 @@
 // ===========================================================================
 // static member definitions
 // ===========================================================================
-OutputDevice* OutputDevice_CERR::myInstance = 0;
+OutputDevice* OutputDevice_CERR::myInstance = nullptr;
 
 
 // ===========================================================================
@@ -44,7 +38,7 @@ OutputDevice* OutputDevice_CERR::myInstance = 0;
 OutputDevice*
 OutputDevice_CERR::getDevice() {
     // check whether the device has already been aqcuired
-    if (myInstance == 0) {
+    if (myInstance == nullptr) {
         myInstance = new OutputDevice_CERR();
     }
     return myInstance;
@@ -54,11 +48,13 @@ OutputDevice_CERR::getDevice() {
 // ===========================================================================
 // method definitions
 // ===========================================================================
-OutputDevice_CERR::OutputDevice_CERR() {}
+OutputDevice_CERR::OutputDevice_CERR() {
+    myFilename = "CERR";
+}
 
 
 OutputDevice_CERR::~OutputDevice_CERR() {
-    myInstance = 0;
+    myInstance = nullptr;
 }
 
 
