@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2012-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    OutputFormatter.h
 /// @author  Daniel Krajzewicz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <vector>
@@ -99,16 +93,18 @@ public:
     virtual void openTag(std::ostream& into, const SumoXMLTag& xmlElement) = 0;
 
 
-    /** @brief Closes the most recently opened tag
+    /** @brief Closes the most recently opened tag and optinally add a comment
      *
      * @param[in] into The output stream to use
      * @return Whether a further element existed in the stack and could be closed
      * @todo it is not verified that the topmost element was closed
      */
-    virtual bool closeTag(std::ostream& into) = 0;
+    virtual bool closeTag(std::ostream& into, const std::string& comment = "") = 0;
 
     virtual void writePreformattedTag(std::ostream& into, const std::string& val) = 0;
 
+    virtual void writePadding(std::ostream& into, const std::string& val) = 0;
+
 };
 
 
