@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2012-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    PlainXMLFormatter.cpp
 /// @author  Daniel Krajzewicz
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/common/ToString.h>
 #include <utils/options/OptionsCont.h>
@@ -87,14 +81,14 @@ PlainXMLFormatter::openTag(std::ostream& into, const SumoXMLTag& xmlElement) {
 
 
 bool
-PlainXMLFormatter::closeTag(std::ostream& into) {
+PlainXMLFormatter::closeTag(std::ostream& into, const std::string& comment) {
     if (!myXMLStack.empty()) {
         if (myHavePendingOpener) {
-            into << "/>\n";
+            into << "/>" << comment << "\n";
             myHavePendingOpener = false;
         } else {
             const std::string indent(4 * (myXMLStack.size() + myDefaultIndentation - 1), ' ');
-            into << indent << "</" << myXMLStack.back() << ">\n";
+            into << indent << "</" << myXMLStack.back() << ">" << comment << "\n";
         }
         myXMLStack.pop_back();
         return true;
@@ -112,5 +106,10 @@ PlainXMLFormatter::writePreformattedTag(std::ostream& into, const std::string& v
     into << val;
 }
 
+void
+PlainXMLFormatter::writePadding(std::ostream& into, const std::string& val) {
+    into << val;
+}
+
 /****************************************************************************/
 
