@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    OptionsCont.cpp
 /// @author  Daniel Krajzewicz
@@ -22,11 +20,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <map>
 #include <string>
@@ -68,7 +62,7 @@ OptionsCont::getOptions() {
 
 OptionsCont::OptionsCont()
     : myAddresses(), myValues(), myDeprecatedSynonymes(), myHaveInformedAboutDeprecatedDivider(false) {
-    myCopyrightNotices.push_back("Copyright (C) 2001-2017 German Aerospace Center (DLR) and others; http://sumo.dlr.de");
+    myCopyrightNotices.push_back("Copyright (C) 2001-2018 German Aerospace Center (DLR) and others; http://sumo.dlr.de");
 }
 
 
@@ -239,6 +233,13 @@ OptionsCont::getIntVector(const std::string& name) const {
 }
 
 
+const FloatVector&
+OptionsCont::getFloatVector(const std::string& name) const {
+    Option* o = getSecure(name);
+    return o->getFloatVector();
+}
+
+
 bool
 OptionsCont::set(const std::string& name, const std::string& value) {
     Option* o = getSecure(name);
@@ -293,6 +294,12 @@ OptionsCont::getSynonymes(const std::string& name) const {
 }
 
 
+const std::string&
+OptionsCont::getDescription(const std::string& name) const {
+    return getSecure(name)->getDescription();
+}
+
+
 std::ostream&
 operator<<(std::ostream& os, const OptionsCont& oc) {
     std::vector<std::string> done;
@@ -329,30 +336,19 @@ operator<<(std::ostream& os, const OptionsCont& oc) {
 
 void
 OptionsCont::relocateFiles(const std::string& configuration) const {
-    for (ItemAddressContType::const_iterator i = myAddresses.begin(); i != myAddresses.end(); i++) {
-        if ((*i)->isFileName() && (*i)->isSet()) {
-            StringTokenizer st((*i)->getString(), ";, ", true);
-            std::string conv;
-            while (st.hasNext()) {
-                std::string tmp = st.next();
-                // Test whether this is a whitespace string and disregard item if so.
-                // This may stem, e.g., from separating filenames by ', ' in the configuration file
-                if (tmp.find_first_not_of("\t ") == std::string::npos) {
-                    continue;
-                }
-                if (!FileHelpers::isAbsolute(tmp)) {
-                    tmp = FileHelpers::getConfigurationRelative(configuration, tmp);
-                }
-                if (conv.length() != 0) {
-                    conv += ',';
-                }
-                conv += StringUtils::urlDecode(tmp);
+    for (Option* const option : myAddresses) {
+        if (option->isFileName() && option->isSet()) {
+            std::vector<std::string> fileList = StringTokenizer(option->getString(), ",").getVector();
+            for (std::string& f : fileList) {
+                // Pruning is necessary because filenames may be separated by ', ' in the configuration file
+                f = StringUtils::urlDecode(FileHelpers::checkForRelativity(StringUtils::prune(f), configuration));
             }
-            if (conv != (*i)->getString()) {
-                const bool hadDefault = (*i)->isDefault();
-                (*i)->set(conv);
+            const std::string conv = joinToString(fileList, ',');
+            if (conv != option->getString()) {
+                const bool hadDefault = option->isDefault();
+                option->set(conv);
                 if (hadDefault) {
-                    (*i)->resetDefault();
+                    option->resetDefault();
                 }
             }
         }
@@ -571,11 +567,12 @@ OptionsCont::processMetaOptions(bool missingOptions) {
                     myCopyrightNotices.begin(); it != myCopyrightNotices.end(); ++it) {
             std::cout << " " << *it << std::endl;
         }
-        std::cout << " License EPLv2: Eclipse Public License Version 2 <https://eclipse.org/legal/epl-v20.html>\n";
+        std::cout << " License EPL-2.0: Eclipse Public License Version 2 <https://eclipse.org/legal/epl-v20.html>\n";
         std::cout << " Use --help to get the list of options." << std::endl;
         return true;
     }
 
+    myWriteLicense = getBool("write-license");
     // check whether the help shall be printed
     if (getBool("help")) {
         std::cout << myFullName << std::endl;
@@ -595,16 +592,11 @@ OptionsCont::processMetaOptions(bool missingOptions) {
             std::cout << " " << *it << std::endl;
         }
         std::cout << "\n" << myFullName << " is part of SUMO.\n";
-        std::cout << "SUMO is free software: you can redistribute it and/or modify\n";
-        std::cout << "it under the terms of the GNU General Public License as published by\n";
-        std::cout << "the Free Software Foundation, either version 3 of the License, or\n";
-        std::cout << "(at your option) any later version.\n\n";
-        std::cout << "This program is distributed in the hope that it will be useful,\n";
-        std::cout << "but WITHOUT ANY WARRANTY; without even the implied warranty of\n";
-        std::cout << "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n";
-        std::cout << "GNU General Public License for more details.\n\n";
-        std::cout << "You should have received a copy of the GNU General Public License\n";
-        std::cout << "along with this program. If not, see http://www.gnu.org/licenses/gpl.html" << std::endl;
+        std::cout << "This program and the accompanying materials\n";
+        std::cout << "are made available under the terms of the Eclipse Public License v2.0\n";
+        std::cout << "which accompanies this distribution, and is available at\n";
+        std::cout << "http://www.eclipse.org/legal/epl-v20.html\n";
+        std::cout << "SPDX-License-Identifier: EPL-2.0" << std::endl;
         return true;
     }
     // check whether the settings shall be printed
@@ -648,14 +640,14 @@ OptionsCont::processMetaOptions(bool missingOptions) {
     }
     if (isSet("save-schema", false)) { // sumo-gui does not register these
         if (getString("save-schema") == "-" || getString("save-schema") == "stdout") {
-            writeSchema(std::cout, getBool("save-commented"));
+            writeSchema(std::cout);
             return true;
         }
         std::ofstream out(getString("save-schema").c_str());
         if (!out.good()) {
             throw ProcessError("Could not save schema to '" + getString("save-schema") + "'");
         } else {
-            writeSchema(out, getBool("save-commented"));
+            writeSchema(out);
             if (getBool("verbose")) {
                 WRITE_MESSAGE("Written schema to '" + getString("save-schema") + "'");
             }
@@ -756,7 +748,7 @@ OptionsCont::printHelp(std::ostream& os) {
         }
     }
     os << std::endl;
-    os << "Report bugs at <http://sumo.dlr.de/trac/>." << std::endl;
+    os << "Report bugs at <https://github.com/eclipse/sumo/issues>." << std::endl;
     os << "Get in contact via <sumo@dlr.de>." << std::endl;
 }
 
@@ -764,8 +756,10 @@ OptionsCont::printHelp(std::ostream& os) {
 void
 OptionsCont::writeConfiguration(std::ostream& os, const bool filled,
                                 const bool complete, const bool addComments,
-                                const bool maskDoubleHyphen) const {
-    os << "<?xml version=\"1.0\"" << SUMOSAXAttributes::ENCODING << "?>\n\n";
+                                const bool inComment) const {
+    if (!inComment) {
+        writeXMLHeader(os, false);
+    }
     os << "<configuration xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:noNamespaceSchemaLocation=\"http://sumo.dlr.de/xsd/";
     if (myAppName == "sumo-gui") {
         os << "sumo";
@@ -795,12 +789,12 @@ OptionsCont::writeConfiguration(std::ostream& os, const bool filled,
             }
             // add the comment if wished
             if (addComments) {
-                os << "        <!-- " << StringUtils::escapeXML(o->getDescription(), maskDoubleHyphen) << " -->" << std::endl;
+                os << "        <!-- " << StringUtils::escapeXML(o->getDescription(), inComment) << " -->" << std::endl;
             }
             // write the option and the value (if given)
             os << "        <" << *j << " value=\"";
             if (o->isSet() && (filled || o->isDefault())) {
-                os << StringUtils::escapeXML(o->getValueString(), maskDoubleHyphen);
+                os << StringUtils::escapeXML(o->getValueString(), inComment);
             }
             if (complete) {
                 std::vector<std::string> synonymes = getSynonymes(*j);
@@ -834,8 +828,8 @@ OptionsCont::writeConfiguration(std::ostream& os, const bool filled,
 
 
 void
-OptionsCont::writeSchema(std::ostream& os, bool /* addComments */) {
-    os << "<?xml version=\"1.0\"" << SUMOSAXAttributes::ENCODING << "?>\n\n";
+OptionsCont::writeSchema(std::ostream& os) {
+    writeXMLHeader(os, false);
     os << "<xsd:schema elementFormDefault=\"qualified\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\">\n\n";
     os << "    <xsd:include schemaLocation=\"baseTypes.xsd\"/>\n";
     os << "    <xsd:element name=\"configuration\" type=\"configurationType\"/>\n\n";
@@ -848,7 +842,7 @@ OptionsCont::writeSchema(std::ostream& os, bool /* addComments */) {
         }
         std::replace(subtopic.begin(), subtopic.end(), ' ', '_');
         std::transform(subtopic.begin(), subtopic.end(), subtopic.begin(), tolower);
-        os << "            <xsd:element name=\"" << subtopic << "\" type=\"" << subtopic << "Type\" minOccurs=\"0\"/>\n";
+        os << "            <xsd:element name=\"" << subtopic << "\" type=\"" << subtopic << "TopicType\" minOccurs=\"0\"/>\n";
     }
     os << "        </xsd:all>\n";
     os << "    </xsd:complexType>\n\n";
@@ -859,7 +853,7 @@ OptionsCont::writeSchema(std::ostream& os, bool /* addComments */) {
         }
         std::replace(subtopic.begin(), subtopic.end(), ' ', '_');
         std::transform(subtopic.begin(), subtopic.end(), subtopic.begin(), tolower);
-        os << "    <xsd:complexType name=\"" << subtopic << "Type\">\n";
+        os << "    <xsd:complexType name=\"" << subtopic << "TopicType\">\n";
         os << "        <xsd:all>\n";
         const std::vector<std::string>& entries = mySubTopicEntries[*i];
         for (std::vector<std::string>::const_iterator j = entries.begin(); j != entries.end(); ++j) {
@@ -879,7 +873,7 @@ OptionsCont::writeSchema(std::ostream& os, bool /* addComments */) {
 
 
 void
-OptionsCont::writeXMLHeader(std::ostream& os) {
+OptionsCont::writeXMLHeader(std::ostream& os, const bool includeConfig) const {
     time_t rawtime;
     char buffer [80];
 
@@ -887,7 +881,16 @@ OptionsCont::writeXMLHeader(std::ostream& os) {
     time(&rawtime);
     strftime(buffer, 80, "<!-- generated on %c by ", localtime(&rawtime));
     os << buffer << myFullName << "\n";
-    writeConfiguration(os, true, false, false, true);
+    if (myWriteLicense) {
+        os << "This data file and the accompanying materials\n";
+        os << "are made available under the terms of the Eclipse Public License v2.0\n";
+        os << "which accompanies this distribution, and is available at\n";
+        os << "http://www.eclipse.org/legal/epl-v20.html\n";
+        os << "SPDX-License-Identifier: EPL-2.0\n";
+    }
+    if (includeConfig) {
+        writeConfiguration(os, true, false, false, true);
+    }
     os << "-->\n\n";
 }
 
