@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    OptionsLoader.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <algorithm>
 #include <string>
@@ -36,7 +30,7 @@
 #include <xercesc/sax/AttributeList.hpp>
 #include <xercesc/sax/SAXParseException.hpp>
 #include <xercesc/sax/SAXException.hpp>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include <utils/common/StringTokenizer.h>
 #include "OptionsLoader.h"
 #include "OptionsCont.h"
@@ -58,11 +52,11 @@ OptionsLoader::~OptionsLoader() {}
 
 void OptionsLoader::startElement(const XMLCh* const name,
                                  XERCES_CPP_NAMESPACE::AttributeList& attributes) {
-    myItem = TplConvert::_2str(name);
+    myItem = StringUtils::transcode(name);
     if (!myRootOnly) {
         for (int i = 0; i < (int)attributes.getLength(); i++) {
-            std::string key = TplConvert::_2str(attributes.getName(i));
-            std::string value = TplConvert::_2str(attributes.getValue(i));
+            std::string key = StringUtils::transcode(attributes.getName(i));
+            std::string value = StringUtils::transcode(attributes.getValue(i));
             if (key == "value" || key == "v") {
                 setValue(myItem, value);
             }
@@ -91,7 +85,7 @@ void OptionsLoader::setValue(const std::string& key,
 
 void OptionsLoader::characters(const XMLCh* const chars,
                                const XERCES3_SIZE_t length) {
-    myValue = myValue + TplConvert::_2str(chars, (int) length);
+    myValue = myValue + StringUtils::transcode(chars, (int) length);
 }
 
 
@@ -122,7 +116,7 @@ OptionsLoader::endElement(const XMLCh* const /*name*/) {
 
 void
 OptionsLoader::warning(const XERCES_CPP_NAMESPACE::SAXParseException& exception) {
-    WRITE_WARNING(TplConvert::_2str(exception.getMessage()));
+    WRITE_WARNING(StringUtils::transcode(exception.getMessage()));
     WRITE_WARNING(" (At line/column " \
                   + toString(exception.getLineNumber() + 1) + '/' \
                   + toString(exception.getColumnNumber()) + ").");
@@ -133,7 +127,7 @@ OptionsLoader::warning(const XERCES_CPP_NAMESPACE::SAXParseException& exception)
 void
 OptionsLoader::error(const XERCES_CPP_NAMESPACE::SAXParseException& exception) {
     WRITE_ERROR(
-        TplConvert::_2str(exception.getMessage()));
+        StringUtils::transcode(exception.getMessage()));
     WRITE_ERROR(
         " (At line/column "
         + toString(exception.getLineNumber() + 1) + '/'
@@ -145,7 +139,7 @@ OptionsLoader::error(const XERCES_CPP_NAMESPACE::SAXParseException& exception) {
 void
 OptionsLoader::fatalError(const XERCES_CPP_NAMESPACE::SAXParseException& exception) {
     WRITE_ERROR(
-        TplConvert::_2str(exception.getMessage()));
+        StringUtils::transcode(exception.getMessage()));
     WRITE_ERROR(
         " (At line/column "
         + toString(exception.getLineNumber() + 1) + '/'
@@ -155,7 +149,7 @@ OptionsLoader::fatalError(const XERCES_CPP_NAMESPACE::SAXParseException& excepti
 
 
 bool
-OptionsLoader::errorOccured() const {
+OptionsLoader::errorOccurred() const {
     return myError;
 }
 
