@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    OptionsLoader.h
 /// @author  Daniel Krajzewicz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <xercesc/sax/HandlerBase.hpp>
 #include <xercesc/sax/AttributeList.hpp>
@@ -120,8 +114,8 @@ public:
 
 
 
-    /** @brief Returns the information whether an error occured */
-    bool errorOccured() const;
+    /** @brief Returns the information whether an error occurred */
+    bool errorOccurred() const;
 
     /** @brief Returns the last item read */
     const std::string& getItem() const {
@@ -166,7 +160,7 @@ private:
     /// @brief The information whether only the root element should be parsed
     bool myRootOnly;
 
-    /// @brief The information whether an error occured
+    /// @brief The information whether an error occurred
     bool myError;
 
     /// @brief The options to fill
