@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2004-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2004-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    SUMOPolygon.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/iodevices/OutputDevice.h>
 #include <utils/common/StringUtils.h>
@@ -39,12 +33,14 @@
 // member definitions
 // ===========================================================================
 SUMOPolygon::SUMOPolygon(const std::string& id, const std::string& type,
-                         const RGBColor& color, const PositionVector& shape, bool geo, bool fill,
-                         double layer, double angle, const std::string& imgFile) :
-    Shape(id, type, color, layer, angle, imgFile),
+                         const RGBColor& color, const PositionVector& shape, bool geo, bool fill, double lineWidth,
+                         double layer, double angle, const std::string& imgFile, bool relativePath) :
+    Shape(id, type, color, layer, angle, imgFile, relativePath),
     myShape(shape),
     myGEO(geo),
-    myFill(fill) {
+    myFill(fill),
+    myLineWidth(lineWidth)
+{
 }
 
 
@@ -55,12 +51,15 @@ void
 SUMOPolygon::writeXML(OutputDevice& out, bool geo) {
     out.openTag(SUMO_TAG_POLY);
     out.writeAttr(SUMO_ATTR_ID, StringUtils::escapeXML(getID()));
-    if (getType().size() > 0) {
-        out.writeAttr(SUMO_ATTR_TYPE, StringUtils::escapeXML(getType()));
+    if (getShapeType().size() > 0) {
+        out.writeAttr(SUMO_ATTR_TYPE, StringUtils::escapeXML(getShapeType()));
     }
-    out.writeAttr(SUMO_ATTR_COLOR, getColor());
+    out.writeAttr(SUMO_ATTR_COLOR, getShapeColor());
     out.writeAttr(SUMO_ATTR_FILL,  getFill());
-    out.writeAttr(SUMO_ATTR_LAYER, getLayer());
+    if (getLineWidth() != 1) {
+        out.writeAttr(SUMO_ATTR_LINEWIDTH, getLineWidth());
+    }
+    out.writeAttr(SUMO_ATTR_LAYER, getShapeLayer());
     PositionVector shape = getShape();
     if (geo) {
         out.writeAttr(SUMO_ATTR_GEO, true);
@@ -68,12 +67,21 @@ SUMOPolygon::writeXML(OutputDevice& out, bool geo) {
             GeoConvHelper::getFinal().cartesian2geo(shape[i]);
         }
     }
+    out.setPrecision(gPrecisionGeo);
     out.writeAttr(SUMO_ATTR_SHAPE, shape);
-    if (getNaviDegree() != Shape::DEFAULT_ANGLE) {
-        out.writeAttr(SUMO_ATTR_ANGLE, getNaviDegree());
+    out.setPrecision();
+    if (getShapeNaviDegree() != Shape::DEFAULT_ANGLE) {
+        out.writeAttr(SUMO_ATTR_ANGLE, getShapeNaviDegree());
     }
-    if (getImgFile() != Shape::DEFAULT_IMG_FILE) {
-        out.writeAttr(SUMO_ATTR_IMGFILE, getImgFile());
+    if (getShapeImgFile() != Shape::DEFAULT_IMG_FILE) {
+        if (getShapeRelativePath()) {
+            // write only the file name, without file path
+            std::string file = getShapeImgFile();
+            file.erase(0, FileHelpers::getFilePath(getShapeImgFile()).size());
+            out.writeAttr(SUMO_ATTR_IMGFILE, file);
+        } else {
+            out.writeAttr(SUMO_ATTR_IMGFILE, getShapeImgFile());
+        }
     }
     writeParams(out);
     out.closeTag();
