@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2012-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    Shape.cpp
 /// @author  Jakob Erdmann
@@ -22,11 +20,8 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
+#include <utils/gui/globjects/GUIGlObjectTypes.h>
 
 #include "Shape.h"
 
@@ -35,8 +30,11 @@
 // ===========================================================================
 const std::string Shape::DEFAULT_TYPE = "";
 const double Shape::DEFAULT_LAYER = 128;
+const double Shape::DEFAULT_LINEWIDTH = 1;
+const double Shape::DEFAULT_LAYER_POI = (double)GLO_POI;
 const double Shape::DEFAULT_ANGLE = 0;
 const std::string Shape::DEFAULT_IMG_FILE = "";
+const bool Shape::DEFAULT_RELATIVEPATH = false;
 const double Shape::DEFAULT_IMG_WIDTH = 1;
 const double Shape::DEFAULT_IMG_HEIGHT = 1;
 
@@ -45,13 +43,14 @@ const double Shape::DEFAULT_IMG_HEIGHT = 1;
 // ===========================================================================
 Shape::Shape(const std::string& id, const std::string& type,
              const RGBColor& color, double layer,
-             double angle, const std::string& imgFile) :
+             double angle, const std::string& imgFile, bool relativePath) :
     Named(id),
     myType(type),
     myColor(color),
     myLayer(layer),
     myNaviDegreeAngle(angle),
-    myImgFile(imgFile) {
+    myImgFile(imgFile),
+    myRelativePath(relativePath) {
 }
 
 
