@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    ShapeContainer.cpp
 /// @author  Daniel Krajzewicz
@@ -24,11 +22,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <fstream>
 #include <stdlib.h>
@@ -54,17 +48,17 @@ ShapeContainer::~ShapeContainer() {}
 bool
 ShapeContainer::addPolygon(const std::string& id, const std::string& type,
                            const RGBColor& color, double layer,
-                           double angle, const std::string& imgFile,
-                           const PositionVector& shape, bool geo, bool fill, bool ignorePruning) {
-    return add(new SUMOPolygon(id, type, color, shape, geo, fill, layer, angle, imgFile), ignorePruning);
+                           double angle, const std::string& imgFile, bool relativePath,
+                           const PositionVector& shape, bool geo, bool fill, double lineWidth, bool ignorePruning) {
+    return add(new SUMOPolygon(id, type, color, shape, geo, fill, lineWidth, layer, angle, imgFile, relativePath), ignorePruning);
 }
 
 
 bool
 ShapeContainer::addPOI(const std::string& id, const std::string& type, const RGBColor& color, const Position& pos, bool geo,
                        const std::string& lane, double posOverLane, double posLat, double layer, double angle,
-                       const std::string& imgFile, double width, double height, bool ignorePruning) {
-    return add(new PointOfInterest(id, type, color, pos, geo, lane, posOverLane, posLat, layer, angle, imgFile, width, height), ignorePruning);
+                       const std::string& imgFile, bool relativePath, double width, double height, bool ignorePruning) {
+    return add(new PointOfInterest(id, type, color, pos, geo, lane, posOverLane, posLat, layer, angle, imgFile, relativePath, width, height), ignorePruning);
 }
 
 
@@ -83,7 +77,7 @@ ShapeContainer::removePOI(const std::string& id) {
 void
 ShapeContainer::movePOI(const std::string& id, const Position& pos) {
     PointOfInterest* p = myPOIs.get(id);
-    if (p != 0) {
+    if (p != nullptr) {
         static_cast<Position*>(p)->set(pos);
     }
 }
@@ -92,7 +86,7 @@ ShapeContainer::movePOI(const std::string& id, const Position& pos) {
 void
 ShapeContainer::reshapePolygon(const std::string& id, const PositionVector& shape) {
     SUMOPolygon* p = myPolygons.get(id);
-    if (p != 0) {
+    if (p != nullptr) {
         p->setShape(shape);
     }
 }
