@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2012-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    TraCIAPI.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <vector>
 #include <limits>
@@ -84,21 +78,17 @@ public:
     /// @}
 
     /// @brief Advances by one step (or up to the given time)
-    void simulationStep(SUMOTime time = 0);
+    void simulationStep(double time = 0);
 
     /// @brief Let sumo load a simulation using the given command line like options.
     void load(const std::vector<std::string>& args);
 
     /// @name Atomar getter
     /// @{
-
-    SUMOTime getSUMOTime(int cmd, int var, const std::string& id, tcpip::Storage* add = 0);
     int getUnsignedByte(int cmd, int var, const std::string& id, tcpip::Storage* add = 0);
     int getByte(int cmd, int var, const std::string& id, tcpip::Storage* add = 0);
     int getInt(int cmd, int var, const std::string& id, tcpip::Storage* add = 0);
-    double getFloat(int cmd, int var, const std::string& id, tcpip::Storage* add = 0);
     double getDouble(int cmd, int var, const std::string& id, tcpip::Storage* add = 0);
-    libsumo::TraCIBoundary getBoundingBox(int cmd, int var, const std::string& id, tcpip::Storage* add = 0);
     libsumo::TraCIPositionVector getPolygon(int cmd, int var, const std::string& id, tcpip::Storage* add = 0);
     libsumo::TraCIPosition getPosition(int cmd, int var, const std::string& id, tcpip::Storage* add = 0);
     libsumo::TraCIPosition getPosition3D(int cmd, int var, const std::string& id, tcpip::Storage* add = 0);
@@ -118,15 +108,47 @@ public:
         /** @brief Constructor
          * @param[in] parent The parent TraCI client which offers the connection
          */
-        TraCIScopeWrapper(TraCIAPI& parent) : myParent(parent) {}
+        TraCIScopeWrapper(TraCIAPI& parent, int cmdGetID, int cmdSetID, int subscribeID, int contextSubscribeID) :
+            myParent(parent),
+            myCmdGetID(cmdGetID),
+            myCmdSetID(cmdSetID),
+            mySubscribeID(subscribeID),
+            myContextSubscribeID(contextSubscribeID) {
+        }
 
         /// @brief Destructor
         virtual ~TraCIScopeWrapper() {}
 
+        /// @brief retrieve generic paramter
+        std::string getParameter(const std::string& objectID, const std::string& key) const;
+
+        /// @brief set generic paramter
+        void setParameter(const std::string& objectID, const std::string& key, const std::string& value) const;
+
+        void subscribe(const std::string& objID, const std::vector<int>& vars, double beginTime, double endTime) const;
+        void subscribeContext(const std::string& objID, int domain, double range, const std::vector<int>& vars, double beginTime, double endTime) const;
+
+        const libsumo::SubscriptionResults getAllSubscriptionResults() const;
+        const libsumo::TraCIResults getSubscriptionResults(const std::string& objID) const;
+
+        const libsumo::ContextSubscriptionResults getAllContextSubscriptionResults() const;
+        const libsumo::SubscriptionResults getContextSubscriptionResults(const std::string& objID) const;
+
+        // the following are only for internal use
+        void clearSubscriptionResults();
+        libsumo::SubscriptionResults& getModifiableSubscriptionResults();
+        libsumo::SubscriptionResults& getModifiableContextSubscriptionResults(const std::string& objID);
+
 
     protected:
         /// @brief The parent TraCI client which offers the connection
         TraCIAPI& myParent;
+        int myCmdGetID;
+        int myCmdSetID;
+        int mySubscribeID;
+        int myContextSubscribeID;
+        libsumo::SubscriptionResults mySubscriptionResults;
+        libsumo::ContextSubscriptionResults myContextSubscriptionResults;
 
 
     private:
@@ -147,13 +169,13 @@ public:
      */
     class EdgeScope : public TraCIScopeWrapper {
     public:
-        EdgeScope(TraCIAPI& parent) : TraCIScopeWrapper(parent) {}
+        EdgeScope(TraCIAPI& parent) : TraCIScopeWrapper(parent, CMD_GET_EDGE_VARIABLE, CMD_SET_EDGE_VARIABLE, CMD_SUBSCRIBE_EDGE_VARIABLE, CMD_SUBSCRIBE_EDGE_CONTEXT) {}
         virtual ~EdgeScope() {}
 
         std::vector<std::string> getIDList() const;
         int getIDCount() const;
         double getAdaptedTraveltime(const std::string& edgeID, double time) const;
-        double getEffort(const std::string& edgeID, SUMOTime time) const;
+        double getEffort(const std::string& edgeID, double time) const;
         double getCO2Emission(const std::string& edgeID) const;
         double getCOEmission(const std::string& edgeID) const;
         double getHCEmission(const std::string& edgeID) const;
@@ -169,9 +191,11 @@ public:
         int getLastStepVehicleNumber(const std::string& edgeID) const;
         double getLastStepHaltingNumber(const std::string& edgeID) const;
         std::vector<std::string> getLastStepVehicleIDs(const std::string& edgeID) const;
+        int getLaneNumber(const std::string& edgeID) const;
+        std::string getStreetName(const std::string& id) const;
 
-        void adaptTraveltime(const std::string& edgeID, double time, int beginSeconds = 0, int endSeconds = std::numeric_limits<int>::max()) const;
-        void setEffort(const std::string& edgeID, double effort, int beginSeconds = 0, int endSeconds = std::numeric_limits<int>::max()) const;
+        void adaptTraveltime(const std::string& edgeID, double time, double beginSeconds = 0., double endSeconds = std::numeric_limits<double>::max()) const;
+        void setEffort(const std::string& edgeID, double effort, double beginSeconds = 0., double endSeconds = std::numeric_limits<double>::max()) const;
         void setMaxSpeed(const std::string& edgeID, double speed) const;
 
     private:
@@ -192,19 +216,19 @@ public:
      */
     class GUIScope : public TraCIScopeWrapper {
     public:
-        GUIScope(TraCIAPI& parent) : TraCIScopeWrapper(parent) {}
+        GUIScope(TraCIAPI& parent) : TraCIScopeWrapper(parent, CMD_GET_GUI_VARIABLE, CMD_SET_GUI_VARIABLE, CMD_SUBSCRIBE_GUI_VARIABLE, CMD_SUBSCRIBE_GUI_CONTEXT) {}
         virtual ~GUIScope() {}
 
         std::vector<std::string> getIDList() const;
         double getZoom(const std::string& viewID = DEFAULT_VIEW) const;
         libsumo::TraCIPosition getOffset(const std::string& viewID = DEFAULT_VIEW) const;
         std::string getSchema(const std::string& viewID = DEFAULT_VIEW) const;
-        libsumo::TraCIBoundary getBoundary(const std::string& viewID = DEFAULT_VIEW) const;
+        libsumo::TraCIPositionVector getBoundary(const std::string& viewID = DEFAULT_VIEW) const;
         void setZoom(const std::string& viewID, double zoom) const;
         void setOffset(const std::string& viewID, double x, double y) const;
         void setSchema(const std::string& viewID, const std::string& schemeName) const;
         void setBoundary(const std::string& viewID, double xmin, double ymin, double xmax, double ymax) const;
-        void screenshot(const std::string& viewID, const std::string& filename) const;
+        void screenshot(const std::string& viewID, const std::string& filename, const int width = -1, const int height = -1) const;
         void trackVehicle(const std::string& viewID, const std::string& vehID) const;
 
     private:
@@ -225,7 +249,7 @@ public:
      */
     class InductionLoopScope : public TraCIScopeWrapper {
     public:
-        InductionLoopScope(TraCIAPI& parent) : TraCIScopeWrapper(parent) {}
+        InductionLoopScope(TraCIAPI& parent) : TraCIScopeWrapper(parent, CMD_GET_INDUCTIONLOOP_VARIABLE, -1, CMD_SUBSCRIBE_INDUCTIONLOOP_VARIABLE, CMD_SUBSCRIBE_INDUCTIONLOOP_CONTEXT) {}
         virtual ~InductionLoopScope() {}
 
         std::vector<std::string> getIDList() const;
@@ -258,7 +282,7 @@ public:
      */
     class JunctionScope : public TraCIScopeWrapper {
     public:
-        JunctionScope(TraCIAPI& parent) : TraCIScopeWrapper(parent) {}
+        JunctionScope(TraCIAPI& parent) : TraCIScopeWrapper(parent, CMD_GET_JUNCTION_VARIABLE, CMD_SET_JUNCTION_VARIABLE, CMD_SUBSCRIBE_JUNCTION_VARIABLE, CMD_SUBSCRIBE_JUNCTION_CONTEXT) {}
         virtual ~JunctionScope() {}
 
         std::vector<std::string> getIDList() const;
@@ -282,7 +306,7 @@ public:
      */
     class LaneScope : public TraCIScopeWrapper {
     public:
-        LaneScope(TraCIAPI& parent) : TraCIScopeWrapper(parent) {}
+        LaneScope(TraCIAPI& parent) : TraCIScopeWrapper(parent, CMD_GET_LANE_VARIABLE, CMD_SET_LANE_VARIABLE, CMD_SUBSCRIBE_LANE_VARIABLE, CMD_SUBSCRIBE_LANE_CONTEXT) {}
         virtual ~LaneScope() {}
 
         std::vector<std::string> getIDList() const;
@@ -334,7 +358,7 @@ public:
     */
     class LaneAreaScope : public TraCIScopeWrapper {
     public:
-        LaneAreaScope(TraCIAPI& parent) : TraCIScopeWrapper(parent) {}
+        LaneAreaScope(TraCIAPI& parent) : TraCIScopeWrapper(parent, CMD_GET_LANEAREA_VARIABLE, -1, CMD_SUBSCRIBE_LANEAREA_VARIABLE, CMD_SUBSCRIBE_LANEAREA_CONTEXT) {}
         virtual ~LaneAreaScope() {}
 
         std::vector<std::string> getIDList() const;
@@ -354,7 +378,7 @@ public:
      */
     class MeMeScope : public TraCIScopeWrapper {
     public:
-        MeMeScope(TraCIAPI& parent) : TraCIScopeWrapper(parent) {}
+        MeMeScope(TraCIAPI& parent) : TraCIScopeWrapper(parent, CMD_GET_MULTIENTRYEXIT_VARIABLE, -1, CMD_SUBSCRIBE_MULTIENTRYEXIT_VARIABLE, CMD_SUBSCRIBE_MULTIENTRYEXIT_CONTEXT) {}
         virtual ~MeMeScope() {}
 
         std::vector<std::string> getIDList() const;
@@ -381,10 +405,11 @@ public:
      */
     class POIScope : public TraCIScopeWrapper {
     public:
-        POIScope(TraCIAPI& parent) : TraCIScopeWrapper(parent) {}
+        POIScope(TraCIAPI& parent) : TraCIScopeWrapper(parent, CMD_GET_POI_VARIABLE, CMD_SET_POI_VARIABLE, CMD_SUBSCRIBE_POI_VARIABLE, CMD_SUBSCRIBE_POI_CONTEXT) {}
         virtual ~POIScope() {}
 
         std::vector<std::string> getIDList() const;
+        int getIDCount() const;
         std::string getType(const std::string& poiID) const;
         libsumo::TraCIPosition getPosition(const std::string& poiID) const;
         libsumo::TraCIColor getColor(const std::string& poiID) const;
@@ -413,16 +438,19 @@ public:
      */
     class PolygonScope : public TraCIScopeWrapper {
     public:
-        PolygonScope(TraCIAPI& parent) : TraCIScopeWrapper(parent) {}
+        PolygonScope(TraCIAPI& parent) : TraCIScopeWrapper(parent, CMD_GET_POLYGON_VARIABLE, CMD_SET_POLYGON_VARIABLE, CMD_SUBSCRIBE_POLYGON_VARIABLE, CMD_SUBSCRIBE_POLYGON_CONTEXT) {}
         virtual ~PolygonScope() {}
 
         std::vector<std::string> getIDList() const;
+        int getIDCount() const;
+        double getLineWidth(const std::string& polygonID) const;
         std::string getType(const std::string& polygonID) const;
         libsumo::TraCIPositionVector getShape(const std::string& polygonID) const;
         libsumo::TraCIColor getColor(const std::string& polygonID) const;
         void setType(const std::string& polygonID, const std::string& setType) const;
         void setShape(const std::string& polygonID, const libsumo::TraCIPositionVector& shape) const;
         void setColor(const std::string& polygonID, const libsumo::TraCIColor& c) const;
+        void setLineWidth(const std::string& polygonID, const double lineWidth) const;
         void add(const std::string& polygonID, const libsumo::TraCIPositionVector& shape, const libsumo::TraCIColor& c, bool fill, const std::string& type, int layer) const;
         void remove(const std::string& polygonID, int layer = 0) const;
 
@@ -444,7 +472,7 @@ public:
      */
     class RouteScope : public TraCIScopeWrapper {
     public:
-        RouteScope(TraCIAPI& parent) : TraCIScopeWrapper(parent) {}
+        RouteScope(TraCIAPI& parent) : TraCIScopeWrapper(parent, CMD_GET_ROUTE_VARIABLE, CMD_SET_ROUTE_VARIABLE, CMD_SUBSCRIBE_ROUTE_VARIABLE, CMD_SUBSCRIBE_ROUTE_CONTEXT) {}
         virtual ~RouteScope() {}
 
         std::vector<std::string> getIDList() const;
@@ -463,21 +491,16 @@ public:
 
 
 
-    /// @brief {object->{variable->value}}
-    typedef std::map<int, libsumo::TraCIValue> TraCIValues;
-    typedef std::map<std::string, TraCIValues> SubscribedValues;
-    typedef std::map<std::string, SubscribedValues> SubscribedContextValues;
-
-
     /** @class SimulationScope
      * @brief Scope for interaction with the simulation
      */
     class SimulationScope : public TraCIScopeWrapper {
     public:
-        SimulationScope(TraCIAPI& parent) : TraCIScopeWrapper(parent) {}
+        SimulationScope(TraCIAPI& parent) : TraCIScopeWrapper(parent, CMD_GET_SIM_VARIABLE, CMD_SET_SIM_VARIABLE, CMD_SUBSCRIBE_SIM_VARIABLE, CMD_SUBSCRIBE_SIM_CONTEXT) {}
         virtual ~SimulationScope() {}
 
-        SUMOTime getCurrentTime() const;
+        int getCurrentTime() const;
+        double getTime() const;
         int getLoadedNumber() const;
         std::vector<std::string> getLoadedIDList() const;
         int getDepartedNumber() const;
@@ -488,18 +511,12 @@ public:
         std::vector<std::string> getStartingTeleportIDList() const;
         int getEndingTeleportNumber() const;
         std::vector<std::string> getEndingTeleportIDList() const;
-        SUMOTime getDeltaT() const;
-        libsumo::TraCIBoundary getNetBoundary() const;
+        double getDeltaT() const;
+        libsumo::TraCIPositionVector getNetBoundary() const;
         int getMinExpectedNumber() const;
+        double getDistance2D(double x1, double y1, double x2, double y2, bool isGeo = false, bool isDriving = false);
+        double getDistanceRoad(const std::string& edgeID1, double pos1, const std::string& edgeID2, double pos2, bool isDriving = false);
 
-        void subscribe(int domID, const std::string& objID, SUMOTime beginTime, SUMOTime endTime, const std::vector<int>& vars) const;
-        void subscribeContext(int domID, const std::string& objID, SUMOTime beginTime, SUMOTime endTime, int domain, double range, const std::vector<int>& vars) const;
-
-        const SubscribedValues& getSubscriptionResults() const;
-        const TraCIValues& getSubscriptionResults(const std::string& objID) const;
-
-        const SubscribedContextValues& getContextSubscriptionResults() const;
-        const SubscribedValues& getContextSubscriptionResults(const std::string& objID) const;
 
     private:
         /// @brief invalidated copy constructor
@@ -519,22 +536,24 @@ public:
      */
     class TrafficLightScope : public TraCIScopeWrapper {
     public:
-        TrafficLightScope(TraCIAPI& parent) : TraCIScopeWrapper(parent) {}
+        TrafficLightScope(TraCIAPI& parent) : TraCIScopeWrapper(parent, CMD_GET_TL_VARIABLE, CMD_SET_TL_VARIABLE, CMD_SUBSCRIBE_TL_VARIABLE, CMD_SUBSCRIBE_TL_CONTEXT) {}
         virtual ~TrafficLightScope() {}
 
         std::vector<std::string> getIDList() const;
+        int getIDCount() const;
         std::string getRedYellowGreenState(const std::string& tlsID) const;
         std::vector<libsumo::TraCILogic> getCompleteRedYellowGreenDefinition(const std::string& tlsID) const;
         std::vector<std::string> getControlledLanes(const std::string& tlsID) const;
         std::vector<std::vector<libsumo::TraCILink> > getControlledLinks(const std::string& tlsID) const;
         std::string getProgram(const std::string& tlsID) const;
         int getPhase(const std::string& tlsID) const;
-        int getNextSwitch(const std::string& tlsID) const;
+        double getPhaseDuration(const std::string& tlsID) const;
+        double getNextSwitch(const std::string& tlsID) const;
 
         void setRedYellowGreenState(const std::string& tlsID, const std::string& state) const;
         void setPhase(const std::string& tlsID, int index) const;
         void setProgram(const std::string& tlsID, const std::string& programID) const;
-        void setPhaseDuration(const std::string& tlsID, int phaseDuration) const;
+        void setPhaseDuration(const std::string& tlsID, double phaseDuration) const;
         void setCompleteRedYellowGreenDefinition(const std::string& tlsID, const libsumo::TraCILogic& logic) const;
 
     private:
@@ -555,7 +574,7 @@ public:
      */
     class VehicleTypeScope : public TraCIScopeWrapper {
     public:
-        VehicleTypeScope(TraCIAPI& parent) : TraCIScopeWrapper(parent) {}
+        VehicleTypeScope(TraCIAPI& parent) : TraCIScopeWrapper(parent, CMD_GET_VEHICLETYPE_VARIABLE, CMD_SET_VEHICLETYPE_VARIABLE, CMD_SUBSCRIBE_VEHICLETYPE_VARIABLE, CMD_SUBSCRIBE_VEHICLETYPE_CONTEXT) {}
         virtual ~VehicleTypeScope() {}
 
         std::vector<std::string> getIDList() const;
@@ -620,14 +639,33 @@ public:
      */
     class VehicleScope : public TraCIScopeWrapper {
     public:
-        VehicleScope(TraCIAPI& parent) : TraCIScopeWrapper(parent), LAST_TRAVEL_TIME_UPDATE(-1) {}
+        VehicleScope(TraCIAPI& parent) : TraCIScopeWrapper(parent, CMD_GET_VEHICLE_VARIABLE, CMD_SET_VEHICLE_VARIABLE, CMD_SUBSCRIBE_VEHICLE_VARIABLE, CMD_SUBSCRIBE_VEHICLE_CONTEXT) {}
         virtual ~VehicleScope() {}
 
+        enum VehicleSignal {
+            SIGNAL_BLINKER_RIGHT = 1,
+            SIGNAL_BLINKER_LEFT = 2,
+            SIGNAL_BLINKER_EMERGENCY = 4,
+            SIGNAL_BRAKELIGHT = 8,
+            SIGNAL_FRONTLIGHT = 16,
+            SIGNAL_FOGLIGHT = 32,
+            SIGNAL_HIGHBEAM = 64,
+            SIGNAL_BACKDRIVE = 128,
+            SIGNAL_WIPER = 256,
+            SIGNAL_DOOR_OPEN_LEFT = 512,
+            SIGNAL_DOOR_OPEN_RIGHT = 1024,
+            SIGNAL_EMERGENCY_BLUE = 2048,
+            SIGNAL_EMERGENCY_RED = 4096,
+            SIGNAL_EMERGENCY_YELLOW = 8192,
+            SIGNAL_RESET = -1, /*< sending a negative signal resets all signals to their computed values immediately */
+        };
+
         /// @name vehicle value retrieval
         /// @{
         std::vector<std::string> getIDList() const;
         int getIDCount() const;
         double getSpeed(const std::string& vehicleID) const;
+        double getAcceleration(const std::string& vehicleID) const;
         libsumo::TraCIPosition getPosition(const std::string& vehicleID) const;
         libsumo::TraCIPosition getPosition3D(const std::string& vehicleID) const;
         double getAngle(const std::string& vehicleID) const;
@@ -637,12 +675,11 @@ public:
         std::string getTypeID(const std::string& vehicleID) const;
         std::string getRouteID(const std::string& vehicleID) const;
         int getRouteIndex(const std::string& vehicleID) const;
-        std::vector<std::string> getEdges(const std::string& vehicleID) const; /*< deprecated in favour of getRoute */
         std::vector<std::string> getRoute(const std::string& vehicleID) const;
         libsumo::TraCIColor getColor(const std::string& vehicleID) const;
         double getLanePosition(const std::string& vehicleID) const;
         double getDistance(const std::string& vehicleID) const;
-        int getSignalStates(const std::string& vehicleID) const;
+        int getSignals(const std::string& vehicleID) const;
         double getCO2Emission(const std::string& vehicleID) const;
         double getCOEmission(const std::string& vehicleID) const;
         double getHCEmission(const std::string& vehicleID) const;
@@ -658,6 +695,7 @@ public:
         double getSlope(const std::string& vehicleID) const;
         double getAllowedSpeed(const std::string& vehicleID) const;
         int getPersonNumber(const std::string& vehicleID) const;
+        std::vector<std::string> getPersonIDList(const std::string& vehicleID) const;
         double getSpeedWithoutTraCI(const std::string& vehicleID) const;
         bool isRouteValid(const std::string& vehicleID) const;
         double getLateralLanePosition(const std::string& vehicleID) const;
@@ -667,6 +705,8 @@ public:
         std::vector<libsumo::TraCINextTLSData> getNextTLS(const std::string& vehID) const;
         std::vector<libsumo::TraCIBestLanesData> getBestLanes(const std::string& vehicleID) const;
         std::pair<std::string, double> getLeader(const std::string& vehicleID, double dist) const;
+        int getRoutingMode(const std::string& vehicleID) const;
+        std::pair<int, int> getLaneChangeState(const std::string& vehicleID, int direction) const;
         /// @}
 
         /// @name vehicle type value retrieval shortcuts
@@ -710,30 +750,40 @@ public:
                  int personNumber = 0) const;
 
         void changeTarget(const std::string& vehicleID, const std::string& edgeID) const;
+        void changeLane(const std::string& vehicleID, int laneIndex, double duration) const;
+        void changeLaneRelative(const std::string& vehicleID, int laneChange, double duration) const;
+        void changeSublane(const std::string& vehicleID, double latDist) const;
         void setRouteID(const std::string& vehicleID, const std::string& routeID) const;
         void setRoute(const std::string& vehicleID, const std::vector<std::string>& edge) const;
         void rerouteTraveltime(const std::string& vehicleID, bool currentTravelTimes = true) const;
         void moveTo(const std::string& vehicleID, const std::string& laneID, double position) const;
         void moveToXY(const std::string& vehicleID, const std::string& edgeID, const int lane, const double x, const double y, const double angle, const int keepRoute) const;
-        void slowDown(const std::string& vehicleID, double speed, SUMOTime duration) const;
+        void slowDown(const std::string& vehicleID, double speed, double duration) const;
+        void openGap(const std::string& vehicleID, double newTau, double duration, double changeRate, double maxDecel) const;
         void setSpeed(const std::string& vehicleID, double speed) const;
+        void setSpeedMode(const std::string& vehicleID, int mode) const;
+        void setStop(const std::string vehicleID, const std::string edgeID, const double endPos = 1.,
+                     const int laneIndex = 0, const double duration = std::numeric_limits<double>::max(),
+                     const int flags = 0, const double startPos = std::numeric_limits<int>::min(),
+                     const double until = -1) const;
         void setType(const std::string& vehicleID, const std::string& typeID) const;
         void remove(const std::string& vehicleID, char reason = REMOVE_VAPORIZED) const;
         void setColor(const std::string& vehicleID, const libsumo::TraCIColor& c) const;
         void setLine(const std::string& vehicleID, const std::string& line) const;
         void setVia(const std::string& vehicleID, const std::vector<std::string>& via) const;
+        void setSignals(const std::string& vehicleID, int signals) const;
+        void setRoutingMode(const std::string& vehicleID, int routingMode) const;
         /// @}
 
         /// @name vehicle type attribute changing shortcuts
         /// @{
         void setShapeClass(const std::string& vehicleID, const std::string& clazz) const;
         void setEmissionClass(const std::string& vehicleID, const std::string& clazz) const;
+        void setSpeedFactor(const std::string& vehicleID, double factor) const;
         void setMaxSpeed(const std::string& vehicleID, double speed) const;
         /// @}
 
     private:
-        mutable SUMOTime LAST_TRAVEL_TIME_UPDATE;
-
         /// @brief invalidated copy constructor
         VehicleScope(const VehicleScope& src);
 
@@ -747,13 +797,14 @@ public:
      * */
     class PersonScope : public TraCIScopeWrapper {
     public:
-        PersonScope(TraCIAPI& parent) : TraCIScopeWrapper(parent) {}
+        PersonScope(TraCIAPI& parent) : TraCIScopeWrapper(parent, CMD_GET_PERSON_VARIABLE, CMD_SET_PERSON_VARIABLE, CMD_SUBSCRIBE_PERSON_VARIABLE, CMD_SUBSCRIBE_PERSON_CONTEXT) {}
         virtual ~PersonScope() {}
 
         std::vector<std::string> getIDList() const;
         int getIDCount() const;
         double getSpeed(const std::string& personID) const;
         libsumo::TraCIPosition getPosition(const std::string& personID) const;
+        libsumo::TraCIPosition getPosition3D(const std::string& personID) const;
         std::string getRoadID(const std::string& personID) const;
         std::string getTypeID(const std::string& personID) const;
         double getWaitingTime(const std::string& personID) const;
@@ -762,10 +813,14 @@ public:
         int getRemainingStages(const std::string& personID) const;
         int getStage(const std::string& personID, int nextStageIndex = 0) const;
         std::vector<std::string> getEdges(const std::string& personID, int nextStageIndex = 0) const;
-        // TODO:
-        // double getAngle(const std::string& personID) const;
-        // double getLanePosition(const std::string& personID) const;
-        // libsumo::TraCIColor getColor(const std::string& personID) const;
+        double getAngle(const std::string& personID) const;
+        double getLanePosition(const std::string& personID) const;
+        libsumo::TraCIColor getColor(const std::string& personID) const;
+
+        /// @name vehicle type value retrieval shortcuts
+        /// @{
+        double getLength(const std::string& personID) const;
+        /// @}
 
 
         void removeStages(const std::string& personID) const;
@@ -832,7 +887,7 @@ protected:
 
     /** @brief Sends a SimulationStep command
      */
-    void send_commandSimulationStep(SUMOTime time) const;
+    void send_commandSimulationStep(double time) const;
 
 
     /** @brief Sends a Close command
@@ -869,7 +924,7 @@ protected:
      * @param[in] endTime The end time step of subscriptions
      * @param[in] vars The variables to subscribe
      */
-    void send_commandSubscribeObjectVariable(int domID, const std::string& objID, SUMOTime beginTime, SUMOTime endTime, const std::vector<int>& vars) const;
+    void send_commandSubscribeObjectVariable(int domID, const std::string& objID, double beginTime, double endTime, const std::vector<int>& vars) const;
 
 
     /** @brief Sends a SubscribeContext request
@@ -881,7 +936,7 @@ protected:
      * @param[in] range The range around the obj to investigate
      * @param[in] vars The variables to subscribe
      */
-    void send_commandSubscribeObjectContext(int domID, const std::string& objID, SUMOTime beginTime, SUMOTime endTime,
+    void send_commandSubscribeObjectContext(int domID, const std::string& objID, double beginTime, double endTime,
                                             int domain, double range, const std::vector<int>& vars) const;
     /// @}
 
@@ -909,9 +964,9 @@ protected:
     void processGET(tcpip::Storage& inMsg, int command, int expectedType, bool ignoreCommandId = false) const;
     /// @}
 
-    void readVariableSubscription(tcpip::Storage& inMsg);
-    void readContextSubscription(tcpip::Storage& inMsg);
-    void readVariables(tcpip::Storage& inMsg, const std::string& objectID, int variableCount, SubscribedValues& into);
+    void readVariableSubscription(int cmdId, tcpip::Storage& inMsg);
+    void readContextSubscription(int cmdId, tcpip::Storage& inMsg);
+    void readVariables(tcpip::Storage& inMsg, const std::string& objectID, int variableCount, libsumo::SubscriptionResults& into);
 
     template <class T>
     static inline std::string toString(const T& t, std::streamsize accuracy = PRECISION) {
@@ -926,11 +981,9 @@ protected:
     void closeSocket();
 
 protected:
+    std::map<int, TraCIScopeWrapper*> myDomains;
     /// @brief The socket
     tcpip::Socket* mySocket;
-
-    SubscribedValues mySubscribedValues;
-    SubscribedContextValues mySubscribedContextValues;
 };
 
 
