@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2012-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    AStarLookupTable.h
 /// @author  Jakob Erdmann
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include <fstream>
@@ -118,7 +112,7 @@ public:
         if (!strm.good()) {
             throw ProcessError("Could not load landmark-lookup-table from '" + filename + "'.");
         }
-        std::ofstream* ostrm = 0;
+        std::ofstream* ostrm = nullptr;
         if (!outfile.empty()) {
             ostrm = new std::ofstream(outfile.c_str());
             if (!ostrm->good()) {
@@ -138,7 +132,7 @@ public:
                 myLandmarks[lm] = numLandMarks++;
                 myFromLandmarkDists.push_back(std::vector<double>(0));
                 myToLandmarkDists.push_back(std::vector<double>(0));
-                if (ostrm != 0) {
+                if (ostrm != nullptr) {
                     (*ostrm) << lm << "\n";
                 }
             } else {
@@ -148,14 +142,15 @@ public:
                 if (numericID[edge] != (int)myFromLandmarkDists[myLandmarks[lm]].size()) {
                     WRITE_WARNING("Unknown or unordered edge '" + edge + "' in landmark file.");
                 }
-                const double distFrom = TplConvert::_2double(st.get(2).c_str());
-                const double distTo = TplConvert::_2double(st.get(3).c_str());
+                const double distFrom = StringUtils::toDouble(st.get(2));
+                const double distTo = StringUtils::toDouble(st.get(3));
                 myFromLandmarkDists[myLandmarks[lm]].push_back(distFrom);
                 myToLandmarkDists[myLandmarks[lm]].push_back(distTo);
             }
         }
         if (myLandmarks.empty()) {
             WRITE_WARNING("No landmarks in '" + filename + "', falling back to standard A*.");
+            delete ostrm;
             return;
         }
 #ifdef HAVE_FOX
@@ -164,21 +159,22 @@ public:
         for (int i = 0; i < (int)myLandmarks.size(); ++i) {
             if ((int)myFromLandmarkDists[i].size() != (int)edges.size() - myFirstNonInternal) {
                 const std::string landmarkID = getLandmark(i);
-                const E* landmark = 0;
+                const E* landmark = nullptr;
                 // retrieve landmark edge
-                for (typename std::vector<E*>::const_iterator it_e = edges.begin(); it_e != edges.end(); ++it_e) {
-                    if ((*it_e)->getID() == landmarkID) {
-                        landmark = *it_e;
+                for (const E* const edge : edges) {
+                    if (edge->getID() == landmarkID) {
+                        landmark = edge;
+                        break;
                     }
                 }
-                if (landmark == 0) {
+                if (landmark == nullptr) {
                     WRITE_WARNING("Landmark '" + landmarkID + "' does not exist in the network.");
                     continue;
                 }
-                if (router != 0) {
-                    const std::string missing = filename + ".missing";
+                if (router != nullptr) {
+                    const std::string missing = outfile.empty() ? filename + ".missing" : outfile;
                     WRITE_WARNING("Not all network edges were found in the lookup table '" + filename + "' for landmark '" + landmarkID + "'. Saving missing values to '" + missing + "'.");
-                    if (ostrm == 0) {
+                    if (ostrm == nullptr) {
                         ostrm = new std::ofstream(missing.c_str());
                         if (!ostrm->good()) {
                             throw ProcessError("Could not open file '" + missing + "' for writing.");
@@ -248,11 +244,11 @@ public:
 #endif
                 for (int j = (int)myFromLandmarkDists[i].size() + myFirstNonInternal; j < (int)edges.size(); ++j) {
                     const E* edge = edges[j];
-                    double distFrom = -1;
-                    double distTo = -1;
+                    double distFrom = -1.;
+                    double distTo = -1.;
                     if (landmark == edge) {
-                        distFrom = 0;
-                        distTo = 0;
+                        distFrom = 0.;
+                        distTo = 0.;
                     } else {
                         std::vector<const E*> routeE(1, edge);
                         const double sourceDestCost = lmCost + router->recomputeCosts(routeE, defaultVehicle, 0);
