@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    CHBuilder.h
 /// @author  Jakob Erdmann
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <functional>
@@ -238,12 +232,15 @@ private:
         /// @brief Constructor
         CHInfo(const E* e) :
             edge(e),
+            priority(0.),
             contractedNeighbors(0),
             rank(-1),
             level(0),
             underlyingTotal(0),
             visited(false),
-            traveltime(std::numeric_limits<double>::max()) {
+            traveltime(std::numeric_limits<double>::max()),
+            depth(0),
+            permissions(SVC_IGNORING) {
         }
 
         /// @brief recompute the contraction priority and report whether it changed
@@ -434,16 +431,21 @@ private:
         if (prune && ((edge->getPermissions() & mySVC) != mySVC)) {
             return;
         }
-        const double cost = effortProvider->getEffort(edge, vehicle, time);
+        const double baseCost = effortProvider->getEffort(edge, vehicle, time);
 
-        const std::vector<E*>& successors = edge->getSuccessors(mySVC);
-        for (typename std::vector<E*>::const_iterator it = successors.begin(); it != successors.end(); ++it) {
-            const E* fEdge = *it;
+        for (const std::pair<const E*, const E*>& successor : edge->getViaSuccessors(mySVC)) {
+            const E* fEdge = successor.first;
             if (prune && ((fEdge->getPermissions() & mySVC) != mySVC)) {
                 continue;
             }
-            CHInfo* follower = getCHInfo(fEdge);
-            SVCPermissions permissions = (edge->getPermissions() & follower->edge->getPermissions());
+            CHInfo* const follower = getCHInfo(fEdge);
+            const SVCPermissions permissions = (edge->getPermissions() & fEdge->getPermissions());
+            double cost = baseCost;
+            const E* viaEdge = successor.second;
+            while (viaEdge != nullptr && viaEdge->isInternal()) {
+                cost += effortProvider->getEffort(viaEdge, vehicle, time);
+                viaEdge = viaEdge->getViaSuccessors().front().first;
+            }
             info.followers.push_back(CHConnection(follower, cost, permissions, 1));
             follower->approaching.push_back(CHConnection(&info, cost, permissions, 1));
         }
