@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    CHRouter.h
 /// @author  Jakob Erdmann
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <functional>
@@ -65,74 +59,40 @@
  *  be reported as an error or as a warning.
  *
  */
-template<class E, class V, class PF>
-class CHRouter: public SUMOAbstractRouter<E, V>, public PF {
+template<class E, class V, class BASE>
+class CHRouter: public BASE {
 
 public:
     /// Type of the function that is used to retrieve the edge effort.
     typedef double(* Operation)(const E* const, const V* const, double);
 
-    /**
-     * @struct EdgeInfo
-     * A definition about a route's edge with the effort needed to reach it and
-     *  the information about the previous edge.
-     */
-    class EdgeInfo {
-    public:
-        /// Constructor
-        EdgeInfo(const E* e) :
-            edge(e),
-            traveltime(std::numeric_limits<double>::max()),
-            prev(0),
-            visited(false) {
-        }
-
-        /// The current edge
-        const E* edge;
-
-        /// Effort to reach the edge
-        double traveltime;
-
-        /// The previous edge
-        EdgeInfo* prev;
-
-        /// Whether the shortest path to this edge is already found
-        bool visited;
-
-        inline void reset() {
-            traveltime = std::numeric_limits<double>::max();
-            visited = false;
-        }
-    };
-
-
     /// A meeting point of the two search scopes
-    typedef std::pair<const EdgeInfo*, const EdgeInfo*> Meeting;
+    typedef std::pair<const typename BASE::EdgeInfo*, const typename BASE::EdgeInfo*> Meeting;
 
     /**
      * @class Unidirectional
      * class for searching in one direction
      */
-    class Unidirectional: public PF {
+    class Unidirectional {
     public:
         /// @brief Constructor
         Unidirectional(const std::vector<E*>& edges, bool forward):
             myAmForward(forward),
             myVehicle(0) {
-            for (typename std::vector<E*>::const_iterator i = edges.begin(); i != edges.end(); ++i) {
-                myEdgeInfos.push_back(EdgeInfo(*i));
+            for (const E* const e: edges) {
+                myEdgeInfos.push_back(typename BASE::EdgeInfo(e));
             }
         }
 
-        inline bool found(const E* edge) const {
+        inline bool found(const E* const edge) const {
             return myFound.count(edge) > 0;
         }
 
-        inline EdgeInfo* getEdgeInfo(const E* const edge) {
+        inline typename BASE::EdgeInfo* getEdgeInfo(const E* const edge) {
             return &(myEdgeInfos[edge->getNumericalID()]);
         }
 
-        inline const EdgeInfo* getEdgeInfo(const E* const edge) const {
+        inline const typename BASE::EdgeInfo* getEdgeInfo(const E* const edge) const {
             return &(myEdgeInfos[edge->getNumericalID()]);
         }
 
@@ -143,11 +103,11 @@ public:
         class EdgeInfoByTTComparator {
         public:
             /// Comparing method
-            bool operator()(const EdgeInfo* nod1, const EdgeInfo* nod2) const {
-                if (nod1->traveltime == nod2->traveltime) {
+            bool operator()(const typename BASE::EdgeInfo* nod1, const typename BASE::EdgeInfo* nod2) const {
+                if (nod1->effort == nod2->effort) {
                     return nod1->edge->getNumericalID() > nod2->edge->getNumericalID();
                 }
-                return nod1->traveltime > nod2->traveltime;
+                return nod1->effort > nod2->effort;
             }
         };
 
@@ -155,18 +115,18 @@ public:
         void init(const E* const start, const V* const vehicle) {
             assert(vehicle != 0);
             // all EdgeInfos touched in the previous query are either in myFrontier or myFound: clean those up
-            for (typename std::vector<EdgeInfo*>::iterator i = myFrontier.begin(); i != myFrontier.end(); i++) {
-                (*i)->reset();
+            for (auto ei : myFrontier) {
+                ei->reset();
             }
             myFrontier.clear();
-            for (typename std::set<const E*>::const_iterator i = myFound.begin(); i != myFound.end(); i++) {
-                getEdgeInfo(*i)->reset();
+            for (auto edge : myFound) {
+                getEdgeInfo(edge)->reset();
             }
             myFound.clear();
             myVehicle = vehicle;
-            EdgeInfo* startInfo = getEdgeInfo(start);
-            startInfo->traveltime = 0;
-            startInfo->prev = 0;
+            auto startInfo = getEdgeInfo(start);
+            startInfo->effort = 0.;
+            startInfo->prev = nullptr;
             myFrontier.push_back(startInfo);
         }
 
@@ -178,7 +138,7 @@ public:
          */
         bool step(const std::vector<ConnectionVector>& uplinks, const Unidirectional& otherSearch, double& minTTSeen, Meeting& meeting) {
             // pop the node with the minimal length
-            EdgeInfo* const minimumInfo = myFrontier.front();
+            auto* const minimumInfo = myFrontier.front();
             pop_heap(myFrontier.begin(), myFrontier.end(), myComparator);
             myFrontier.pop_back();
             // check for a meeting with the other search
@@ -191,8 +151,8 @@ public:
             std::cout << "\n";
 #endif
             if (otherSearch.found(minEdge)) {
-                const EdgeInfo* const otherInfo = otherSearch.getEdgeInfo(minEdge);
-                const double ttSeen = minimumInfo->traveltime + otherInfo->traveltime;
+                const auto* const otherInfo = otherSearch.getEdgeInfo(minEdge);
+                const double ttSeen = minimumInfo->effort + otherInfo->effort;
 #ifdef CHRouter_DEBUG_QUERY
                 std::cout << "DEBUG: " << (myAmForward ? "Forward" : "Backward") << "-Search hit other search at '" << minEdge->getID() << "', tt: " << ttSeen << " \n";
 #endif
@@ -211,20 +171,19 @@ public:
             minimumInfo->visited = true;
             // XXX we only need to keep found elements if they have a higher rank than the lowest rank in the other search queue
             myFound.insert(minimumInfo->edge);
-            const ConnectionVector& upward = uplinks[minEdge->getNumericalID()];
-            for (typename ConnectionVector::const_iterator it = upward.begin(); it != upward.end(); it++) {
-                EdgeInfo* upwardInfo = &myEdgeInfos[it->target];
-                const double traveltime = minimumInfo->traveltime + it->cost;
+            for (const auto& uplink : uplinks[minEdge->getNumericalID()]) {
+                const auto upwardInfo = &myEdgeInfos[uplink.target];
+                const double effort = minimumInfo->effort + uplink.cost;
                 const SUMOVehicleClass svc = myVehicle->getVClass();
                 // check whether it can be used
-                if ((it->permissions & svc) != svc) {
+                if ((uplink.permissions & svc) != svc) {
                     continue;
                 }
-                const double oldTraveltime = upwardInfo->traveltime;
-                if (!upwardInfo->visited && traveltime < oldTraveltime) {
-                    upwardInfo->traveltime = traveltime;
+                const double oldEffort = upwardInfo->effort;
+                if (!upwardInfo->visited && effort < oldEffort) {
+                    upwardInfo->effort = effort;
                     upwardInfo->prev = minimumInfo;
-                    if (oldTraveltime == std::numeric_limits<double>::max()) {
+                    if (oldEffort == std::numeric_limits<double>::max()) {
                         myFrontier.push_back(upwardInfo);
                         push_heap(myFrontier.begin(), myFrontier.end(), myComparator);
                     } else {
@@ -239,18 +198,18 @@ public:
             // quadrupled. We could implement a better stopping criterion (Holte)
             // However since the search shall take place in a contracted graph
             // it probably does not matter
-            return !myFrontier.empty() && myFrontier.front()->traveltime < minTTSeen;
+            return !myFrontier.empty() && myFrontier.front()->effort < minTTSeen;
         }
 
     private:
         /// @brief the role of this search
         bool myAmForward;
         /// @brief the min edge heap
-        std::vector<EdgeInfo*> myFrontier;
+        std::vector<typename BASE::EdgeInfo*> myFrontier;
         /// @brief the set of visited (settled) Edges
         std::set<const E*> myFound;
         /// @brief The container of edge information
-        std::vector<EdgeInfo> myEdgeInfos;
+        std::vector<typename BASE::EdgeInfo> myEdgeInfos;
 
         EdgeInfoByTTComparator myComparator;
 
@@ -263,11 +222,11 @@ public:
      *            If set to false, the net is pruned in synchronize() and the
      *            hierarchy is tailored to the svc
      */
-    CHRouter(const std::vector<E*>& edges, bool unbuildIsWarning, Operation operation,
+    CHRouter(const std::vector<E*>& edges, bool unbuildIsWarning, typename BASE::Operation operation,
              const SUMOVehicleClass svc,
              SUMOTime weightPeriod,
              bool validatePermissions):
-        SUMOAbstractRouter<E, V>(operation, "CHRouter"),
+        BASE("CHRouter", operation),
         myEdges(edges),
         myErrorMsgHandler(unbuildIsWarning ? MsgHandler::getWarningInstance() : MsgHandler::getErrorInstance()),
         myForwardSearch(edges, true),
@@ -281,11 +240,11 @@ public:
 
     /** @brief Cloning constructor
      */
-    CHRouter(const std::vector<E*>& edges, bool unbuildIsWarning, Operation operation,
+    CHRouter(const std::vector<E*>& edges, bool unbuildIsWarning, typename BASE::Operation operation,
              const SUMOVehicleClass svc,
              SUMOTime weightPeriod,
              const typename CHBuilder<E, V>::Hierarchy* hierarchy) :
-        SUMOAbstractRouter<E, V>(operation, "CHRouter"),
+        BASE("CHRouterClone", operation),
         myEdges(edges),
         myErrorMsgHandler(unbuildIsWarning ? MsgHandler::getWarningInstance() : MsgHandler::getErrorInstance()),
         myForwardSearch(edges, true),
@@ -308,7 +267,7 @@ public:
 
     virtual SUMOAbstractRouter<E, V>* clone() {
         WRITE_MESSAGE("Cloning Contraction Hierarchy for " + SumoVehicleClassStrings.getString(mySVC) + " and time " + time2string(myValidUntil) + ".");
-        CHRouter<E, V, PF>* clone = new CHRouter<E, V, PF>(myEdges, myErrorMsgHandler == MsgHandler::getWarningInstance(), this->myOperation,
+        CHRouter<E, V, BASE>* clone = new CHRouter<E, V, BASE>(myEdges, myErrorMsgHandler == MsgHandler::getWarningInstance(), this->myOperation,
                 mySVC, myWeightPeriod, myHierarchy);
         clone->myValidUntil = myValidUntil;
         return clone;
@@ -334,7 +293,7 @@ public:
         myForwardSearch.init(from, vehicle);
         myBackwardSearch.init(to, vehicle);
         double minTTSeen = std::numeric_limits<double>::max();
-        Meeting meeting(static_cast<EdgeInfo*>(0), static_cast<EdgeInfo*>(0));
+        Meeting meeting(nullptr, nullptr);
         bool continueForward = true;
         bool continueBackward = true;
         int num_visited_fw = 0;
@@ -363,25 +322,12 @@ public:
         return result;
     }
 
-
-    double recomputeCosts(const std::vector<const E*>& edges, const V* const v, SUMOTime msTime) const {
-        const double time = STEPS2TIME(msTime);
-        double costs = 0;
-        for (typename std::vector<const E*>::const_iterator i = edges.begin(); i != edges.end(); ++i) {
-            if (PF::operator()(*i, v)) {
-                return -1;
-            }
-            costs += this->getEffort(*i, v, time + costs);
-        }
-        return costs;
-    }
-
     /// normal routing methods
 
     /// Builds the path from marked edges
     void buildPathFromMeeting(Meeting meeting, std::vector<const E*>& into) const {
         std::deque<const E*> tmp;
-        const EdgeInfo* backtrack = meeting.first;
+        const auto* backtrack = meeting.first;
         while (backtrack != 0) {
             tmp.push_front((E*) backtrack->edge);  // !!!
             backtrack = backtrack->prev;
