@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    CarEdge.h
 /// @author  Michael Behrisch
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #ifdef HAVE_FOX
 #include <fx.h>
@@ -53,7 +47,7 @@ public:
         return true;
     }
 
-    const std::vector<_IntermodalEdge*>& getSuccessors(SUMOVehicleClass vClass) const {
+    const std::vector<_IntermodalEdge*>& getSuccessors(SUMOVehicleClass vClass = SVC_IGNORING) const {
         if (vClass == SVC_IGNORING) {
             return this->myFollowingEdges;
         }
@@ -74,9 +68,31 @@ public:
             }
             return myClassesSuccessorMap[vClass];
         }
-
     }
 
+    virtual const std::vector<std::pair<const _IntermodalEdge*, const _IntermodalEdge*> >& getViaSuccessors(SUMOVehicleClass vClass = SVC_IGNORING) const {
+        if (vClass == SVC_IGNORING) {
+            return this->myFollowingViaEdges;
+        }
+#ifdef HAVE_FOX
+        FXMutexLock locker(myLock);
+#endif
+        typename std::map<SUMOVehicleClass, std::vector<std::pair<const _IntermodalEdge*, const _IntermodalEdge*> > >::const_iterator i = myClassesViaSuccessorMap.find(vClass);
+        if (i != myClassesViaSuccessorMap.end()) {
+            // can use cached value
+            return i->second;
+        } else {
+            // this vClass is requested for the first time. rebuild all successors
+            const std::set<std::pair<const E*, const E*> > classedCarFollowers = std::set<std::pair<const E*, const E*> >(this->getEdge()->getViaSuccessors(vClass).begin(), this->getEdge()->getViaSuccessors(vClass).end());
+            for (const std::pair<const _IntermodalEdge*, const _IntermodalEdge*>& e : this->myFollowingViaEdges) {
+                const auto viaPair = std::make_pair(e.first->getEdge(), e.second == nullptr ? nullptr : e.second->getEdge());
+                if (!e.first->includeInRoute(false) || e.first->getEdge() == this->getEdge() || classedCarFollowers.count(viaPair) > 0) {
+                    myClassesViaSuccessorMap[vClass].push_back(e);
+                }
+            }
+            return myClassesViaSuccessorMap[vClass];
+        }
+    }
 
     bool prohibits(const IntermodalTrip<E, N, V>* const trip) const {
         return trip->vehicle == 0 || this->getEdge()->prohibits(trip->vehicle);
@@ -95,6 +111,14 @@ public:
         return travelTime * distTravelled / this->getEdge()->getLength();
     }
 
+    double getStartPos() const {
+        return myStartPos;
+    }
+
+    double getEndPos() const {
+        return myStartPos + this->getLength();
+    }
+
 private:
     /// @brief the starting position for split edges
     const double myStartPos;
@@ -102,6 +126,9 @@ private:
     /// @brief The successors available for a given vClass
     mutable std::map<SUMOVehicleClass, std::vector<_IntermodalEdge*> > myClassesSuccessorMap;
 
+    /// @brief The successors available for a given vClass
+    mutable std::map<SUMOVehicleClass, std::vector<std::pair<const _IntermodalEdge*, const _IntermodalEdge*> > > myClassesViaSuccessorMap;
+
 #ifdef HAVE_FOX
     /// The mutex used to avoid concurrent updates of myClassesSuccessorMap
     mutable FXMutex myLock;
@@ -109,106 +136,6 @@ private:
 };
 
 
-/// @brief the stop edge type representing bus and train stops
-template<class E, class L, class N, class V>
-class StopEdge : public IntermodalEdge<E, L, N, V> {
-public:
-    StopEdge(const std::string id, int numericalID, const E* edge) :
-        IntermodalEdge<E, L, N, V>(id, numericalID, edge, "!stop") { }
-
-    bool includeInRoute(bool /* allEdges */) const {
-        return true;
-    }
-
-    bool prohibits(const IntermodalTrip<E, N, V>* const trip) const {
-        return (trip->modeSet & SVC_BUS) == 0;
-    }
-};
-
-
-/// @brief the public transport edge type connecting the stop edges
-template<class E, class L, class N, class V>
-class PublicTransportEdge : public IntermodalEdge<E, L, N, V> {
-private:
-    struct Schedule {
-        Schedule(const SUMOTime _begin, const SUMOTime _end, const SUMOTime _period, const double _travelTimeSec)
-            : begin(_begin), end(_end), period(_period), travelTimeSec(_travelTimeSec) {}
-        const SUMOTime begin;
-        const SUMOTime end;
-        const SUMOTime period;
-        const double travelTimeSec;
-    private:
-        /// @brief Invalidated assignment operator
-        Schedule& operator=(const Schedule& src);
-    };
-
-public:
-    PublicTransportEdge(const std::string id, int numericalID, const IntermodalEdge<E, L, N, V>* entryStop, const E* endEdge, const std::string& line) :
-        IntermodalEdge<E, L, N, V>(line + ":" + (id != "" ? id : endEdge->getID()), numericalID, endEdge, line), myEntryStop(entryStop) { }
-
-    bool includeInRoute(bool /* allEdges */) const {
-        return true;
-    }
-
-    const IntermodalEdge<E, L, N, V>* getEntryStop() const {
-        return myEntryStop;
-    }
-
-    void addSchedule(const SUMOTime begin, const SUMOTime end, const SUMOTime period, const double travelTimeSec) {
-        //std::cout << " edge=" << myEntryStop->getID() << "->" << this->getID() << " beg=" << STEPS2TIME(begin) << " end=" << STEPS2TIME(end)
-        //    << " period=" << STEPS2TIME(period)
-        //    << " travelTime=" << travelTimeSec << "\n";
-        mySchedules.insert(std::make_pair(STEPS2TIME(begin), Schedule(begin, end, period, travelTimeSec)));
-    }
-
-    double getTravelTime(const IntermodalTrip<E, N, V>* const /* trip */, double time) const {
-        double minArrivalSec = std::numeric_limits<double>::max();
-        for (typename std::multimap<double, Schedule>::const_iterator it = mySchedules.begin(); it != mySchedules.end(); ++it) {
-            if (it->first > minArrivalSec) {
-                break;
-            }
-            if (time < STEPS2TIME(it->second.end)) {
-                const int running = MAX2(0, (int)ceil((time - STEPS2TIME(it->second.begin)) / STEPS2TIME(it->second.period)));
-                const SUMOTime nextDepart = it->second.begin + running * it->second.period;
-                minArrivalSec = MIN2(STEPS2TIME(nextDepart) + it->second.travelTimeSec, minArrivalSec);
-                //std::cout << " edge=" << myEntryStop->getID() << "->" << this->getID() << " beg=" << STEPS2TIME(it->second.begin) << " end=" << STEPS2TIME(it->second.end)
-                //    << " atTime=" << time
-                //    << " running=" << running << " nextDepart=" << nextDepart
-                //    << " minASec=" << minArrivalSec << " travelTime=" << minArrivalSec - time << "\n";
-            }
-        }
-        return minArrivalSec - time;
-    }
-
-private:
-    std::multimap<double, Schedule> mySchedules;
-    const IntermodalEdge<E, L, N, V>* const myEntryStop;
-
-};
-
-
-/// @brief the access edge connecting different modes that is given to the internal router (SUMOAbstractRouter)
-template<class E, class L, class N, class V>
-class AccessEdge : public IntermodalEdge<E, L, N, V> {
-private:
-    typedef IntermodalEdge<E, L, N, V> _IntermodalEdge;
-
-public:
-    AccessEdge(int numericalID, const _IntermodalEdge* inEdge, const _IntermodalEdge* outEdge,
-               const double transferTime = NUMERICAL_EPS) :
-        _IntermodalEdge(inEdge->getID() + ":" + outEdge->getID(), numericalID, outEdge->getEdge(), "!access"),
-        myTransferTime(transferTime) { }
-
-    double getTravelTime(const IntermodalTrip<E, N, V>* const /* trip */, double /* time */) const {
-        return myTransferTime;
-    }
-
-private:
-    const double myTransferTime;
-
-};
-
-
 #endif
 
 /****************************************************************************/
