@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    PedestrianRouter.h
 /// @author  Jakob Erdmann
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <vector>
@@ -50,25 +44,26 @@
  * @class PedestrianRouter
  * The router for pedestrians (on a bidirectional network of sidewalks and crossings)
  */
-template<class E, class L, class N, class V, class INTERNALROUTER>
+template<class E, class L, class N, class V>
 class PedestrianRouter : public SUMOAbstractRouter<E, IntermodalTrip<E, N, V> > {
-public:
-
+private:
     typedef IntermodalEdge<E, L, N, V> _IntermodalEdge;
     typedef IntermodalNetwork<E, L, N, V> _IntermodalNetwork;
     typedef IntermodalTrip<E, N, V> _IntermodalTrip;
+    typedef DijkstraRouter<_IntermodalEdge, _IntermodalTrip, SUMOAbstractRouterPermissions<_IntermodalEdge, _IntermodalTrip > > _InternalRouter;
 
+public:
     /// Constructor
     PedestrianRouter():
-        SUMOAbstractRouter<E, _IntermodalTrip>(0, "PedestrianRouter"), myAmClone(false) {
-        myPedNet = new _IntermodalNetwork(E::getAllEdges());
-        myInternalRouter = new INTERNALROUTER(myPedNet->getAllEdges(), true, &_IntermodalEdge::getTravelTimeStatic);
+        SUMOAbstractRouter<E, _IntermodalTrip>("PedestrianRouter"), myAmClone(false) {
+        myPedNet = new _IntermodalNetwork(E::getAllEdges(), true);
+        myInternalRouter = new _InternalRouter(myPedNet->getAllEdges(), true, &_IntermodalEdge::getTravelTimeStatic);
     }
 
     PedestrianRouter(_IntermodalNetwork* net):
-        SUMOAbstractRouter<E, _IntermodalTrip>(0, "PedestrianRouter"), myAmClone(true) {
+        SUMOAbstractRouter<E, _IntermodalTrip>("PedestrianRouterClone"), myAmClone(true) {
         myPedNet = net;
-        myInternalRouter = new INTERNALROUTER(myPedNet->getAllEdges(), true, &_IntermodalEdge::getTravelTimeStatic);
+        myInternalRouter = new _InternalRouter(myPedNet->getAllEdges(), true, &_IntermodalEdge::getTravelTimeStatic);
     }
 
     /// Destructor
@@ -80,7 +75,7 @@ public:
     }
 
     virtual SUMOAbstractRouter<E, _IntermodalTrip>* clone() {
-        return new PedestrianRouter<E, L, N, V, INTERNALROUTER>(myPedNet);
+        return new PedestrianRouter<E, L, N, V>(myPedNet);
     }
 
     /** @brief Builds the route between the given edges using the minimum effort at the given time
@@ -129,10 +124,6 @@ public:
         throw ProcessError("Do not use this method");
     }
 
-    double recomputeCosts(const std::vector<const E*>&, const _IntermodalTrip* const, SUMOTime) const {
-        throw ProcessError("Do not use this method");
-    }
-
     void prohibit(const std::vector<E*>& toProhibit) {
         std::vector<_IntermodalEdge*> toProhibitPE;
         for (typename std::vector<E*>::const_iterator it = toProhibit.begin(); it != toProhibit.end(); ++it) {
@@ -144,7 +135,7 @@ public:
 
 private:
     const bool myAmClone;
-    INTERNALROUTER* myInternalRouter;
+    _InternalRouter* myInternalRouter;
     _IntermodalNetwork* myPedNet;
 
 
@@ -154,11 +145,6 @@ private:
 
 };
 
-// common specializations
-template<class E, class L, class N, class V>
-class PedestrianRouterDijkstra : public PedestrianRouter < E, L, N, V,
-    DijkstraRouter<IntermodalEdge<E, L, N, V>, IntermodalTrip<E, N, V>, prohibited_withPermissions<IntermodalEdge<E, L, N, V>, IntermodalTrip<E, N, V> > > > { };
-
 
 #endif
 
