@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    SUMOVTypeParameter.cpp
 /// @author  Daniel Krajzewicz
@@ -23,16 +21,12 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <algorithm>
 #include <utils/vehicle/SUMOVTypeParameter.h>
 #include <utils/common/ToString.h>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include <utils/common/MsgHandler.h>
 #include <utils/iodevices/OutputDevice.h>
 #include <utils/options/OptionsCont.h>
@@ -45,16 +39,22 @@
 // ===========================================================================
 // member method definitions
 // ===========================================================================
-SUMOVTypeParameter::SUMOVTypeParameter(const std::string& vtid, const SUMOVehicleClass vclass)
-    : id(vtid), length(5./*4.3*/), minGap(2.5), maxSpeed(200. / 3.6),
-      actionStepLength(0), defaultProbability(DEFAULT_VEH_PROB),
-      speedFactor("normc", 1.0, 0.0, 0.2, 2.0),
-      emissionClass(PollutantsInterface::getClassByName(EMPREFIX + "PC_G_EU4", vclass)), color(RGBColor::DEFAULT_COLOR),
-      vehicleClass(vclass), impatience(0.0), personCapacity(4), containerCapacity(0), boardingDuration(500),
-      loadingDuration(90000), width(1.8), height(1.5), shape(SVS_UNKNOWN), osgFile("car-normal-citrus.obj"),
-      cfModel(SUMO_TAG_CF_KRAUSS), lcModel(LCM_DEFAULT),
-      maxSpeedLat(1.0), latAlignment(LATALIGN_CENTER), minGapLat(0.6),
-      parametersSet(0), saved(false), onlyReferenced(false) {
+SUMOVTypeParameter::SUMOVTypeParameter(const std::string& vtid, const SUMOVehicleClass vclass) :
+    id(vtid), length(5./*4.3*/), minGap(2.5), maxSpeed(200. / 3.6),
+    actionStepLength(0), defaultProbability(DEFAULT_VEH_PROB),
+    speedFactor("normc", 1.0, 0.0, 0.2, 2.0),
+    emissionClass(PollutantsInterface::getClassByName(EMPREFIX + "PC_G_EU4", vclass)), color(RGBColor::DEFAULT_COLOR),
+    vehicleClass(vclass), impatience(0.0), personCapacity(4), containerCapacity(0), boardingDuration(500),
+    loadingDuration(90000), width(1.8), height(1.5), shape(SVS_UNKNOWN), osgFile("car-normal-citrus.obj"),
+    cfModel(SUMO_TAG_CF_KRAUSS),
+    hasDriverState(false), lcModel(LCM_DEFAULT),
+    maxSpeedLat(1.0), latAlignment(LATALIGN_CENTER), minGapLat(0.6),
+    parametersSet(0), saved(false), onlyReferenced(false) {
+    const OptionsCont& oc = OptionsCont::getOptions();
+    if (oc.exists("carfollow.model")) {
+        // check for valid value has been performed in MSFrame
+        cfModel = SUMOXMLDefinitions::CarFollowModels.get(oc.getString("carfollow.model"));
+    }
     switch (vclass) {
         case SVC_PEDESTRIAN:
             length = 0.215;
@@ -64,6 +64,7 @@ SUMOVTypeParameter::SUMOVTypeParameter(const std::string& vtid, const SUMOVehicl
             height = 1.719;
             shape = SVS_PEDESTRIAN;
             emissionClass = PollutantsInterface::getClassByName(EMPREFIX + "zero", vclass);
+            speedFactor.getParameter()[1] = 0.1;
             break;
         case SVC_BICYCLE:
             length = 1.6;
@@ -74,6 +75,7 @@ SUMOVTypeParameter::SUMOVTypeParameter(const std::string& vtid, const SUMOVehicl
             shape = SVS_BICYCLE;
             personCapacity = 1;
             emissionClass = PollutantsInterface::getClassByName(EMPREFIX + "zero", vclass);
+            speedFactor.getParameter()[1] = 0.1;
             break;
         case SVC_MOPED:
             length = 2.1;
@@ -83,6 +85,7 @@ SUMOVTypeParameter::SUMOVTypeParameter(const std::string& vtid, const SUMOVehicl
             shape = SVS_MOPED;
             personCapacity = 1;
             emissionClass = PollutantsInterface::getClassByName(EMPREFIX + "LDV_G_EU6", vclass);
+            speedFactor.getParameter()[1] = 0.1;
             break;
         case SVC_MOTORCYCLE:
             length = 2.2;
@@ -91,6 +94,7 @@ SUMOVTypeParameter::SUMOVTypeParameter(const std::string& vtid, const SUMOVehicl
             shape = SVS_MOTORCYCLE;
             personCapacity = 1;
             emissionClass = PollutantsInterface::getClassByName(EMPREFIX + "LDV_G_EU6", vclass);
+            speedFactor.getParameter()[1] = 0.1;
             break;
         case SVC_TRUCK:
             length = 7.1;
@@ -102,6 +106,7 @@ SUMOVTypeParameter::SUMOVTypeParameter(const std::string& vtid, const SUMOVehicl
             personCapacity = 2;
             containerCapacity = 1;
             emissionClass = PollutantsInterface::getClassByName(EMPREFIX + "HDV", vclass);
+            speedFactor.getParameter()[1] = 0.05;
             break;
         case SVC_TRAILER:
             length = 16.5;
@@ -113,6 +118,7 @@ SUMOVTypeParameter::SUMOVTypeParameter(const std::string& vtid, const SUMOVehicl
             personCapacity = 2;
             containerCapacity = 2;
             emissionClass = PollutantsInterface::getClassByName(EMPREFIX + "HDV", vclass);
+            speedFactor.getParameter()[1] = 0.05;
             break;
         case SVC_BUS:
             length = 12.;
@@ -133,6 +139,7 @@ SUMOVTypeParameter::SUMOVTypeParameter(const std::string& vtid, const SUMOVehicl
             osgFile = "car-minibus-citrus.obj";
             personCapacity = 70;
             emissionClass = PollutantsInterface::getClassByName(EMPREFIX + "Coach", vclass);
+            speedFactor.getParameter()[1] = 0.05;
             break;
         case SVC_TRAM:
             length = 22.;
@@ -154,7 +161,7 @@ SUMOVTypeParameter::SUMOVTypeParameter(const std::string& vtid, const SUMOVehicl
             break;
         case SVC_RAIL:
             length = 67.5 * 2;
-            maxSpeed = 1600. / 3.6;
+            maxSpeed = 160. / 3.6;
             width = 2.84;
             height = 3.75;
             shape = SVS_RAIL;
@@ -178,6 +185,7 @@ SUMOVTypeParameter::SUMOVTypeParameter(const std::string& vtid, const SUMOVehicl
             shape = SVS_DELIVERY;
             personCapacity = 2;
             emissionClass = PollutantsInterface::getClassByName(EMPREFIX + "LDV", vclass);
+            speedFactor.getParameter()[1] = 0.05;
             break;
         case SVC_EMERGENCY:
             length = 6.5;
@@ -187,12 +195,23 @@ SUMOVTypeParameter::SUMOVTypeParameter(const std::string& vtid, const SUMOVehicl
             personCapacity = 2;
             emissionClass = PollutantsInterface::getClassByName(EMPREFIX + "LDV", vclass);
             break;
+        case SVC_PRIVATE:
+        case SVC_VIP:
         case SVC_PASSENGER:
+        case SVC_HOV:
+        case SVC_CUSTOM1:
+        case SVC_CUSTOM2:
             shape = SVS_PASSENGER;
+            speedFactor.getParameter()[1] = 0.1;
+            break;
+        case SVC_TAXI:
+            shape = SVS_PASSENGER;
+            speedFactor.getParameter()[1] = 0.05;
             break;
         case SVC_E_VEHICLE:
             shape = SVS_E_VEHICLE;
             emissionClass = PollutantsInterface::getClassByName(EMPREFIX + "zero", vclass);
+            speedFactor.getParameter()[1] = 0.1;
             break;
         case SVC_SHIP:
             length = 17;
@@ -202,10 +221,19 @@ SUMOVTypeParameter::SUMOVTypeParameter(const std::string& vtid, const SUMOVehicl
             shape = SVS_SHIP;
             // slight understatement (-:
             emissionClass = PollutantsInterface::getClassByName(EMPREFIX + "HDV_D_EU0", vclass);
+            speedFactor.getParameter()[1] = 0.1;
             break;
         default:
             break;
     }
+    if (oc.exists("default.speeddev")) {
+        const double defaultSpeedDev = oc.getFloat("default.speeddev");
+        if (defaultSpeedDev >= 0) {
+            speedFactor.getParameter()[1] = defaultSpeedDev;
+        }
+    } else {
+        speedFactor.getParameter()[1] = 0;
+    }
 }
 
 
@@ -235,6 +263,10 @@ SUMOVTypeParameter::write(OutputDevice& dev) const {
         // Note: action step length is only exposed in seconds to the user
         dev.writeAttr(SUMO_ATTR_ACTIONSTEPLENGTH, STEPS2TIME(actionStepLength));
     }
+    if (wasSet(VTYPEPARS_ACTIONSTEPLENGTH_SET)) {
+        // Note: action step length is only exposed in seconds to the user
+        dev.writeAttr(SUMO_ATTR_HASDRIVERSTATE, hasDriverState);
+    }
     if (wasSet(VTYPEPARS_VEHICLECLASS_SET)) {
         dev.writeAttr(SUMO_ATTR_VCLASS, toString(vehicleClass));
     }
@@ -310,7 +342,7 @@ SUMOVTypeParameter::write(OutputDevice& dev) const {
 double
 SUMOVTypeParameter::getCFParam(const SumoXMLAttr attr, const double defaultValue) const {
     if (cfParameter.count(attr)) {
-        return TplConvert::_str2double(cfParameter.find(attr)->second);
+        return StringUtils::toDouble(cfParameter.find(attr)->second);
     } else {
         return defaultValue;
     }
@@ -329,17 +361,22 @@ SUMOVTypeParameter::getCFParamString(const SumoXMLAttr attr, const std::string d
 double
 SUMOVTypeParameter::getLCParam(const SumoXMLAttr attr, const double defaultValue) const {
     if (lcParameter.count(attr)) {
-        return TplConvert::_str2double(lcParameter.find(attr)->second);
+        return StringUtils::toDouble(lcParameter.find(attr)->second);
     } else {
         return defaultValue;
     }
 }
 
+const SUMOVTypeParameter::SubParams&
+SUMOVTypeParameter::getLCParams() const {
+    return lcParameter;
+}
+
 
 double
 SUMOVTypeParameter::getJMParam(const SumoXMLAttr attr, const double defaultValue) const {
     if (jmParameter.count(attr)) {
-        return TplConvert::_str2double(jmParameter.find(attr)->second);
+        return StringUtils::toDouble(jmParameter.find(attr)->second);
     } else {
         return defaultValue;
     }
@@ -392,19 +429,14 @@ SUMOVTypeParameter::getDefaultDecel(const SUMOVehicleClass vc) {
         case SVC_MOTORCYCLE:
             return 10.;
         case SVC_TRUCK:
-            return 4.;
         case SVC_TRAILER:
-            return 4.;
         case SVC_BUS:
-            return 4.;
         case SVC_COACH:
             return 4.;
         case SVC_TRAM:
-            return 3.;
         case SVC_RAIL_URBAN:
             return 3.;
         case SVC_RAIL:
-            return 1.3;
         case SVC_RAIL_ELECTRIC:
             return 1.3;
         case SVC_SHIP:
@@ -416,36 +448,44 @@ SUMOVTypeParameter::getDefaultDecel(const SUMOVehicleClass vc) {
 
 
 double
-SUMOVTypeParameter::getDefaultEmergencyDecel(const SUMOVehicleClass vc) {
-    switch (vc) {
-        case SVC_PEDESTRIAN:
-            return 3.;
-        case SVC_BICYCLE:
-            return 5.;
-        case SVC_MOPED:
-            return 8.;
-        case SVC_MOTORCYCLE:
-            return 10.;
-        case SVC_TRUCK:
-            return 7.;
-        case SVC_TRAILER:
-            return 7.;
-        case SVC_BUS:
-            return 7.;
-        case SVC_COACH:
-            return 7.;
-        case SVC_TRAM:
-            return 5.;
-        case SVC_RAIL_URBAN:
-            return 5.;
-        case SVC_RAIL:
-            return 4;
-        case SVC_RAIL_ELECTRIC:
-            return 4;
-        case SVC_SHIP:
-            return 1;
-        default:
-            return 9;//7.5;
+SUMOVTypeParameter::getDefaultEmergencyDecel(const SUMOVehicleClass vc, double decel, double defaultOption) {
+    if (defaultOption == VTYPEPARS_DEFAULT_EMERGENCYDECEL_DEFAULT) {
+        double vcDecel;
+        switch (vc) {
+            case SVC_PEDESTRIAN:
+                vcDecel = 5.;
+                break;
+            case SVC_BICYCLE:
+                vcDecel = 7.;
+                break;
+            case SVC_MOPED:
+            case SVC_MOTORCYCLE:
+                vcDecel = 10.;
+                break;
+            case SVC_TRUCK:
+            case SVC_TRAILER:
+            case SVC_BUS:
+            case SVC_COACH:
+            case SVC_TRAM:
+            case SVC_RAIL_URBAN:
+                vcDecel = 7.;
+                break;
+            case SVC_RAIL:
+            case SVC_RAIL_ELECTRIC:
+                vcDecel = 5.;
+                break;
+            case SVC_SHIP:
+                vcDecel = 1.;
+                break;
+            default:
+                vcDecel = 9.;
+        }
+        return MAX2(decel, vcDecel);
+    } else if (defaultOption == VTYPEPARS_DEFAULT_EMERGENCYDECEL_DECEL) {
+        return decel;
+    } else {
+        // value already checked in MSFrame::checkOptions
+        return MAX2(decel, defaultOption);
     }
 }
 
