@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    SUMOVTypeParameter.h
 /// @author  Daniel Krajzewicz
@@ -25,14 +23,8 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
-
 #include <config.h>
 
-#endif
-
 #include <string>
 #include <map>
 #include <utils/common/Parameterised.h>
@@ -75,8 +67,12 @@ const int VTYPEPARS_MAXSPEED_LAT_SET = 1 << 20;
 const int VTYPEPARS_LATALIGNMENT_SET = 1 << 21;
 const int VTYPEPARS_MINGAP_LAT_SET = 1 << 22;
 const int VTYPEPARS_ACTIONSTEPLENGTH_SET = 1 << 23;
+const int VTYPEPARS_HASDRIVERSTATE_SET = 1 << 24;
 
 
+const int VTYPEPARS_DEFAULT_EMERGENCYDECEL_DEFAULT = -1;
+const int VTYPEPARS_DEFAULT_EMERGENCYDECEL_DECEL = -2;
+
 // ===========================================================================
 // struct definitions
 // ===========================================================================
@@ -135,6 +131,12 @@ public:
      */
     double getLCParam(const SumoXMLAttr attr, const double defaultValue) const;
 
+    /// @brief sub-model parameters
+    typedef std::map<SumoXMLAttr, std::string> SubParams;
+
+    /// @brief Returns the LC parameter
+    const SubParams& getLCParams() const;
+
     /** @brief Returns the named value from the map, or the default if it is not contained there
      * @param[in] attr The corresponding xml attribute
      * @param[in] defaultValue The value to return if the given map does not contain the named variable
@@ -199,8 +201,9 @@ public:
     /// @brief The enum-representation of the car-following model to use
     SumoXMLTag cfModel;
 
-    /// @brief sub-model parameters
-    typedef std::map<SumoXMLAttr, std::string> SubParams;
+    /// @brief Whether vehicles of this type are equipped with a driver (i.e. MSDriverState))
+    bool hasDriverState;
+
     /// @brief Car-following parameter
     SubParams cfParameter;
     /// @brief Lane-changing parameter
@@ -226,7 +229,7 @@ public:
     mutable bool saved;
 
     /// @brief Information whether this is a type-stub, being only referenced but not defined (needed by routers)
-    mutable bool onlyReferenced;
+    bool onlyReferenced;
 
     /** @brief Returns the default acceleration for the given vehicle class
      * This needs to be a function because the actual value is stored in the car following model
@@ -245,9 +248,10 @@ public:
     /** @brief Returns the default emergency deceleration for the given vehicle class
      * This needs to be a function because the actual value is stored in the car following model
      * @param[in] vc the vehicle class
-     * @return the deceleration in m/s^2
+     * @param[in] decel the deceleration of the vehicle type
+     * @return the emergency deceleration in m/s^2
      */
-    static double getDefaultEmergencyDecel(const SUMOVehicleClass vc = SVC_IGNORING);
+    static double getDefaultEmergencyDecel(const SUMOVehicleClass vc, double decel, double defaultOption);
 
     /** @brief Returns the default driver's imperfection (sigma or epsilon in Krauss' model) for the given vehicle class
      * This needs to be a function because the actual value is stored in the car following model
