@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    SUMOVehicleParameter.cpp
 /// @author  Daniel Krajzewicz
@@ -23,15 +21,11 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include "SUMOVehicleParameter.h"
 #include <utils/common/ToString.h>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include <utils/common/MsgHandler.h>
 #include <utils/iodevices/OutputDevice.h>
 #include <utils/options/OptionsCont.h>
@@ -146,7 +140,7 @@ SUMOVehicleParameter::write(OutputDevice& dev, const OptionsCont& oc, const Sumo
     //  departPosLat
     if (wasSet(VEHPARS_DEPARTPOSLAT_SET)) {
         std::string val;
-        switch (departPosProcedure) {
+        switch (departPosLatProcedure) {
             case DEPART_POSLAT_GIVEN:
                 val = toString(departPos);
                 break;
@@ -224,6 +218,9 @@ SUMOVehicleParameter::write(OutputDevice& dev, const OptionsCont& oc, const Sumo
             case ARRIVAL_POS_RANDOM:
                 val = "random";
                 break;
+            case ARRIVAL_POS_CENTER:
+                val = "center";
+                break;
             case ARRIVAL_POS_MAX:
                 val = "max";
                 break;
@@ -238,7 +235,7 @@ SUMOVehicleParameter::write(OutputDevice& dev, const OptionsCont& oc, const Sumo
     //  arrivalPosLat
     if (wasSet(VEHPARS_ARRIVALPOSLAT_SET)) {
         std::string val;
-        switch (arrivalPosProcedure) {
+        switch (arrivalPosLatProcedure) {
             case ARRIVAL_POSLAT_GIVEN:
                 val = toString(arrivalPos);
                 break;
@@ -320,10 +317,10 @@ SUMOVehicleParameter::Stop::write(OutputDevice& dev) const {
         }
     }
     if (duration >= 0) {
-        dev.writeAttr(SUMO_ATTR_DURATION, STEPS2TIME(duration));
+        dev.writeAttr(SUMO_ATTR_DURATION, time2string(duration));
     }
     if (until >= 0) {
-        dev.writeAttr(SUMO_ATTR_UNTIL, STEPS2TIME(until));
+        dev.writeAttr(SUMO_ATTR_UNTIL, time2string(until));
     }
     if ((parametersSet & STOP_TRIGGER_SET) != 0) {
         dev.writeAttr(SUMO_ATTR_TRIGGERED, triggered);
@@ -352,6 +349,7 @@ SUMOVehicleParameter::parseDepart(const std::string& val, const std::string& ele
     } else if (val == "containerTriggered") {
         dd = DEPART_CONTAINER_TRIGGERED;
     } else if (val == "now") {
+        // only used via TraCI. depart must be set by the calling code
         dd = DEPART_NOW;
     } else {
         try {
@@ -386,7 +384,7 @@ SUMOVehicleParameter::parseDepartLane(const std::string& val, const std::string&
         dld = DEPART_LANE_FIRST_ALLOWED;
     } else {
         try {
-            lane = TplConvert::_2int(val.c_str());
+            lane = StringUtils::toInt(val);
             dld = DEPART_LANE_GIVEN;
             if (lane < 0) {
                 ok = false;
@@ -418,7 +416,7 @@ SUMOVehicleParameter::parseDepartPos(const std::string& val, const std::string&
         dpd = DEPART_POS_LAST;
     } else {
         try {
-            pos = TplConvert::_2double(val.c_str());
+            pos = StringUtils::toDouble(val);
             dpd = DEPART_POS_GIVEN;
         } catch (...) {
             ok = false;
@@ -449,7 +447,7 @@ SUMOVehicleParameter::parseDepartPosLat(const std::string& val, const std::strin
         dpd = DEPART_POSLAT_LEFT;
     } else {
         try {
-            pos = TplConvert::_2double(val.c_str());
+            pos = StringUtils::toDouble(val);
             dpd = DEPART_POSLAT_GIVEN;
         } catch (...) {
             ok = false;
@@ -472,7 +470,7 @@ SUMOVehicleParameter::parseDepartSpeed(const std::string& val, const std::string
         dsd = DEPART_SPEED_MAX;
     } else {
         try {
-            speed = TplConvert::_2double(val.c_str());
+            speed = StringUtils::toDouble(val);
             dsd = DEPART_SPEED_GIVEN;
             if (speed < 0) {
                 ok = false;
@@ -496,7 +494,7 @@ SUMOVehicleParameter::parseArrivalLane(const std::string& val, const std::string
         ald = ARRIVAL_LANE_CURRENT;
     } else {
         try {
-            lane = TplConvert::_2int(val.c_str());
+            lane = StringUtils::toInt(val);
             ald = ARRIVAL_LANE_GIVEN;
             if (lane < 0) {
                 ok = false;
@@ -518,11 +516,13 @@ SUMOVehicleParameter::parseArrivalPos(const std::string& val, const std::string&
     bool ok = true;
     if (val == "random") {
         apd = ARRIVAL_POS_RANDOM;
+    } else if (val == "center") {
+        apd = ARRIVAL_POS_CENTER;
     } else if (val == "max") {
         apd = ARRIVAL_POS_MAX;
     } else {
         try {
-            pos = TplConvert::_2double(val.c_str());
+            pos = StringUtils::toDouble(val);
             apd = ARRIVAL_POS_GIVEN;
         } catch (...) {
             ok = false;
@@ -547,7 +547,7 @@ SUMOVehicleParameter::parseArrivalPosLat(const std::string& val, const std::stri
         apd = ARRIVAL_POSLAT_LEFT;
     } else {
         try {
-            pos = TplConvert::_2double(val.c_str());
+            pos = StringUtils::toDouble(val);
             apd = ARRIVAL_POSLAT_GIVEN;
         } catch (...) {
             ok = false;
@@ -568,7 +568,7 @@ SUMOVehicleParameter::parseArrivalSpeed(const std::string& val, const std::strin
         asd = ARRIVAL_SPEED_CURRENT;
     } else {
         try {
-            speed = TplConvert::_2double(val.c_str());
+            speed = StringUtils::toDouble(val);
             if (speed < 0) {
                 ok = false;
             }
