@@ -1,25 +1,22 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    SUMOVehicleParameter.h
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @author  Axel Wegener
 /// @author  Michael Behrisch
 /// @date    2006-01-24
-/// @version $Id: SUMOVehicleParameter.h 23150 2017-02-27 12:08:30Z behrisch $
+/// @version $Id$
 ///
 // Structure representing possible vehicle parameter
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 #ifndef SUMOVehicleParameter_h
 #define SUMOVehicleParameter_h
 
@@ -27,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <utils/common/Parameterised.h>
@@ -70,6 +63,7 @@ const int VEHPARS_PERSON_NUMBER_SET = 2 << 15;
 const int VEHPARS_CONTAINER_NUMBER_SET = 2 << 16;
 const int VEHPARS_DEPARTPOSLAT_SET = 2 << 17;
 const int VEHPARS_ARRIVALPOSLAT_SET = 2 << 18;
+const int VEHPARS_VIA_SET = 2 << 19;
 
 const int STOP_INDEX_END = -1;
 const int STOP_INDEX_FIT = -2;
@@ -223,6 +217,8 @@ enum ArrivalPosDefinition {
     ARRIVAL_POS_GIVEN,
     /// @brief The arrival position is chosen randomly
     ARRIVAL_POS_RANDOM,
+    /// @brief Half the road length
+    ARRIVAL_POS_CENTER,
     /// @brief The maximum arrival position is used
     ARRIVAL_POS_MAX,
     /// @brief Tag for the last element in the enum for safe int casting
@@ -297,7 +293,7 @@ public:
      * @return Whether the given parameter was set
      */
     bool wasSet(int what) const {
-        return (setParameter & what) != 0;
+        return (parametersSet & what) != 0;
     }
 
 
@@ -461,7 +457,6 @@ public:
     /// @brief The vehicle's color, TraCI may change this
     mutable RGBColor color;
 
-
     /// @name Departure definition
     /// @{
 
@@ -568,11 +563,11 @@ public:
         /// @brief IDs of containers the vehicle has to wait for until departing
         std::set<std::string> awaitedContainers;
         /// @brief lanes and positions connected to this stop
-        std::multimap<std::string, double> accessPos;
+        std::vector<std::tuple<std::string, double, double> > accessPos;
         /// @brief at which position in the stops list
         int index;
         /// @brief Information for the output which parameter were set
-        int setParameter;
+        int parametersSet = 0;
 
         /** @brief Writes the stop as XML
          *
@@ -595,8 +590,7 @@ public:
     int containerNumber;
 
     /// @brief Information for the router which parameter were set, TraCI may modify this (whe changing color)
-    mutable int setParameter;
-
+    mutable int parametersSet;
 
 };
 
