@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    SUMORouteLoader.cpp
 /// @author  Daniel Krajzewicz
@@ -21,11 +19,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/xml/SUMORouteHandler.h>
 #include <utils/xml/SUMOSAXReader.h>
@@ -37,7 +31,7 @@
 // method definitions
 // ===========================================================================
 SUMORouteLoader::SUMORouteLoader(SUMORouteHandler* handler)
-    : myParser(0), myMoreAvailable(true), myHandler(handler) {
+    : myParser(nullptr), myMoreAvailable(true), myHandler(handler) {
     myParser = XMLSubSys::getSAXReader(*myHandler);
     if (!myParser->parseFirst(myHandler->getFileName())) {
         throw ProcessError("Can not read XML-file '" + myHandler->getFileName() + "'.");
@@ -53,7 +47,7 @@ SUMORouteLoader::~SUMORouteLoader() {
 
 SUMOTime
 SUMORouteLoader::loadUntil(SUMOTime time) {
-    // read only when further data is available, no error occured
+    // read only when further data is available, no error occurred
     //  and vehicles may be found in the between the departure time of
     //  the last read vehicle and the time to read until
     if (!myMoreAvailable) {
