@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2007-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2007-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    SUMOSAXAttributes.cpp
 /// @author  Daniel Krajzewicz
@@ -23,11 +21,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <iostream>
@@ -43,7 +37,6 @@
 // ===========================================================================
 // static members
 // ===========================================================================
-bool SUMOSAXAttributes::myHaveInformedAboutDeprecatedDivider = false;
 const std::string SUMOSAXAttributes::ENCODING = " encoding=\"UTF-8\"";
 
 
@@ -54,6 +47,18 @@ SUMOSAXAttributes::SUMOSAXAttributes(const std::string& objectType):
     myObjectType(objectType) {}
 
 
+const std::string invalid_return<std::string>::value = "";
+const std::string invalid_return<std::string>::type = "string";
+template<>
+std::string SUMOSAXAttributes::getInternal(const int attr) const {
+    const std::string ret = getString(attr);
+    if (ret == "") {
+        throw EmptyData();
+    }
+    return ret;
+}
+
+
 SUMOTime
 SUMOSAXAttributes::getSUMOTimeReporting(int attr, const char* objectid,
                                         bool& ok, bool report) const {
@@ -65,15 +70,16 @@ SUMOSAXAttributes::getSUMOTimeReporting(int attr, const char* objectid,
         return -1;
     }
     try {
-        return TIME2STEPS(getFloat(attr));
-    } catch (NumberFormatException&) {
-        if (report) {
-            emitFormatError(getName(attr), "a time value", objectid);
-        }
+        const std::string val = getInternal<std::string>(attr);
+        return string2time(val);
     } catch (EmptyData&) {
         if (report) {
             emitEmptyError(getName(attr), objectid);
         }
+    } catch (ProcessError&) {
+        if (report) {
+            emitFormatError(getName(attr), "a time value", objectid);
+        }
     }
     ok = false;
     return (SUMOTime) - 1;
@@ -87,29 +93,27 @@ SUMOSAXAttributes::getOptSUMOTimeReporting(int attr, const char* objectid,
         return defaultValue;
     }
     try {
-        return (SUMOTime)(getFloat(attr) * 1000.);
-    } catch (NumberFormatException&) {
-        if (report) {
-            emitFormatError(getName(attr), "a real number", objectid);
-        }
+        const std::string val = getInternal<std::string>(attr);
+        return string2time(val);
     } catch (EmptyData&) {
         if (report) {
             emitEmptyError(getName(attr), objectid);
         }
+    } catch (ProcessError&) {
+        if (report) {
+            emitFormatError(getName(attr), "a real number", objectid);
+        }
     }
     ok = false;
     return (SUMOTime) - 1;
 }
 
 
-
-
-
 void
 SUMOSAXAttributes::emitUngivenError(const std::string& attrname, const char* objectid) const {
     std::ostringstream oss;
     oss << "Attribute '" << attrname << "' is missing in definition of ";
-    if (objectid == 0 || objectid[0] == 0) {
+    if (objectid == nullptr || objectid[0] == 0) {
         oss << "a " << myObjectType;
     } else {
         oss << myObjectType << " '" << objectid << "'";
@@ -123,7 +127,7 @@ void
 SUMOSAXAttributes::emitEmptyError(const std::string& attrname, const char* objectid) const {
     std::ostringstream oss;
     oss << "Attribute '" << attrname << "' in definition of ";
-    if (objectid == 0 || objectid[0] == 0) {
+    if (objectid == nullptr || objectid[0] == 0) {
         oss << "a " << myObjectType;
     } else {
         oss << myObjectType << " '" << objectid << "'";
@@ -137,7 +141,7 @@ void
 SUMOSAXAttributes::emitFormatError(const std::string& attrname, const std::string& type, const char* objectid) const {
     std::ostringstream oss;
     oss << "Attribute '" << attrname << "' in definition of ";
-    if (objectid == 0 || objectid[0] == 0) {
+    if (objectid == nullptr || objectid[0] == 0) {
         oss << "a " << myObjectType;
     } else {
         oss << myObjectType << " '" << objectid << "'";
@@ -149,13 +153,7 @@ SUMOSAXAttributes::emitFormatError(const std::string& attrname, const std::strin
 
 void
 SUMOSAXAttributes::parseStringVector(const std::string& def, std::vector<std::string>& into) {
-    if (def.find(';') != std::string::npos || def.find(',') != std::string::npos) {
-        if (!myHaveInformedAboutDeprecatedDivider) {
-            WRITE_WARNING("Please note that using ';' and ',' as XML list separators is deprecated.\n From 1.0 onwards, only ' ' will be accepted.");
-            myHaveInformedAboutDeprecatedDivider = true;
-        }
-    }
-    StringTokenizer st(def, ";, ", true);
+    StringTokenizer st(def, " ", true);
     while (st.hasNext()) {
         into.push_back(st.next());
     }
@@ -164,81 +162,63 @@ SUMOSAXAttributes::parseStringVector(const std::string& def, std::vector<std::st
 
 void
 SUMOSAXAttributes::parseStringSet(const std::string& def, std::set<std::string>& into) {
-    if (def.find(';') != std::string::npos || def.find(',') != std::string::npos) {
-        if (!myHaveInformedAboutDeprecatedDivider) {
-            WRITE_WARNING("Please note that using ';' and ',' as XML list separators is deprecated.\n From 1.0 onwards, only ' ' will be accepted.");
-            myHaveInformedAboutDeprecatedDivider = true;
-        }
-    }
-    StringTokenizer st(def, ";, ", true);
+    StringTokenizer st(def, " ", true);
     while (st.hasNext()) {
         into.insert(st.next());
     }
 }
 
 
-template<> const int invalid_return<int>::value = -1;
-template<> const std::string invalid_return<int>::type = "int";
+const int invalid_return<int>::value = -1;
+const std::string invalid_return<int>::type = "int";
 template<>
 int SUMOSAXAttributes::getInternal(const int attr) const {
     return getInt(attr);
 }
 
 
-template<> const long long int invalid_return<long long int>::value = -1;
-template<> const std::string invalid_return<long long int>::type = "long";
+const long long int invalid_return<long long int>::value = -1;
+const std::string invalid_return<long long int>::type = "long";
 template<>
 long long int SUMOSAXAttributes::getInternal(const int attr) const {
     return getLong(attr);
 }
 
 
-template<> const double invalid_return<double>::value = -1;
-template<> const std::string invalid_return<double>::type = "float";
+const double invalid_return<double>::value = -1;
+const std::string invalid_return<double>::type = "float";
 template<>
 double SUMOSAXAttributes::getInternal(const int attr) const {
     return getFloat(attr);
 }
 
 
-template<> const bool invalid_return<bool>::value = false;
-template<> const std::string invalid_return<bool>::type = "bool";
+const bool invalid_return<bool>::value = false;
+const std::string invalid_return<bool>::type = "bool";
 template<>
 bool SUMOSAXAttributes::getInternal(const int attr) const {
     return getBool(attr);
 }
 
 
-template<> const std::string invalid_return<std::string>::value = "";
-template<> const std::string invalid_return<std::string>::type = "string";
-template<>
-std::string SUMOSAXAttributes::getInternal(const int attr) const {
-    const std::string ret = getString(attr);
-    if (ret == "") {
-        throw EmptyData();
-    }
-    return ret;
-}
-
-
-template<> const RGBColor invalid_return<RGBColor>::value = RGBColor();
-template<> const std::string invalid_return<RGBColor>::type = "color";
+const RGBColor invalid_return<RGBColor>::value = RGBColor();
+const std::string invalid_return<RGBColor>::type = "color";
 template<>
 RGBColor SUMOSAXAttributes::getInternal(const int /* attr */) const {
     return getColor();
 }
 
 
-template<> const PositionVector invalid_return<PositionVector>::value = PositionVector();
-template<> const std::string invalid_return<PositionVector>::type = "PositionVector";
+const PositionVector invalid_return<PositionVector>::value = PositionVector();
+const std::string invalid_return<PositionVector>::type = "PositionVector";
 template<>
 PositionVector SUMOSAXAttributes::getInternal(const int attr) const {
     return getShape(attr);
 }
 
 
-template<> const Boundary invalid_return<Boundary>::value = Boundary();
-template<> const std::string invalid_return<Boundary>::type = "Boundary";
+const Boundary invalid_return<Boundary>::value = Boundary();
+const std::string invalid_return<Boundary>::type = "Boundary";
 template<>
 Boundary SUMOSAXAttributes::getInternal(const int attr) const {
     return getBoundary(attr);
@@ -246,4 +226,3 @@ Boundary SUMOSAXAttributes::getInternal(const int attr) const {
 
 
 /****************************************************************************/
-
