@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2007-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2007-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    SUMOSAXAttributes.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <string>
 #include <vector>
@@ -83,7 +77,7 @@ public:
      * @param[in] objectid The name of the parsed object; used for error message generation
      * @param[out] ok Whether the value could be read
      * @param[in] report Whether errors shall be written to msg handler's error instance
-     * @return The read value if given and correct; -1 if an error occured
+     * @return The read value if given and correct; -1 if an error occurred
      */
     template <typename T>
     T get(int attr, const char* objectid, bool& ok, bool report = true) const;
@@ -102,7 +96,7 @@ public:
      * @param[out] ok Whether the value could be read
      * @param[in] defaultValue The value to return if the attribute is not within the element
      * @param[in] report Whether errors shall be written to msg handler's error instance
-     * @return The read value if given and correct; the default value if the attribute does not exist;  -1 if an error occured
+     * @return The read value if given and correct; the default value if the attribute does not exist;  -1 if an error occurred
      */
     template <typename T>
     T getOpt(int attr, const char* objectid, bool& ok, T defaultValue, bool report = true) const;
@@ -122,7 +116,7 @@ public:
      * @param[in] objectid The name of the parsed object; used for error message generation
      * @param[out] ok Whether the value could be read
      * @param[in] report Whether errors shall be written to msg handler's error instance
-     * @return The read value if given and correct; -1 if an error occured
+     * @return The read value if given and correct; -1 if an error occurred
      */
     SUMOTime getSUMOTimeReporting(int attr, const char* objectid, bool& ok,
                                   bool report = true) const;
@@ -145,7 +139,7 @@ public:
      * @param[out] ok Whether the value could be read
      * @param[in] defaultValue The value to return if the attribute is not within the element
      * @param[in] report Whether errors shall be written to msg handler's error instance
-     * @return The read value if given and correct; the default value if the attribute does not exist;  -1 if an error occured
+     * @return The read value if given and correct; the default value if the attribute does not exist;  -1 if an error occurred
      */
     SUMOTime getOptSUMOTimeReporting(int attr, const char* objectid, bool& ok,
                                      SUMOTime defaultValue, bool report = true) const;
@@ -321,6 +315,11 @@ public:
      */
     virtual SumoXMLNodeType getNodeType(bool& ok) const = 0;
 
+    /**
+     * @brief Returns the right-of-way method 
+     */
+    virtual RightOfWay getRightOfWay(bool& ok) const = 0;
+
 
     /**
      * @brief Returns the value of the named attribute
@@ -334,21 +333,21 @@ public:
     /** @brief Tries to read given attribute assuming it is a PositionVector
      *
      * @param[in] attr The id of the attribute to read
-     * @return The read value if given and not empty; empty position vector if an error occured
+     * @return The read value if given and not empty; empty position vector if an error occurred
      */
     virtual PositionVector getShape(int attr) const = 0;
 
     /** @brief Tries to read given attribute assuming it is a Boundary
      *
      * @param[in] attr The id of the attribute to read
-     * @return The read value if given and not empty; empty Boundary if an error occured
+     * @return The read value if given and not empty; empty Boundary if an error occurred
      */
     virtual Boundary getBoundary(int attr) const = 0;
 
     /** @brief Tries to read given attribute assuming it is a string vector
      *
      * @param[in] attr The id of the attribute to read
-     * @return The read value if given and not empty; empty vector if an error occured
+     * @return The read value if given and not empty; empty vector if an error occurred
      */
     virtual std::vector<std::string> getStringVector(int attr) const = 0;
     //}
@@ -412,10 +411,6 @@ protected:
     void emitEmptyError(const std::string& attrname, const char* objectid) const;
     void emitFormatError(const std::string& attrname, const std::string& type, const char* objectid) const;
 
-private:
-    /// @brief Information whether the usage of a deprecated divider was reported
-    static bool myHaveInformedAboutDeprecatedDivider;
-
 private:
     /// @brief Invalidated copy constructor.
     SUMOSAXAttributes(const SUMOSAXAttributes& src);
@@ -440,6 +435,46 @@ template<typename X> struct invalid_return {
     static const std::string type;
 };
 
+template<> struct invalid_return<bool> {
+    static const bool value;
+    static const std::string type;
+};
+
+template<> struct invalid_return<int> {
+    static const int value;
+    static const std::string type;
+};
+
+template<> struct invalid_return<long long int> {
+    static const long long int value;
+    static const std::string type;
+};
+
+template<> struct invalid_return<double> {
+    static const double value;
+    static const std::string type;
+};
+
+template<> struct invalid_return<std::string> {
+    static const std::string value;
+    static const std::string type;
+};
+
+template<> struct invalid_return<RGBColor> {
+    static const RGBColor value;
+    static const std::string type;
+};
+
+template<> struct invalid_return<PositionVector> {
+    static const PositionVector value;
+    static const std::string type;
+};
+
+template<> struct invalid_return<Boundary> {
+    static const Boundary value;
+    static const std::string type;
+};
+
 
 template <typename T>
 T SUMOSAXAttributes::get(int attr, const char* objectid,
