@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    SUMOSAXAttributesImpl_Binary.cpp
 /// @author  Daniel Krajzewicz
@@ -23,16 +21,12 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <cassert>
 #include <sstream>
 #include <utils/common/RGBColor.h>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include <utils/geom/Boundary.h>
 #include <utils/geom/PositionVector.h>
 #include <utils/iodevices/BinaryFormatter.h>
@@ -189,8 +183,8 @@ SUMOSAXAttributesImpl_Binary::getInt(int id) const {
 
 
 long long int
-SUMOSAXAttributesImpl_Binary::getLong(int /* id */) const {
-    throw NumberFormatException();
+SUMOSAXAttributesImpl_Binary::getLong(int id) const {
+    return StringUtils::toLong(getString(id));
 }
 
 
@@ -219,7 +213,7 @@ double
 SUMOSAXAttributesImpl_Binary::getFloat(int id) const {
     const std::map<int, double>::const_iterator i = myFloatValues.find(id);
     if (i == myFloatValues.end()) {
-        return TplConvert::_2double(getString(id).c_str());
+        return StringUtils::toDouble(getString(id));
     }
     return i->second;
 }
@@ -272,6 +266,19 @@ SUMOSAXAttributesImpl_Binary::getNodeType(bool& ok) const {
 }
 
 
+RightOfWay
+SUMOSAXAttributesImpl_Binary::getRightOfWay(bool& ok) const {
+    try {
+        return SUMOXMLDefinitions::RightOfWayValues.get(getString(SUMO_ATTR_RIGHT_OF_WAY));
+    } catch (InvalidArgument) {
+        ok = false;
+        return RIGHT_OF_WAY_DEFAULT;
+    } catch (EmptyData) {
+        return RIGHT_OF_WAY_DEFAULT;
+    }
+}
+
+
 RGBColor
 SUMOSAXAttributesImpl_Binary::getColor() const {
     const std::map<int, int>::const_iterator i = myIntValues.find(SUMO_ATTR_COLOR);
