@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2007-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2007-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    SUMOSAXAttributesImpl_Binary.h
 /// @author  Daniel Krajzewicz
@@ -25,11 +23,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <map>
 #include <set>
@@ -237,6 +231,8 @@ public:
      */
     SumoXMLNodeType getNodeType(bool& ok) const;
 
+    /// @brief returns rightOfWay method
+    RightOfWay getRightOfWay(bool& ok) const; 
 
     /**
      * @brief Returns the value of the named attribute
@@ -250,7 +246,7 @@ public:
     /** @brief Tries to read given attribute assuming it is a PositionVector
      *
      * @param[in] attr The id of the attribute to read
-     * @return The read value if given and not empty; "" if an error occured
+     * @return The read value if given and not empty; "" if an error occurred
      */
     PositionVector getShape(int attr) const;
 
@@ -258,14 +254,14 @@ public:
     /** @brief Tries to read given attribute assuming it is a Boundary
      *
      * @param[in] attr The id of the attribute to read
-     * @return The read value if given and not empty; "" if an error occured
+     * @return The read value if given and not empty; "" if an error occurred
      */
     Boundary getBoundary(int attr) const;
 
     /** @brief Tries to read given attribute assuming it is a string vector
      *
      * @param[in] attr The id of the attribute to read
-     * @return The read value if given and not empty; empty vector if an error occured
+     * @return The read value if given and not empty; empty vector if an error occurred
      */
     std::vector<std::string> getStringVector(int attr) const;
 
