@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    SUMOVehicleParserHelper.h
 /// @author  Daniel Krajzewicz
@@ -26,11 +24,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <random>
 #include <string>
@@ -63,7 +57,7 @@ public:
      *
      * @see SUMOVehicleParameter
      * @param[in] attr The SAX-attributes to get vehicle parameter from
-     * @return The parsed attribute structure if no error occured, 0 otherwise
+     * @return The parsed attribute structure if no error occurred, 0 otherwise
      * @exception ProcessError If an attribute's value is invalid
      * @note: the caller is responsible for deleting the returned pointer
      */
@@ -79,7 +73,7 @@ public:
      * @param[in] optionalID Whether the id shall be skipped
      * @param[in] skipDepart Whether parsing the departure time shall be skipped
      * @param[in] isPerson   Whether a person is parsed
-     * @return The parsed attribute structure if no error occured, 0 otherwise
+     * @return The parsed attribute structure if no error occurred, 0 otherwise
      * @exception ProcessError If an attribute's value is invalid
      * @note: the caller is responsible for deleting the returned pointer
      */
@@ -91,13 +85,11 @@ public:
      *
      * @param[in] attr The SAX-attributes to get vehicle parameter from
      * @param[in] file The name of the file being parsed (for resolving paths)
-     * @param[in] defaultCFModel The XML tag of the default car following model (SUMO_TAG_NOTHING means no default)
      * @exception ProcessError If an attribute's value is invalid
      * @see SUMOVTypeParameter
      * @note: the caller is responsible for deleting the returned pointer
      */
-    static SUMOVTypeParameter* beginVTypeParsing(const SUMOSAXAttributes& attrs, const std::string& file,
-            const SumoXMLTag defaultCFModel);
+    static SUMOVTypeParameter* beginVTypeParsing(const SUMOSAXAttributes& attrs, const std::string& file);
 
 
     /** @brief Parses an element embedded in vtype definition
