@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    SUMOXMLDefinitions.h
 /// @author  Daniel Krajzewicz
@@ -28,11 +26,7 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <utils/common/StringBijection.h>
 
@@ -72,6 +66,8 @@ enum SumoXMLTag {
     SUMO_TAG_INDUCTION_LOOP,
     /// @brief an e2 detector
     SUMO_TAG_E2DETECTOR,
+    /// @brief an e2 detector over multiple lanes (used by Netedit)
+    SUMO_TAG_E2DETECTOR_MULTILANE,
     /// @brief alternative tag for e2 detector
     SUMO_TAG_LANE_AREA_DETECTOR,
     /// @brief an e3 detector
@@ -146,6 +142,8 @@ enum SumoXMLTag {
     SUMO_TAG_TRIP,
     /// @brief a flow definition (used by router)
     SUMO_TAG_FLOW,
+    /// @brief a flow state definition (used when saving and loading simulatino state)
+    SUMO_TAG_FLOWSTATE,
     /// @brief trigger: a step description
     SUMO_TAG_STEP,
     /// @brief an aggreagated-output interval
@@ -209,6 +207,8 @@ enum SumoXMLTag {
     SUMO_TAG_CROSSING,
     /// @brief walking area for pedestrians
     SUMO_TAG_WALKINGAREA,
+    /// @brief Information on vClass specific stop offsets at lane end
+    SUMO_TAG_STOPOFFSET,
 
     SUMO_TAG_WAY,
     SUMO_TAG_ND,
@@ -240,10 +240,12 @@ enum SumoXMLTag {
     SUMO_TAG_VIEWPORT,
     SUMO_TAG_SNAPSHOT,
     SUMO_TAG_BREAKPOINTS_FILE,
+    SUMO_TAG_BREAKPOINT,
     SUMO_TAG_LOCATION,
     SUMO_TAG_COLORSCHEME,
     SUMO_TAG_SCALINGSCHEME,
     SUMO_TAG_ENTRY,
+    SUMO_TAG_RNGSTATE,
     /// @}
 
     SUMO_TAG_VEHICLETRANSFER,
@@ -262,6 +264,8 @@ enum SumoXMLTag {
     SUMO_TAG_CF_PWAGNER2009,
     SUMO_TAG_CF_BKERNER,
     SUMO_TAG_CF_WIEDEMANN,
+    SUMO_TAG_CF_ACC,
+    SUMO_TAG_CF_CACC,
     SUMO_TAG_CF_RAIL,
     /// @}
 
@@ -348,6 +352,7 @@ enum SumoXMLAttr {
     SUMO_ATTR_BIKELANEWIDTH,
     SUMO_ATTR_REMOVE,
     SUMO_ATTR_LENGTH,
+    SUMO_ATTR_BIDI,
     SUMO_ATTR_ID_BEFORE,
     SUMO_ATTR_ID_AFTER,
     SUMO_ATTR_X,
@@ -401,14 +406,18 @@ enum SumoXMLAttr {
     SUMO_ATTR_DECEL,
     SUMO_ATTR_EMERGENCYDECEL,
     SUMO_ATTR_APPARENTDECEL,
+    SUMO_ATTR_HASDRIVERSTATE,
     SUMO_ATTR_ACTIONSTEPLENGTH,
     SUMO_ATTR_VCLASS,
+    SUMO_ATTR_VCLASSES,
+    SUMO_ATTR_EXCEPTIONS,
     SUMO_ATTR_REPNUMBER,
     SUMO_ATTR_SPEEDFACTOR,
     SUMO_ATTR_SPEEDDEV,
     SUMO_ATTR_LANE_CHANGE_MODEL,
     SUMO_ATTR_CAR_FOLLOW_MODEL,
     SUMO_ATTR_MINGAP,
+    SUMO_ATTR_COLLISION_MINGAP_FACTOR,
     SUMO_ATTR_BOARDING_DURATION,
     SUMO_ATTR_LOADING_DURATION,
     /// @}
@@ -502,6 +511,29 @@ enum SumoXMLAttr {
     SUMO_ATTR_TMP5,
     /// @}
 
+    // @name Train ACC model attributes
+    /// @{
+    SUMO_ATTR_SC_GAIN,
+    SUMO_ATTR_GCC_GAIN_SPEED,
+    SUMO_ATTR_GCC_GAIN_SPACE,
+    SUMO_ATTR_GC_GAIN_SPEED,
+    SUMO_ATTR_GC_GAIN_SPACE,
+    SUMO_ATTR_CA_GAIN_SPEED,
+    SUMO_ATTR_CA_GAIN_SPACE,
+    /// @}
+
+    // @name Train CACC model attributes
+    /// @{
+    SUMO_ATTR_SC_GAIN_CACC,
+    SUMO_ATTR_GCC_GAIN_GAP_CACC,
+    SUMO_ATTR_GCC_GAIN_GAP_DOT_CACC,
+    SUMO_ATTR_GC_GAIN_GAP_CACC,
+    SUMO_ATTR_GC_GAIN_GAP_DOT_CACC,
+    SUMO_ATTR_CA_GAIN_GAP_CACC,
+    SUMO_ATTR_CA_GAIN_GAP_DOT_CACC,
+    /// @}
+
+
     /// @name Train model attributes
     /// @{
     SUMO_ATTR_TRAIN_TYPE, //used by: Rail
@@ -514,6 +546,7 @@ enum SumoXMLAttr {
     SUMO_ATTR_LCA_SPEEDGAIN_PARAM,
     SUMO_ATTR_LCA_KEEPRIGHT_PARAM,
     SUMO_ATTR_LCA_SUBLANE_PARAM,
+    SUMO_ATTR_LCA_OPPOSITE_PARAM,
     SUMO_ATTR_LCA_PUSHY,
     SUMO_ATTR_LCA_PUSHYGAP,
     SUMO_ATTR_LCA_ASSERTIVE,
@@ -522,6 +555,9 @@ enum SumoXMLAttr {
     SUMO_ATTR_LCA_ACCEL_LAT,
     SUMO_ATTR_LCA_LOOKAHEADLEFT,
     SUMO_ATTR_LCA_SPEEDGAINRIGHT,
+    SUMO_ATTR_LCA_MAXSPEEDLATSTANDING,
+    SUMO_ATTR_LCA_MAXSPEEDLATFACTOR,
+    SUMO_ATTR_LCA_TURN_ALIGNMENT_DISTANCE,
     SUMO_ATTR_LCA_EXPERIMENTAL1,
     /// @}
 
@@ -541,6 +577,7 @@ enum SumoXMLAttr {
     /// @{
     SUMO_ATTR_LAST,
     SUMO_ATTR_COST,
+    SUMO_ATTR_SAVINGS,
     SUMO_ATTR_PROB,
     SUMO_ATTR_PROBS,
     SUMO_ATTR_ROUTES,
@@ -594,6 +631,8 @@ enum SumoXMLAttr {
     SUMO_ATTR_TLTYPE,
     /// @brief link: the index of the link within the traffic light
     SUMO_ATTR_TLLINKINDEX,
+    /// @brief link: the index of the opposite direction link of a pedestrian crossing
+    SUMO_ATTR_TLLINKINDEX2,
     /// @brief edge: the shape in xml-definition
     SUMO_ATTR_SHAPE,
     /// @brief The information about how to spread the lanes from the given position
@@ -602,6 +641,8 @@ enum SumoXMLAttr {
     SUMO_ATTR_RADIUS,
     /// @brief Whether vehicles must keep the junction clear
     SUMO_ATTR_KEEP_CLEAR,
+    /// @brief How to compute right of way
+    SUMO_ATTR_RIGHT_OF_WAY,
     /// @brief whether a given shape is user-defined
     SUMO_ATTR_CUSTOMSHAPE,
     /// @brief A color information
@@ -616,6 +657,7 @@ enum SumoXMLAttr {
     SUMO_ATTR_LAYER,
     /// @brief Fill the polygon
     SUMO_ATTR_FILL,
+    SUMO_ATTR_LINEWIDTH,
     SUMO_ATTR_PREFIX,
     SUMO_ATTR_DISCARD,
 
@@ -633,6 +675,8 @@ enum SumoXMLAttr {
     SUMO_ATTR_MINDURATION,
     /// @brief maximum duration of a phase
     SUMO_ATTR_MAXDURATION,
+    /// @brief succesor phase index
+    SUMO_ATTR_NEXT,
     /// @}
 
     /// @name Attributes for junction-internal lanes
@@ -649,6 +693,8 @@ enum SumoXMLAttr {
     SUMO_ATTR_HALTING_TIME_THRESHOLD,
     SUMO_ATTR_HALTING_SPEED_THRESHOLD,
     SUMO_ATTR_JAM_DIST_THRESHOLD,
+    SUMO_ATTR_SHOW_DETECTOR,
+    SUMO_ATTR_OPEN_ENTRY,
     /// @}
 
     SUMO_ATTR_WAUT_ID,
@@ -667,9 +713,11 @@ enum SumoXMLAttr {
     SUMO_ATTR_CONTAINER_STOP,
     SUMO_ATTR_PARKING_AREA,
     SUMO_ATTR_ROADSIDE_CAPACITY,
+    SUMO_ATTR_ONROAD,
     SUMO_ATTR_CHARGING_STATION,
     SUMO_ATTR_LINE,
     SUMO_ATTR_LINES,
+    SUMO_ATTR_INTENDED,
     SUMO_ATTR_VALUE,
     SUMO_ATTR_PROHIBITOR,
     SUMO_ATTR_PROHIBITED,
@@ -683,6 +731,7 @@ enum SumoXMLAttr {
     SUMO_ATTR_GUISHAPE,
     SUMO_ATTR_OSGFILE,
     SUMO_ATTR_IMGFILE,
+    SUMO_ATTR_RELATIVEPATH,
     SUMO_ATTR_ANGLE,
     SUMO_ATTR_EMISSIONCLASS,
     SUMO_ATTR_IMPATIENCE,
@@ -742,6 +791,9 @@ enum SumoXMLAttr {
     SUMO_ATTR_RECTANGULAR_LANE_CUT,
     SUMO_ATTR_WALKINGAREAS,
     SUMO_ATTR_LEFTHAND,
+    SUMO_ATTR_LIMIT_TURN_SPEED,
+    SUMO_ATTR_CHECKLANEFOES_ALL,
+    SUMO_ATTR_CHECKLANEFOES_ROUNDABOUT,
     SUMO_ATTR_COMMAND,
 
     SUMO_ATTR_ACTORCONFIG,
@@ -753,6 +805,7 @@ enum SumoXMLAttr {
     SUMO_ATTR_AMOUNT,
     SUMO_ATTR_ORIGIN,
     SUMO_ATTR_DESTINATION,
+    SUMO_ATTR_VISIBLE,
 
 
     /// @name ActivityGen Tags
@@ -826,12 +879,16 @@ enum SumoXMLAttr {
 
     //@name Netedit Attributes (used as virtual property holders, must be in SumoXMLAttr)
     //@{
+    /// @brief element is selected
+    GNE_ATTR_SELECTED,
     /// @brief whether a feature has been loaded,guessed,modified or approved
     GNE_ATTR_MODIFICATION_STATUS,
     /// @brief first coordinate of edge shape
     GNE_ATTR_SHAPE_START,
     /// @brief last coordinate of edge shape
     GNE_ATTR_SHAPE_END,
+    /// @brief whether an edge is part of a bidirectional railway
+    GNE_ATTR_BIDIR,
     /// @brief block movement of a graphic element
     GNE_ATTR_BLOCK_MOVEMENT,
     /// @brief block shape of a graphic element (Used mainly in GNEShapes)
@@ -840,12 +897,39 @@ enum SumoXMLAttr {
     GNE_ATTR_CLOSE_SHAPE,
     /// @brief parent of an additional element
     GNE_ATTR_PARENT,
+    /// @brief generic attribute
+    GNE_ATTR_GENERIC,
+    /// @brief min source (used only by TAZs)
+    GNE_ATTR_MIN_SOURCE,
+    /// @brief min sink (used only by TAZs)
+    GNE_ATTR_MIN_SINK,
+    /// @brief max source (used only by TAZs)
+    GNE_ATTR_MAX_SOURCE,
+    /// @brief max sink (used only by TAZs)
+    GNE_ATTR_MAX_SINK,
+    /// @brief average source (used only by TAZs)
+    GNE_ATTR_AVERAGE_SOURCE,
+    /// @brief average sink (used only by TAZs)
+    GNE_ATTR_AVERAGE_SINK,
+    /// @brief Color of TAZSources/TAZChilds
+    GNE_ATTR_TAZCOLOR,
     // @}
 
     SUMO_ATTR_TARGETLANE,
     SUMO_ATTR_CROSSING,
     SUMO_ATTR_XMLNS,
-    SUMO_ATTR_SCHEMA_LOCATION
+    SUMO_ATTR_SCHEMA_LOCATION,
+
+    //@name RNG state saving attributes
+    // @{
+    SUMO_ATTR_RNG_DEFAULT,
+    SUMO_ATTR_RNG_ROUTEHANDLER,
+    SUMO_ATTR_RNG_INSERTIONCONTROL,
+    SUMO_ATTR_RNG_DEVICE,
+    SUMO_ATTR_RNG_DEVICE_BT,
+    SUMO_ATTR_RNG_DRIVERSTATE
+    // @}
+
 };
 
 /*
@@ -914,6 +998,13 @@ enum LaneSpreadFunction {
 };
 
 
+/// @brief algorithms for computing right of way
+enum RightOfWay {
+    RIGHT_OF_WAY_DEFAULT,
+    RIGHT_OF_WAY_EDGEPRIORITY
+};
+
+
 /**
  * @enum LinkState
  * @brief The right-of-way state of a link between two lanes
@@ -959,7 +1050,6 @@ enum LinkState {
     LINKSTATE_DEADEND = '-'
 };
 
-
 /**
  * @enum LinkDirection
  * @brief The different directions a link between two lanes may take (or a
@@ -989,7 +1079,8 @@ enum LinkDirection {
 /// @enum TrafficLightType
 enum TrafficLightType {
     TLTYPE_STATIC,
-    TLTYPE_RAIL,
+    TLTYPE_RAIL_SIGNAL,
+    TLTYPE_RAIL_CROSSING,
     TLTYPE_ACTUATED,
     TLTYPE_DELAYBASED,
     TLTYPE_SOTL_PHASE,
@@ -999,6 +1090,7 @@ enum TrafficLightType {
     TLTYPE_SOTL_MARCHING,
     TLTYPE_SWARM_BASED,
     TLTYPE_HILVL_DETERMINISTIC,
+    TLTYPE_OFF,
     TLTYPE_INVALID //< must be the last one
 };
 
@@ -1049,6 +1141,8 @@ enum LaneChangeAction {
     LCA_INSUFFICIENT_SPACE = 1 << 14,
     /// @brief used by the sublane model
     LCA_SUBLANE = 1 << 15,
+    /// @brief Vehicle is too slow to guarantee success of lane change (used for continuous lane changing in case that maxSpeedLatStanding==0)
+    LCA_INSUFFICIENT_SPEED = 1 << 28,
     /// @brief lane can change
     LCA_WANTS_LANECHANGE = LCA_LEFT | LCA_RIGHT,
     /// @brief lane can change or stay
@@ -1062,12 +1156,29 @@ enum LaneChangeAction {
     /// @brief blocker by follower
     LCA_BLOCKED_BY_FOLLOWER = LCA_BLOCKED_BY_LEFT_FOLLOWER | LCA_BLOCKED_BY_RIGHT_FOLLOWER,
     /// @brief blocked in all directions
-    LCA_BLOCKED = LCA_BLOCKED_LEFT | LCA_BLOCKED_RIGHT | LCA_INSUFFICIENT_SPACE,
+    LCA_BLOCKED = LCA_BLOCKED_LEFT | LCA_BLOCKED_RIGHT | LCA_INSUFFICIENT_SPACE | LCA_INSUFFICIENT_SPEED,
     /// @brief reasons of lane change
-    LCA_CHANGE_REASONS = (LCA_STRATEGIC | LCA_COOPERATIVE | LCA_SPEEDGAIN | LCA_KEEPRIGHT | LCA_SUBLANE | LCA_TRACI)
-                         // LCA_BLOCKED_BY_CURRENT_LEADER = 1 << 28
-                         // LCA_BLOCKED_BY_CURRENT_FOLLOWER = 1 << 29
-                         /// @}
+    LCA_CHANGE_REASONS = (LCA_STRATEGIC | LCA_COOPERATIVE | LCA_SPEEDGAIN | LCA_KEEPRIGHT | LCA_SUBLANE | LCA_TRACI),
+    // LCA_BLOCKED_BY_CURRENT_LEADER = 1 << 28
+    // LCA_BLOCKED_BY_CURRENT_FOLLOWER = 1 << 29
+    /// @}
+
+    /// @name originally model specific states (migrated here since
+    ///       they were duplicated in all current models)
+    /// @{
+    LCA_AMBLOCKINGLEADER = 1 << 16,
+    LCA_AMBLOCKINGFOLLOWER = 1 << 17,
+    LCA_MRIGHT = 1 << 18,
+    LCA_MLEFT = 1 << 19,
+    // !!! never set LCA_UNBLOCK = 1 << 20,
+    LCA_AMBLOCKINGFOLLOWER_DONTBRAKE = 1 << 21,
+    // !!! never used LCA_AMBLOCKINGSECONDFOLLOWER = 1 << 22,
+    LCA_CHANGE_TO_HELP = 1 << 23,
+    // !!! never read LCA_KEEP1 = 1 << 24,
+    // !!! never used LCA_KEEP2 = 1 << 25,
+    LCA_AMBACKBLOCKER = 1 << 26,
+    LCA_AMBACKBLOCKER_STANDING = 1 << 27
+                                 /// @}
 };
 
 
@@ -1132,6 +1243,9 @@ public:
     /// @brief lane spread functions
     static StringBijection<LaneSpreadFunction> LaneSpreadFunctions;
 
+    /// @brief lane spread functions
+    static StringBijection<RightOfWay> RightOfWayValues;
+
     /// @brief link states
     static StringBijection<LinkState> LinkStates;
 
@@ -1156,12 +1270,48 @@ public:
 
     /// @name Helper functions for ID-string manipulations
     /// @{
+
+    /// @brief whether the given string is a valid id for a network element
+    static bool isValidNetID(const std::string& value);
+
+    /// @brief whether the given string is a valid id for a vehicle or flow
+    static bool isValidVehicleID(const std::string& value);
+
+    /// @brief whether the given string is a valid id for an edge or vehicle type
+    static bool isValidTypeID(const std::string& value);
+
+    /// @brief whether the given string is a valid id for an detector
+    static bool isValidDetectorID(const std::string& value);
+
+    /// @brief whether the given string is a valid attribute for a certain key (for example, a name)
+    static bool isValidAttribute(const std::string& value);
+
+    /// @brief whether the given string is a valid attribute for a filename (for example, a name)
+    static bool isValidFilename(const std::string& value);
+
+    /// @brief whether the given string is a valid list of id for a network (empty aren't allowed)
+    static bool isValidListOfNetIDs(const std::string& value);
+
+    /// @brief whether the given string is a valid list of ids for an edge or vehicle type (empty aren't allowed)
+    static bool isValidListOfTypeID(const std::string& value);
+
+    /// @brief whether the given string is a valid key for a generic parameter
+    static bool isValidGenericParameterKey(const std::string& value);
+
+    /// @brief whether the given string is a valid value for a generic parameter
+    static bool isValidGenericParameterValue(const std::string& value);
+
     /// @brief return the junction id when given an edge of type internal, crossing or WalkingArea
     static std::string getJunctionIDFromInternalEdge(const std::string internalEdge);
 
     /// @brief return edge id when given the lane ID
     static std::string getEdgeIDFromLane(const std::string laneID);
     /// @}
+    
+    /// @brief all allowed characters for phase state 
+    static const std::string ALLOWED_TLS_LINKSTATES;
+
+
 
 private:
     /// @brief containers for the different SUMOXMLDefinitions
@@ -1176,6 +1326,9 @@ private:
     /// @brief lane spread function values
     static StringBijection<LaneSpreadFunction>::Entry laneSpreadFunctionValues[];
 
+    /// @brief lane spread function values
+    static StringBijection<RightOfWay>::Entry rightOfWayValuesInitializer[];
+
     /// @brief link state values
     static StringBijection<LinkState>::Entry linkStateValues[];
 
@@ -1197,6 +1350,9 @@ private:
     /// @brief lane change action values
     static StringBijection<LaneChangeAction>::Entry laneChangeActionValues[];
     /// @}
+    
+    /// @brief all allowed characters for phase state 
+    static const char AllowedTLS_linkStatesInitializer[];
 };
 
 #endif
