@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2002-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2002-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    XMLSubSys.cpp
 /// @author  Daniel Krajzewicz
@@ -23,15 +21,12 @@
 // ===========================================================================
 // included modules
 // ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
+#include <cstdint>
 #include <xercesc/util/PlatformUtils.hpp>
 #include <utils/common/MsgHandler.h>
-#include <utils/common/TplConvert.h>
+#include <utils/common/StringUtils.h>
 #include "SUMOSAXHandler.h"
 #include "SUMOSAXReader.h"
 #include "XMLSubSys.h"
@@ -55,7 +50,7 @@ XMLSubSys::init() {
         XERCES_CPP_NAMESPACE::XMLPlatformUtils::Initialize();
         myNextFreeReader = 0;
     } catch (const XERCES_CPP_NAMESPACE::XMLException& e) {
-        throw ProcessError("Error during XML-initialization:\n " + TplConvert::_2str(e.getMessage()));
+        throw ProcessError("Error during XML-initialization:\n " + StringUtils::transcode(e.getMessage()));
     }
 }
 
@@ -83,6 +78,15 @@ XMLSubSys::setValidation(const std::string& validationScheme, const std::string&
 }
 
 
+bool
+XMLSubSys::isValidating(const bool net) {
+    if (net) {
+        return myNetValidationScheme != XERCES_CPP_NAMESPACE::SAX2XMLReader::Val_Never;
+    }
+    return myValidationScheme != XERCES_CPP_NAMESPACE::SAX2XMLReader::Val_Never;
+}
+
+
 void
 XMLSubSys::close() {
     for (std::vector<SUMOSAXReader*>::iterator i = myReaders.begin(); i != myReaders.end(); ++i) {
@@ -132,7 +136,7 @@ XMLSubSys::runParser(GenericSAXHandler& handler,
         WRITE_ERROR("Error occurred: " + std::string(ex.what()) + " while parsing '" + file + "'");
         return false;
     } catch (...) {
-        WRITE_ERROR("Unspecified error occured wile parsing '" + file + "'");
+        WRITE_ERROR("Unspecified error occurred wile parsing '" + file + "'");
         return false;
     }
     return !MsgHandler::getErrorInstance()->wasInformed();
