@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    Assignment.py
 # @author  Jakob Erdmann
@@ -39,7 +40,7 @@ from outputs import timeForInput, outputODZone, outputNetwork, outputStatistics,
 from assign import doSUEAssign, doLohseStopCheck, doSUEVehAssign, doIncAssign
 from tables import updateCurveTable
 sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
-import sumolib.net
+import sumolib.net  # noqa
 
 
 def initLinkChoiceMap(net, startVertices, endVertices, matrixPshort, linkChoiceMap, odPairsMap):
@@ -161,8 +162,8 @@ def main():
         # the disk space
         vehicles = []
         iterInterval = 0
-        matrixPshort, startVertices, endVertices, CurrentMatrixSum, begintime, assignPeriod, Pshort_EffCells, matrixSum, smallDemandRatio = getMatrix(
-            net, options.verbose, matrix, matrixSum, options.demandscale)
+        matrixPshort, startVertices, endVertices, CurrentMatrixSum, begintime, assignPeriod, Pshort_EffCells, \
+            matrixSum, smallDemandRatio = getMatrix(net, options.verbose, matrix, matrixSum, options.demandscale)
         options.hours = float(assignPeriod)
         smallDemandPortion = math.ceil(
             float(options.maxiteration) / 2. * smallDemandRatio)
@@ -205,9 +206,8 @@ def main():
 
         # the number of origins, the umber of destinations and the number of
         # the OD pairs
-        origins = len(startVertices)
-        dests = len(endVertices)
-        ODpairs = origins * dests
+        len(startVertices)
+        len(endVertices)
 
         # output the origin and destination zones and the number of effective
         # OD pairs
@@ -273,7 +273,8 @@ def main():
                 if checkKPaths:
                     checkPathStart = datetime.datetime.now()
                     newRoutes = net.calcKPaths(
-                        options.verbose, options.kPaths, newRoutes, startVertices, endVertices, matrixPshort, options.gamma)
+                        options.verbose, options.kPaths, newRoutes, startVertices, endVertices, matrixPshort,
+                        options.gamma)
                     checkPathEnd = datetime.datetime.now() - checkPathStart
                     foutlog.write(
                         '- Time for finding the k-shortest paths: %s\n' % checkPathEnd)
@@ -327,7 +328,8 @@ def main():
                     foutlog.write(
                         'The max. number of iterations is reached!\n')
                     foutlog.write(
-                        'The number of new routes and the parameter stable will be set to zero and True respectively.\n')
+                        'The number of new routes and the parameter stable will be set to zero and ' +
+                        'True respectively.\n')
                     print('newRoutes:', newRoutes)
                     stable = True
                     newRoutes = 0
@@ -362,6 +364,7 @@ def main():
         print('Total assigned vehicles:', vehID)
     print('Total number of the assigned trips:', matrixSum)
 
+
 optParser = OptionParser()
 optParser.add_option("-m", "--matrix-file", dest="mtxpsfile",
                      help="read OD matrix for passenger vehicles from FILE (mandatory)", metavar="FILE")
@@ -416,7 +419,8 @@ optParser.add_option("-r", "--profile", action="store_true", dest="profile",
                      default=False, help="writing profiling info")
 optParser.add_option("-+", "--dijkstra", dest="dijkstra", type="choice",
                      choices=('extend', 'plain', 'boost'),
-                     default="plain", help="use penalty, plain(original) or boost in dijkstra implementation [default: %default]")
+                     default="plain", help="use penalty, plain(original) or boost in dijkstra implementation " +
+                                           "[default: %default]")
 optParser.add_option("-x", "--odestimation", action="store_true", dest="odestimation",
                      default=False, help="generate trips for OD estimation")
 optParser.add_option("-f", "--scale-factor", dest="demandscale",
