@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2010-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2010-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    cadytsIterate.py
 # @author  Jakob Erdmann
@@ -23,34 +24,37 @@ from __future__ import absolute_import
 from __future__ import print_function
 import os
 import sys
+import glob
 from datetime import datetime
 from argparse import ArgumentParser
 from duaIterate import call, writeSUMOConf, addGenericOptions
 
-sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
+TOOLS_DIR = os.path.dirname(os.path.dirname(os.path.realpath(__file__)))
+sys.path.append(TOOLS_DIR)
 import sumolib  # noqa
 
 
 def initOptions():
+    jars = glob.glob(os.path.join(TOOLS_DIR, "contributed", "calibration", "*", "target", "*.jar")) + \
+        glob.glob(os.path.join(TOOLS_DIR, "..", "bin", "*.jar"))
     argParser = ArgumentParser()
     addGenericOptions(argParser)
-
     argParser.add_argument("-r", "--route-alternatives", dest="routes",
                            help="route alternatives from sumo (comma separated list, mandatory)", metavar="FILE")
     argParser.add_argument("-d", "--detector-values", dest="detvals",
                            help="adapt to the flow on the given edges", metavar="FILE")
-    argParser.add_argument("-c", "--classpath", dest="classpath",
-                           default=os.path.join(os.path.dirname(
-                               sys.argv[0]), "..", "contributed", "calibration", "cadytsSumoController.jar"),
+    argParser.add_argument("-c", "--classpath", dest="classpath", default=os.pathsep.join(jars),
                            help="classpath for the calibrator [default: %default]")
     argParser.add_argument("-l", "--last-calibration-step", dest="calibStep",
                            type=int, default=100, help="last step of the calibration [default: %default]")
     argParser.add_argument("-S", "--demandscale", dest="demandscale",
                            type=float, default=2., help="scaled demand [default: %default]")
     argParser.add_argument("-F", "--freezeit",  dest="freezeit",
-                           type=int, default=85, help="define the number of iterations for stablizing the results in the DTA-calibration")
+                           type=int, default=85, help="define the number of iterations for stablizing the results " +
+                                                      "in the DTA-calibration")
     argParser.add_argument("-V", "--varscale",  dest="varscale",
-                           type=float, default=1., help="define variance of the measured traffic flows for the DTA-calibration")
+                           type=float, default=1., help="define variance of the measured traffic flows for the" +
+                                                        "DTA-calibration")
     argParser.add_argument("-P", "--PREPITS",  type=int, dest="PREPITS",
                            default=5, help="number of preparatory iterations")
     argParser.add_argument("-W", "--evaluation-prefix", dest="evalprefix",
@@ -70,9 +74,11 @@ def initOptions():
     argParser.add_argument("-N", "--clone-postfix", dest="clonepostfix",
                            default='-CLONE', help="postfix attached to clone ids")
     argParser.add_argument("-X", "--cntfirstlink", action="store_true", dest="cntfirstlink",
-                           default=False, help="if entering vehicles are assumed to cross the upstream sensor of their entry link")
+                           default=False, help="if entering vehicles are assumed to cross the upstream sensor of" +
+                                               "their entry link")
     argParser.add_argument("-K", "--cntlastlink", action="store_true", dest="cntlastlink",
-                           default=False, help="if exiting vehicles are assumed to cross the upstream sensor of their exit link")
+                           default=False, help="if exiting vehicles are assumed to cross the upstream sensor of" +
+                           "their exit link")
     argParser.add_argument("remaining_args", nargs='*')
     return argParser
 
@@ -90,7 +96,7 @@ def main():
     else:
         sumoBinary = sumolib.checkBinary("sumo", options.path)
     calibrator = ["java", "-cp", options.classpath, "-Xmx1G",
-                  "cadyts.interfaces.sumo.SumoController"]
+                  "floetteroed.cadyts.interfaces.sumo.SumoController"]
     log = open("cadySumo-log.txt", "w+")
 
     # calibration init
@@ -104,14 +110,16 @@ def main():
         call(calibrator + ["INIT", "-varscale", options.varscale, "-freezeit", options.freezeit,
                            "-measfile", options.detvals, "-binsize", options.aggregation, "-PREPITS", options.PREPITS,
                            "-bruteforce", options.bruteforce, "-demandscale", options.demandscale,
-                           "-mincountstddev", options.mincountstddev, "-overridett", options.overridett, "-clonepostfix", options.clonepostfix,
-                           "-fmaprefix", options.fmaprefix, "-cntfirstlink", options.cntfirstlink, "-cntlastlink", options.cntlastlink], log)
+                           "-mincountstddev", options.mincountstddev, "-overridett", options.overridett,
+                           "-clonepostfix", options.clonepostfix, "-fmaprefix", options.fmaprefix,
+                           "-cntfirstlink", options.cntfirstlink, "-cntlastlink", options.cntlastlink], log)
     else:
         call(calibrator + ["INIT", "-varscale", options.varscale, "-freezeit", options.freezeit,
                            "-measfile", options.detvals, "-binsize", options.aggregation, "-PREPITS", options.PREPITS,
                            "-bruteforce", options.bruteforce, "-demandscale", options.demandscale,
                            "-mincountstddev", options.mincountstddev, "-overridett", options.overridett,
-                           "-clonepostfix", options.clonepostfix, "-cntfirstlink", options.cntfirstlink, "-cntlastlink", options.cntlastlink], log)
+                           "-clonepostfix", options.clonepostfix, "-cntfirstlink", options.cntfirstlink,
+                           "-cntlastlink", options.cntlastlink], log)
 
     for step in range(options.calibStep):
         print('calibration step:', step)
@@ -134,8 +142,7 @@ def main():
         btime = datetime.now()
         print(">>> Begin time: %s" % btime)
         writeSUMOConf(sumoBinary, step, options, [], ",".join(files))
-        retCode = call(
-            [sumoBinary, "-c", "iteration_%03i.sumocfg" % step], log)
+        call([sumoBinary, "-c", "iteration_%03i.sumocfg" % step], log)
         etime = datetime.now()
         print(">>> End time: %s" % etime)
         print(">>> Duration: %s" % (etime - btime))
@@ -156,5 +163,6 @@ def main():
     print("calibration ended (duration: %s)" % (datetime.now() - starttime))
     log.close()
 
+
 if __name__ == "__main__":
     main()
