@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2009-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2009-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    costFunctionChecker.py
 # @author  Michael Behrisch
@@ -128,6 +129,7 @@ def generateWeights(step, options, edges, weights, costFunction):
     print('</netstats>', file=fd)
     fd.close()
 
+
 optParser = OptionParser()
 optParser.add_option("-v", "--verbose", action="store_true", dest="verbose",
                      default=False, help="tell me what you are doing")
@@ -225,7 +227,8 @@ for step in range(options.firstStep, options.lastStep):
     parser.setContentHandler(reader)
     for f in files:
         parser.parse(f)
-    generateWeights(step, options, edges, reader, costFunction)
+    # see evaluation of options.costfunc above
+    generateWeights(step, options, edges, reader, costFunction)  # noqa
     print("<<")
     print("< Step %s ended (duration: %s)" % (step, datetime.now() - btimeA))
     print("------------------\n")
