@@ -1,31 +1,27 @@
 # -*- coding: utf-8 -*-
-"""
-@file    costMemory.py
-@author  Jakob Erdmann
-@author  Michael Behrisch
-@date    2012-03-14
-@version $Id: costMemory.py 22608 2017-01-17 06:28:54Z behrisch $
+# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+# Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
+# This program and the accompanying materials
+# are made available under the terms of the Eclipse Public License v2.0
+# which accompanies this distribution, and is available at
+# http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
-Perform smoothing of edge costs across successive iterations of duaIterate
+# @file    costMemory.py
+# @author  Jakob Erdmann
+# @author  Michael Behrisch
+# @date    2012-03-14
+# @version $Id$
 
-SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2012-2017 DLR (http://www.dlr.de/) and contributors
-
-This file is part of SUMO.
-SUMO is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 3 of the License, or
-(at your option) any later version.
-"""
 from __future__ import print_function
 from __future__ import absolute_import
 import os
 import sys
 from collections import defaultdict
-from xml.sax import saxutils, make_parser, handler
+from xml.sax import make_parser, handler
 
 sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
-from sumolib.net import readNet
+from sumolib.net import readNet  # noqa
 
 
 class EdgeMemory:
@@ -108,7 +104,7 @@ class CostMemory(handler.ContentHandler):
                 "Skipped loading of costs because the weight was %s but should have been > 0\n" % weight)
             return
         assert(weight > 0)
-        if self.iteration == None and iteration != 0:
+        if self.iteration is None and iteration != 0:
             print("Warning: continuing with empty memory")
         # update memory weights. memory is a weighted average across all runs
         self.new_weight = float(weight)
@@ -156,9 +152,9 @@ class CostMemory(handler.ContentHandler):
     def avg_error(self, values=None):
         if not values:
             values = self.errors
-        l = len(list(values))
-        if l > 0:
-            return (sum(list(values)) / l)
+        length = len(list(values))
+        if length > 0:
+            return (sum(list(values)) / length)
         else:
             return 0
 
