@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2007-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2007-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    dijkstra.py
 # @author  Yun-Pang Floetteroed
@@ -26,7 +27,7 @@ import sys
 from collections import defaultdict
 from xml.sax import make_parser, handler
 sys.path.append(os.path.join(os.path.dirname(__file__), '..'))
-from sumolib.net import readNet
+from sumolib.net import readNet  # noqa
 
 
 class priorityDictionary(dict):
