@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    duaIterate.py
 # @author  Daniel Krajzewicz
@@ -32,7 +33,7 @@ from costMemory import CostMemory
 
 sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
 import sumolib  # noqa
-from sumolib.options import get_long_option_names
+from sumolib.options import get_long_option_names  # noqa
 
 
 def addGenericOptions(argParser):
@@ -63,7 +64,8 @@ def addGenericOptions(argParser):
     argParser.add_argument("-q", "--meso-multiqueue", dest="mesomultiqueue", action="store_true",
                            default=False, help="Enable multiple queues at edge ends")
     argParser.add_argument("--meso-recheck", dest="mesorecheck", type=int, default=0,
-                           help="Delay before checking whether a jam is gone. (higher values can lead to a big speed increase)")
+                           help="Delay before checking whether a jam is gone. (higher values can lead to a big speed " +
+                                "increase)")
     argParser.add_argument("-Q", "--eco-measure", dest="ecomeasure",
                            choices=[
                                'CO', 'CO2', 'PMx', 'HC', 'NOx', 'fuel', 'noise'],
@@ -84,8 +86,9 @@ def addGenericOptions(argParser):
 def initOptions():
     argParser = argparse.ArgumentParser(
         description=""" Any options of the form sumo--long-option-name will be passed to sumo.
-These must be given after all the other options
-example: sumo--step-length 0.5 will add the option --step-length 0.5 to sumo.""", formatter_class=argparse.ArgumentDefaultsHelpFormatter)
+        These must be given after all the other options
+        example: sumo--step-length 0.5 will add the option --step-length 0.5 to sumo.""",
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter)
     addGenericOptions(argParser)
 
     argParser.add_argument("-C", "--continue-on-unbuild", action="store_true", dest="continueOnUnbuild",
@@ -111,7 +114,8 @@ example: sumo--step-length 0.5 will add the option --step-length 0.5 to sumo."""
     argParser.add_argument("--inc-max", dest="incMax",
                            type=float, default=1, help="Maximum for incrementing scale")
     argParser.add_argument("--inc-base", dest="incBase",
-                           type=int, default=-1, help="Give the incrementation base. Negative values disable incremental scaling")
+                           type=int, default=-1, help="Give the incrementation base. Negative values disable " +
+                                                      "incremental scaling")
     argParser.add_argument("--incrementation", dest="incValue",
                            type=int, default=1, help="Give the incrementation")
     argParser.add_argument("--time-inc", dest="timeInc",
@@ -154,11 +158,13 @@ example: sumo--step-length 0.5 will add the option --step-length 0.5 to sumo."""
     argParser.add_argument("-M", "--external-gawron", action="store_true", dest="externalgawron",
                            default=False, help="use the external gawron calculation")
     argParser.add_argument("-N", "--calculate-oldprob", action="store_true", dest="caloldprob",
-                           default=False, help="calculate the old route probabilities with the free-flow travel times when using the external gawron calculation")
+                           default=False, help="calculate the old route probabilities with the free-flow " +
+                                               "travel times when using the external gawron calculation")
     argParser.add_argument("--weight-memory", action="store_true", default=False, dest="weightmemory",
                            help="smooth edge weights across iterations")
     argParser.add_argument(
-        "--pessimism", default=1, type=float, help="give traffic jams a higher weight when using option --weight-memory")
+        "--pessimism", default=1, type=float, help="give traffic jams a higher weight when using option " +
+                                                   " --weight-memory")
     argParser.add_argument("--clean-alt", action="store_true", dest="clean_alt",
                            default=False, help="Whether old rou.alt.xml files shall be removed")
     argParser.add_argument("--binary", action="store_true",
@@ -174,7 +180,7 @@ def call(command, log):
     log.flush()
     retCode = subprocess.call(command, stdout=log, stderr=log)
     if retCode != 0:
-        print("Execution of %s failed. Look into %s for details." %
+        print(("Execution of %s failed. Look into %s for details.") %
               (command, log.name), file=sys.stderr)
         sys.exit(retCode)
 
@@ -352,7 +358,8 @@ def writeSUMOConf(sumoBinary, step, options, additional_args, route_files):
             print('    <edgeData id="dump%s" freq="%s" file="%s" excludeEmpty="true" minSamples="1"/>' % (
                 suffix, options.aggregation, get_dumpfilename(options, step, "dump")), file=fd)
         if options.ecomeasure:
-            print('    <edgeData id="eco%s" type="hbefa" freq="%s" file="dump%s.xml" excludeEmpty="true" minSamples="1"/>' %
+            print(('    <edgeData id="eco%s" type="hbefa" freq="%s" file="dump%s.xml" ' +
+                   'excludeEmpty="true" minSamples="1"/>') %
                   (suffix, options.aggregation, suffix), file=fd)
         print("</a>", file=fd)
 
@@ -423,7 +430,6 @@ def assign_remaining_args(application, prefix, args):
             else:
                 sys.exit('"%s" is not a valid option for "%s"' %
                          (option, application))
-                unassigned += item
 
     return assigned
 
@@ -459,12 +465,14 @@ def main(args=None):
         subprocess.call(duaBinary, stdout=subprocess.PIPE)
     except OSError:
         sys.exit(
-            "Error: Could not locate duarouter (%s).\nMake sure its on the search path or set environment variable DUAROUTER_BINARY\n" % duaBinary)
+            ("Error: Could not locate duarouter (%s).\nMake sure its on the search path or set environment " +
+             "variable DUAROUTER_BINARY\n") % duaBinary)
     try:
         subprocess.call(sumoBinary, stdout=subprocess.PIPE)
     except OSError:
         sys.exit(
-            "Error: Could not locate sumo (%s).\nMake sure its on the search path or set environment variable SUMO_BINARY\n" % sumoBinary)
+            ("Error: Could not locate sumo (%s).\nMake sure its on the search path or set environment " +
+             "variable SUMO_BINARY\n") % sumoBinary)
 
     sumo_args = assign_remaining_args(
         sumoBinary, 'sumo', options.remaining_args)
@@ -479,7 +487,7 @@ def main(args=None):
                 "Error: Please use either --zip or --clean-alt but not both.")
         try:
             subprocess.call("7z", stdout=open(os.devnull, 'wb'))
-        except:
+        except Exception:
             sys.exit(
                 "Error: Could not locate 7z, please make sure its on the search path.")
         zipProcesses = {}
@@ -554,13 +562,18 @@ def main(args=None):
                 print("<<")
                 # use the external gawron
                 if options.externalgawron:
+                    basename = get_basename(router_input)
+                    if ((step > 0 and not options.skipFirstRouting) or step > 1):
+                        basename = basename[:-4]
+                    print('basename', basename)
                     ecomeasure = None
                     if options.ecomeasure:
                         ecomeasure = options.ecomeasure
                     if step == options.firstStep + 1 and options.skipFirstRouting:
                         if options.caloldprob:
                             calFirstRouteProbs("dump_000_%s.xml" % (
-                                options.aggregation), basename + "_001.rou.alt.xml", options.addweights, ecomeasure)
+                                options.aggregation), basename + "_001.rou.alt.xml", options.addweights,
+                                ecomeasure)
                         else:
                             shutil.copy(
                                 basename + "_001.rou.alt.xml", basename + "_001.rou.galt.xml")
@@ -578,7 +591,8 @@ def main(args=None):
                             step - 1, options.aggregation)
                         if (not options.skipFirstRouting) or (options.skipFirstRouting and step > 1):
                             output, edgesMap = getRouteChoices(
-                                edgesMap, dumpfile, basename + "_%03i.rou.alt.xml" % step, options.net, options.addweights, options.gA, options.gBeta, step, ecomeasure)
+                                edgesMap, dumpfile, basename + "_%03i.rou.alt.xml" % step, options.net,
+                                options.addweights, options.gA, options.gBeta, step, ecomeasure)
 
         # simulation
         print(">> Running simulation")
@@ -622,12 +636,13 @@ def main(args=None):
                     for f in glob.glob("*_%03i*" % s):
                         try:
                             os.remove(f)
-                        except:
+                        except Exception:
                             print("Could not remove %s" % f, file=zipLog)
                     del zipProcesses[s]
             zipStep = step - 2
             zipProcesses[zipStep] = subprocess.Popen(
-                ["7z", "a", "iteration%03i.7z" % zipStep] + glob.glob("*_%03i*" % zipStep), stdout=zipLog, stderr=zipLog)
+                ["7z", "a", "iteration%03i.7z" % zipStep] + glob.glob("*_%03i*" % zipStep), stdout=zipLog,
+                stderr=zipLog)
 
         converged = False
         if options.convDev:
@@ -657,12 +672,13 @@ def main(args=None):
             for f in glob.glob("*_%03i*" % s):
                 try:
                     os.remove(f)
-                except:
+                except Exception:
                     print("Could not remove %s" % f, file=zipLog)
         zipLog.close()
     print("dua-iterate ended (duration: %s)" % (datetime.now() - starttime))
 
     log.close()
 
+
 if __name__ == "__main__":
     main()
