@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2007-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2007-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    elements.py
 # @author  Yun-Pang Floetteroed
@@ -27,7 +28,7 @@ import math
 import os
 from tables import crCurveTable, laneTypeTable
 sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
-import sumolib.net
+import sumolib.net  # noqa
 
 # This class is used for finding the k shortest paths.
 
@@ -171,7 +172,8 @@ class Edge(sumolib.net.Edge):
         cap = str(self.capacity)
         if self.capacity == sys.maxsize or self.connection != 0:
             cap = "inf"
-        return "%s_%s_%s_%s<%s|%s|%s|%s|%s|%s|%s|%s|%s>" % (self._function, self._id, self._from, self._to, self.junctiontype, self._speed,
+        return "%s_%s_%s_%s<%s|%s|%s|%s|%s|%s|%s|%s|%s>" % (self._function, self._id, self._from, self._to,
+                                                            self.junctiontype, self._speed,
                                                             self.flow, self._length, self._lanes,
                                                             self.CRcurve, self.estcapacity, cap, self.ratio)
 
@@ -269,7 +271,8 @@ class Edge(sumolib.net.Edge):
                     (1 + (curve[0] * (self.flow /
                                       (self.estcapacity * curve[2]))**curve[1]))
 
-            if (self.flow > self.estcapacity or self.flow == self.estcapacity) and self.flow > 0. and self.connection == 0:
+            if ((self.flow > self.estcapacity or self.flow == self.estcapacity) and
+                    self.flow > 0. and self.connection == 0):
                 self.queuetime = self.queuetime + options.lamda * \
                     (self.actualtime - self.freeflowtime * (1 + curve[0]))
                 if self.queuetime < 1.:
@@ -387,7 +390,9 @@ class Vehicle:
         self.rank = 0.
 
     def __repr__(self):
-        return "%s_%s_%s_%s_%s_%s<%s>" % (self.label, self.depart, self.arrival, self.speed, self.traveltime, self.travellength, self.route)
+        return "%s_%s_%s_%s_%s_%s<%s>" % (self.label, self.depart, self.arrival, self.speed,
+                                          self.traveltime, self.travellength, self.route)
+
 
 pathNum = 0
 
@@ -421,7 +426,8 @@ class Path:
         self.currentshortest = True
 
     def __repr__(self):
-        return "%s_%s_%s<%s|%s|%s|%s>" % (self.label, self.source, self.target, self.freepathtime, self.pathflow, self.actpathtime, self.edges)
+        return "%s_%s_%s<%s|%s|%s|%s>" % (self.label, self.source, self.target, self.freepathtime,
+                                          self.pathflow, self.actpathtime, self.edges)
 
     def getPathLength(self):
         for edge in self.edges:
