@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2007-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2007-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    inputs.py
 # @author  Yun-Pang Floetteroed
@@ -91,7 +92,8 @@ def getMatrix(net, verbose, matrix, matrixSum, demandscale=None):
         print('number of end Vertices):', net.getendCounts())
         print('smallDemandRatio):', smallDemandRatio)
 
-    return matrixPshort, startVertices, endVertices, currentMatrixSum, begintime, assignPeriod, Pshort_EffCells, matrixSum, smallDemandRatio
+    return matrixPshort, startVertices, endVertices, currentMatrixSum, begintime, assignPeriod, \
+        Pshort_EffCells, matrixSum, smallDemandRatio
 
 # estimate the travel times on the district connectors
 # assumption: all vehilces can reach the access links within 20 min (1200
