@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2007-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2007-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    networkStatistics.py
 # @author  Yun-Pang Floetteroed
@@ -14,7 +15,8 @@
 
 """
 This script is to calculate the global performance indices according to the SUMO-based simulation results.
-Besides, this script is also to execute the significance test for evaluating the results from different assignment methods.
+Besides, this script is also to execute the significance test for evaluating the results from different assignment
+methods.
 The t test and the Kruskal-Wallis test are available in this script.
 If not specified, the Kruskal-Wallis test will be applied with the assumption that data are not normally distributed.
 
@@ -32,7 +34,8 @@ import operator
 
 from xml.sax import make_parser
 from optparse import OptionParser
-from statisticsElements import Assign, T_Value, H_Value, VehInformationReader, getStatisticsOutput, getSignificanceTestOutput
+from statisticsElements import Assign, T_Value, H_Value, VehInformationReader
+from statisticsElements import getStatisticsOutput, getSignificanceTestOutput
 from tables import chiSquareTable, tTable
 
 
@@ -42,7 +45,6 @@ def getBasicStats(verbose, method, vehicles, assignments):
     totalTravelLength = 0.
     totalTravelSpeed = 0.
     totalWaitTime = 0.
-    totalDiffTime = 0.
     totalDiffSpeed = 0.
     totalDiffLength = 0.
     totalDiffWaitTime = 0.
@@ -280,9 +282,11 @@ def doKruskalWallisTest(verbose, groups, combivehlist, assignments, label, hValu
             if c > 0.:
                 adjH.waittime = H.waittime / c
 
+
 optParser = OptionParser()
 optParser.add_option("-t", "--tripinform-file", dest="vehfile",
-                     help="read vehicle information generated by the DUA assignment from FILE (mandatory)", metavar="FILE")
+                     help="read vehicle information generated by the DUA assignment from FILE (mandatory)",
+                     metavar="FILE")
 optParser.add_option("-o", "--output-file", dest="outputfile", default="Global_MOE.txt",
                      help="write output to FILE", metavar="FILE")
 optParser.add_option("-g", "--SGToutput-file", dest="sgtoutputfile", default="significanceTest.txt",
