@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    one-shot.py
 # @author  Daniel Krajzewicz
@@ -81,13 +82,15 @@ def writeSUMOConf(step, options, files):
         <verbose value="True"/>
         <no-warnings value="%s"/>
     </reports>
-</configuration>""" % (step, options.updateInterval, options.withtaz, options.reroutingexplicit, options.lastRoutes, options.withexittime, options.routesorted, not options.withWarnings), file=fd)
+</configuration>""" % (step, options.updateInterval, options.withtaz, options.reroutingexplicit, options.lastRoutes,
+                       options.withexittime, options.routesorted, not options.withWarnings), file=fd)
     fd.close()
     if options.costmodifier != 'None':
         fd = open("%s_dump_%s.add.xml" % (options.costmodifier, step), "w")
         print("""<a>
         <edgeData id="%s_dump_%s_%s" freq="%s" file="%s_dump_%s_%s.xml" excludeEmpty="true"/>
-        </a>""" % (options.costmodifier, step, options.aggregation, options.aggregation, options.costmodifier, step, options.aggregation), file=fd)
+        </a>""" % (options.costmodifier, step, options.aggregation, options.aggregation, options.costmodifier, step,
+                   options.aggregation), file=fd)
         fd.close()
     else:
         fd = open("dump_%s.add.xml" % step, "w")
@@ -96,6 +99,7 @@ def writeSUMOConf(step, options, files):
         </a>""" % (step, options.aggregation, options.aggregation, step, options.aggregation), file=fd)
         fd.close()
 
+
 optParser = OptionParser()
 optParser.add_option("-W", "--with-warnings", action="store_true", dest="withWarnings",
                      default=False, help="enables warnings")
