@@ -1,15 +1,16 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2016-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2016-2018 German Aerospace Center (DLR) and others.
 # SUMOPy module
 # Copyright (C) 2012-2017 University of Bologna - DICAM
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    geometry.py
 # @author  Joerg Schweizer
-# @date    
+# @date
 # @version $Id$
 
 import numpy as np
@@ -31,7 +32,7 @@ def get_length_polylines(polylines):
         # print '  v=\n',v,v.shape
         # print '  v[:,0,:]\n',v[:,0,:]
         # print '  v[:,1,:]\n',v[:,1,:]
-        lengths[i] = np.sum(np.sqrt(np.sum((v[:, 1, :] - v[:, 0, :])**2, 1)))
+        lengths[i] = np.sum(np.sqrt(np.sum((v[:, 1, :]-v[:, 0, :])**2, 1)))
         i += 1
     return lengths
 
@@ -42,16 +43,16 @@ def get_length_polypoints(polylines):
     lengths = np.zeros(len(polylines), np.float)
     i = 0
     for v in polylines:
-        # print '  v=\n',v,v.shape
+        # print '  v=\n',v
         a = np.array(v, np.float32)
-        lengths[i] = np.sum(np.sqrt(np.sum((a[1:, :] - a[:-1, :])**2, 1)))
+        # print '  a=\n',a,a.shape
+        lengths[i] = np.sum(np.sqrt(np.sum((a[1:, :]-a[:-1, :])**2, 1)))
         i += 1
     return lengths
 
 
 def polypoints_to_polylines(polypoints):
-    # np.zeros((0,2,3),np.float32)
-    linevertices = np.array([None] * len(polypoints), np.object)
+    linevertices = np.array([None]*len(polypoints), np.object)  # np.zeros((0,2,3),np.float32)
     #polyinds = []
     #lineinds = []
 
@@ -59,7 +60,7 @@ def polypoints_to_polylines(polypoints):
     ind_line = 0
     for polyline in polypoints:
         # Important type conversion!!
-        v = np.zeros((2 * len(polyline) - 2, 3), np.float32)
+        v = np.zeros((2*len(polyline)-2, 3), np.float32)
         v[0] = polyline[0]
         v[-1] = polyline[-1]
         if len(v) > 2:
@@ -93,27 +94,27 @@ def get_vec_on_polyline_from_pos(polyline, pos, length, angle=0.0):
 
     for j in xrange(1, len(polyline)):
         x2, y2, z2 = polyline[j]
-        seglength = np.linalg.norm([x2 - x1, y2 - y1])
+        seglength = np.linalg.norm([x2-x1, y2-y1])
         pos_edge += seglength
 
         if (pos >= pos_edge_pre) & (pos <= pos_edge):
 
-            dxn = (x2 - x1) / seglength
-            dyn = (y2 - y1) / seglength
-            u1 = (pos - pos_edge_pre)
+            dxn = (x2-x1)/seglength
+            dyn = (y2-y1)/seglength
+            u1 = (pos-pos_edge_pre)
 
-            u2 = (pos + length - pos_edge_pre)
-            return [[x1 + u1 * dxn, y1 + u1 * dyn, z2], [x1 + u2 * dxn, y1 + u2 * dyn, z2]]
+            u2 = (pos+length-pos_edge_pre)
+            return np.array([[x1 + u1 * dxn, y1 + u1 * dyn, z2], [x1 + u2 * dxn, y1 + u2 * dyn, z2]], np.float32)
 
         x1, y1 = x2, y2
         pos_edge_pre = pos_edge
 
     x1, y1, z1 = polyline[-1]
-    dxn = (x2 - x1) / seglength
-    dyn = (y2 - y1) / seglength
-    u1 = (pos - pos_edge_pre)
-    u2 = (pos + length - pos_edge_pre)
-    return [[x2, y2, z2], [x2 + u2 * dxn, y1 + u2 * dyn, z2]]
+    dxn = (x2-x1)/seglength
+    dyn = (y2-y1)/seglength
+    u1 = (pos-pos_edge_pre)
+    u2 = (pos+length-pos_edge_pre)
+    return np.array([[x2, y2, z2], [x2 + u2 * dxn, y1 + u2 * dyn, z2]], np.float32)
 
 
 def get_coord_on_polyline_from_pos(polyline, pos):
@@ -123,23 +124,53 @@ def get_coord_on_polyline_from_pos(polyline, pos):
 
     for j in xrange(1, len(polyline)):
         x2, y2, z2 = polyline[j]
-        length = np.linalg.norm([x2 - x1, y2 - y1])
+        length = np.linalg.norm([x2-x1, y2-y1])
         pos_edge += length
 
         if (pos >= pos_edge_pre) & (pos <= pos_edge):
-            u = (pos - pos_edge_pre) / length
-            x = x1 + u * (x2 - x1)
-            y = y1 + u * (y2 - y1)
-            return x, y, z2
+            u = (pos-pos_edge_pre)/length
+            x = x1 + u * (x2-x1)
+            y = y1 + u * (y2-y1)
+            return np.array([x, y, z2], np.float32)
 
         x1, y1 = x2, y2
         pos_edge_pre = pos_edge
 
-    return x2, y2, z2
+    return np.array([x2, y2, z2], np.float32)
+
+
+def get_coord_angle_on_polyline_from_pos(polyline, pos):
+    """
+    Return coordinate and respective angle
+    at position pos on the polygon.
+    """
+    pos_edge = 0.0
+    pos_edge_pre = 0.0
+    x1, y1, z1 = polyline[0]
+
+    for j in xrange(1, len(polyline)):
+        x2, y2, z2 = polyline[j]
+        length = np.linalg.norm([x2-x1, y2-y1])
+        pos_edge += length
+
+        if (pos >= pos_edge_pre) & (pos <= pos_edge):
+            u = (pos-pos_edge_pre)/length
+            dx = (x2-x1)
+            dy = (y2-y1)
+            x = x1 + u * dx
+            y = y1 + u * dy
+            return np.array([x, y, z2], np.float32), np.arctan2(dy, dx)
+
+        dx = (x2-x1)
+        dy = (y2-y1)
+        x1, y1 = x2, y2
+        pos_edge_pre = pos_edge
+
+    return np.array([x2, y2, z2], np.float32), np.arctan2(dy, dx)
 
 
 def get_pos_on_polyline_from_coord(polyline, coord):
-    xc, yx, zc = coord
+    xc, yc, zc = coord
     n_segs = len(polyline)
 
     d_min = 10.0**8
@@ -148,7 +179,7 @@ def get_pos_on_polyline_from_coord(polyline, coord):
     j_min = 0
     p_min = 0.0
     pos = 0.0
-    x1, y1, z1 = shape[0]
+    x1, y1, z1 = polyline[0]
     for j in xrange(1, n_segs):
         x2, y2, z2 = polyline[j]
         d, xp, yp = shortest_dist(x1, y1, x2, y2, xc, yc)
@@ -162,11 +193,11 @@ def get_pos_on_polyline_from_coord(polyline, coord):
             j_min = j
             p_min = pos
         # print '    pos',pos,[x2-x1,y2-y1],'p_min',p_min
-        pos += np.linalg.norm([x2 - x1, y2 - y1])
+        pos += np.linalg.norm([x2-x1, y2-y1])
         x1, y1 = x2, y2
 
-    x1, y1 = polyline[j_min - 1]
-    return p_min + np.linalg.norm([x_min - x1, y_min - y1])
+    x1, y1, z1 = polyline[j_min-1]
+    return p_min+np.linalg.norm([x_min-x1, y_min-y1])
 
 
 def shortest_dist(x1, y1, x2, y2, x3, y3):  # x3,y3 is the point
@@ -175,10 +206,10 @@ def shortest_dist(x1, y1, x2, y2, x3, y3):  # x3,y3 is the point
     Returns distance and projected point on line.
     """
 
-    px = x2 - x1
-    py = y2 - y1
+    px = x2-x1
+    py = y2-y1
 
-    something = px * px + py * py
+    something = px*px + py*py
     if something > 0:
         u = ((x3 - x1) * px + (y3 - y1) * py) / float(something)
     else:
@@ -205,16 +236,29 @@ def shortest_dist(x1, y1, x2, y2, x3, y3):  # x3,y3 is the point
     # can just return the squared distance instead
     # (i.e. remove the sqrt) to gain a little performance
 
-    dist = np.sqrt(dx * dx + dy * dy)
+    dist = np.sqrt(dx*dx + dy*dy)
 
     return dist, x, y
 
 
-def get_dist_point_to_segs(p, y1, x1, y2, x2, is_ending=True):
+def get_dist_point_to_segs(p, y1, x1, y2, x2, is_ending=True,
+                           is_detect_initial=False,
+                           is_detect_final=False,
+                           #is_return_pos = False
+                           ):
     """
-    Minimum Distance between a Point p = (x,y) and a Line segments ,
+    Minimum square distance between a Point p = (x,y) and a Line segments ,
     where vectors x1, y1 are the first  points and x2,y2 are the second points 
     of the line segments.
+
+    If is_detect_initial is True then a point whose projection is beyond
+    the start of the segment will result in a NaN distance.
+
+    If is_detect_final is True then a point whose projection is beyond
+    the end of the segment will result in a NaN distance.
+
+    If is_return_pos then the position on the section is returned.
+
     Written by Paul Bourke,    October 1988
     http://astronomy.swin.edu.au/~pbourke/geometry/pointline/
 
@@ -225,23 +269,23 @@ def get_dist_point_to_segs(p, y1, x1, y2, x2, is_ending=True):
 
     d = np.zeros(len(y1), dtype=np.float32)
 
-    dx21 = (x2 - x1)
-    dy21 = (y2 - y1)
+    dx21 = (x2-x1)
+    dy21 = (y2-y1)
 
-    lensq21 = dx21 * dx21 + dy21 * dy21
+    lensq21 = dx21*dx21 + dy21*dy21
 
     # indexvector for all zero length lines
     iz = (lensq21 == 0)
 
-    dy = y3 - y1[iz]
-    dx = x3 - x1[iz]
+    dy = y3-y1[iz]
+    dx = x3-x1[iz]
 
-    d[iz] = dx * dx + dy * dy
+    d[iz] = dx*dx + dy*dy
 
     lensq21[iz] = 1.0  # replace zeros with 1.0 to avoid div by zero error
 
-    u = (x3 - x1) * dx21 + (y3 - y1) * dy21
-    u = u / lensq21
+    u = (x3-x1)*dx21 + (y3-y1)*dy21
+    u = u / lensq21  # normalize position
 
     x = x1 + u * dx21
     y = y1 + u * dy21
@@ -254,9 +298,16 @@ def get_dist_point_to_segs(p, y1, x1, y2, x2, is_ending=True):
         x[ie] = x2[ie]
         y[ie] = y2[ie]
 
-    dx30 = x3 - x
-    dy30 = y3 - y
-    d[~iz] = (dx30 * dx30 + dy30 * dy30)[~iz]
+    dx30 = x3-x
+    dy30 = y3-y
+    d[~iz] = (dx30*dx30 + dy30*dy30)[~iz]
+
+    if is_detect_final:
+        d[iz | (u > 1)] = np.nan
+
+    if is_detect_initial:
+        d[iz | (u < 0)] = np.nan
+
     return d
 
 
@@ -266,11 +317,11 @@ def is_inside_triangles(p, x1, y1, x2, y2, x3, y3):
     inside a triangle.
     x1,y1,x2,y2,x3,y3 are vectors with the 3 coordiantes of the triangles.
     """
-    alpha = ((y2 - y3) * (p[0] - x3) + (x3 - x2) * (p[1] - y3)) \
-        / ((y2 - y3) * (x1 - x3) + (x3 - x2) * (y1 - y3))
+    alpha = ((y2 - y3)*(p[0] - x3) + (x3 - x2)*(p[1] - y3)) \
+        / ((y2 - y3)*(x1 - x3) + (x3 - x2)*(y1 - y3))
 
-    beta = ((y3 - y1) * (p[0] - x3) + (x1 - x3) * (p[1] - y3)) \
-        / ((y2 - y3) * (x1 - x3) + (x3 - x2) * (y1 - y3))
+    beta = ((y3 - y1)*(p[0] - x3) + (x1 - x3)*(p[1] - y3)) \
+        / ((y2 - y3)*(x1 - x3) + (x3 - x2)*(y1 - y3))
 
     gamma = 1.0 - alpha - beta
     return (alpha > 0) & (beta > 0) & (gamma > 0)
@@ -286,10 +337,10 @@ def find_area_perim(array):
     p = 0
     ox, oy = array[0]
     for x, y in array[1:]:
-        a += (x * oy - y * ox)
-        p += abs((x - ox) + (y - oy) * 1j)
+        a += (x*oy-y*ox)
+        p += abs((x-ox)+(y-oy)*1j)
         ox, oy = x, y
-    return a / 2, p
+    return a/2, p
 
 
 def find_area(array):
@@ -301,11 +352,20 @@ def find_area(array):
     a = 0
     ox, oy = array[0]
     for x, y in array[1:]:
-        a += (x * oy - y * ox)
+        a += (x*oy-y*ox)
         ox, oy = x, y
 
     # print '  =',np.abs(a/2)
-    return np.abs(a / 2)
+    return np.abs(a/2)
+
+
+def get_polygonarea_fast(x, y):
+    """
+    Returns area in polygon represented by x,y vectors.
+    Attention: last point is not first point.
+    """
+    # https://stackoverflow.com/questions/24467972/calculate-area-of-polygon-given-x-y-coordinates
+    return 0.5*np.abs(np.dot(x, np.roll(y, 1))-np.dot(y, np.roll(x, 1)))
 
 
 def is_point_in_polygon(point, poly):
@@ -323,7 +383,7 @@ def is_point_in_polygon(point, poly):
     n = len(poly)
     inside = False
 
-    for i in range(n + 1):
+    for i in range(n+1):
         if is_3d:
             p2x, p2y, p2z = poly[i % n]
         else:
@@ -332,7 +392,7 @@ def is_point_in_polygon(point, poly):
             if y <= max(p1y, p2y):
                 if x <= max(p1x, p2x):
                     if p1y != p2y:
-                        xints = (y - p1y) * (p2x - p1x) / (p2y - p1y) + p1x
+                        xints = (y-p1y)*(p2x-p1x)/(p2y-p1y)+p1x
                     if p1x == p2x or x <= xints:
                         inside = not inside
         p1x, p1y = p2x, p2y
@@ -367,13 +427,13 @@ def get_angles_perpendicular(shape):
 
     #width = self.widths_lanes_default[_id]
     # print '  shape',  shape ,len(  shape)
-    v_ext_begin = (shape[0] - (shape[1] - shape[0])).reshape(1, 3)
-    v_ext_end = (shape[-1] + (shape[-1] - shape[-2])).reshape(1, 3)
+    v_ext_begin = (shape[0]-(shape[1]-shape[0])).reshape(1, 3)
+    v_ext_end = (shape[-1]+(shape[-1]-shape[-2])).reshape(1, 3)
 
     exshape = np.concatenate((v_ext_begin, shape, v_ext_end))[:, 0:2]
     # print '  exshape',  exshape,len(  exshape)
-    vertex_delta_x = exshape[1:, 0] - exshape[0:-1, 0]
-    vertex_delta_y = exshape[1:, 1] - exshape[0:-1, 1]
+    vertex_delta_x = exshape[1:, 0]-exshape[0:-1, 0]
+    vertex_delta_y = exshape[1:, 1]-exshape[0:-1, 1]
 
     angles = np.arctan2(vertex_delta_y, vertex_delta_x)
     #angles = np.mod(np.arctan2(vertex_delta_y,vertex_delta_x)+2*np.pi,2*np.pi)
@@ -381,28 +441,106 @@ def get_angles_perpendicular(shape):
 
     angles1 = angles[1:]
     angles2 = angles[0:-1]
-    ind_discont = (angles1 < -0.5 * np.pi) & ((angles2 > 0.5 * np.pi)
-                                              ) | (angles2 < -0.5 * np.pi) & ((angles1 > 0.5 * np.pi))
-    angle_sum = angles1 + angles2
-    angle_sum[ind_discont] += 2 * np.pi
+    ind_discont = (angles1 < -0.5*np.pi) & ((angles2 > 0.5*np.pi)) | (angles2 < -0.5*np.pi) & ((angles1 > 0.5*np.pi))
+    angle_sum = angles1+angles2
+    angle_sum[ind_discont] += 2*np.pi
 
     #angles = np.mod(np.arctan2(vertex_delta_y,vertex_delta_x)+2*np.pi,2*np.pi)
     #angle_sum = angles[1:]+angles[0:-1]
     #ind_discont = angle_sum>2*np.pi
     #angle_sum[ind_discont] = angle_sum[ind_discont]-2*np.pi
-    return 0.5 * angle_sum - np.pi / 2
+    return 0.5*angle_sum-np.pi/2
 
 
+def rotate_vertices(vec_x, vec_y, alphas=None,
+                    sin_alphas=None, cos_alphas=None,
+                    is_array=False):
+    """
+    Rotates all vertices around
+    """
+    # print 'rotate_vertices',vec_x, vec_y
+
+    if alphas is not None:
+        sin_alphas = np.sin(alphas)
+        cos_alphas = np.cos(alphas)
+    # print '  sin_alphas',sin_alphas
+    # print '  cos_alphas',cos_alphas
+    #deltas = vertices - offsets
+    #vertices_rot = np.zeros(vertices.shape, np.float32)
+    #n= size(vec_x)
+    vec_x_rot = vec_x*cos_alphas - vec_y*sin_alphas
+    vec_y_rot = vec_x*sin_alphas + vec_y*cos_alphas
+    # print '  vec_x_rot',vec_x_rot
+    # print '  vec_y_rot',vec_y_rot
+    if is_array:
+        # print '   concatenate', np.concatenate((vec_x_rot.reshape(-1,1), vec_y_rot.reshape(-1,1)),1)
+        return np.concatenate((vec_x_rot.reshape(-1, 1), vec_y_rot.reshape(-1, 1)), 1)
+    else:
+        return vec_x_rot, vec_y_rot
+
+
+T = np.array([[0, -1], [1, 0]])
+
+
+def line_intersect(a1, a2, b1, b2):
+    """
+    Works for multiple points in each of the input arguments, i.e., a1, a2, b1, b2 can be Nx2 row arrays of 2D points.
+    https://stackoverflow.com/questions/3252194/numpy-and-line-intersections
+    """
+    da = np.atleast_2d(a2 - a1)
+    db = np.atleast_2d(b2 - b1)
+    dp = np.atleast_2d(a1 - b1)
+    dap = np.dot(da, T)
+    denom = np.sum(dap * db, axis=1)
+    num = np.sum(dap * dp, axis=1)
+    return np.atleast_2d(num / denom).T * db + b1
+
+
+def line_intersect2(a1, a2, b1, b2):
+    """
+    Works for multiple points in each of the input arguments, i.e., a1, a2, b1, b2 can be Nx2 row arrays of 2D points.
+    https://stackoverflow.com/questions/3252194/numpy-and-line-intersections
+    Returns also a scale factor which indicates wheter the intersection
+    is in positive or negative direction of the b vector.
+    """
+    da = np.atleast_2d(a2 - a1)
+    db = np.atleast_2d(b2 - b1)
+    dp = np.atleast_2d(a1 - b1)
+    dap = np.dot(da, T)
+    denom = np.sum(dap * db, axis=1)
+    num = np.sum(dap * dp, axis=1)
+    la = np.atleast_2d(num / denom).T
+    return la * db + b1, la
+
+
+def get_diff_angle_clockwise(p1, p2):
+    """
+    Returns the clockwise angle between vector 
+    0 -> p1 and 0 -> p2
+
+    p1=np.array([[x11,x11,x13,...],[y11,y12,y13,...]])
+    p2 =np.array([[x21,x21,x23,...],[y21,y22,y23,...]])
+
+    """
+    ang1 = np.arctan2(*p1[::-1])
+    ang2 = np.arctan2(*p2[::-1])
+    # return np.rad2deg((ang1 - ang2) % (2 * np.pi))
+    return (ang1 - ang2) % (2 * np.pi)
 ################################################################
 # old
+
+# find indees where 2 arrays are identical
+#idx = np.argwhere(np.diff(np.sign(f - g)) != 0).reshape(-1) + 0
+
+
 def angle2D(p1, p2):
     theta1 = math.atan2(p1[1], p1[0])
     theta2 = math.atan2(p2[1], p2[0])
     dtheta = theta2 - theta1
-    while dtheta > 3.1415926535897932384626433832795:
-        dtheta -= 2.0 * 3.1415926535897932384626433832795
-    while dtheta < -3.1415926535897932384626433832795:
-        dtheta += 2.0 * 3.1415926535897932384626433832795
+    while dtheta > np.pi:
+        dtheta -= 2.0*np.pi
+    while dtheta < -np.pi:
+        dtheta += 2.0*np.pi
     return dtheta
 
 
@@ -410,12 +548,12 @@ def is_point_within_polygon(pos, shape):
     angle = 0.
     pos = np.array(pos, float)
     shape = np.array(shape, float)
-    for i in range(0, len(shape) - 1):
+    for i in range(0, len(shape)-1):
         p1 = ((shape[i][0] - pos[0]), (shape[i][1] - pos[1]))
-        p2 = ((shape[i + 1][0] - pos[0]), (shape[i + 1][1] - pos[1]))
+        p2 = ((shape[i+1][0] - pos[0]), (shape[i+1][1] - pos[1]))
         angle = angle + angle2D(p1, p2)
-    i = len(shape) - 1
+    i = len(shape)-1
     p1 = ((shape[i][0] - pos[0]), (shape[i][1] - pos[1]))
     p2 = ((shape[0][0] - pos[0]), (shape[0][1] - pos[1]))
     angle = angle + angle2D(p1, p2)
-    return math.fabs(angle) >= 3.1415926535897932384626433832795
+    return math.fabs(angle) >= np.pi
