@@ -1,19 +1,19 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2016-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2016-2018 German Aerospace Center (DLR) and others.
 # SUMOPy module
 # Copyright (C) 2012-2017 University of Bologna - DICAM
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    wxmisc.py
 # @author  Joerg Schweizer
-# @date    
+# @date
 # @version $Id$
 
 
-
 import sys
 import os
 import types
@@ -52,7 +52,6 @@ def get_tablecolors():
 
 
 class AgileToolbarMixin:
-
     """
     Easy to use toolbar where strings can be used to identify tools. 
     Mixin for frames.
@@ -111,7 +110,7 @@ class AgileToolbarMixin:
         else:
             name = args['name']
 
-        if widget != None:
+        if widget is not None:
             # tool is a widget
             self.toolbar.AddControl(widget)
         else:
@@ -157,7 +156,6 @@ class AgileToolbarMixin:
 
 
 class AgileToolbarFrameMixin(AgileToolbarMixin):
-
     """
     Easy to use toolbar where strings can be used to identify tools. 
     Mixin for frames only.
@@ -189,7 +187,6 @@ class AgileToolbarFrameMixin(AgileToolbarMixin):
 
 
 class AgileMenuMixin:
-
     """
     Easy to use menue mixin for main menu and popup
     """
@@ -265,8 +262,7 @@ class AgileMenuMixin:
                 # print "  *create submenu",key
                 parentmenu, parentmenu_dict, parentid = self.get_menu(menupath)
                 # print ' PARENTMENU ATTRS: self,dir(parentmenu)',parentmenu,dir(parentmenu)
-                # print '
-                # parentmenu,key,parentmenu_dict,parentid',parentmenu,key,parentmenu_dict,parentid
+                # print '  parentmenu,key,parentmenu_dict,parentid',parentmenu,key,parentmenu_dict,parentid
                 menu, id = self._create_menu(parentmenu, key, **args)
                 parentmenu_dict[key] = (menu, {}, id)
 
@@ -287,7 +283,7 @@ class AgileMenuMixin:
             alt = ''
 
         id = wx.NewId()
-        if menu == None:
+        if menu is None:
             menu = wx.Menu()
 
         if parentmenu == self:
@@ -301,14 +297,13 @@ class AgileMenuMixin:
             else:
                 # !! this is the way to append a menue to toplevel
                 # which is a menubar !!
-                self.Append(menu, alt + data['name'])
+                self.Append(menu, alt+data['name'])
 
         else:
             # attach menu to a submenu
             # print '  make submenu'
 
-            item, id = self._create_item(
-                key, parentmenu, function=None, **args)
+            item, id = self._create_item(key, parentmenu, function=None, **args)
             item.SetSubMenu(menu)
             parentmenu.AppendItem(item)
             # parentmenu.AppendMenu(id,alt+data['name'],menu)
@@ -347,7 +342,7 @@ class AgileMenuMixin:
         # default item
         data = {'alt': True,
                 'shortkey': '',
-                'info': '',
+                # 'info':'',
                 }
 
         # overwrite with args
@@ -356,6 +351,12 @@ class AgileMenuMixin:
         if not data.has_key('name'):
             data['name'] = string.capitalize(key)
 
+        if not data.has_key('info'):
+            if function.__doc__ is not None:
+                data['info'] = function.__doc__.replace('\n', ' ').strip()
+            else:
+                data['info'] = data['name']
+
         # print '_create_item',data
 
         # create item
@@ -364,9 +365,9 @@ class AgileMenuMixin:
             alt = '&'
         else:
             alt = ''
-        itemtext = alt + data['name']
+        itemtext = alt+data['name']
         if data['shortkey'] != '':
-            itemtext += '\t' + data['shortkey']
+            itemtext += '\t'+data['shortkey']
 
         if data.has_key('radio'):
 
@@ -378,8 +379,7 @@ class AgileMenuMixin:
             # check boxes AFTER append
 
         else:
-            item = wx.MenuItem(menu, id, itemtext, data[
-                               'info'], wx.ITEM_NORMAL)
+            item = wx.MenuItem(menu, id, itemtext, data['info'], wx.ITEM_NORMAL)
             # print ' normal item'
 
         if data.has_key('bitmap'):
@@ -389,7 +389,7 @@ class AgileMenuMixin:
             item.SetBitmap(data['bitmap'])
 
         # define callback function
-        if function != None:  # None for submenueitem
+        if function is not None:  # None for submenueitem
             # wx.EVT_MENU(self.parent,id,function)
             self.parent.Bind(wx.EVT_MENU, function, id=id)
 
@@ -428,7 +428,7 @@ class AgileMenuMixin:
             # create main menue entry, if necessary
             if not self.menus.has_key(name):
                 newmenue = wx.Menu()
-                self.Append(newmenue, '&' + name)
+                self.Append(newmenue, '&'+name)
                 self.menus[name] = (-1, {})
 
         elif len(name) == 2:
@@ -436,7 +436,7 @@ class AgileMenuMixin:
             name1, name2 = name
             if not self.menus.has_key(name1):
                 newmenue = wx.Menu()
-                self.Append(newmenue, '&' + name1)
+                self.Append(newmenue, '&'+name1)
                 self.menus[name] = (-1, {})
 
             menuid, submenus = self.menus[name1]
@@ -445,7 +445,7 @@ class AgileMenuMixin:
                 id = wx.NewId()
                 get_menu_item()
                 newmenue = wx.Menu()
-                self.Append(newmenue, '&' + name1)
+                self.Append(newmenue, '&'+name1)
                 self.menus[name] = {}
 
             submenu = self.menus
@@ -465,7 +465,6 @@ class AgileMenuMixin:
 
 
 class AgilePopupMenu(wx.Menu, AgileMenuMixin):
-
     """
     Easy to use popup
     """
@@ -478,15 +477,15 @@ class AgilePopupMenu(wx.Menu, AgileMenuMixin):
         AgileMenuMixin.append_menu(self, '.')
 
     def append_menu(self, path, **args):
-        AgileMenuMixin.append_menu(self, './' + path, popup=True, **args)
+        AgileMenuMixin.append_menu(self, './'+path, popup=True, **args)
 
     def append_item(self, path, function, **args):
-        return AgileMenuMixin.append_item(self, './' + path, function, **args)
+        return AgileMenuMixin.append_item(self, './'+path, function, **args)
 
     def get_menuitem(self, path):
-        return AgileMenuMixin.get_menuitem(self, './' + path)
+        return AgileMenuMixin.get_menuitem(self, './'+path)
 
-#-------------------------------------------------------------------------
+# -------------------------------------------------------------------------------
     # the folling methods are used with contect<sebitive menus
     # on a grid based widget.
     # When initializing the menu the row and column of its location can
@@ -614,7 +613,6 @@ KEYMAP = {
 
 
 class KeyHandler:
-
     """
     Mixin for handling key events in wx
     """
@@ -624,7 +622,7 @@ class KeyHandler:
         Sets events and variables for parent.
         If no parent is defined then self is assumed to be parent.
         """
-        if parent == None:
+        if parent is None:
             parent = self
 
         self.key_pressed = ''  # string code of currently pressed key
@@ -642,7 +640,7 @@ class KeyHandler:
         """
         A key has been pressed down...
         """
-        if self.GUIMode == None:
+        if self.GUIMode is None:
             # try custom tool of metacanvas
             input = self.set_keypress(event)
             # print 'on_key_down',input
@@ -678,7 +676,7 @@ class KeyHandler:
                     keyname = "NUL"
                 elif (keycode < 27) & (not ignore_specials):
                     # keycode is a special control key
-                    keyname = "Ctrl-%s" % chr(ord('A') + keycode - 1)
+                    keyname = "Ctrl-%s" % chr(ord('A') + keycode-1)
                 elif (keycode < 27):
                     keyname = ''
                 else:
@@ -701,13 +699,13 @@ class KeyHandler:
         code = ''
 
         if event.ControlDown():
-            code += 'CONTROL' + sep
+            code += 'CONTROL'+sep
 
         if event.ShiftDown():
-            code += 'SHIFT' + sep
+            code += 'SHIFT'+sep
 
         if event.AltDown():
-            code += 'ALT' + sep
+            code += 'ALT'+sep
 
         return code
 
@@ -715,7 +713,6 @@ class KeyHandler:
 
 
 class OptionsFrame(wx.Frame):
-
     """
     Simple wx frame with some special features.
     """
@@ -724,7 +721,7 @@ class OptionsFrame(wx.Frame):
                  size=wx.DefaultSize, style=wx.DEFAULT_FRAME_STYLE,
                  name='frame'):
 
-        if mainframe == None:
+        if mainframe is None:
             self._mainframe = parent
         else:
             self._mainframe = mainframe
@@ -740,7 +737,6 @@ class OptionsFrame(wx.Frame):
 
 
 class OptionsPanel(AgileToolbarMixin, wx.Panel):
-
     """
     UNUSED
     Simple wx panele with some special features.
@@ -750,7 +746,7 @@ class OptionsPanel(AgileToolbarMixin, wx.Panel):
 
         wx.Panel.__init__(self, parent, -1, wx.DefaultPosition,
                           wx.DefaultSize, wx.SUNKEN_BORDER | wx.WANTS_CHARS)
-        if mainframe == None:
+        if mainframe is None:
             self._mainframe = parent
         else:
             self._mainframe = mainframe
@@ -760,14 +756,13 @@ class OptionsPanel(AgileToolbarMixin, wx.Panel):
 
 
 class AgileStatusbar(wx.StatusBar):
-
-    def __init__(self, parent, fields=[('action', -1),
+    def __init__(self, parent, fields=[('action', -4),
                                        ('message', -4),
-                                       #('coords',-1),
-                                       #('zoom',-1),
+                                       # ('coords',-1),
+                                       # ('zoom',-1),
                                        ('progress', -1),
                                        ('status', -1),
-                                       #('coords',-1),
+                                       # ('coords',-1),
                                        ]):
 
         wx.StatusBar.__init__(self, parent, -1, wx.ST_SIZEGRIP)
@@ -803,7 +798,9 @@ class AgileStatusbar(wx.StatusBar):
         """
         Set bar of progressbar in percent
         """
+        # print 'set_progress',percent
         self.progressbar.SetValue(int(percent))
+        self.Update()
 
     def set_fields(self, fields):
         """
@@ -826,6 +823,7 @@ class AgileStatusbar(wx.StatusBar):
         ind_field = self._ind_fields[key]
         # print 'AgileStatusbar.__setitem__',key,ind_field
         self.SetStatusText(message, ind_field)
+        self.Update()
 
     def has_key(self, key):
         return self._ind_fields.has_key(key)
@@ -853,7 +851,6 @@ class AgileStatusbar(wx.StatusBar):
 
 
 class AgileMenubar(AgileMenuMixin, wx.MenuBar):
-
     """
     Easy to use main menu bar
     """
@@ -865,13 +862,14 @@ class AgileMenubar(AgileMenuMixin, wx.MenuBar):
 
 def get_bitmap(name, size=22):
     """Return bitmap of right size from imgImages library"""
-    name = name + "_" + str(size)
+    name = name + "_"+str(size)
     try:
         return imgImages.catalog[name].getBitmap()
     except:
         print 'WARNING in get_bitmap: failed to return image', name
         return wx.NullBitmap
 
+
 # These are some functions for bitmaps of icons.
 import cPickle
 import zlib
@@ -889,7 +887,7 @@ def GetHandData():
 def GetHandBitmap():
     return wx.BitmapFromXPMData(GetHandData())
 
-#----------------------------------------------------------------------
+# ----------------------------------------------------------------------
 
 
 def GetPlusData():
@@ -904,7 +902,7 @@ def GetPlusData():
 def GetPlusBitmap():
     return wx.BitmapFromXPMData(GetPlusData())
 
-#----------------------------------------------------------------------
+# ----------------------------------------------------------------------
 
 
 def GetMinusData():
