@@ -1,21 +1,22 @@
-/*   
-    Copyright (C) 2015 Mario Krumnow, Dresden University of Technology
-
-    This file is part of TraaS.
-
-    TraaS is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License.
-
-    TraaS is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with TraaS.  If not, see <http://www.gnu.org/licenses/>.
-*/
-
+/****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2017-2018 German Aerospace Center (DLR) and others.
+// TraaS module
+// Copyright (C) 2016-2017 Dresden University of Technology
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
+/// @file    Simulation.java
+/// @author  Mario Krumnow
+/// @author  Evamarie Wiessner
+/// @date    2016
+/// @version $Id$
+///
+//
+/****************************************************************************/
 package de.tudresden.sumo.cmd;
 import de.tudresden.sumo.config.Constants;
 import de.tudresden.sumo.util.SumoCommand;
@@ -66,9 +67,18 @@ public class Simulation {
 	 * @param y y
 	 * @param fromGeo geo
 	 */
-	public static SumoCommand convertGeo(double x, double y, String fromGeo){
-		Object[] array = new Object[]{y, fromGeo};
-		return new SumoCommand(Constants.CMD_GET_SIM_VARIABLE, Constants.POSITION_CONVERSION, x, array, Constants.RESPONSE_GET_SIM_VARIABLE, Constants.TYPE_STRINGLIST);
+	public static SumoCommand convertGeo(double x, double y, boolean fromGeo){
+		
+		 byte fromType = Constants.POSITION_2D;
+		 byte toType = Constants.POSITION_LON_LAT;
+		
+		 if(fromGeo){
+			 fromType = Constants.POSITION_LON_LAT;
+		     toType = Constants.POSITION_2D;
+		 }
+		 
+		Object[] array = new Object[]{fromType, x, y, toType};
+		return new SumoCommand(Constants.CMD_GET_SIM_VARIABLE, Constants.POSITION_CONVERSION, "", array, Constants.RESPONSE_GET_SIM_VARIABLE, fromGeo ? Constants.POSITION_2D : Constants.POSITION_LON_LAT);
 	}
 
 	/**
@@ -159,6 +169,43 @@ public class Simulation {
 	}
 	
 	
+	/**
+	 * getCollidingVehiclesNumber()
+	 * @return Return number of vehicles involved in a collision (typically 2 per collision).
+	 */
+
+	public static SumoCommand getCollidingVehiclesNumber(){
+		return new SumoCommand(Constants.CMD_GET_SIM_VARIABLE, Constants.VAR_COLLIDING_VEHICLES_NUMBER, "", Constants.RESPONSE_GET_SIM_VARIABLE, Constants.TYPE_INTEGER);
+	}
+	
+	/**
+	 * getCollidingVehiclesNumber()
+	 * @return Return Ids of vehicles involved in a collision (typically 2 per collision)
+	 */
+
+	public static SumoCommand getCollidingVehiclesIDList(){
+		return new SumoCommand(Constants.CMD_GET_SIM_VARIABLE, Constants.VAR_COLLIDING_VEHICLES_IDS, "", Constants.RESPONSE_GET_SIM_VARIABLE, Constants.TYPE_STRINGLIST);
+	}
+	
+	/**
+	 * getEmergencyStoppingVehiclesNumber()
+	 * @return Return number of vehicles that performed an emergency stop in the last step
+	 */
+
+	public static SumoCommand getEmergencyStoppingVehiclesNumber(){
+		return new SumoCommand(Constants.CMD_GET_SIM_VARIABLE, Constants.VAR_EMERGENCYSTOPPING_VEHICLES_NUMBER, "", Constants.RESPONSE_GET_SIM_VARIABLE, Constants.TYPE_INTEGER);
+	}
+	
+	/**
+	 * getEmergencyStoppingVehiclesIDList()
+	 * @return Return Ids of vehicles that peformed an emergency stop in the last step
+	 */
+
+	public static SumoCommand getEmergencyStoppingVehiclesIDList(){
+		return new SumoCommand(Constants.CMD_GET_SIM_VARIABLE, Constants.VAR_EMERGENCYSTOPPING_VEHICLES_IDS, "", Constants.RESPONSE_GET_SIM_VARIABLE, Constants.TYPE_STRINGLIST);
+	}
+	
+	
 	/**
 	 * getStopEndingVehiclesNumber()
 	 * @return number of vehicles
@@ -167,6 +214,8 @@ public class Simulation {
 	public static SumoCommand getStopEndingVehiclesNumber(){
 		return new SumoCommand(Constants.CMD_GET_SIM_VARIABLE, Constants.VAR_STOP_ENDING_VEHICLES_NUMBER, "", Constants.RESPONSE_GET_SIM_VARIABLE, Constants.TYPE_INTEGER);
 	}
+
+	
 	
 	/**
 	 * getStopStartingVehiclesIDList()
@@ -309,7 +358,7 @@ public class Simulation {
 	 * @return SumoCommand
 	 */
 	public static SumoCommand getNetBoundary(){
-		return new SumoCommand(Constants.CMD_GET_SIM_VARIABLE, Constants.VAR_NET_BOUNDING_BOX, "", Constants.RESPONSE_GET_SIM_VARIABLE, Constants.TYPE_BOUNDINGBOX);
+		return new SumoCommand(Constants.CMD_GET_SIM_VARIABLE, Constants.VAR_NET_BOUNDING_BOX, "", Constants.RESPONSE_GET_SIM_VARIABLE, Constants.TYPE_POLYGON);
 	}
 
 	/**
@@ -352,4 +401,41 @@ public class Simulation {
 		return new SumoCommand(Constants.CMD_SET_SIM_VARIABLE, Constants.CMD_SAVE_SIMSTATE, "", filename);
 	}
 	
+	/**
+	 * findRoute
+	 * @param fromEdge first edge
+	 * @param toEdge second edge
+	 * @param vType vehicle type
+	 * @param depart depart
+	 * @param routingMode routing mode
+	 * @return the route
+	 */
+	public static SumoCommand findRoute(String fromEdge, String toEdge, String vType, double depart, int routingMode){
+		Object[] array = new Object[]{fromEdge, toEdge, vType, depart, routingMode};
+		return new SumoCommand(Constants.CMD_GET_SIM_VARIABLE, Constants.FIND_ROUTE, "", array, Constants.RESPONSE_GET_SIM_VARIABLE, Constants.TYPE_COMPOUND);
+	}
+	
+	/**
+	 * findIntermodalRoute
+	 * @param fromEdge first edge
+	 * @param toEdge second edge
+	 * @param modes modes
+	 * @param depart depart
+	 * @param routingMode routing mode
+	 * @param speed speed
+	 * @param walkingFactor walkingFactor
+	 * @param departPos departPos
+	 * @param arrivalPos arrivalPos
+	 * @param departPosLat departPosLat
+	 * @param pType pType
+	 * @param vType vType
+	 * @param destStop destStop
+	 * @return the route
+	 */
+	public static SumoCommand findIntermodalRoute(String fromEdge, String toEdge, String modes, double depart, int routingMode, 
+												double speed, double walkingFactor, double departPos, double arrivalPos, double departPosLat, String pType, String vType, String destStop){
+		Object[] array = new Object[]{fromEdge, toEdge, modes, depart, routingMode, speed, walkingFactor, departPos, arrivalPos, departPosLat, pType, vType, destStop};
+		return new SumoCommand(Constants.CMD_GET_SIM_VARIABLE, Constants.FIND_INTERMODAL_ROUTE, "", array, Constants.RESPONSE_GET_SIM_VARIABLE, Constants.TYPE_COMPOUND);
+	}
+	
 }
\ No newline at end of file
