@@ -1,22 +1,22 @@
-/*   
-    Copyright (C) 2017 Mario Krumnow, Dresden University of Technology
-
-    This file is part of TraaS.
-
-    TraaS is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License.
-
-    TraaS is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with TraaS.  If not, see <http://www.gnu.org/licenses/>.
-*/
-
-
+/****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2017-2018 German Aerospace Center (DLR) and others.
+// TraaS module
+// Copyright (C) 2016-2017 Dresden University of Technology
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
+/// @file    Vehicle.java
+/// @author  Mario Krumnow
+/// @author  Evamarie Wiessner
+/// @date    2016
+/// @version $Id$
+///
+//
+/****************************************************************************/
 package de.tudresden.sumo.cmd;
 import de.tudresden.sumo.config.Constants;
 import de.tudresden.sumo.util.SumoCommand;
@@ -45,6 +45,16 @@ public class Vehicle {
 		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_ACCEL, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_DOUBLE);
 	}
 
+	/**
+	 *  Returns the action step length for this vehicle.
+	 * @param vehID id of the vehicle
+	 * @return action step length for this vehicle
+	 */
+
+	public static SumoCommand getActionStepLength(String vehID){
+		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_ACTIONSTEPLENGTH, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_DOUBLE);
+	}
+	
 	/**
 	 * Returns the number of all vehicles in the network.
 	 * @return current number of vehicles in the network
@@ -77,7 +87,38 @@ public class Vehicle {
 		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_ANGLE, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_DOUBLE);
 	}
 
+	/**
+	 * Returns the apparent deceleration in m/s^2 of this vehicle.
+	 * @param vehID id of the vehicle
+	 * @return angle
+	 */
+
+	public static SumoCommand getApparentDecel(String vehID){
+		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_APPARENT_DECEL, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_DOUBLE);
+	}
 	
+	/**
+	 * Returns the maximum lateral speed in m/s of this vehicle.
+	 * @param vehID id of the vehicle
+	 * @return angle
+	 */
+
+	public static SumoCommand getMaxSpeedLat(String vehID){
+		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_MAXSPEED_LAT, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_DOUBLE);
+	}
+	
+	
+	/**
+	 * Returns The desired lateral gap of this vehicle at 50km/h in m
+	 * @param vehID id of the vehicle
+	 * @return angle
+	 */
+
+	public static SumoCommand getMinGapLat(String vehID){
+		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_MINGAP_LAT, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_DOUBLE);
+	}
+	
+		
 	/**
 	 * Returns the maximum allowed speed on the current lane regarding speed factor in m/s for this vehicle.
 	 * @param vehID id of the vehicle
@@ -98,6 +139,71 @@ public class Vehicle {
 		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_HEIGHT, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_DOUBLE);
 	}
 	
+	/**
+	 *Returns The lateral position of the vehicle on its current lane measured in m.
+     * @param vehID id of the vehicle
+	 * @return the leading vehicle
+	 */
+
+	public static SumoCommand getLateralLanePosition(String vehID){
+		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_LANEPOSITION_LAT, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_DOUBLE);
+	}
+
+	
+	/**
+	 * Returns the maximal physically possible deceleration in m/s^2 of this vehicle.
+	 * @param vehID id of the vehicle
+	 * @param direction direction
+	 * @return SumoCommand
+	 */
+	public static SumoCommand getLaneChangeState(String vehID, int direction){
+
+		Object[] array = new Object[]{direction};
+		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.CMD_CHANGELANE, vehID, array, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_COMPOUND);
+	}
+
+	/**
+	 * Returns the maximal physically possible deceleration in m/s^2 of this vehicle.
+	 * @param vehID id of the vehicle
+	 * @return SumoCommand
+	 */
+	public static SumoCommand getEmergencyDecel(String vehID){
+		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_EMERGENCY_DECEL, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_DOUBLE);
+	}
+		
+
+	/**
+	 *  Returns the time of last action point for this vehicle.
+     * @param vehID id of the vehicle
+	 * @return  time of last action point for this vehicle.
+	 */
+
+	public static SumoCommand getLastActionTime(String vehID){
+		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_LASTACTIONTIME, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_DOUBLE);
+	}
+	
+	
+	/**
+	 * Returns The preferred lateral alignment of the vehicle
+     * @param vehID id of the vehicle
+	 * @return the leading vehicle
+	 */
+
+	public static SumoCommand getLateralAlignment(String vehID){
+		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_LATALIGNMENT, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_STRING);
+	}
+	
+	/**
+	 *  Gets the vehicle's lane change mode as a bitset.
+     * @param vehID id of the vehicle
+	 * @return  vehicle's lane change mode as a bitset.
+	 */
+
+	public static SumoCommand getLaneChangeMode(String vehID){
+		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_LANECHANGE_MODE, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_INTEGER);
+	}
+	
+	
 	/**
 	 * Return the leading vehicle id together with the distance.
       The dist parameter defines the maximum lookahead, 0 calculates a lookahead from the brake gap.
@@ -267,7 +373,7 @@ public class Vehicle {
 	 */
 
 	public static SumoCommand getIDList(){
-		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.ID_LIST, "", Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_STRINGLIST);
+		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.TRACI_ID_LIST, "", Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_STRINGLIST);
 	}
 
 	/**
@@ -310,6 +416,8 @@ public class Vehicle {
 		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_LANEPOSITION, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_DOUBLE);
 	}
 
+	
+	
 	/**
 	 * Returns the length (in m) of the named vehicle.
 	 * @param vehID id of the vehicle
@@ -360,6 +468,25 @@ public class Vehicle {
 		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_NEXT_TLS, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_COMPOUND);
 	}
 	
+	/**
+	 *  Return list of upcoming stops [(lane, endPos, stoppingPlaceID, stopFlags, duration, until), ...]
+        where integer stopFlag is defined as:
+               1 * stopped +
+               2 * parking +
+               4 * personTriggered +
+               8 * containerTriggered +
+              16 * isBusStop +
+              32 * isContainerStop +
+              64 * chargingStation +
+             128 * parkingarea
+        with each of these flags defined as 0 or 1.
+	 * @param vehID id of the vehicle
+	 * @return next traffic lights (compound)
+	 */
+	public static SumoCommand getNextStops(String vehID){
+		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_NEXT_STOPS, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_COMPOUND);
+	}
+	
 	
 
 	/**
@@ -467,6 +594,18 @@ public class Vehicle {
 		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_ROUTE_INDEX, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_INTEGER);
 	}
 	
+	/**
+	 *  returns the current routing mode:
+        tc.ROUTING_MODE_DEFAULT    : use weight storages and fall-back to edge speeds (default)
+        tc.ROUTING_MODE_AGGREGATED : use global smoothed travel times from device.rerouting
+	 * @param vehID id of the vehicle
+	 * @return  current routing mode
+	 */
+
+	public static SumoCommand getRoutingMode(String vehID){
+		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_ROUTING_MODE, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_INTEGER);
+	}
+	
 	/**
 	 * getShapeClass
 	 * @param vehID id of the vehicle
@@ -601,6 +740,18 @@ public class Vehicle {
 		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_TYPE, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_STRING);
 	}
 
+	/**
+	 * Returns the list of persons which includes those defined using attribute 'personNumber'
+        as well as <person>-objects which are riding in this vehicle.
+	 * @param vehID id of the vehicle
+	 * @return vehicle class
+	 */
+
+	public static SumoCommand getPersonIDList(String vehID){
+		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.LAST_STEP_PERSON_ID_LIST, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_INTEGER);
+	}
+
+	
 	/**
 	 * Returns the vehicle class.
 	 * @param vehID id of the vehicle
@@ -611,6 +762,17 @@ public class Vehicle {
 		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_VEHICLECLASS, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_STRING);
 	}
 
+
+	/**
+	 * Returns the vehicle class.
+	 * @param vehID id of the vehicle
+	 * @return vehicle class
+	 */
+
+	public static SumoCommand getAccumulatedWaitingTime(String vehID){
+		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_ACCUMULATED_WAITING_TIME, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_DOUBLE);
+	}
+	
 	/**
 	 * Returns the vehicle's width (in m).
 	 * @param vehID id of the vehicle
@@ -620,7 +782,7 @@ public class Vehicle {
 	public static SumoCommand getWidth(String vehID){
 		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_WIDTH, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_DOUBLE);
 	}
-
+	
 	
 	/**
 	 * isStopped
@@ -629,7 +791,7 @@ public class Vehicle {
 	 */
 
 	public static SumoCommand isStopped(String vehID){
-		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_STOPSTATE, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_UBYTE, "isStopped");
+		return new SumoCommand(Constants.CMD_GET_VEHICLE_VARIABLE, Constants.VAR_STOPSTATE, vehID, Constants.RESPONSE_GET_VEHICLE_VARIABLE, Constants.TYPE_INTEGER, "isStopped");
 	}
 	
 	/**
@@ -726,7 +888,7 @@ public class Vehicle {
 	public static SumoCommand addFull(String vehID, String routeID, String typeID, String depart, String departLane, String departPosition, 
 									  String departSpeed, String arrivalLane, String arrivalPosition, String arrivalSpeed,  String fromTAZ, String toTAZ, String line, int person_capacity, int person_number){
 
-		Object[] array = new Object[]{ routeID, typeID, depart, departLane, departPosition, departSpeed, arrivalLane, arrivalPosition, arrivalSpeed, fromTAZ, toTAZ, line, person_capacity, person_number};
+		Object[] array = new Object[]{routeID, typeID, depart, departLane, departPosition, departSpeed, arrivalLane, arrivalPosition, arrivalSpeed, fromTAZ, toTAZ, line, person_capacity, person_number};
 		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.ADD_FULL, vehID, array);
 	}
 	
@@ -756,6 +918,33 @@ public class Vehicle {
 		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.CMD_CHANGETARGET, vehID, edgeID);
 	}
 
+	
+	/**
+	 * Forces a lateral change by the given amount (negative values indicate changing to the right, positive to the left)
+	        This will override any other lane change motivations but conform to
+	        safety-constraints as configured by laneChangeMode.
+	 * @param vehID vehicle id
+	 * @param latDist latDist
+	 * @return SumoCommand
+	 */
+	public static SumoCommand changeSublane(String vehID, double latDist){
+		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.CMD_CHANGESUBLANE, vehID, latDist);
+	}
+	
+	/**
+	 *  Adds or modifies a stop at a parkingArea with the given parameters. The duration and the until attribute are
+	        in milliseconds.
+	 * @param vehID vehicle id
+	 * @param stopID stopID
+	 * @param duration duration
+	 * @return SumoCommand
+	 */
+	public static SumoCommand setParkingAreaStop(String vehID, String stopID, int duration){
+		SumoStopFlags sf = new SumoStopFlags(true, false, false, false, false);
+    	return setStop(vehID, stopID, 1, (byte) 0, duration, sf);
+	}
+
+	
 	/**
 	 * Moves the vehicle to a new position.
 
@@ -793,7 +982,7 @@ public class Vehicle {
 	public static SumoCommand moveToXY(String vehID, String edgeID, int lane, double x, double y, double angle, byte keepRoute){
 
 		Object[] array = new Object[]{edgeID, lane, x, y, angle, keepRoute};
-		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_MOVE_TO_VTD, vehID, array);
+		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.MOVE_TO_XY, vehID, array);
 	}
 	
 	
@@ -856,6 +1045,42 @@ public class Vehicle {
 		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_EDGE_TRAVELTIME, vehID, array);
 	}
 
+	/**
+	 *  Sets the preferred lateral alignment for this vehicle.
+	 * @param vehID id of the vehicle
+	 * @param align align
+	 * @return SumoCommand
+	 */
+	public static SumoCommand setLateralAlignment(String vehID, String align){
+
+		Object[] array = new Object[]{align};
+		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_LATALIGNMENT, vehID, array);
+	}
+
+	/**
+	 * Sets the apparent deceleration in m/s^2 for this vehicle.
+	 * @param vehID id of the vehicle
+	 * @param decel decel
+	 * @return SumoCommand
+	 */
+	public static SumoCommand setApparentDecel(String vehID, double decel){
+
+		Object[] array = new Object[]{decel};
+		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_APPARENT_DECEL, vehID, array);
+	}
+	
+	/**
+	 * Sets the minimum lateral gap of the vehicle at 50km/h in m
+	 * @param vehID id of the vehicle
+	 * @param minGapLat minGapLat
+	 * @return SumoCommand
+	 */
+	public static SumoCommand setMinGapLat(String vehID, double minGapLat){
+
+		Object[] array = new Object[]{minGapLat};
+		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_MINGAP_LAT, vehID, array);
+	}
+	
 	
 	/**
 	 * Sets the vehicle's color (RGBA).
@@ -899,6 +1124,15 @@ public class Vehicle {
 		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_LANECHANGE_MODE, vehID, lcm);
 	}
 	
+	/**
+	 *  Sets the maximal physically possible deceleration in m/s^2 for this vehicle.
+	 * @param vehID id of the vehicle
+	 * @param decel decel
+	 * @return SumoCommand
+	 */
+	public static SumoCommand setEmergencyDecel(String vehID, double decel){
+		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_EMERGENCY_DECEL, vehID, decel);
+	}
 	
 	/**
 	 * Sets the IDs of the edges the vehicle's route is made of.
@@ -911,6 +1145,19 @@ public class Vehicle {
 		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_ROUTE, vehID, array);
 	}
 	
+	/**
+	 * sets the current routing mode:
+        tc.ROUTING_MODE_DEFAULT    : use weight storages and fall-back to edge speeds (default)
+        tc.ROUTING_MODE_AGGREGATED : use global smoothed travel times from device.rerouting
+	 * @param vehID id of the vehicle
+	 * @param routingMode routingMode
+	 * @return SumoCommand
+	 */
+	public static SumoCommand setRoutingMode(String vehID, int routingMode){
+		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_ROUTING_MODE, vehID, routingMode);
+	}
+	
+	
 	/**
 	 * Sets the id of the type for the named vehicle.
 	 * @param vehID id of the vehicle
@@ -968,6 +1215,23 @@ public class Vehicle {
 	public static SumoCommand setLength(String vehID, double length){
 		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_LENGTH, vehID, length);
 	}
+	
+	/**
+	 *  Sets the action step length for this vehicle. If resetActionOffset == True (default), the
+        next action point is scheduled immediately. if If resetActionOffset == False, the interval
+        between the last and the next action point is updated to match the given value, or if the latter
+        is smaller than the time since the last action point, the next action follows immediately.
+	 * @param vehID vehicle id
+	 * @param actionStepLength actionStepLength
+	 * @param resetActionOffset resetActionOffset
+	 * @return SumoCommand 
+	 */
+	public static SumoCommand setActionStepLength(String vehID, double actionStepLength, boolean resetActionOffset){
+		
+		if(!resetActionOffset) {actionStepLength *= -1;}
+		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_ACTIONSTEPLENGTH, vehID, actionStepLength);
+	}
+	
 
 	/**
 	 * Sets the line information for this vehicle.
@@ -1005,6 +1269,16 @@ public class Vehicle {
 		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_MAXSPEED, vehID, speed);
 	}
 
+	/**
+	 * Sets the maximum lateral speed in m/s for this vehicle.
+	 * @param vehID vehicle id
+	 * @param speed speed
+	 * @return SumoCommand
+	 */
+	public static SumoCommand setMaxSpeedLat(String vehID, double speed){
+		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_MAXSPEED_LAT, vehID, speed);
+	}
+	
 	/**
 	 * Sets the minimum gap (in m) between this vehicle and the vehicle before it.
 	 * @param vehID vehicle id
@@ -1104,7 +1378,24 @@ public class Vehicle {
 		Object[] array = new Object[]{edgeID, pos, laneIndex, duration, sf};
 		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.CMD_STOP, vehID, array);
 	}
-
+	
+	/**
+	 *  Adds or modifies a stop at a chargingStation with the given parameters. The duration and the until attribute are
+	    in milliseconds.
+	        
+	 * @param vehID
+	 * @param stopID
+	 * @param duration
+	 * @param until
+	 * @return SumoCommand
+	 */
+	
+	public static SumoCommand setChargingStationStop(String vehID, String stopID, int duration, int until){
+		SumoStopFlags sf = new SumoStopFlags(false, false, false, true, false);
+    	return setStop(vehID, stopID, 1, (byte) 0, duration, sf);
+	}
+	
+	
 	/**
 	 * Adds or modifies a bus stop with the given parameters. The duration and the until attribute are in milliseconds.
 	 * @param vehID id of the vehicle
@@ -1175,4 +1466,33 @@ public class Vehicle {
 		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_WIDTH, vehID, width);
 	}
 
-}
\ No newline at end of file
+	/**
+	 *  Inserts the information about the travel time of edge "edgeID" valid
+        from begin time to end time into the vehicle's internal edge weights
+        container.
+        If the time is not specified, any previously set values for that edge
+        are removed.
+        If begTime or endTime are not specified the value is set for the whole
+        simulation duration.
+	 * @param vehID vehicle id
+	 * @return SumoCommand
+	 */
+
+	public static SumoCommand updateBestLanes(String vehID){
+		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_UPDATE_BESTLANES, vehID, "");
+	}
+	
+	/**
+	 * Changes the next parking area in parkingAreaID, updates the vehicle route,
+        and preserve consistency in case of passengers/containers on board.
+	 * @param vehID vehicle id
+	 * @param parkingAreaID parkingAreaID
+	 * @return SumoCommand
+	 */
+
+	public static SumoCommand rerouteParkingArea(String vehID, String parkingAreaID){
+		return new SumoCommand(Constants.CMD_SET_VEHICLE_VARIABLE, Constants.VAR_UPDATE_BESTLANES, vehID, parkingAreaID);
+	}
+	
+	
+}
