@@ -1,21 +1,22 @@
-/*   
-    Copyright (C) 2017 Mario Krumnow, Dresden University of Technology
-
-    This file is part of TraaS.
-
-    TraaS is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License.
-
-    TraaS is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with TraaS.  If not, see <http://www.gnu.org/licenses/>.
-*/
-
+/****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2017-2018 German Aerospace Center (DLR) and others.
+// TraaS module
+// Copyright (C) 2016-2017 Dresden University of Technology
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
+/// @file    ContextSubscription.java
+/// @author  Mario Krumnow
+/// @author  Evamarie Wiessner
+/// @date    2016
+/// @version $Id$
+///
+//
+/****************************************************************************/
 package de.tudresden.sumo.subscription;
 
 import java.util.LinkedList;
@@ -26,8 +27,8 @@ import it.polito.appeal.traci.protocol.Command;
 public class ContextSubscription implements Subscription  {
 
 	public SubscriptionContext context;
-	public int start;
-	public int stop;
+	public double start;
+	public double stop;
 	public String objectID;
 	public SumoDomain contextDomain;
 	public double contextRange;
@@ -49,7 +50,7 @@ public class ContextSubscription implements Subscription  {
 		
 	}
 	
-	public ContextSubscription(SubscriptionContext context, int start, int stop, String objectID, SumoDomain contextDomain, double contextRange){
+	public ContextSubscription(SubscriptionContext context, double start, double stop, String objectID, SumoDomain contextDomain, double contextRange){
 		
 		this.context = context;
 		this.start = start;
@@ -65,8 +66,8 @@ public class ContextSubscription implements Subscription  {
 	public Command getCommand() {
 		
 		Command cmd = new Command(this.context.id);
-		cmd.content().writeInt(this.start);
-		cmd.content().writeInt(this.stop);
+		cmd.content().writeDouble(this.start);
+		cmd.content().writeDouble(this.stop);
 		cmd.content().writeStringASCII(this.objectID);
 		cmd.content().writeUnsignedByte(this.contextDomain.id);
 		cmd.content().writeDouble(this.contextRange);
