@@ -1,21 +1,22 @@
-/*   
-    Copyright (C) 2017 Mario Krumnow, Dresden University of Technology
-
-    This file is part of TraaS.
-
-    TraaS is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License.
-
-    TraaS is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with TraaS.  If not, see <http://www.gnu.org/licenses/>.
-*/
-
+/****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2017-2018 German Aerospace Center (DLR) and others.
+// TraaS module
+// Copyright (C) 2016-2017 Dresden University of Technology
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
+/// @file    CommandProcessor.java
+/// @author  Mario Krumnow
+/// @author  Evamarie Wiessner
+/// @date    2016
+/// @version $Id$
+///
+//
+/****************************************************************************/
 package de.tudresden.sumo.util;
 
 import it.polito.appeal.traci.TraCIException.UnexpectedData;
@@ -29,7 +30,6 @@ import java.util.LinkedList;
 import de.tudresden.sumo.config.Constants;
 import de.tudresden.sumo.subscription.Subscription;
 import de.tudresden.ws.container.SumoBestLanes;
-import de.tudresden.ws.container.SumoBoundingBox;
 import de.tudresden.ws.container.SumoColor;
 import de.tudresden.ws.container.SumoGeometry;
 import de.tudresden.ws.container.SumoLeader;
@@ -43,6 +43,7 @@ import de.tudresden.ws.container.SumoPrimitive;
 import de.tudresden.ws.container.SumoStopFlags;
 import de.tudresden.ws.container.SumoStringList;
 import de.tudresden.ws.container.SumoTLSProgram;
+import de.tudresden.ws.container.SumoVehicleData;
 import de.uniluebeck.itm.tcpip.Storage;
 import de.tudresden.ws.container.SumoTLSPhase;
 import de.tudresden.ws.container.SumoTLSController;
@@ -68,7 +69,7 @@ public class CommandProcessor extends Query{
 		fireAndForget(cs.getCommand());
 	}
 	
-	public synchronized void do_SimulationStep(int targetTime) throws IOException {
+	public synchronized void do_SimulationStep(double targetTime) throws IOException {
 		doSimulationStep(targetTime);
 	}
 	
@@ -97,15 +98,6 @@ public class CommandProcessor extends Query{
 			}
 			output = ssl;
 		
-		}else if(type == Constants.TYPE_BOUNDINGBOX){
-			
-			double min_x = s.readDouble();
-			double min_y = s.readDouble();
-			double max_x = s.readDouble();
-			double max_y = s.readDouble();
-			
-			output = new SumoBoundingBox(min_x, min_y, max_x, max_y);
-			
 		}else if(type == Constants.VAR_STOPSTATE){
 			
 			short s0 = s.readByte();
@@ -331,8 +323,7 @@ public class CommandProcessor extends Query{
 			
 			output = sg;
 		
-		}
-		else if(type == Constants.TYPE_COLOR){
+		} else if(type == Constants.TYPE_COLOR){
 			
 			int r = s.readUnsignedByte();
 			int g = s.readUnsignedByte();
@@ -340,7 +331,7 @@ public class CommandProcessor extends Query{
 			int a = s.readUnsignedByte();
 			
 			output = new SumoColor(r, g, b, a);
-		
+
 		}else if(type == Constants.TYPE_UBYTE){
 			output = new SumoPrimitive(s.readUnsignedByte());
 		}
@@ -348,7 +339,6 @@ public class CommandProcessor extends Query{
 		return output;
 	}
 	
-	
 	public synchronized Object do_job_get(SumoCommand sc) throws IOException{
 		
 		Object output = null;
@@ -361,7 +351,7 @@ public class CommandProcessor extends Query{
 		if(sc.output_type == Constants.TYPE_INTEGER){output = resp.content().readInt();
 		}else if(sc.output_type == Constants.TYPE_DOUBLE){output = resp.content().readDouble();
 		}else if(sc.output_type == Constants.TYPE_STRING){output = resp.content().readStringUTF8();
-		}else if(sc.output_type == Constants.POSITION_2D){
+		}else if(sc.output_type == Constants.POSITION_2D || sc.output_type == Constants.POSITION_LON_LAT){
 			double x = resp.content().readDouble();
 			double y = resp.content().readDouble();
 			output = new SumoPosition2D(x,y);
@@ -379,15 +369,6 @@ public class CommandProcessor extends Query{
 			}
 			output = ssl;
 		
-		}else if(sc.output_type == Constants.TYPE_BOUNDINGBOX){
-			
-			double min_x = resp.content().readDouble();
-			double min_y = resp.content().readDouble();
-			double max_x = resp.content().readDouble();
-			double max_y = resp.content().readDouble();
-			
-			output = new SumoBoundingBox(min_x, min_y, max_x, max_y);
-			
 		}else if(sc.input2 == Constants.VAR_STOPSTATE){
 			short s = resp.content().readByte();
 			SumoStopFlags sf = new SumoStopFlags((byte) s);
@@ -604,13 +585,93 @@ public class CommandProcessor extends Query{
 				}
 			
 				output = sl;
+
+            }else if(sc.input2 == Constants.LAST_STEP_VEHICLE_DATA){
+
+                resp.content().readUnsignedByte();
+                resp.content().readInt();
+
+                SumoVehicleData vehData  = new SumoVehicleData();
+
+                int numItems = resp.content().readInt();
+                for(int i=0; i<numItems; i++){
+
+                    resp.content().readUnsignedByte();
+                    String vehID = resp.content().readStringASCII();
+
+                    resp.content().readUnsignedByte();
+                    double length = resp.content().readDouble();
+
+                    resp.content().readUnsignedByte();
+                    double entryTime = resp.content().readDouble();
+
+                    resp.content().readUnsignedByte();
+                    double leaveTime = resp.content().readDouble();
+
+                    resp.content().readUnsignedByte();
+                    String typeID = resp.content().readStringASCII();
+
+                    vehData.add(vehID, length, entryTime, leaveTime, typeID);
+                }
+                output = vehData;
 				
+			}else if(sc.input2 == Constants.FIND_ROUTE){
+				
+				resp.content().readInt();
+				resp.content().readUnsignedByte();
+				resp.content().readInt();
+				resp.content().readUnsignedByte();
+				
+				resp.content().readStringASCII();
+				resp.content().readUnsignedByte();
+				resp.content().readStringASCII();
+				resp.content().readUnsignedByte();
+				
+				SumoStringList ssl = new SumoStringList();
+				int size = resp.content().readInt();
+				for(int i=0; i<size; i++){
+					ssl.add(resp.content().readStringASCII());
+				}
+				
+				resp.content().readDouble();
+				output = ssl;
+				
+			}else if(sc.input2 == Constants.FIND_INTERMODAL_ROUTE){
+				
+				LinkedList<SumoStringList> ll = new LinkedList<SumoStringList>();
+				int l = resp.content().readInt();
+				System.out.println("l: " + l);
+				
+				for(int i1=0; i1<l; i1++) {
+				
+					resp.content().readInt();
+					resp.content().readUnsignedByte();
+					resp.content().readInt();
+					resp.content().readUnsignedByte();
+					
+					resp.content().readStringASCII();
+					resp.content().readUnsignedByte();
+					resp.content().readStringASCII();
+					resp.content().readUnsignedByte();
+					
+					SumoStringList ssl = new SumoStringList();
+					int size = resp.content().readInt();
+					for(int i=0; i<size; i++){
+						ssl.add(resp.content().readStringASCII());
+					}
+					
+					resp.content().readDouble();
+					ll.add(ssl);
+				}
+				
+				output = ll;
+					
 			}else{
 				
-				int laenge = resp.content().readInt();
-				obj = new Object[laenge];
+				int size = resp.content().readInt();
+				obj = new Object[size];
 				
-				for(int i=0; i<laenge; i++){
+				for(int i=0; i<size; i++){
 					
 					//int k = resp.content().readUnsignedByte();
 					//obj[i] = this.get_value(k, resp);
