@@ -1,22 +1,22 @@
-/*   
-    Copyright (C) 2011 ApPeAL Group, Politecnico di Torino
-
-    This file is part of TraCI4J.
-
-    TraCI4J is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    TraCI4J is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with TraCI4J.  If not, see <http://www.gnu.org/licenses/>.
-*/
-
+/****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2017-2018 German Aerospace Center (DLR) and others.
+// TraCI4J module
+// Copyright (C) 2011 ApPeAL Group, Politecnico di Torino
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
+/// @file    ResponseMessage.java
+/// @author  Enrico Gueli
+/// @author  Mario Krumnow
+/// @date    2011
+/// @version $Id$
+///
+//
+/****************************************************************************/
 package it.polito.appeal.traci.protocol;
 
 import java.io.DataInputStream;
@@ -44,6 +44,7 @@ public class ResponseMessage {
 		Constants.CMD_SET_EDGE_VARIABLE,
 		Constants.CMD_SET_GUI_VARIABLE,
 		Constants.CMD_SET_LANE_VARIABLE,
+		Constants.CMD_SET_PERSON_VARIABLE,
 		Constants.CMD_SET_POI_VARIABLE,
 		Constants.CMD_SET_POLYGON_VARIABLE,
 		Constants.CMD_SET_ROUTE_VARIABLE,
@@ -65,7 +66,7 @@ public class ResponseMessage {
 	 * <ul>
 	 * <li>if the status response is not {@link Constants#RTYPE_OK}, another
 	 * status response or the end of the stream are expected.</li>
-	 * <li>if the status ID is equal to {@link Constants#CMD_SIMSTEP2}, it is
+	 * <li>if the status ID is equal to {@link Constants#CMD_SIMSTEP}, it is
 	 * expected an integer representing N and N following sub-responses;</li>
 	 * <li>if the status ID matches one of the commands in
 	 * {@link #STATUS_ONLY_RESPONSES} , it is expected another status response;
@@ -75,8 +76,8 @@ public class ResponseMessage {
 	 * A new {@link ResponseMessage}, collecting all the data that belong to the
 	 * same request, is built and appended to an internal list.
 	 * 
-	 * @param dis
-	 * @throws IOException
+	 * @param dis dis
+	 * @throws IOException Exception
 	 */
 	public ResponseMessage(DataInputStream dis) throws IOException {
 		int totalLen = dis.readInt() - Integer.SIZE/8;
@@ -93,7 +94,7 @@ public class ResponseMessage {
 			if (sr.result() != Constants.RTYPE_OK) {
 				responseContainer = new ResponseContainer(sr, null);
 			}
-			else if (sr.id() == Constants.CMD_SIMSTEP2) {
+			else if (sr.id() == Constants.CMD_SIMSTEP) {
 				int nSubResponses = s.readInt();
 				List<Command> subResponses = new ArrayList<Command>(
 						nSubResponses);
