@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2012-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    generateBidiDistricts.py
 # @author  Jakob Erdmann
@@ -38,7 +39,7 @@ def parse_args():
     options, args = optParser.parse_args()
     try:
         options.net, = args
-    except:
+    except Exception:
         sys.exit(USAGE)
     if options.outfile is None:
         options.outfile = options.net + ".taz.xml"
@@ -55,6 +56,7 @@ def getCandidates(edge, net, radius):
         candidates.append(nearby)
     return candidates
 
+
 ASYM_BIDI_CACHE = {}  # edge : opposites
 
 
@@ -110,6 +112,7 @@ def main(netFile, outFile, radius, travelDist, symmetrical):
         outf.write('</tazs>\n')
     return net
 
+
 if __name__ == "__main__":
     options = parse_args()
     main(options.net, options.outfile, options.radius,
