@@ -1,21 +1,17 @@
 #!/usr/bin/env python
-"""
-@file    transportationTestProblems.py
-@author  Michael Behrisch
-@date    2015-02-24
-@version $Id: transportationTestProblems.py 22608 2017-01-17 06:28:54Z behrisch $
+# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+# Copyright (C) 2014-2018 German Aerospace Center (DLR) and others.
+# This program and the accompanying materials
+# are made available under the terms of the Eclipse Public License v2.0
+# which accompanies this distribution, and is available at
+# http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
-Create a network and trips for inputs found at http://www.bgu.ac.il/~bargera/tntp/.
+# @file    transportationTestProblems.py
+# @author  Michael Behrisch
+# @date    2015-02-24
+# @version $Id$
 
-SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2014-2017 DLR (http://www.dlr.de/) and contributors
-
-This file is part of SUMO.
-SUMO is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 3 of the License, or
-(at your option) any later version.
-"""
 
 from __future__ import print_function
 from __future__ import absolute_import
@@ -24,7 +20,7 @@ import sys
 import subprocess
 import csv
 sys.path.append(os.path.join(os.environ["SUMO_HOME"], 'tools'))
-import sumolib
+import sumolib  # noqa
 
 csvfile = csv.DictReader(open(sys.argv[1]), delimiter='\t')
 with open("nodes.nod.xml", "w") as nodeout:
