@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2009-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2009-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    convert_detectors2SUMO.py
 # @author  Lukas Grohmann <Lukas.Grohmann@ait.ac.at>
@@ -27,13 +28,12 @@ from xml.dom.minidom import Document
 # want the sumolib tools
 import sys
 import os
+import numpy as np
 THIS_PATH = os.path.abspath(__file__)
 addpath = os.path.abspath(THIS_PATH + '/../../../sumolib')
 if addpath not in sys.path:
     sys.path.append(addpath)
-import geomhelper
-
-import numpy as np
+import geomhelper  # noqa
 
 
 def dict_from_node_attributes(node):
