@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2009-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2009-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    tls_vissimXML2SUMOnet_update.py
 # @author  Lukas Grohmann <Lukas.Grohmann@ait.ac.at>
@@ -267,7 +268,7 @@ def get_sg_connection_data(
                     link = signal['link']
                     lane = str(int(signal['lane']) - 1)
                     # tls on normal edge or verbinder?
-                    if is_verbinder_d[link] == False:
+                    if is_verbinder_d[link] is False:
                         if link in edge_list:
                             connection = conn_tab[
                                 (conn_tab["from"] == link) & (
