@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2009-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2009-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    vissim_parseBusStops.py
 # @author  Daniel Krajzewicz
@@ -24,6 +25,7 @@ The read routes are saved as <OUTPUT_PREFIX>_stops.add.xml
 """
 from __future__ import absolute_import
 from __future__ import print_function
+import sys
 
 edgemap = {}
 edgemap["203"] = "203[0]"
@@ -32,10 +34,6 @@ edgemap["77"] = "77[0]"
 edgemap["203"] = "203[0]"
 
 
-import sys
-from random import *
-
-
 def getName(vals, beg):
     name = vals[beg]
     while name.count('"') != 2:
@@ -82,7 +80,7 @@ def parseBusRoute(br, stops):
             i = vals.index("HALTESTELLE", i)
             i = i + 1
             stops.insert(0, int(vals[i]))
-        except:
+        except Exception:
             i = len(vals) + 1
     return (id, name, startKante, ziel, zeiten, stops)
 
