@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2009-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2009-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    vissim_parseRoutes.py
 # @author  Daniel Krajzewicz
@@ -54,7 +55,6 @@ def parseInFlow(inflow, suggested_name):
     else:
         q = float(vals[i + 1])
     i = vals.index("ZUSAMMENSETZUNG", i + 1)
-    zusammensetzung = vals[i + 1]
     i = vals.index("ZEIT", i)
     i = vals.index("VON", i)
     von = float(vals[i + 1])
@@ -97,7 +97,7 @@ def parseRouteDecision(rd):
         else:
             try:
                 i = vals.index("ROUTE", i)
-            except:
+            except Exception:
                 i = -1
         if r_ziel in edgemap:
             r_edges.append(edgemap[r_ziel])
