@@ -1,37 +1,34 @@
 #!/usr/bin/env python
-"""
-@file    visum_convertTurnPercentages.py
-@author  Daniel Krajzewicz
-@author  Michael Behrisch
-@date    2009-06-12
-@version $Id: visum_convertTurnPercentages.py 20482 2016-04-18 20:49:42Z behrisch $
+# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+# Copyright (C) 2009-2018 German Aerospace Center (DLR) and others.
+# This program and the accompanying materials
+# are made available under the terms of the Eclipse Public License v2.0
+# which accompanies this distribution, and is available at
+# http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
+# @file    visum_convertTurnPercentages.py
+# @author  Daniel Krajzewicz
+# @author  Michael Behrisch
+# @date    2009-06-12
+# @version $Id$
+
+"""
 
 Converts VISUM turning percentages into
  turning percentages JTRROUTER can read.
-
-SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2009-2016 DLR (http://www.dlr.de/) and contributors
-
-This file is part of SUMO.
-SUMO is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 3 of the License, or
-(at your option) any later version.
 """
 from __future__ import absolute_import
 from __future__ import print_function
 
 
 import os
-import string
 import sys
-import StringIO
-from xml.sax import saxutils, make_parser, handler
+from xml.sax import make_parser
 
 sys.path.append(
     os.path.join(os.path.abspath(os.path.dirname(sys.argv[0])), "../../lib"))
-import sumonet
+import sumonet  # noqa
 
 
 if len(sys.argv) < 4:
@@ -64,6 +61,7 @@ found = 0
 foundN = 0
 missing = 0
 missingN = 0
+attributes = []
 fd = open(sys.argv[2])
 for line in fd:
     if line.find("$") == 0 or line.find("*") == 0 or line.find(";") < 0:
