@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2010-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2010-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    launcher.py
 # @author  Jakob Erdmann
@@ -16,8 +17,8 @@ from __future__ import absolute_import
 import os
 import re
 import subprocess
-from Tkinter import *
-from ttk import *
+from Tkinter import Canvas, Menu, StringVar, Tk, LEFT
+from ttk import Button, Frame, Menubutton, Label, Scrollbar, Entry
 import tkFileDialog
 from sumolib.options import Option, readOptions
 
@@ -186,6 +187,7 @@ def parse_help(app):
     options = []
     optName = None
     optHelp = ""
+    optType = ""
     for line in helpstring.split(os.linesep):
         if '--' in line:
             if optName is not None:
@@ -213,5 +215,6 @@ def main():
     app = Launcher(root, app, appOptions)
     root.mainloop()
 
+
 if __name__ == "__main__":
     main()
