@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2011-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    netdiff.py
 # @author  Daniel Krajzewicz
@@ -35,7 +36,7 @@ from collections import defaultdict
 
 sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
 import sumolib  # noqa
-from OrderedMultiSet import OrderedMultiSet
+from OrderedMultiSet import OrderedMultiSet  # noqa
 
 INDENT = 4
 
@@ -54,7 +55,8 @@ PLAIN_TYPES = [
 # traffic lights have some peculiarities
 # CAVEAT1 - ids are not unique (only in combination with programID)
 # CAVEAT2 - the order of their children (phases) is important.
-#     this makes partial diffs unfeasible. The easiest solution is to forgo diffs and always export the whole new traffic light
+#     this makes partial diffs unfeasible. The easiest solution is to forgo diffs and always
+#     export the whole new traffic light
 # CAVEAT3 - deletes need not be written because they are also signaled by a changed node type
 #     (and they complicate the handling of deleted tl-connections)
 # CAVEAT4 - deleted connections must be written with their tlID and tlIndex, otherwise
@@ -359,7 +361,8 @@ def create_plain(netfile, netconvert):
     prefix = netfile[:-8]
     call([netconvert,
           "--sumo-net-file", netfile,
-          "--plain-output-prefix", prefix])
+          "--plain-output-prefix", prefix,
+          "--roundabouts.guess", "false"])
     return prefix
 
 
@@ -452,5 +455,6 @@ def main():
                     type,
                     copy_tags)
 
+
 if __name__ == "__main__":
     main()
