@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    visum_mapDistricts.py
 # @author  Daniel Krajzewicz
@@ -27,8 +28,8 @@ import math
 from optparse import OptionParser
 
 sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
-import sumolib.net
-import netshiftadaptor
+import sumolib.net  # noqa
+import netshiftadaptor  # noqa
 
 
 def computeDistance(n1, n2):
@@ -427,7 +428,8 @@ for d in nmap1to2:
                 for i in range(0, outgoingLaneNo):
                     net1.addLane(e2, 18, 100.)
                     fdd.write('    <connection from="' + dn1i._incoming[
-                              0]._id + '" to="' + "i" + d + "#" + n2._id + '" lane="' + str(runningInLaneNumber) + ':' + str(i) + '"/>\n')
+                              0]._id + '" to="' + "i" + d + "#" + n2._id + '" lane="' + str(runningInLaneNumber) +
+                              ':' + str(i) + '"/>\n')
                     runningInLaneNumber = runningInLaneNumber + 1
                 if outgoingLaneNo == 0:
                     net1.addLane(e2, 18, 100.)
@@ -492,6 +494,7 @@ def writeEdges(net):
     fd.write("</edges>\n")
     fd.close()
 
+
 fdd.write("</connections>\n")
 writeNodes(net1)
 writeEdges(net1)
