@@ -1,26 +1,25 @@
 #!/usr/bin/env python
-"""
-@file    xmlconnections_mapEdges.py
-@author  Daniel Krajzewicz
-@author  Michael Behrisch
-@date    2009-08-01
-@version $Id: xmlconnections_mapEdges.py 20433 2016-04-13 08:00:14Z behrisch $
+# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+# Copyright (C) 2009-2018 German Aerospace Center (DLR) and others.
+# This program and the accompanying materials
+# are made available under the terms of the Eclipse Public License v2.0
+# which accompanies this distribution, and is available at
+# http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
+# @file    xmlconnections_mapEdges.py
+# @author  Daniel Krajzewicz
+# @author  Michael Behrisch
+# @date    2009-08-01
+# @version $Id$
+
+"""
 Reads edge id replacements from "edgemap.txt"; the format of this file is
  <OLD_EDGE_ID>-><NEW_EDGE_ID>
 Reads the given connections file <CONNECTIONS> and replaces old edge names by new.
 The result is written to <CONNECTIONS>.mod.xml
 
 Call: xmlconnections_mapEdges.py <CONNECTIONS>
-
-SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2009-2016 DLR (http://www.dlr.de/) and contributors
-
-This file is part of SUMO.
-SUMO is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 3 of the License, or
-(at your option) any later version.
 """
 from __future__ import absolute_import
 from __future__ import print_function
