@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    vehLanes.py
 # @author  Jakob Erdmann
@@ -17,7 +18,7 @@ import os
 import sys
 from collections import defaultdict
 sys.path.append(os.path.join(os.path.dirname(sys.argv[0]), '..'))
-from sumolib.output import parse
+from sumolib.output import parse  # noqa
 
 
 def trackLanes(netstate, out):
@@ -60,6 +61,7 @@ def trackLanes(netstate, out):
                 laneChanges[veh_id]))
         f.write("</vehLanes>\n")
 
+
 if __name__ == "__main__":
     if len(sys.argv) != 3:
         sys.exit("call %s <netstate-dump> <output-file>" % sys.argv[0])
