@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2014-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2014-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    implausibleRoutes.py
 # @author  Jakob Erdmann
@@ -47,30 +48,40 @@ def get_options():
                          help="Routes with an implausibility-score above treshold are reported")
     optParser.add_option("--airdist-ratio-factor", type="float", default=1, dest="airdist_ratio_factor",
                          help="Implausibility factor for the ratio of routeDist/airDist ")
-    optParser.add_option("--detour-ratio-factor", type="float", default=1,  dest="detour_ratio_factor",
+    optParser.add_option("--detour-ratio-factor", type="float", default=1, dest="detour_ratio_factor",
                          help="Implausibility factor for the ratio of routeDuration/shortestDuration ")
     optParser.add_option("--detour-factor", type="float", default=0.01, dest="detour_factor",
-                         help="Implausibility factor for the absolute detour time in (routeDuration-shortestDuration) in seconds")
+                         help="Implausibility factor for the absolute detour time in (routeDuration-shortestDuration)" +
+                              " in seconds")
     optParser.add_option("--min-dist", type="float", default=0, dest="min_dist",
                          help="Minimum shortest-path distance below which routes are implausible")
     optParser.add_option("--min-air-dist", type="float", default=0, dest="min_air_dist",
                          help="Minimum air distance below which routes are implausible")
     optParser.add_option("--standalone", action="store_true",
-                         default=False, help="Parse stand-alone routes that are not define as child-element of a vehicle")
+                         default=False, help="Parse stand-alone routes that are not define as child-element of " +
+                                             "a vehicle")
     optParser.add_option("--blur", type="float", default=0,
                          help="maximum random disturbance to output polygon geometry")
     optParser.add_option("--ignore-routes", dest="ignore_routes",
-                         help="List of route IDs (one per line) that are filtered when generating polygons and command line output (they will still be added to restrictions-output)")
+                         help="List of route IDs (one per line) that are filtered when generating polygons and " +
+                              "command line output (they will still be added to restrictions-output)")
     optParser.add_option("--restriction-output", dest="restrictions_output",
                          help="Write flow-restriction output suitable for passing to flowrouter.py to FILE")
     optParser.add_option("--od-restrictions", action="store_true", dest="odrestrictions",
-                         default=False, help="Write restrictions for origin-destination relations rather than whole routes")
+                         default=False, help="Write restrictions for origin-destination relations rather than " +
+                                             "whole routes")
     options, args = optParser.parse_args()
 
     if len(args) != 2:
         sys.exit(USAGE)
     options.network = args[0]
     options.routeFile = args[1]
+    # options for generate_poly
+    options.layer = 100
+    options.geo = False
+    options.internal = False
+    options.spread = None
+
     return options
 
 
@@ -142,7 +153,8 @@ def main():
                 routeInfos[vehicle.id].detour = 0
                 routeInfos[vehicle.id].detourRatio = 1
                 if oldCosts < newCosts:
-                    sys.stderr.write("Warning: fastest route for '%s' is slower than original route (old=%s, new=%s). Check vehicle types\n" % (
+                    sys.stderr.write(("Warning: fastest route for '%s' is slower than original route " +
+                                      "(old=%s, new=%s). Check vehicle types\n") % (
                         vehicle.id, oldCosts, newCosts))
             else:
                 routeInfos[vehicle.id].detour = oldCosts - newCosts
@@ -185,13 +197,14 @@ def main():
     with open(polyOutput, 'w') as outf:
         outf.write('<additional>\n')
         for score, rID, ri in sorted(implausible):
-            generate_poly(net, rID, colorgen(), 100, False, ri.edges, options.blur, outf, score)
+            generate_poly(options, net, rID, colorgen(), ri.edges, outf, score)
         outf.write('</additional>\n')
 
     sys.stdout.write('score\troute\t(airDistRatio, detourRatio, detour, shortestDist, airDist)\n')
     for score, rID, ri in sorted(implausible):
         # , ' '.join(ri.edges)))
-        sys.stdout.write('%.7f\t%s\t%s\n' % (score, rID, (ri.airDistRatio, ri.detourRatio, ri.detour, ri.shortest_path_distance, ri.airDist)))
+        sys.stdout.write('%.7f\t%s\t%s\n' % (score, rID, (ri.airDistRatio, ri.detourRatio,
+                                                          ri.detour, ri.shortest_path_distance, ri.airDist)))
 
     print(allRoutesStats)
     print(implausibleRoutesStats)
