@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2014-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2014-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    routeStats.py
 # @author  Jakob Erdmann
@@ -69,11 +70,15 @@ def main():
     attribute_retriever = None
     if options.attribute == "length":
         net = readNet(options.network)
-        attribute_retriever = lambda vehicle: sum([net.getEdge(e).getLength() for e in vehicle.route[0].edges.split()])
+
+        def attribute_retriever(vehicle):
+            return sum([net.getEdge(e).getLength() for e in vehicle.route[0].edges.split()])
     elif options.attribute == "depart":
-        attribute_retriever = lambda vehicle: float(vehicle.depart)
+        def attribute_retriever(vehicle):
+            return float(vehicle.depart)
     elif options.attribute == "numEdges":
-        attribute_retriever = lambda vehicle: len(vehicle.route[0].edges.split())
+        def attribute_retriever(vehicle):
+            return len(vehicle.route[0].edges.split())
     else:
         sys.exit("Invalid value '%s' for option --attribute" % options.attribute)
 
@@ -115,5 +120,6 @@ def main():
             for val, id in sorted(data):
                 f.write("%s %s\n" % (val, id))
 
+
 if __name__ == "__main__":
     main()
