@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2007-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2007-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    sort_routes.py
 # @author  Jakob Erdmann
@@ -19,8 +20,8 @@ import sys
 from xml.dom import pulldom
 from xml.sax import handler
 from xml.sax import make_parser
-from xml.sax import handler
 from optparse import OptionParser
+import time
 
 DEPART_ATTRS = {'vehicle': 'depart', 'flow': 'begin', 'person': 'depart'}
 
@@ -53,7 +54,11 @@ def sort_departs(routefilename, outfile):
             routes_doc.expandNode(parsenode)
             departAttr = DEPART_ATTRS.get(parsenode.localName)
             if departAttr is not None:
-                start = float(parsenode.getAttribute(departAttr))
+                startString = parsenode.getAttribute(departAttr)
+                if ':' in startString:
+                    start = time.strptime(startString, "%d:%H:%M:%S")
+                else:
+                    start = float(startString)
                 vehicles.append(
                     (start, parsenode.toprettyxml(indent="", newl="")))
             else:
