@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    vehicle2flow.py
 # @author  Michael Behrisch
@@ -35,7 +36,7 @@ def parse_args():
     options, args = optParser.parse_args()
     try:
         options.routefile = args[0]
-    except:
+    except Exception:
         sys.exit(USAGE)
     if options.outfile is None:
         options.outfile = options.routefile + ".rou.xml"
@@ -46,7 +47,6 @@ def main():
     options = parse_args()
     with open(options.routefile) as f:
         with open(options.outfile, 'w') as outf:
-            headerSeen = False
             for line in f:
                 if options.with_entities:
                     if "<routes " in line or "<routes>" in line:
@@ -56,12 +56,15 @@ def main():
     ]>
     """ % (options.repeat, options.end))
                     line = re.sub(
-                        r'<vehicle(.*)depart( ?= ?"[^"]*")', r'<flow\1begin\2 end="&RepeatEnd;" period="&RepeatInterval;"', line)
+                        r'<vehicle(.*)depart( ?= ?"[^"]*")', r'<flow\1begin\2 end="&RepeatEnd;" ' +
+                        'period="&RepeatInterval;"', line)
                 else:
                     line = re.sub(
-                        r'<vehicle(.*)depart( ?= ?"[^"]*")', r'<flow\1begin\2 end="%s" period="%s"' % (options.end, options.repeat), line)
+                        r'<vehicle(.*)depart( ?= ?"[^"]*")', r'<flow\1begin\2 end="%s" period="%s"' %
+                        (options.end, options.repeat), line)
                 line = re.sub(r'</vehicle>', '</flow>', line)
                 outf.write(line)
 
+
 if __name__ == "__main__":
     main()
