@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2009-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2009-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    poi_alongRoads.py
 # @author  Ronald Nippold
@@ -32,7 +33,7 @@ from __future__ import print_function
 import os
 import sys
 sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
-import sumolib.net
+import sumolib.net  # noqa
 
 if len(sys.argv) < 4:
     print("Usage: " +
@@ -68,6 +69,7 @@ def poiAppend(poi_edge, poi_nr, poi_x, poi_y, poi_buf):
     poi_buf.append('    <poi id="%s-%s" type="default" color="1,0,0" layer="0" x="%.2f" y="%.2f"/>' %
                    (poi_edge, poi_nr, poi_x, poi_y))
 
+
 print("Reading net ...")
 net = sumolib.net.readNet(sys.argv[1])
 
