@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    selection.py
 # @author  Daniel Krajzewicz
@@ -12,7 +13,6 @@
 # @version $Id$
 
 
-
 def read(file, lanes2edges=True):
     ret = {}
     fd = open(file)
@@ -35,4 +35,4 @@ def write(fdo, entries):
 
 def writeTyped(fdo, typeName, entries):
     for e in entries:
-        fdo.write("%s:%s" % (typeName, entries))
+        fdo.write("%s:%s\n" % (typeName, e))
