@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    __init__.py
 # @author  Daniel Krajzewicz
@@ -25,19 +26,19 @@ from __future__ import absolute_import
 import os
 import sys
 import math
-import re
-from xml.sax import saxutils, parse, handler
+import heapq
+from xml.sax import handler, parse
 from copy import copy
-from itertools import *
+from itertools import *  # noqa
 from collections import defaultdict
 
 import sumolib
 from . import lane, edge, node, connection, roundabout
-from .lane import Lane
-from .edge import Edge
-from .node import Node
-from .connection import Connection
-from .roundabout import Roundabout
+from .lane import Lane  # noqa
+from .edge import Edge  # noqa
+from .node import Node  # noqa
+from .connection import Connection  # noqa
+from .roundabout import Roundabout  # noqa
 
 
 class TLS:
@@ -63,10 +64,10 @@ class TLS:
 
     def getLinks(self):
         links = {}
-        for connection in self._connections:
-            if connection[2] not in links:
-                links[connection[2]] = []
-            links[connection[2]].append(connection)
+        for the_connection in self._connections:
+            if the_connection[2] not in links:
+                links[the_connection[2]] = []
+            links[the_connection[2]].append(the_connection)
         return links
 
     def getEdges(self):
@@ -91,6 +92,20 @@ class TLS:
         return self._programs
 
 
+class Phase:
+
+    def __init__(self, duration, state, minDur=-1, maxDur=-1, next=-1):
+        self.duration = duration
+        self.state = state
+        self.minDur = minDur  # minimum duration (only for actuated tls)
+        self.maxDur = maxDur  # maximum duration (only for actuated tls)
+        self.next = next
+
+    def __repr__(self):
+        return ("Phase(duration=%s, state='%s', minDur=%s, maxDur=%s, next=%s)" %
+                (self.duration, self.state, self.minDur, self.maxDur, self.next))
+
+
 class TLSProgram:
 
     def __init__(self, id, offset, type):
@@ -99,15 +114,18 @@ class TLSProgram:
         self._offset = offset
         self._phases = []
 
-    def addPhase(self, state, duration):
-        self._phases.append((state, duration))
+    def addPhase(self, state, duration, minDur=-1, maxDur=-1, next=-1):
+        self._phases.append(Phase(duration, state, minDur, maxDur, next))
 
     def toXML(self, tlsID):
         ret = '  <tlLogic id="%s" type="%s" programID="%s" offset="%s">\n' % (
             tlsID, self._type, self._id, self._offset)
         for p in self._phases:
+            minDur = '' if p.minDur < 0 else ' minDur="%s"' % p.minDur
+            maxDur = '' if p.maxDur < 0 else ' maxDur="%s"' % p.maxDur
+            next = '' if p.next < 0 else ' next="%s"' % p.next
             ret = ret + \
-                '    <phase duration="%s" state="%s"/>\n' % (p[1], p[0])
+                '    <phase duration="%s" state="%s"%s%s%s/>\n' % (p.duration, p.state, minDur, maxDur, next)
         ret = ret + '  </tlLogic>\n'
         return ret
 
@@ -134,6 +152,7 @@ class Net:
         self._allLanes = []
         self._origIdx = None
         self.hasWarnedAboutMissingRTree = False
+        self.hasInternal = False
 
     def setLocation(self, netOffset, convBoundary, origBoundary, projParameter):
         self._location["netOffset"] = netOffset
@@ -173,10 +192,12 @@ class Net:
             e = edge.Edge(id, fromN, toN, prio, function, name)
             self._edges.append(e)
             self._id2edge[id] = e
+            if function:
+                self.hasInternal = True
         return self._id2edge[id]
 
-    def addLane(self, edge, speed, length, allow=None, disallow=None):
-        return lane.Lane(edge, speed, length, allow, disallow)
+    def addLane(self, edge, speed, length, width, allow=None, disallow=None):
+        return lane.Lane(edge, speed, length, width, allow, disallow)
 
     def addRoundabout(self, nodes, edges=None):
         r = roundabout.Roundabout(nodes, edges)
@@ -189,9 +210,22 @@ class Net:
         fromEdge.addOutgoing(conn)
         fromlane.addOutgoing(conn)
         toEdge._addIncoming(conn)
+        if viaLaneID:
+            try:
+                # internal lanes are only available when building with option withInternal=True
+                viaLane = self.getLane(viaLaneID)
+                viaEdge = viaLane.getEdge()
+                viaEdge._addIncoming(connection.Connection(
+                    fromEdge, viaEdge, fromlane, viaLane, direction, tls,
+                    tllink, state, ''))
+            except Exception:
+                pass
 
-    def getEdges(self):
-        return self._edges
+    def getEdges(self, withInternal=True):
+        if not withInternal:
+            return [e for e in self._edges if e.getFunction() == '']
+        else:
+            return self._edges
 
     def getRoundabouts(self):
         return self._roundabouts
@@ -231,11 +265,11 @@ class Net:
                     "Warning: Module 'rtree' not available. Using brute-force fallback")
                 self.hasWarnedAboutMissingRTree = True
 
-            for edge in self._edges:
+            for the_edge in self._edges:
                 d = sumolib.geomhelper.distancePointToPolygon(
-                    (x, y), edge.getShape(includeJunctions))
+                    (x, y), the_edge.getShape(includeJunctions))
                 if d < r:
-                    edges.append((edge, d))
+                    edges.append((the_edge, d))
         return edges
 
     def getNeighboringLanes(self, x, y, r=0.1, includeJunctions=True):
@@ -243,8 +277,8 @@ class Net:
         try:
             if self._rtree is None:
                 if not self._allLanes:
-                    for edge in self._edges:
-                        self._allLanes += edge.getLanes()
+                    for the_edge in self._edges:
+                        self._allLanes += the_edge.getLanes()
                 self._initRTree(self._allLanes, includeJunctions)
             for i in self._rtree.intersection((x - r, y - r, x + r, y + r)):
                 l = self._allLanes[i]
@@ -253,8 +287,8 @@ class Net:
                 if d < r:
                     lanes.append((l, d))
         except ImportError:
-            for edge in self._edges:
-                for l in edge.getLanes():
+            for the_edge in self._edges:
+                for l in the_edge.getLanes():
                     d = sumolib.geomhelper.distancePointToPolygon(
                         (x, y), l.getShape(includeJunctions))
                     if d < r:
@@ -270,6 +304,9 @@ class Net:
     def getNodes(self):
         return self._nodes
 
+    def getTLS(self, tlid):
+        return self._id2tls[tlid]
+
     def getTLSSecure(self, tlid):
         if tlid in self._id2tls:
             tls = self._id2tls[tlid]
@@ -301,7 +338,16 @@ class Net:
     def forbids(self, possProhibitor, possProhibited):
         return possProhibitor.getFrom().getToNode().forbids(possProhibitor, possProhibited)
 
-    def getDownstreamEdges(self, edge, distance, stopOnTLS):
+    def getDownstreamEdges(self, edge, distance, stopOnTLS, stopOnTurnaround):
+        """return a list of lists of the form
+           [[firstEdge, pos, [edge_0, edge_1, ..., edge_k], aborted], ...]
+           where
+             firstEdge: is the downstream edge furthest away from the intersection,
+             [edge_0, ..., edge_k]: is the list of edges from the intersection downstream to firstEdge
+             pos: is the position on firstEdge with distance to the end of the input edge
+             aborted: a flag indicating whether the downstream
+                 search stopped at a TLS or a node without incoming edges before reaching the distance threshold
+        """
         ret = []
         seen = set()
         toProc = []
@@ -319,27 +365,31 @@ class Net:
                 ret.append([ie[0], ie[0].getLength() + ie[1], ie[2], True])
                 continue
             mn = []
-            hadTLS = False
+            stop = False
             for ci in ie[0]._incoming:
                 if ci not in seen:
                     prev = copy(ie[2])
-                    if stopOnTLS and ci._tls and ci != edge and not hadTLS:
+                    if stopOnTLS and ci._tls and ci != edge and not stop:
                         ret.append([ie[0], ie[1], prev, True])
-                        hadTLS = True
+                        stop = True
+                    elif (stopOnTurnaround and ie[0]._incoming[ci][0].getDirection() == Connection.LINKDIR_TURN and
+                          not stop):
+                        ret.append([ie[0], ie[1], prev, True])
+                        stop = True
                     else:
                         prev.append(ie[0])
                         mn.append([ci, ie[0].getLength() + ie[1], prev])
-            if not hadTLS:
+            if not stop:
                 toProc.extend(mn)
         return ret
 
     def getEdgesByOrigID(self, origID):
         if self._origIdx is None:
             self._origIdx = defaultdict(set)
-            for edge in self._edges:
-                for lane in edge.getLanes():
-                    for oID in lane.getParam("origId", "").split():
-                        self._origIdx[oID].add(edge)
+            for the_edge in self._edges:
+                for the_lane in the_edge.getLanes():
+                    for oID in the_lane.getParam("origId", "").split():
+                        self._origIdx[oID].add(the_edge)
         return self._origIdx[origID]
 
     def getBBoxXY(self):
@@ -398,6 +448,35 @@ class Net:
                             for p in l.getShape3D()]
             e.rebuildShape()
 
+    def getShortestPath(self, fromEdge, toEdge, maxCost=1e400):
+        q = [(0, fromEdge.getID(), fromEdge, ())]
+        seen = set()
+        dist = {fromEdge: fromEdge.getLength()}
+        while q:
+            cost, _, e1, path = heapq.heappop(q)
+            if e1 in seen:
+                continue
+            seen.add(e1)
+            path += (e1,)
+            if e1 == toEdge:
+                return path, cost
+            if cost > maxCost:
+                return None, cost
+            for e2, conn in e1.getOutgoing().items():
+                if e2 not in seen:
+                    newCost = cost + e2.getLength()
+                    if self.hasInternal:
+                        minInternalCost = 1e400
+                        for c in conn:
+                            if c.getViaLaneID() is not None:
+                                minInternalCost = min(minInternalCost, self.getLane(c.getViaLaneID()).getLength())
+                        if minInternalCost < 1e400:
+                            newCost += minInternalCost
+                    if e2 not in dist or newCost < dist[e2]:
+                        dist[e2] = newCost
+                        heapq.heappush(q, (newCost, e2.getID(), e2, path))
+        return None, 1e400
+
 
 class NetReader(handler.ContentHandler):
 
@@ -414,7 +493,11 @@ class NetReader(handler.ContentHandler):
             self._withPhases = True
         self._withConnections = others.get('withConnections', True)
         self._withFoes = others.get('withFoes', True)
-        self._withInternal = others.get('withInternal', False)
+        self._withPedestrianConnections = others.get('withPedestrianConnections', False)
+        self._withInternal = others.get('withInternal', self._withPedestrianConnections)
+        if self._withPedestrianConnections and not self._withInternal:
+            sys.stderr.write("Warning: Option withPedestrianConnections requires withInternal\n")
+            self._withInternal = True
 
     def startElement(self, name, attrs):
         if name == 'location':
@@ -450,9 +533,12 @@ class NetReader(handler.ContentHandler):
                 self._currentEdge,
                 float(attrs['speed']),
                 float(attrs['length']),
+                float(attrs.get('width', 3.2)),
                 attrs.get('allow'),
                 attrs.get('disallow'))
             self._currentLane.setShape(convertShape(attrs.get('shape', '')))
+        if name == 'neigh' and self._currentLane is not None:
+            self._currentLane.setNeigh(attrs['lane'])
         if name == 'junction':
             if attrs['id'][0] != ':':
                 intLanes = None
@@ -460,7 +546,8 @@ class NetReader(handler.ContentHandler):
                     intLanes = attrs["intLanes"].split(" ")
                 self._currentNode = self._net.addNode(attrs['id'], attrs['type'],
                                                       tuple(
-                                                          map(float, [attrs['x'], attrs['y'], attrs['z'] if 'z' in attrs else '0'])),
+                                                          map(float, [attrs['x'], attrs['y'],
+                                                                      attrs['z'] if 'z' in attrs else '0'])),
                                                       attrs['incLanes'].split(" "), intLanes)
                 self._currentNode.setShape(
                     convertShape(attrs.get('shape', '')))
@@ -498,8 +585,8 @@ class NetReader(handler.ContentHandler):
         if name == 'connection' and self._withConnections and (attrs['from'][0] != ":" or self._withInternal):
             fromEdgeID = attrs['from']
             toEdgeID = attrs['to']
-            if not (fromEdgeID in self._net._crossings_and_walkingAreas or toEdgeID in
-                    self._net._crossings_and_walkingAreas):
+            if self._withPedestrianConnections or not (fromEdgeID in self._net._crossings_and_walkingAreas or toEdgeID in
+                                                       self._net._crossings_and_walkingAreas):
                 fromEdge = self._net.getEdge(fromEdgeID)
                 toEdge = self._net.getEdge(toEdgeID)
                 fromLane = fromEdge.getLane(int(attrs['fromLane']))
@@ -537,7 +624,11 @@ class NetReader(handler.ContentHandler):
                 attrs['id'], attrs['programID'], float(attrs['offset']), attrs['type'], self._latestProgram)
         if self._withPhases and name == 'phase':
             self._currentProgram.addPhase(
-                attrs['state'], int(attrs['duration']))
+                attrs['state'], int(attrs['duration']),
+                int(attrs['minDur']) if 'minDur' in attrs else -1,
+                int(attrs['maxDur']) if 'maxDur' in attrs else -1,
+                int(attrs['next']) if 'next' in attrs else -1
+            )
         if name == 'roundabout':
             self._net.addRoundabout(
                 attrs['nodes'].split(), attrs['edges'].split())
@@ -583,14 +674,19 @@ def convertShape(shapeString):
 
 
 def readNet(filename, **others):
+    """ load a .net.xml file
+    The following named options are supported:
+
+        'net' : initialize data structurs with an existing net object (default Net())
+        'withPrograms' : import all traffic light programs (default False)
+        'withLatestPrograms' : import only the last program for each traffic light.
+                               This is the program that would be active in sumo by default.
+                               (default False)
+        'withConnections' : import all connections (default True)
+        'withFoes' : import right-of-way information (default True)
+        'withInternal' : import internal edges and lanes (default False)
+        'withPedestrianConnections' : import connections between sidewalks, crossings (default False)
+    """
     netreader = NetReader(**others)
-    try:
-        if not os.path.isfile(filename):
-            print("Network file '%s' not found" % filename, file=sys.stderr)
-            sys.exit(1)
-        parse(filename, netreader)
-    except None:
-        print(
-            "Please mind that the network format has changed in 0.13.0, you may need to update your network!", file=sys.stderr)
-        sys.exit(1)
+    parse(filename, netreader)
     return netreader.getNet()
