@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2011-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    edge.py
 # @author  Daniel Krajzewicz
@@ -93,6 +94,10 @@ class Edge:
     def getOutgoing(self):
         return self._outgoing
 
+    def getConnections(self, toEdge):
+        """Returns all connections to the given target edge"""
+        return self._outgoing.get(toEdge, [])
+
     def getRawShape(self):
         """Return the shape that was used in netconvert for building this edge (2D)."""
         if self._shape is None:
@@ -179,11 +184,14 @@ class Edge:
                 self._shape3D.append(
                     (x / float(numLanes), y / float(numLanes), z / float(numLanes)))
 
-        self._shapeWithJunctions3D = addJunctionPos(self._shape3D,
-                                                    self._from.getCoord3D(), self._to.getCoord3D())
-
-        if self._rawShape3D == []:
-            self._rawShape3D = [self._from.getCoord3D(), self._to.getCoord3D()]
+        if self._function in ["crossing", "walkingarea"]:
+            self._shapeWithJunctions3D = self._shape3D
+            self._rawShape3D = self._shape3D
+        else:
+            self._shapeWithJunctions3D = addJunctionPos(self._shape3D,
+                                                        self._from.getCoord3D(), self._to.getCoord3D())
+            if self._rawShape3D == []:
+                self._rawShape3D = [self._from.getCoord3D(), self._to.getCoord3D()]
 
         # 2d - versions
         self._shape = [(x, y) for x, y, z in self._shape3D]
@@ -215,7 +223,7 @@ class Edge:
     def allows(self, vClass):
         """true if this edge has a lane which allows the given vehicle class"""
         for lane in self._lanes:
-            if vClass in lane._allowed:
+            if lane.allows(vClass):
                 return True
         return False
 
