@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    __init__.py
 # @author  Daniel Krajzewicz
@@ -12,9 +13,9 @@
 # @version $Id$
 
 from __future__ import absolute_import
-from . import network
-from . import demand
-from . import cross
-from . import straight
-from . import grid
-from . import corridor
+from . import network  # noqa
+from . import demand  # noqa
+from . import cross  # noqa
+from . import straight  # noqa
+from . import grid  # noqa
+from . import corridor  # noqa
