@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    cross.py
 # @author  Daniel Krajzewicz
@@ -12,14 +13,7 @@
 # @version $Id$
 
 from __future__ import absolute_import
-import os
-import sys
-sys.path.append(
-    os.path.join(os.path.dirname(__file__), '..', '..', '..', '..', 'tools'))
-sys.path.append(os.path.join(os.environ.get("SUMO_HOME", os.path.join(
-    os.path.dirname(__file__), '..', '..', '..', '..')), 'tools'))
-
-from . import network
+from . import network  # noqa
 
 
 def cross(defaultNode=None, defaultEdge=None, centralReservation=0):
@@ -35,6 +29,7 @@ def cross(defaultNode=None, defaultEdge=None, centralReservation=0):
     net.connectNodes("1/2", "1/1", True, centralReservation)
     return net
 
+
 if __name__ == "__main__":
     net = cross()
     net.build()
