@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    demand.py
 # @author  Daniel Krajzewicz
@@ -144,7 +145,6 @@ class Demand:
 
     def build(self, b, e, netName="net.net.xml", routesName="input_routes.rou.xml", sampleFactor=None):
         vehicles = []
-        running = 0
         for s in self.streams:
             vehicles.extend(s.toVehicles(b, e, len(vehicles), sampleFactor))
         fdo = tempfile.NamedTemporaryFile(mode="w", delete=False)
@@ -166,6 +166,6 @@ class Demand:
         print("routesName > %s" % routesName)
         # aeh, implicitly setting --no-warnings is not nice, is it?; and the
         # need to dump generated vtypes to a temporary file as well
-        retCode = subprocess.call([duarouter, "-v", "-n", netName, "-t", fdo.name, "-o", routesName,
-                                   "--no-warnings", "--additional-files", "vtypes.add.xml", "--vtype-output", "tmp.add.xml"])
+        subprocess.call([duarouter, "-v", "-n", netName, "-t", fdo.name, "-o", routesName,
+                         "--no-warnings", "--additional-files", "vtypes.add.xml", "--vtype-output", "tmp.add.xml"])
         os.remove(fdo.name)
