@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    grid.py
 # @author  Daniel Krajzewicz
@@ -19,7 +20,7 @@ sys.path.append(
 sys.path.append(os.path.join(os.environ.get("SUMO_HOME", os.path.join(
     os.path.dirname(__file__), '..', '..', '..', '..')), 'tools'))
 
-from . import network
+from . import network  # noqa
 
 
 def grid(numIntersectionsX=10, numIntersectionsY=5, defaultNode=None, defaultEdge=None, centralReservation=0):
@@ -55,6 +56,7 @@ def grid(numIntersectionsX=10, numIntersectionsY=5, defaultNode=None, defaultEdg
 #  d.addStream(demand.Stream("1/0_to_1/2", 10, "1/0 1/2"))
 #  d.build(3600)
 
+
 if __name__ == "__main__":
     net = grid()
     net.build()
