@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    network.py
 # @author  Daniel Krajzewicz
@@ -90,8 +91,6 @@ class Edge:
         ret = []
 
         seen = {}
-        seenRight = 0
-        seenLeft = 0
         for i, l in enumerate(self.lanes):
             for d in l.dirs:
                 if d not in seen:
@@ -241,8 +240,7 @@ class Net:
             print('    <edge id="%s" from="%s" to="%s" numLanes="%s" speed="%s">' % (
                 e.eid, e.fromNode.nid, e.toNode.nid, e.numLanes, e.maxSpeed), file=edgesFile)
             for s in e.splits:
-                print('        <split pos="%s" lanes="%s"/>' % (-s.distance, str(
-                    s.lanes)[1:-1].replace(",", "")), file=edgesFile)
+                print('        <split pos="%s" lanes="%s"/>' % (-s.distance, " ".join(map(str, s.lanes))), file=edgesFile)
 
             """
         for i,l in enumerate(e.lanes):
@@ -305,8 +303,8 @@ class Net:
 
         netconvert = sumolib.checkBinary("netconvert")
 
-        retCode = subprocess.call(
-            [netconvert, "-v", "-n", nodesFile.name, "-e", edgesFile.name, "-x", connectionsFile.name, "-o", netName])
+        subprocess.call([netconvert, "-v", "-n", nodesFile.name, "-e", edgesFile.name, "-x", connectionsFile.name,
+                         "-o", netName])
         os.remove(nodesFile.name)
         os.remove(edgesFile.name)
         os.remove(connectionsFile.name)
