@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2011-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    node.py
 # @author  Daniel Krajzewicz
@@ -15,7 +16,6 @@
 # @version $Id$
 
 
-
 class Node:
 
     """ Nodes from a sumo network """
@@ -97,12 +97,15 @@ class Node:
     def getLinkIndex(self, conn):
         ret = 0
         for lane_id in self._incLanes:
-            (edge_id, index) = lane_id.split("_")
-            edge = [e for e in self._incoming if e.getID() == edge_id][0]
-            for candidate_conn in edge.getLane(int(index)).getOutgoing():
-                if candidate_conn == conn:
-                    return ret
-                ret += 1
+            lastUnderscore = lane_id.rfind("_")
+            if lastUnderscore > 0:
+                edge_id = lane_id[:lastUnderscore]
+                index = lane_id[lastUnderscore+1:]
+                edge = [e for e in self._incoming if e.getID() == edge_id][0]
+                for candidate_conn in edge.getLane(int(index)).getOutgoing():
+                    if candidate_conn == conn:
+                        return ret
+                    ret += 1
         return -1
 
     def forbids(self, possProhibitor, possProhibited):
@@ -123,18 +126,30 @@ class Node:
         return self._type
 
     def getConnections(self, source=None, target=None):
-        incoming = list(self.getIncoming())
         if source:
             incoming = [source]
+        else:
+            incoming = list(self._incoming)
         conns = []
         for e in incoming:
-            for l in e.getLanes():
+            if (hasattr(e, "getLanes")):
+                lanes = e.getLanes()
+            else:
+                # assuming source is a lane
+                lanes = [e]
+            for l in lanes:
                 all_outgoing = l.getOutgoing()
                 outgoing = []
                 if target:
-                    for o in all_outgoing:
-                        if o.getTo() == target:
-                            outgoing.append(o)
+                    if hasattr(target, "getLanes"):
+                        for o in all_outgoing:
+                            if o.getTo() == target:
+                                outgoing.append(o)
+                    else:
+                        # assuming target is a lane
+                        for o in all_outgoing:
+                            if o.getToLane() == target:
+                                outgoing.append(o)
                 else:
                     outgoing = all_outgoing
                 conns.extend(outgoing)
