@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2011-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    __init__.py
 # @author  Michael Behrisch
@@ -16,8 +17,8 @@ from __future__ import print_function
 from __future__ import absolute_import
 from xml.sax import make_parser
 from xml.sax.handler import ContentHandler
-from . import dump, inductionloop, convert
-from sumolib.xml import *
+from . import dump, inductionloop, convert  # noqa
+from sumolib.xml import *  # noqa
 
 
 class AbstractHandler__byID(ContentHandler):
@@ -57,13 +58,13 @@ class AbstractHandler__asList(ContentHandler):
             for a in self._attributes:
                 try:
                     tmp[a] = float(attrs[a])
-                except:
+                except ValueError:
                     tmp[a] = attrs[a]
         else:
             for a in attrs.keys():
                 try:
                     tmp[a] = float(attrs[a])
-                except:
+                except ValueError:
                     tmp[a] = attrs[a]
         self._values.append(tmp)
 
