@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    gpsdat.py
 # @author  Daniel Krajzewicz
@@ -18,7 +19,7 @@ csv data files used by dlr-fcd processing chain
 from __future__ import print_function
 from __future__ import absolute_import
 import datetime
-import sumolib.output
+import sumolib.output  # noqa
 
 TAXI_STATUS_FREE_FLOW = "70"
 
