@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    ns2.py
 # @author  Daniel Krajzewicz
@@ -108,7 +109,7 @@ def _writeMissing(t, vIDm, seen, vehInfo, removed):
     for v in vIDm._m:
         if v in seen:
             continue
-        nid = vIDm.g(v)
+        vIDm.g(v)
         vehInfo[v][2] = t
         toDel.append(v)
         removed.add(v)
