@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2012-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    checkFlows.py
 # @author  Daniel Krajzewicz
@@ -14,7 +15,7 @@
 from __future__ import absolute_import
 import sys
 import sumolib.output
-from pylab import *
+from pylab import legend, plot, show
 
 
 f = {}
