@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2012-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    basic_crossl.py
 # @author  Daniel Krajzewicz
@@ -14,11 +15,11 @@
 from __future__ import absolute_import
 from __future__ import print_function
 
-from . import *
+from . import fileNeedsRebuild, Scenario
 import os
 import sumolib.net.generator.cross as netGenerator
 import sumolib.net.generator.demand as demandGenerator
-from sumolib.net.generator.network import *
+from sumolib.net.generator.network import Edge, Lane
 
 
 class Scenario_BasicCrossL(Scenario):
