@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2012-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    rilsa1.py
 # @author  Daniel Krajzewicz
@@ -11,14 +12,14 @@
 # @version $Id$
 
 
-
 from __future__ import absolute_import
 
 
-from . import *
+from . import fileNeedsRebuild, Scenario
 import os
+import subprocess
 import sumolib.net.generator.demand as demandGenerator
-from sumolib.net.generator.network import *
+import sumolib
 
 
 flowsRiLSA1 = [
@@ -62,8 +63,7 @@ class Scenario_RiLSA1(Scenario):
         # network
         if fileNeedsRebuild(self.netName, "netconvert"):
             netconvert = sumolib.checkBinary("netconvert")
-            retCode = subprocess.call(
-                [netconvert, "-c", os.path.join(self.THIS_DIR, "build.netc.cfg")])
+            subprocess.call([netconvert, "-c", os.path.join(self.THIS_DIR, "build.netc.cfg")])
         # build the demand model (streams)
         if withDefaultDemand:
             self.demand = demandGenerator.Demand()
