@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2012-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    rilsa1_out_tls24.py
 # @author  Daniel Krajzewicz
@@ -14,11 +15,12 @@
 from __future__ import absolute_import
 
 
-from . import *
+from . import fileNeedsRebuild, Scenario
 import os
 import shutil
+import subprocess
 import sumolib.net.generator.demand as demandGenerator
-from sumolib.net.generator.network import *
+import sumolib
 
 
 flowsRiLSA1 = [
@@ -63,8 +65,7 @@ class Scenario_RiLSA1OutTLS24(Scenario):
         # network
         if fileNeedsRebuild(os.path.join(self.THIS_DIR, self.NET_FILE), "netconvert"):
             netconvert = sumolib.checkBinary("netconvert")
-            retCode = subprocess.call(
-                [netconvert, "-c", os.path.join(self.THIS_DIR, "build.netc.cfg")])
+            subprocess.call([netconvert, "-c", os.path.join(self.THIS_DIR, "build.netc.cfg")])
         # build the demand model (streams)
         if withDefaultDemand:
             self.demand = demandGenerator.Demand()
@@ -79,7 +80,10 @@ class Scenario_RiLSA1OutTLS24(Scenario):
                     lkwNprob = prob - lkwEprob
 
                     self.demand.addStream(demandGenerator.Stream(f[0] + "__" + rel[0], 0, 3600, rel[1], f[0], rel[0],
-                                                                 {"passenger": pkwEprob, "COLOMBO_undetectable_passenger": pkwNprob, "hdv": lkwEprob, "COLOMBO_undetectable_hdv": lkwNprob}))
+                                                                 {"passenger": pkwEprob,
+                                                                  "COLOMBO_undetectable_passenger": pkwNprob,
+                                                                  "hdv": lkwEprob,
+                                                                  "COLOMBO_undetectable_hdv": lkwNprob}))
             if fileNeedsRebuild(self.fullPath("routes.rou.xml"), "duarouter"):
                 self.demand.build(
                     0, 3600, self.fullPath(self.NET_FILE), self.fullPath("routes.rou.xml"))
