@@ -1,9 +1,10 @@
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2012-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2012-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    polygon.py
 # @author  Daniel Krajzewicz
@@ -92,7 +93,7 @@ class PolygonReader(handler.ContentHandler):
                 poly = Polygon(attrs['id'], attrs['type'], c, float(
                                attrs['layer']), attrs['fill'], cshape)
             else:
-                poly = Polygon(attrs['id'], shape=cshape)
+                poly = Polygon(attrs['id'], color=attrs.get('color'), shape=cshape)
             self._id2poly[poly.id] = poly
             self._polys.append(poly)
             self._lastPoly = poly
