@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2011-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    xml.py
 # @author  Michael Behrisch
@@ -16,10 +17,16 @@ from __future__ import print_function
 from __future__ import absolute_import
 import sys
 import re
-import xml.etree.cElementTree as ET
+import datetime
+try:
+    import xml.etree.cElementTree as ET
+except ImportError as e:
+    print("recovering from ImportError '%s'" % e)
+    import xml.etree.ElementTree as ET
 from collections import namedtuple, OrderedDict
 from keyword import iskeyword
 from functools import reduce
+import xml.sax.saxutils
 
 
 def _prefix_keyword(name, warn=False):
@@ -54,11 +61,12 @@ def compound_object(element_name, attrnames, warn=False):
         _original_fields = sorted(attrnames)
         _fields = [_prefix_keyword(a, warn) for a in _original_fields]
 
-        def __init__(self, values, child_dict):
+        def __init__(self, values, child_dict, text=None):
             for name, val in zip(self._fields, values):
                 self.__dict__[name] = val
             self._child_dict = child_dict
             self.name = element_name
+            self._text = text
 
         def getAttributes(self):
             return [(k, getattr(self, k)) for k in self._fields]
@@ -93,6 +101,12 @@ def compound_object(element_name, attrnames, warn=False):
             self._child_dict.setdefault(name, []).append(child)
             return child
 
+        def getText(self):
+            return self._text
+
+        def setText(self, text):
+            self._text = text
+
         def __getattr__(self, name):
             if name[:2] != "__":
                 return self._child_dict.get(name, None)
@@ -117,14 +131,15 @@ def compound_object(element_name, attrnames, warn=False):
             return self._child_dict[name]
 
         def __str__(self):
-            return "<%s,child_dict=%s>" % (self.getAttributes(), dict(self._child_dict))
+            nodeText = '' if self._text is None else ",text=%s" % self._text
+            return "<%s,child_dict=%s%s>" % (self.getAttributes(), dict(self._child_dict), nodeText)
 
         def toXML(self, initialIndent="", indent="    "):
-            fields = ['%s="%s"' % (self._original_fields[i], str(getattr(self, k)))
-                      for i, k in enumerate(self._fields) if getattr(self, k) is not None 
+            fields = ['%s="%s"' % (self._original_fields[i], str_possibly_unicode(getattr(self, k)))
+                      for i, k in enumerate(self._fields) if getattr(self, k) is not None and
                       # see #3454
-                      and not '{' in self._original_fields[i]]
-            if not self._child_dict:
+                      '{' not in self._original_fields[i]]
+            if not self._child_dict and self._text is None:
                 return "%s<%s %s/>\n" % (initialIndent, element_name, " ".join(fields))
             else:
                 s = "%s<%s %s>\n" % (
@@ -132,6 +147,8 @@ def compound_object(element_name, attrnames, warn=False):
                 for l in self._child_dict.values():
                     for c in l:
                         s += c.toXML(initialIndent + indent)
+                if self._text is not None:
+                    s += self._text.strip()
                 return s + "%s</%s>\n" % (initialIndent, element_name)
 
         def __repr__(self):
@@ -140,6 +157,14 @@ def compound_object(element_name, attrnames, warn=False):
     return CompoundObject
 
 
+def str_possibly_unicode(val):
+    # there is probably a better way to do this
+    try:
+        return str(val)
+    except UnicodeEncodeError:
+        return val.encode('utf8')
+
+
 def parse(xmlfile, element_names, element_attrs={}, attr_conversions={},
           heterogeneous=False, warn=False):
     """
@@ -177,7 +202,10 @@ def parse(xmlfile, element_names, element_attrs={}, attr_conversions={},
 
 
 _NO_CHILDREN = {}
-_IDENTITY = lambda x: x
+
+
+def _IDENTITY(x):
+    return x
 
 
 def _get_compound_object(node, elementTypes, element_name, element_attrs, attr_conversions, heterogeneous, warn):
@@ -201,7 +229,7 @@ def _get_compound_object(node, elementTypes, element_name, element_attrs, attr_c
     attrnames = elementTypes[element_name]._original_fields
     return elementTypes[element_name](
         [attr_conversions.get(a, _IDENTITY)(node.get(a)) for a in attrnames],
-        child_dict)
+        child_dict, node.text)
 
 
 def create_document(root_element_name, attrs=None, schema=None):
@@ -229,13 +257,7 @@ def average(elements, attrname):
         raise Exception("average of 0 elements is not defined")
 
 
-def parse_fast(xmlfile, element_name, attrnames, warn=False, optional=False):
-    """
-    Parses the given attrnames from all elements with element_name
-    @Note: The element must be on its own line and the attributes must appear in
-    the given order.
-    @Example: parse_fast('plain.edg.xml', 'edge', ['id', 'speed'])
-    """
+def _createRecordAndPattern(element_name, attrnames, warn, optional):
     prefixedAttrnames = [_prefix_keyword(a, warn) for a in attrnames]
     if optional:
         pattern = ''.join(['<%s' % element_name] +
@@ -243,8 +265,19 @@ def parse_fast(xmlfile, element_name, attrnames, warn=False, optional=False):
     else:
         pattern = '.*'.join(['<%s' % element_name] +
                             ['%s="([^"]*)"' % attr for attr in attrnames])
-    Record = namedtuple(element_name, prefixedAttrnames)
+    Record = namedtuple(_prefix_keyword(element_name, warn), prefixedAttrnames)
     reprog = re.compile(pattern)
+    return Record, reprog
+
+
+def parse_fast(xmlfile, element_name, attrnames, warn=False, optional=False):
+    """
+    Parses the given attrnames from all elements with element_name
+    @Note: The element must be on its own line and the attributes must appear in
+    the given order.
+    @Example: parse_fast('plain.edg.xml', 'edge', ['id', 'speed'])
+    """
+    Record, reprog = _createRecordAndPattern(element_name, attrnames, warn, optional)
     for line in open(xmlfile):
         m = reprog.search(line)
         if m:
@@ -252,3 +285,50 @@ def parse_fast(xmlfile, element_name, attrnames, warn=False, optional=False):
                 yield Record(**m.groupdict())
             else:
                 yield Record(*m.groups())
+
+
+def parse_fast_nested(xmlfile, element_name, attrnames, element_name2, attrnames2, warn=False, optional=False):
+    """
+    Parses the given attrnames from all elements with element_name
+    And attrnames2 from element_name2 where element_name2 is a child element of element_name
+    @Note: The element must be on its own line and the attributes must appear in
+    the given order.
+    @Example: parse_fast_nested('fcd.xml', 'timestep', ['time'], 'vehicle', ['id', 'speed', 'lane']):
+    """
+    Record, reprog = _createRecordAndPattern(element_name, attrnames, warn, optional)
+    Record2, reprog2 = _createRecordAndPattern(element_name2, attrnames2, warn, optional)
+    record = None
+    for line in open(xmlfile):
+        m2 = reprog2.search(line)
+        if m2:
+            if optional:
+                yield record, Record2(**m2.groupdict())
+            else:
+                yield record, Record2(*m2.groups())
+        else:
+            m = reprog.search(line)
+            if m:
+                if optional:
+                    record = Record(**m.groupdict())
+                else:
+                    record = Record(*m.groups())
+
+
+def writeHeader(outf, script, root=None, schemaPath=None):
+    outf.write("""<?xml version="1.0" encoding="UTF-8"?>
+<!-- generated on %s by %s
+  options: %s
+-->
+""" % (datetime.datetime.now(), script,
+       (' '.join(sys.argv[1:]).replace('--', '<doubleminus>'))))
+    if root is not None:
+        if schemaPath is None:
+            schemaPath = root + "_file.xsd"
+        outf.write(('<%s xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" ' +
+                    'xsi:noNamespaceSchemaLocation="http://sumo.dlr.de/xsd/%s">\n') % (root, schemaPath))
+
+
+def quoteattr(val):
+    # saxutils sometimes uses single quotes around the attribute
+    # we can prevent this by adding an artificial single quote to the value and removing it again
+    return '"' + xml.sax.saxutils.quoteattr("'" + val)[2:]
