@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2011-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    _inductionloop.py
 # @author  Michael Behrisch
@@ -33,9 +34,10 @@ def readVehicleData(result):
         leaveTime = result.readDouble()
         result.read("!B")
         typeID = result.readString()
-        data.append([vehID, length, entryTime, leaveTime, typeID])
+        data.append((vehID, length, entryTime, leaveTime, typeID))
     return data
 
+
 _RETURN_VALUE_FUNC = {tc.VAR_POSITION: Storage.readDouble,
                       tc.VAR_LANE_ID: Storage.readString,
                       tc.LAST_STEP_VEHICLE_NUMBER: Storage.readInt,
