@@ -1,23 +1,19 @@
 # -*- coding: utf-8 -*-
-"""
-@file    junction.py
-@author  Michael Behrisch
-@author  Mario Krumnow
-@author  Jakob Erdmann
-@date    2011-03-17
-@version $Id: _junction.py 23179 2017-03-02 08:32:15Z behrisch $
+# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+# Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
+# This program and the accompanying materials
+# are made available under the terms of the Eclipse Public License v2.0
+# which accompanies this distribution, and is available at
+# http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
-Python implementation of the TraCI interface.
+# @file    _junction.py
+# @author  Michael Behrisch
+# @author  Mario Krumnow
+# @author  Jakob Erdmann
+# @date    2011-03-17
+# @version $Id$
 
-SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2011-2017 DLR (http://www.dlr.de/) and contributors
-
-This file is part of SUMO.
-SUMO is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 3 of the License, or
-(at your option) any later version.
-"""
 from __future__ import absolute_import
 from .domain import Domain
 from .storage import Storage
