@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2011-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    _person.py
 # @author  Jakob Erdmann
@@ -18,10 +19,11 @@ from .storage import Storage
 from . import constants as tc
 
 
-_RETURN_VALUE_FUNC = {tc.ID_LIST: Storage.readStringList,
+_RETURN_VALUE_FUNC = {tc.TRACI_ID_LIST: Storage.readStringList,
                       tc.ID_COUNT: Storage.readInt,
                       tc.VAR_SPEED: Storage.readDouble,
                       tc.VAR_POSITION: lambda result: result.read("!dd"),
+                      tc.VAR_POSITION3D: lambda result: result.read("!ddd"),
                       tc.VAR_ANGLE: Storage.readDouble,
                       tc.VAR_ROAD_ID: Storage.readString,
                       tc.VAR_TYPE: Storage.readString,
@@ -41,8 +43,6 @@ _RETURN_VALUE_FUNC = {tc.ID_LIST: Storage.readStringList,
 
 
 class PersonDomain(Domain):
-    DEPART_NOW = -3
-
     def __init__(self):
         Domain.__init__(self, "person", tc.CMD_GET_PERSON_VARIABLE, tc.CMD_SET_PERSON_VARIABLE,
                         tc.CMD_SUBSCRIBE_PERSON_VARIABLE, tc.RESPONSE_SUBSCRIBE_PERSON_VARIABLE,
@@ -201,20 +201,18 @@ class PersonDomain(Domain):
             self.removeStage(personID, 1)
         self.removeStage(personID, 0)
 
-    def add(self, personID, edgeID, pos, depart=DEPART_NOW, typeID="DEFAULT_PEDTYPE"):
-        """add(string, string, double, int, string)
+    def add(self, personID, edgeID, pos, depart=tc.DEPARTFLAG_NOW, typeID="DEFAULT_PEDTYPE"):
+        """add(string, string, double, double, string)
         Inserts a new person to the simulation at the given edge, position and
         time (in s). This function should be followed by appending Stages or the person
-        will immediatly vanish on departure.
+        will immediately vanish on departure.
         """
-        if depart > 0:
-            depart *= 1000
         self._connection._beginMessage(tc.CMD_SET_PERSON_VARIABLE, tc.ADD, personID,
-                                       1 + 4 + 1 + 4 + len(typeID) + 1 + 4 + len(edgeID) + 1 + 4 + 1 + 8)
+                                       1 + 4 + 1 + 4 + len(typeID) + 1 + 4 + len(edgeID) + 1 + 8 + 1 + 8)
         self._connection._string += struct.pack("!Bi", tc.TYPE_COMPOUND, 4)
         self._connection._packString(typeID)
         self._connection._packString(edgeID)
-        self._connection._string += struct.pack("!Bi", tc.TYPE_INTEGER, depart)
+        self._connection._string += struct.pack("!Bd", tc.TYPE_DOUBLE, depart)
         self._connection._string += struct.pack("!Bd", tc.TYPE_DOUBLE, pos)
         self._connection._sendExact()
 
@@ -241,13 +239,14 @@ class PersonDomain(Domain):
     def appendWalkingStage(self, personID, edges, arrivalPos, duration=-1, speed=-1, stopID=""):
         """appendWalkingStage(string, stringList, double, int, double, string)
         Appends a walking stage to the plan of the given person
-        The walking speed can either be specified, computed from the duration parameter (in s) or taken from the type of the person
+        The walking speed can either be specified, computed from the duration parameter (in s) or taken from the
+        type of the person
         """
         if duration is not None:
             duration *= 1000
 
         if isinstance(edges, str):
-            edges = [edgeList]
+            edges = [edges]
         self._connection._beginMessage(tc.CMD_SET_PERSON_VARIABLE, tc.APPEND_STAGE, personID,
                                        1 + 4 +  # compound
                                        1 + 4 +  # stageType
@@ -380,14 +379,14 @@ class PersonDomain(Domain):
 
     def setColor(self, personID, color):
         """setColor(string, (integer, integer, integer, integer))
-        sets color for person with the given ID.
-        i.e. (255,0,0,0) for the color red.
-        The fourth integer (alpha) is only used when drawing persons with raster images
+
+        Sets the color for the vehicle with the given ID, i.e. (255,0,0) for the color red.
+        The fourth component (alpha) is optional.
         """
         self._connection._beginMessage(
             tc.CMD_SET_PERSON_VARIABLE, tc.VAR_COLOR, personID, 1 + 1 + 1 + 1 + 1)
-        self._connection._string += struct.pack("!BBBBB", tc.TYPE_COLOR, int(
-            color[0]), int(color[1]), int(color[2]), int(color[3]))
+        self._connection._string += struct.pack("!BBBBB", tc.TYPE_COLOR, int(color[0]), int(color[1]), int(color[2]),
+                                                int(color[3]) if len(color) > 3 else 255)
         self._connection._sendExact()
 
 
