@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    domain.py
 # @author  Michael Behrisch
@@ -86,7 +87,7 @@ class Domain:
         self._subscribeResponseID = subscribeResponseID
         self._contextID = contextID
         self._contextResponseID = contextResponseID
-        self._retValFunc = {tc.ID_LIST: Storage.readStringList,
+        self._retValFunc = {tc.TRACI_ID_LIST: Storage.readStringList,
                             tc.ID_COUNT: Storage.readInt}
         self._retValFunc.update(retValFunc)
         self._deprecatedFor = deprecatedFor
@@ -119,7 +120,7 @@ class Domain:
 
         Returns a list of all objects in the network.
         """
-        return self._getUniversal(tc.ID_LIST, "")
+        return self._getUniversal(tc.TRACI_ID_LIST, "")
 
     def getIDCount(self):
         """getIDCount() -> integer
@@ -128,7 +129,7 @@ class Domain:
         """
         return self._getUniversal(tc.ID_COUNT, "")
 
-    def subscribe(self, objectID, varIDs=None, begin=0, end=2**31 - 1):
+    def subscribe(self, objectID, varIDs=None, begin=tc.INVALID_DOUBLE_VALUE, end=tc.INVALID_DOUBLE_VALUE):
         """subscribe(string, list(integer), double, double) -> None
 
         Subscribe to one or more object values for the given interval.
@@ -137,7 +138,7 @@ class Domain:
             if tc.LAST_STEP_VEHICLE_NUMBER in self._retValFunc:
                 varIDs = (tc.LAST_STEP_VEHICLE_NUMBER,)
             else:
-                varIDs = (tc.ID_LIST,)
+                varIDs = (tc.TRACI_ID_LIST,)
         self._connection._subscribe(
             self._subscribeID, begin, end, objectID, varIDs)
 
@@ -147,13 +148,12 @@ class Domain:
         Unsubscribe from receiving object values.
         """
         self._connection._subscribe(
-            self._subscribeID, 0, 2**31 - 1, objectID, [])
+            self._subscribeID, tc.INVALID_DOUBLE_VALUE, tc.INVALID_DOUBLE_VALUE, objectID, [])
 
-    def getSubscriptionResults(self, objectID=None):
+    def getSubscriptionResults(self, objectID):
         """getSubscriptionResults(string) -> dict(integer: <value_type>)
 
         Returns the subscription results for the last time step and the given object.
-        If no object id is given, all subscription results are returned in a dict.
         If the object id is unknown or the subscription did for any reason return no data,
         'None' is returned.
         It is not possible to retrieve older subscription results than the ones
@@ -161,7 +161,16 @@ class Domain:
         """
         return self._connection._getSubscriptionResults(self._subscribeResponseID).get(objectID)
 
-    def subscribeContext(self, objectID, domain, dist, varIDs=None, begin=0, end=2**31 - 1):
+    def getAllSubscriptionResults(self):
+        """getAllSubscriptionResults() -> dict(string: dict(integer: <value_type>))
+
+        Returns the subscription results for the last time step and all objects of the domain.
+        It is not possible to retrieve older subscription results than the ones
+        from the last time step.
+        """
+        return self._connection._getSubscriptionResults(self._subscribeResponseID).get(None)
+
+    def subscribeContext(self, objectID, domain, dist, varIDs=None, begin=tc.INVALID_DOUBLE_VALUE, end=tc.INVALID_DOUBLE_VALUE):
         """subscribeContext(string, int, double, list(integer), double, double) -> None
 
         Subscribe to objects of the given domain (specified as domain=traci.constants.CMD_GET_<DOMAIN>_VARIABLE),
@@ -171,17 +180,20 @@ class Domain:
             if tc.LAST_STEP_VEHICLE_NUMBER in self._retValFunc:
                 varIDs = (tc.LAST_STEP_VEHICLE_NUMBER,)
             else:
-                varIDs = (tc.ID_LIST,)
+                varIDs = (tc.TRACI_ID_LIST,)
         self._connection._subscribeContext(
             self._contextID, begin, end, objectID, domain, dist, varIDs)
 
     def unsubscribeContext(self, objectID, domain, dist):
         self._connection._subscribeContext(
-            self._contextID, 0, 2**31 - 1, objectID, domain, dist, [])
+            self._contextID, tc.INVALID_DOUBLE_VALUE, tc.INVALID_DOUBLE_VALUE, objectID, domain, dist, [])
 
-    def getContextSubscriptionResults(self, objectID=None):
+    def getContextSubscriptionResults(self, objectID):
         return self._connection._getSubscriptionResults(self._contextResponseID).getContext(objectID)
 
+    def getAllContextSubscriptionResults(self):
+        return self._connection._getSubscriptionResults(self._contextResponseID).getContext(None)
+
     def getParameter(self, objID, param):
         """getParameter(string, string) -> string
 
