@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    exceptions.py
 # @author  Michael Behrisch
@@ -23,7 +24,7 @@ class TraCIException(Exception):
 
     """Exception class for all TraCI errors which keep the connection intact"""
 
-    def __init__(self, command, errorType, desc):
+    def __init__(self, desc, command=None, errorType=None):
         Exception.__init__(self, desc)
         self._command = command
         self._type = errorType
