@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    csv2vss.py
 # @author  Michael Behrisch
@@ -18,7 +19,7 @@ import sys
 import collections
 from optparse import OptionParser
 sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
-import sumolib.output
+import sumolib.output  # noqa
 
 
 def parse_args():
@@ -31,7 +32,7 @@ def parse_args():
     options, args = optParser.parse_args()
     try:
         options.csvfile = args[0]
-    except:
+    except Exception:
         sys.exit(USAGE)
     if options.outfile is None:
         options.outfile = options.csvfile + ".add.xml"
@@ -53,7 +54,7 @@ def main():
                 if float(data[2]) > 0.:
                     timeline[data[0]].append(
                         (options.scale * float(data[1]), float(data[4]) / 3.6))
-            except:
+            except Exception:
                 pass
     # maybe we should sort the timeline here
     with open(options.outfile, 'w') as outf:
@@ -74,5 +75,6 @@ def main():
             outf.write('    </variableSpeedSign>\n')
         outf.write("</additional>\n")
 
+
 if __name__ == "__main__":
     main()
