@@ -1,21 +1,17 @@
 # -*- coding: utf-8 -*-
-"""
-@file    collectinghandler.py
-@author  Karol Stosiek
-@date    2011-10-26
-@version $Id: collectinghandler.py 20433 2016-04-13 08:00:14Z behrisch $
+# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+# Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
+# This program and the accompanying materials
+# are made available under the terms of the Eclipse Public License v2.0
+# which accompanies this distribution, and is available at
+# http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
-Handler for loggers from logging module. Collects all log messages.
+# @file    collectinghandler.py
+# @author  Karol Stosiek
+# @date    2011-10-26
+# @version $Id$
 
-SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-Copyright (C) 2011-2016 DLR (http://www.dlr.de/) and contributors
-
-This file is part of SUMO.
-SUMO is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 3 of the License, or
-(at your option) any later version.
-"""
 from __future__ import absolute_import
 
 import logging
