@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2011-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    connections.py
 # @author  Karol Stosiek
@@ -16,9 +17,19 @@ from __future__ import absolute_import
 
 import logging
 import unittest
+import os
+import sys
+import collectinghandler
+import xml
+
+if 'SUMO_HOME' in os.environ:
+    tools = os.path.join(os.environ['SUMO_HOME'], 'tools')
+    sys.path.append(tools)
+else:
+    sys.exit("please declare environment variable 'SUMO_HOME'")
 
 import sumolib  # noqa
-import collectinghandler
+
 
 LOGGER = logging.getLogger(__name__)
 
@@ -409,5 +420,6 @@ class ConnectionXMLTestCase(unittest.TestCase):
         self.set_up_connection_xml_without(self.DESTINATION_ATTRIBUTE)
         self.assertRaises(AttributeError, self.connection_xml.get_destination)
 
+
 if __name__ == "__main__":
     unittest.main()
