@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2011-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2011-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    generateTurnDefs.py
 # @author  Karol Stosiek
@@ -19,8 +20,8 @@ import sys
 import logging
 import optparse
 sys.path.append(os.path.join(os.environ["SUMO_HOME"], "tools"))
-import connections
-import turndefinitions
+import connections  # noqa
+import turndefinitions  # noqa
 
 LOGGER = logging.getLogger(__name__)
 
