@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2014-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2014-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    plot_csv_timeline.py
 # @author  Daniel Krajzewicz
@@ -28,16 +29,15 @@ import csv
 
 sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
 import sumolib  # noqa
-from sumolib.visualization import helpers
-
-import matplotlib.pyplot as plt
+from sumolib.visualization import helpers  # noqa
+import matplotlib.pyplot as plt  # noqa
 
 
 def readValues(file, verbose, columns):
-    if verbose:
-        print("Reading '%s'..." % f)
     ret = {}
     with open(file, 'rb') as f:
+        if verbose:
+            print("Reading '%s'..." % f)
         reader = csv.reader(f, delimiter=';')
         for row in reader:
             if columns is None:
@@ -90,5 +90,6 @@ def main(args=None):
         plt.plot(ts[0:len(v)], v, label=l, color=c)
     helpers.closeFigure(fig, ax, options)
 
+
 if __name__ == "__main__":
     sys.exit(main(sys.argv))
