@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2008-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2008-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    plot_net_dump.py
 # @author  Daniel Krajzewicz
@@ -21,16 +22,14 @@ import sys
 from xml.sax.handler import ContentHandler
 
 if 'SUMO_HOME' in os.environ:
-    tools = os.path.join(os.environ['SUMO_HOME'], 'tools')
-    sys.path.append(tools)
+    sys.path.append(os.path.join(os.environ['SUMO_HOME'], 'tools'))
 else:
     sys.exit("please declare environment variable 'SUMO_HOME'")
 
 import sumolib  # noqa
-from sumolib.visualization import helpers
-
-import matplotlib.pyplot as plt
-import matplotlib
+from sumolib.visualization import helpers  # noqa
+import matplotlib.pyplot as plt  # noqa
+import matplotlib  # noqa
 
 
 class WeightsReader(ContentHandler):
@@ -198,9 +197,9 @@ def main(args=None):
                     v = options.widthMax
                 if options.widthMin is not None and v < options.widthMin:
                     v = options.widthMin
-                if not maxWidthValue or maxWidthValue < v:
+                if maxWidthValue is None or maxWidthValue < v:
                     maxWidthValue = v
-                if not minWidthValue or minWidthValue > v:
+                if minWidthValue is None or minWidthValue > v:
                     minWidthValue = v
                 widths[e] = v
         if options.widthMax is not None:
@@ -253,5 +252,6 @@ def main(args=None):
 
     return 0
 
+
 if __name__ == "__main__":
     sys.exit(main(sys.argv))
