@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2013-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2013-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    plot_summary.py
 # @author  Daniel Krajzewicz
@@ -26,9 +27,8 @@ import sys
 
 sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
 import sumolib  # noqa
-from sumolib.visualization import helpers
-
-import matplotlib.pyplot as plt
+from sumolib.visualization import helpers  # noqa
+import matplotlib.pyplot as plt  # noqa
 
 
 def readValues(files, verbose, measure):
@@ -68,7 +68,7 @@ def main(args=None):
     times = readValues(files, options.verbose, "time")
     for f in files:
         maxV = max(maxV, len(nums[f]))
-    ts = range(minV, maxV + 1)
+    range(minV, maxV + 1)
 
     fig, ax = helpers.openFigure(options)
     for i, f in enumerate(files):
@@ -79,5 +79,6 @@ def main(args=None):
         plt.plot(t, v, label=l, color=c)
     helpers.closeFigure(fig, ax, options)
 
+
 if __name__ == "__main__":
     sys.exit(main(sys.argv))
