@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 # Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-# Copyright (C) 2009-2017 German Aerospace Center (DLR) and others.
+# Copyright (C) 2009-2018 German Aerospace Center (DLR) and others.
 # This program and the accompanying materials
 # are made available under the terms of the Eclipse Public License v2.0
 # which accompanies this distribution, and is available at
 # http://www.eclipse.org/legal/epl-v20.html
+# SPDX-License-Identifier: EPL-2.0
 
 # @file    schemaCheck.py
 # @author  Daniel Krajzewicz
@@ -62,7 +63,7 @@ def validate(root, f):
                 s = s[s.find(f.replace('\\', '/')) + len(f):]
                 print(os.path.abspath(
                     f)[len(root) + 1:].replace('\\', '/') + s, file=sys.stderr)
-    except:
+    except Exception:
         print("Error on parsing '%s'!" % os.path.abspath(
             f)[len(root) + 1:].replace('\\', '/'), file=sys.stderr)
         traceback.print_exc()
@@ -116,6 +117,7 @@ def main(srcRoot, toCheck, err):
                 return 1
     return 0
 
+
 if __name__ == "__main__":
     if os.name == "posix" and not haveLxml:
         print("neither SAX2Count nor lxml available, exiting", file=sys.stderr)
