@@ -1,13 +1,11 @@
 /****************************************************************************/
 // Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
-// Copyright (C) 2001-2017 German Aerospace Center (DLR) and others.
-/****************************************************************************/
-//
-//   This program and the accompanying materials
-//   are made available under the terms of the Eclipse Public License v2.0
-//   which accompanies this distribution, and is available at
-//   http://www.eclipse.org/legal/epl-v20.html
-//
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
 /****************************************************************************/
 /// @file    CommandMock.h
 /// @author  Matthias Heppner
@@ -34,15 +32,15 @@ class CommandMock : public Command {
 public:
     /** @brief Constructor
      */
-	CommandMock() throw(){
+	CommandMock() {
 		hasRun = false;
 	}
 
     /// @brief Destructor
-	~CommandMock() throw(){}
+	~CommandMock() {}
 
 	/** @brief Executes the command.*/
-    SUMOTime execute(SUMOTime currentTime) throw(ProcessError) {
+    SUMOTime execute(SUMOTime currentTime) {
 		hasRun = true;
 		return currentTime;
 	} 
