@@ -1,29 +1,24 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2018 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials
+// are made available under the terms of the Eclipse Public License v2.0
+// which accompanies this distribution, and is available at
+// http://www.eclipse.org/legal/epl-v20.html
+// SPDX-License-Identifier: EPL-2.0
+/****************************************************************************/
 /// @file    GeoConvHelperTest.cpp
 /// @author  Jakob Erdmann
 /// @author  Laura Bieker
 /// @date    2011-09-23
-/// @version $Id: GeoConvHelperTest.cpp 18095 2015-03-17 09:39:00Z behrisch $
+/// @version $Id$
 ///
 // Tests the class RandHelper
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2015 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
 
 #include <gtest/gtest.h>
 #include <utils/geom/GeoConvHelper.h>
 
-using namespace std;
-
 /*
 Tests the class GeoConvHelper
 */
@@ -33,11 +28,11 @@ Tests the class GeoConvHelper
 TEST(GeoConvHelper, test_method_x2cartesian) {
     GeoConvHelper gch(
             "+proj=utm +zone=33 +ellps=WGS84 +datum=WGS84 +units=m +no_defs",
-            Position(), Boundary(), Boundary(), 0, false);
+            Position(), Boundary(), Boundary(), 1, false);
 
     Position pos(13.5326994, 52.428098100000007);
     gch.x2cartesian(pos);
     
-	EXPECT_FLOAT_EQ(400235.50494557252, pos.x());
-	EXPECT_FLOAT_EQ(5809666.826070101, pos.y());
+	EXPECT_DOUBLE_EQ(400235.50494557252, pos.x());
+	EXPECT_DOUBLE_EQ(5809666.826070101, pos.y());
 }
